(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2780311,     155204]*)
(*NotebookOutlinePosition[   2781038,     155229]*)
(*  CellTagsIndexPosition[   2780994,     155225]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Analytical-Equation Derivation of the Photon Electric and \
Magnetic Fields",
    FontSize->24],
  "\n",
  StyleBox["\[Copyright]  2005 Blacklight Power Inc",
    FontSize->12]
}], "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "This is a computational notebook to Appendix VI of R. Mills, ",
  StyleBox["The Grand Unified Theory of Classical Quantum Mechanics",
    FontSlant->"Italic"],
  ", January 2005 Edition, posted at: \
http://www.blacklightpower.com/bookdownload.shtml. ",
  "This notebook has all needed equations. Equation numbers here correspond \
to the book, but some equations from the book have been omitted."
}], "Text",
  TextJustification->1],

Cell["We will require the packages:", "Text"],

Cell[BoxData[{
    \(<< Graphics`ParametricPlot3D`\), "\[IndentingNewLine]", 
    \(<< Graphics`Graphics3D`\), "\[IndentingNewLine]", 
    \(<< Graphics`Colors`\), "\[IndentingNewLine]", 
    \(<< Graphics`Shapes`\)}], "Input"],

Cell["We will use the axis rotation matrices:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(zrot[angle_]\), ":=", 
        RowBox[{"(", GridBox[{
              {\(Cos[angle]\), \(Sin[angle]\), "0"},
              {\(-Sin[angle]\), \(Cos[angle]\), "0"},
              {"0", "0", "1"}
              }], ")"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Component Function", "Section",
  TextJustification->1],

Cell["\<\
The function ComponentFunct below will be used repeatedly to generate the \
figures. Input variables include the rotation matrix to be used (RotMatrix) \
the coordinates of the initial loop (FirstLoop), and the color of the loops \
in the series (LoopColor).\
\>", "Text",
  TextJustification->1],

Cell[BoxData[
    \(ComponentFunct[RotMatrix_, FirstLoop_, 
        LoopColor_] := \[IndentingNewLine]\((Steps := 
          15; \[IndentingNewLine]R := 1; \[IndentingNewLine]d\[Theta] := 
          N[\[Pi]\/\(Steps*2\)]; \[IndentingNewLine]Clear[\[Theta], loop, p, 
          LoopCoords]; \[IndentingNewLine]Array[
          LoopCoords, {Steps, 2}]; \[IndentingNewLine]LoopCoords[1, 1] = 
          FirstLoop; \[IndentingNewLine]Array[
          loop, {Steps, 2, 3}]; \[IndentingNewLine]Array[
          p, {Steps}]; \[IndentingNewLine]Do[
          Do[LoopCoords[a, b] := {{0}, {0}, {0}}, {b, 2}], {a, 2, 
            Steps}]; \[IndentingNewLine]Do[
          Do[Do[loop[d, f, g] := 0, {g, 3}], {f, 2}] loop[1, 1, 1], {d, 1, 
            Steps}]; \[IndentingNewLine]\[IndentingNewLine]\[Theta] := 
          0; \[IndentingNewLine]{loop[1, 1, 1], loop[1, 1, 2], 
            loop[1, 1, 3]} := 
          Evaluate[
            ReleaseHold[
              RotMatrix . 
                LoopCoords[1, 1]]]; \[IndentingNewLine]\[IndentingNewLine]p[
            1] = ParametricPlot3D[\[IndentingNewLine]{loop[1, 1, 1], 
              loop[1, 1, 2], loop[1, 1, 3], 
              Evaluate[ReleaseHold[LoopColor]]}, {\[Phi], 0, 
              2  \[Pi]}, \[IndentingNewLine]Boxed \[Rule] 
              False, \ \[IndentingNewLine]AspectRatio \[Rule] Automatic, 
            SphericalRegion \[Rule] True, Axes \[Rule] False, 
            PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 1}, {\(-1\), 
                  1}}]; \[IndentingNewLine]\[IndentingNewLine]Do[\ \
\[IndentingNewLine]\[Theta] := 
            d\[Theta]*\((i - 1)\); \[IndentingNewLine]LoopCoords[i, 1] := 
            Evaluate[
              ReleaseHold[
                RotMatrix . LoopCoords[1, 1]]]; \[IndentingNewLine]{loop[i, 
                1, 1], loop[i, 1, 2], loop[i, 1, 3]} := 
            Evaluate[
              ReleaseHold[
                LoopCoords[i, 1]]]; \[IndentingNewLine]\[IndentingNewLine]p[
              i] = ParametricPlot3D[\[IndentingNewLine]{loop[i, 1, 1], 
                loop[i, 1, 2], loop[i, 1, 3], LoopColor}, {\[Phi], 0, 
                2  \[Pi]}, \[IndentingNewLine]Boxed \[Rule] 
                False, \ \[IndentingNewLine]Axes \[Rule] 
                False, \[IndentingNewLine]AspectRatio \[Rule] Automatic, 
              SphericalRegion \[Rule] 
                True], \[IndentingNewLine]\[IndentingNewLine]{i, 2, 
            Steps}];)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Analytical Equations to Generate the Right-Handed Circularly Polarized \
Photon Electric and Magnetic Vector Field by Rotation of the Great-Circle \
Basis Elements about the (",
  Cell[BoxData[
      \(TraditionalForm\`i\_x\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`i\_y\)]],
  ",0",
  Cell[BoxData[
      \(TraditionalForm\`i\_z\)]],
  ")-Axis by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]],
  "."
}], "Section",
  TextJustification->1],

Cell[TextData[{
  StyleBox["The right-handed circularly polarized (RHCP) photon electric and \
magnetic vector field (photon-e&mvf) is also generated following a similar \
procedure as that used to generate the orbitsphere in Appendix III: \
Analytical Equations to Generate the Orbitsphere Current-Vector Field and the \
Uniform Current (Charge)-Density Function ",
    FontFamily->"New York"],
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_0\^0\)(\[Phi], \[Theta])\)]],
  StyleBox[". The RHCP photon-e&mvf is generated by the rotation of the basis \
elements comprising the great circle magnetic field line in the xz-plane and \
the great circle electric field line in the yz-plane about the ",
    FontFamily->"New York"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`i\_x\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`i\_y\)]],
  ",0",
  Cell[BoxData[
      \(TraditionalForm\`i\_z\)]],
  ")-axis",
  StyleBox[" by ",
    FontFamily->"New York"],
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]],
  StyleBox[". A first transformation matrix is generated by the combined \
rotation of the great circles about the z-axis by ",
    FontFamily->"New York"],
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/4\)]],
  StyleBox[" then about the x-axis by ",
    FontFamily->"New York"],
  "\[Theta]",
  StyleBox[" where positive rotations about an axis are defined as \
clockwise:",
    FontFamily->"New York"]
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{\(Clear[\[Theta]];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Equ1", ":=", 
        RowBox[{"(", GridBox[{
              {\(Cos[\[Pi]\/4]\), \(Sin[\[Pi]\/4]\), "0"},
              {\(\(-Sin[\[Pi]\/4]\) Cos[\[Theta]]\), \(Cos[\[Pi]\/4] 
                  Cos[\[Theta]]\), \(Sin[\[Theta]]\)},
              {\(Sin[\[Pi]\/4] Sin[\[Theta]]\), \(\(-Cos[\[Pi]\/4]\) 
                  Sin[\[Theta]]\), \(Cos[\[Theta]]\)}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(ComponentFunct[
        Equ1, {R\ \ Cos[\[Phi]], 0, R\ \ Sin[\[Phi]]}, Blue];\)}], "Input",
  TextJustification->1],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.4459 .48391 m
.44977 .46359 L
s
.44238 .50432 m
.4459 .48391 L
s
.43922 .52473 m
.44238 .50432 L
s
.44977 .46359 m
.45395 .44345 L
s
.43644 .54504 m
.43922 .52473 L
s
.45395 .44345 m
.45845 .42359 L
s
.43404 .56516 m
.43644 .54504 L
s
.45845 .42359 m
.46324 .40409 L
s
.43205 .58501 m
.43404 .56516 L
s
.46324 .40409 m
.4683 .38506 L
s
.43047 .60448 m
.43205 .58501 L
s
.4683 .38506 m
.47361 .36658 L
s
.42933 .62347 m
.43047 .60448 L
s
.47361 .36658 m
.47915 .34875 L
s
.42863 .64189 m
.42933 .62347 L
s
.47915 .34875 m
.4849 .33168 L
s
.42838 .65963 m
.42863 .64189 L
s
.4849 .33168 m
.49083 .31547 L
s
.42861 .67659 m
.42838 .65963 L
s
.49083 .31547 m
.49691 .30022 L
s
.4293 .69266 m
.42861 .67659 L
s
.49691 .30022 m
.50312 .28603 L
s
.43048 .70773 m
.4293 .69266 L
s
.50312 .28603 m
.50942 .27301 L
s
.43216 .72168 m
.43048 .70773 L
s
.50942 .27301 m
.51579 .26128 L
s
.43433 .73441 m
.43216 .72168 L
s
.51579 .26128 m
.52218 .25094 L
s
.437 .74579 m
.43433 .73441 L
s
.52218 .25094 m
.52855 .2421 L
s
.44016 .75572 m
.437 .74579 L
s
.52855 .2421 m
.53488 .23486 L
s
.44383 .76407 m
.44016 .75572 L
s
.53488 .23486 m
.5411 .22934 L
s
.44798 .77074 m
.44383 .76407 L
s
.5411 .22934 m
.54718 .22563 L
s
.4526 .77562 m
.44798 .77074 L
s
.54718 .22563 m
.55307 .22383 L
s
.45769 .7786 m
.4526 .77562 L
s
.55307 .22383 m
.55871 .22402 L
s
.46322 .7796 m
.45769 .7786 L
s
.55871 .22402 m
.56405 .22627 L
s
.46916 .77852 m
.46322 .7796 L
s
.56405 .22627 m
.56905 .23064 L
s
.47549 .77531 m
.46916 .77852 L
s
.56905 .23064 m
.57363 .23718 L
s
.48215 .7699 m
.47549 .77531 L
s
.57363 .23718 m
.57776 .2459 L
s
.48911 .76227 m
.48215 .7699 L
s
.57776 .2459 m
.58138 .25682 L
s
.49632 .75241 m
.48911 .76227 L
s
.58138 .25682 m
.58444 .2699 L
s
.50372 .74032 m
.49632 .75241 L
s
.58444 .2699 m
.58688 .2851 L
s
.51124 .72606 m
.50372 .74032 L
s
.58688 .2851 m
.58868 .30234 L
s
.51881 .70969 m
.51124 .72606 L
s
.58868 .30234 m
.58978 .32151 L
s
.52637 .69131 m
.51881 .70969 L
s
.58978 .32151 m
.59017 .34246 L
s
.53383 .67107 m
.52637 .69131 L
s
.59017 .34246 m
.58982 .36502 L
s
.54112 .64912 m
.53383 .67107 L
s
.58982 .36502 m
.58872 .38901 L
s
.54816 .62566 m
.54112 .64912 L
s
.58872 .38901 m
.58687 .41418 L
s
.55487 .60091 m
.54816 .62566 L
s
.58687 .41418 m
.58427 .44029 L
s
.56117 .57512 m
.55487 .60091 L
s
.58427 .44029 m
.58095 .46707 L
s
.56699 .54855 m
.56117 .57512 L
s
.58095 .46707 m
.57693 .49423 L
s
.57226 .52149 m
.56699 .54855 L
s
.57693 .49423 m
.57226 .52149 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol009eoo`D07gioo`00Vgoo0P0O1Goo00<07gooOol0Ngoo
002JOol00`0OOomoo`06Ool00`0OOomoo`1jOol009Uoo`0301moogoo00Moo`0301moogoo07Yoo`00
V7oo00<07gooOol02Goo00<07gooOol0NGoo002GOol00`0OOomoo`0:Ool00`0OOomoo`1iOol009Io
o`0301moogoo00aoo`0301moogoo07Qoo`00UWoo00<07gooOol037oo00<07gooOol0N7oo002EOol0
0`0OOomoo`0>Ool00`0OOomoo`1gOol009Aoo`0301moogoo00moo`0301moogoo07Moo`00U7oo00<0
7gooOol03goo00<07gooOol0Mgoo002COol00`0OOomoo`0@Ool00`0OOomoo`1gOol009=oo`0301mo
ogoo015oo`0301moogoo07Ioo`00TWoo00<07gooOol04Woo00<07gooOol0MWoo002BOol00`0OOomo
o`0BOol00`0OOomoo`1fOol0095oo`0301moogoo01=oo`0301moogoo07Ioo`00TGoo00<07gooOol0
57oo00<07gooOol0MGoo002@Ool00`0OOomoo`0EOol00`0OOomoo`1eOol0091oo`0301moogoo01Eo
o`0301moogoo07Eoo`00Sgoo00<07gooOol05Woo00<07gooOol0MGoo002?Ool00`0OOomoo`0FOol0
0`0OOomoo`1eOol008ioo`0301moogoo01Moo`0301moogoo07Eoo`00SWoo00<07gooOol05goo00<0
7gooOol0MGoo002=Ool00`0OOomoo`0HOol00`0OOomoo`1eOol008eoo`0301moogoo01Qoo`0301mo
ogoo07Eoo`00S7oo00<07gooOol06Goo00<07gooOol0MGoo002<Ool00`0OOomoo`0JOol00`0OOomo
o`1dOol008aoo`0301moogoo01Yoo`0301moogoo07Aoo`00S7oo00<07gooOol06Woo00<07gooOol0
M7oo002;Ool00`0OOomoo`0KOol00`0OOomoo`1dOol008]oo`0301moogoo01]oo`0301moogoo07Ao
o`00Rgoo00<07gooOol06goo00<07gooOol0M7oo002;Ool00`0OOomoo`0KOol00`0OOomoo`1dOol0
08Yoo`0301moogoo01aoo`0301moogoo07Aoo`00RWoo00<07gooOol077oo00<07gooOol0M7oo0029
Ool00`0OOomoo`0MOol00`0OOomoo`1dOol008Uoo`0301moogoo01eoo`0301moogoo07Aoo`00RGoo
00<07gooOol07Goo00<07gooOol0M7oo0028Ool00`0OOomoo`0NOol00`0OOomoo`1dOol008Qoo`03
01moogoo01ioo`0301moogoo07Aoo`00Qgoo00<07gooOol07goo00<07gooOol0M7oo0027Ool00`0O
Oomoo`0OOol00`0OOomoo`1dOol008Moo`0301moogoo01moo`0301moogoo07Aoo`00Qgoo00<07goo
Ool07goo00<07gooOol0M7oo0026Ool00`0OOomoo`0OOol00`0OOomoo`1eOol008Ioo`0301moogoo
01moo`0301moogoo07Eoo`00QWoo00<07gooOol07goo00<07gooOol0MGoo0026Ool00`0OOomoo`0O
Ool00`0OOomoo`1eOol008Eoo`0301moogoo021oo`0301moogoo07Eoo`00QGoo00<07gooOol087oo
00<07gooOol0MGoo0024Ool00`0OOomoo`0QOol00`0OOomoo`1eOol008Aoo`0301moogoo025oo`03
01moogoo07Eoo`00Q7oo00<07gooOol08Goo00<07gooOol0MGoo0024Ool00`0OOomoo`0QOol00`0O
Oomoo`1eOol008=oo`0301moogoo029oo`0301moogoo07Eoo`00Pgoo00<07gooOol08Woo00<07goo
Ool0MGoo0023Ool00`0OOomoo`0ROol00`0OOomoo`1eOol008=oo`0301moogoo029oo`0301moogoo
07Eoo`00Pgoo00<07gooOol08Goo00<07gooOol0MWoo0023Ool00`0OOomoo`0QOol00`0OOomoo`1f
Ool0089oo`0301moogoo029oo`0301moogoo07Ioo`00PWoo00<07gooOol08Woo00<07gooOol0MWoo
0022Ool00`0OOomoo`0ROol00`0OOomoo`1fOol0089oo`0301moogoo029oo`0301moogoo07Ioo`00
PWoo00<07gooOol08Woo00<07gooOol0MWoo0022Ool00`0OOomoo`0ROol00`0OOomoo`1fOol0085o
o`0301moogoo029oo`0301moogoo07Moo`00PGoo00<07gooOol08Woo00<07gooOol0Mgoo0021Ool0
0`0OOomoo`0ROol00`0OOomoo`1gOol0085oo`0301moogoo029oo`0301moogoo07Moo`00PGoo00<0
7gooOol08Woo00<07gooOol0Mgoo0020Ool00`0OOomoo`0SOol00`0OOomoo`1gOol0081oo`0301mo
ogoo02=oo`0301moogoo07Moo`00Ogoo00<07gooOol097oo00<07gooOol0Mgoo001oOol00`0OOomo
o`0SOol00`0OOomoo`1hOol007moo`0301moogoo02=oo`0301moogoo07Qoo`00Ogoo00<07gooOol0
8goo00<07gooOol0N7oo001nOol00`0OOomoo`0TOol00`0OOomoo`1hOol007ioo`0301moogoo02Ao
o`0301moogoo07Qoo`00OWoo00<07gooOol097oo00<07gooOol0N7oo001nOol00`0OOomoo`0TOol0
0`0OOomoo`1hOol007ioo`0301moogoo02=oo`0301moogoo07Uoo`00OWoo00<07gooOol08goo00<0
7gooOol0NGoo001nOol00`0OOomoo`0SOol00`0OOomoo`1iOol007ioo`0301moogoo02=oo`0301mo
ogoo07Uoo`00OWoo00<07gooOol08goo00<07gooOol0NGoo001nOol00`0OOomoo`0SOol00`0OOomo
o`1iOol007ioo`0301moogoo029oo`0301moogoo07Yoo`00OWoo00<07gooOol08Woo00<07gooOol0
NWoo001mOol00`0OOomoo`0SOol00`0OOomoo`1jOol007eoo`0301moogoo02=oo`0301moogoo07Yo
o`00OGoo00<07gooOol08Woo00<07gooOol0Ngoo001mOol00`0OOomoo`0ROol00`0OOomoo`1kOol0
07eoo`0301moogoo029oo`0301moogoo07]oo`00OGoo00<07gooOol08Woo00<07gooOol0Ngoo001l
Ool00`0OOomoo`0SOol00`0OOomoo`1kOol007aoo`0301moogoo02=oo`0301moogoo07]oo`00O7oo
00<07gooOol08Woo00<07gooOol0O7oo001lOol00`0OOomoo`0ROol00`0OOomoo`1lOol007aoo`03
01moogoo029oo`0301moogoo07aoo`00O7oo00<07gooOol08Woo00<07gooOol0O7oo001lOol00`0O
Oomoo`0ROol00`0OOomoo`1lOol007aoo`0301moogoo029oo`0301moogoo07aoo`00O7oo00<07goo
Ool08Goo00<07gooOol0OGoo001lOol00`0OOomoo`0QOol00`0OOomoo`1mOol007aoo`0301moogoo
025oo`0301moogoo07eoo`00Ngoo00<07gooOol08Woo00<07gooOol0OGoo001kOol00`0OOomoo`0Q
Ool00`0OOomoo`1nOol007]oo`0301moogoo025oo`0301moogoo07ioo`00Ngoo00<07gooOol08Goo
00<07gooOol0OWoo001kOol00`0OOomoo`0POol00`0OOomoo`1oOol007]oo`0301moogoo021oo`03
01moogoo07moo`00Ngoo00<07gooOol087oo00<07gooOol0Ogoo001kOol00`0OOomoo`0POol00`0O
Oomoo`1oOol007]oo`0301moogoo01moo`0301moogoo081oo`00Ngoo00<07gooOol07goo00<07goo
Ool0P7oo001kOol00`0OOomoo`0OOol00`0OOomoo`20Ool007]oo`0301moogoo01ioo`0301moogoo
085oo`00Ngoo00<07gooOol07Woo00<07gooOol0PGoo001kOol00`0OOomoo`0NOol00`0OOomoo`21
Ool007]oo`0301moogoo01ioo`0301moogoo085oo`00Ngoo00<07gooOol07Goo00<07gooOol0PWoo
001kOol00`0OOomoo`0MOol00`0OOomoo`22Ool007Yoo`0301moogoo01ioo`0301moogoo089oo`00
NWoo00<07gooOol07Goo00<07gooOol0Pgoo001jOol00`0OOomoo`0MOol00`0OOomoo`23Ool007Yo
o`0301moogoo01eoo`0301moogoo08=oo`00NWoo00<07gooOol077oo00<07gooOol0Q7oo001kOol0
0`0OOomoo`0KOol00`0OOomoo`24Ool007]oo`0301moogoo01]oo`0301moogoo08Aoo`00Ngoo00<0
7gooOol06Woo00<07gooOol0QGoo001kOol00`0OOomoo`0JOol00`0OOomoo`25Ool007]oo`0301mo
ogoo01Yoo`0301moogoo08Eoo`00Ngoo00<07gooOol06Goo00<07gooOol0QWoo001kOol00`0OOomo
o`0IOol00`0OOomoo`26Ool007]oo`0301moogoo01Qoo`0301moogoo08Moo`00Ngoo00<07gooOol0
67oo00<07gooOol0Qgoo001kOol00`0OOomoo`0GOol00`0OOomoo`28Ool007]oo`0301moogoo01Mo
o`0301moogoo08Qoo`00Ngoo00<07gooOol05Woo00<07gooOol0RGoo001kOol00`0OOomoo`0FOol0
0`0OOomoo`29Ool007]oo`0301moogoo01Eoo`0301moogoo08Yoo`00O7oo00<07gooOol057oo00<0
7gooOol0RWoo001lOol00`0OOomoo`0COol00`0OOomoo`2;Ool007aoo`0301moogoo01=oo`0301mo
ogoo08]oo`00O7oo00<07gooOol04Woo00<07gooOol0S7oo001lOol00`0OOomoo`0BOol00`0OOomo
o`2<Ool007aoo`0301moogoo015oo`0301moogoo08eoo`00O7oo00<07gooOol04Goo00<07gooOol0
SGoo001mOol00`0OOomoo`0?Ool00`0OOomoo`2>Ool007eoo`0301moogoo00moo`0301moogoo08io
o`00OGoo00<07gooOol03Woo00<07gooOol0Sgoo001nOol00`0OOomoo`0<Ool00`0OOomoo`2@Ool0
07ioo`0301moogoo00aoo`0301moogoo091oo`00Ogoo00<07gooOol02Woo00<07gooOol0TGoo001o
Ool00`0OOomoo`09Ool00`0OOomoo`2BOol007moo`0301moogoo00Qoo`0301moogoo09=oo`00P7oo
00<07gooOol01Woo00<07gooOol0U7oo0021Ool00`0OOomoo`04Ool00`0OOomoo`2EOol0089oo`H0
7iQoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.42301 .48222 m
.42617 .45785 L
s
.42035 .50669 m
.42301 .48222 L
s
.41818 .53114 m
.42035 .50669 L
s
.42617 .45785 m
.42981 .43369 L
s
.41654 .55546 m
.41818 .53114 L
s
.42981 .43369 m
.4339 .40986 L
s
.41541 .57954 m
.41654 .55546 L
s
.4339 .40986 m
.43844 .38646 L
s
.41482 .60326 m
.41541 .57954 L
s
.43844 .38646 m
.44342 .36362 L
s
.41477 .6265 m
.41482 .60326 L
s
.44342 .36362 m
.4488 .34145 L
s
.41528 .64915 m
.41477 .6265 L
s
.4488 .34145 m
.45457 .32007 L
s
.41634 .67107 m
.41528 .64915 L
s
.45457 .32007 m
.46071 .29961 L
s
.41796 .69216 m
.41634 .67107 L
s
.46071 .29961 m
.46719 .28018 L
s
.42014 .71227 m
.41796 .69216 L
s
.46719 .28018 m
.47399 .26192 L
s
.42289 .73129 m
.42014 .71227 L
s
.47399 .26192 m
.48107 .24494 L
s
.4262 .74908 m
.42289 .73129 L
s
.48107 .24494 m
.48841 .22939 L
s
.43007 .7655 m
.4262 .74908 L
s
.48841 .22939 m
.49597 .21539 L
s
.4345 .78042 m
.43007 .7655 L
s
.49597 .21539 m
.5037 .20306 L
s
.43946 .79371 m
.4345 .78042 L
s
.5037 .20306 m
.51157 .19255 L
s
.44495 .80523 m
.43946 .79371 L
s
.51157 .19255 m
.51953 .18397 L
s
.45096 .81485 m
.44495 .80523 L
s
.51953 .18397 m
.52753 .17744 L
s
.45744 .82245 m
.45096 .81485 L
s
.52753 .17744 m
.53551 .17309 L
s
.46438 .82789 m
.45744 .82245 L
s
.53551 .17309 m
.54342 .17101 L
s
.47175 .83106 m
.46438 .82789 L
s
.54342 .17101 m
.5512 .17131 L
s
.47949 .83186 m
.47175 .83106 L
s
.5512 .17131 m
.55878 .17406 L
s
.48757 .83021 m
.47949 .83186 L
s
.55878 .17406 m
.56609 .17934 L
s
.49594 .82601 m
.48757 .83021 L
s
.56609 .17934 m
.57307 .18718 L
s
.50452 .81923 m
.49594 .82601 L
s
.57307 .18718 m
.57964 .1976 L
s
.51327 .80984 m
.50452 .81923 L
s
.57964 .1976 m
.58574 .21061 L
s
.5221 .79781 m
.51327 .80984 L
s
.58574 .21061 m
.59129 .22617 L
s
.53094 .78319 m
.5221 .79781 L
s
.59129 .22617 m
.59623 .24422 L
s
.53971 .76603 m
.53094 .78319 L
s
.59623 .24422 m
.60048 .26465 L
s
.54831 .74642 m
.53971 .76603 L
s
.60048 .26465 m
.604 .28734 L
s
.55668 .72448 m
.54831 .74642 L
s
.604 .28734 m
.60673 .31211 L
s
.56471 .70037 m
.55668 .72448 L
s
.60673 .31211 m
.60862 .33878 L
s
.57231 .67429 m
.56471 .70037 L
s
.60862 .33878 m
.60964 .36709 L
s
.57941 .64647 m
.57231 .67429 L
s
.60964 .36709 m
.60976 .39679 L
s
.58592 .61717 m
.57941 .64647 L
s
.60976 .39679 m
.60897 .42759 L
s
.59176 .58668 m
.58592 .61717 L
s
.60897 .42759 m
.60727 .45917 L
s
.59687 .5553 m
.59176 .58668 L
s
.60727 .45917 m
.60467 .49121 L
s
.60119 .52337 m
.59687 .5553 L
s
.60467 .49121 m
.60119 .52337 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol009Uoo`P07gmoo`00Ugoo0P0O27oo00<07gooOol0O7oo
002FOol00`0OOomoo`09Ool00`0OOomoo`1kOol009Eoo`0301moogoo00]oo`0301moogoo07Yoo`00
U7oo00<07gooOol03Goo00<07gooOol0NGoo002COol00`0OOomoo`0?Ool00`0OOomoo`1hOol0099o
o`0301moogoo011oo`0301moogoo07Qoo`00TGoo00<07gooOol04Woo00<07gooOol0Mgoo002AOol0
0`0OOomoo`0BOol00`0OOomoo`1gOol0091oo`0301moogoo01Aoo`0301moogoo07Ioo`00Sgoo00<0
7gooOol05Goo00<07gooOol0MWoo002?Ool00`0OOomoo`0FOol00`0OOomoo`1eOol008ioo`0301mo
ogoo01Moo`0301moogoo07Eoo`00SGoo00<07gooOol067oo00<07gooOol0MGoo002=Ool00`0OOomo
o`0IOol00`0OOomoo`1dOol008aoo`0301moogoo01Yoo`0301moogoo07Aoo`00S7oo00<07gooOol0
6Woo00<07gooOol0M7oo002<Ool00`0OOomoo`0KOol00`0OOomoo`1cOol008]oo`0301moogoo01ao
o`0301moogoo07=oo`00Rgoo00<07gooOol077oo00<07gooOol0Lgoo002:Ool00`0OOomoo`0NOol0
0`0OOomoo`1bOol008Yoo`0301moogoo01ioo`0301moogoo079oo`00RWoo00<07gooOol07Woo00<0
7gooOol0LWoo0029Ool00`0OOomoo`0OOol00`0OOomoo`1bOol008Uoo`0301moogoo021oo`0301mo
ogoo075oo`00R7oo00<07gooOol08Goo00<07gooOol0LGoo0028Ool00`0OOomoo`0QOol00`0OOomo
o`1aOol008Qoo`0301moogoo025oo`0301moogoo075oo`00Qgoo00<07gooOol08Woo00<07gooOol0
LGoo0027Ool00`0OOomoo`0ROol00`0OOomoo`1aOol008Ioo`0301moogoo02Aoo`0301moogoo071o
o`00QWoo00<07gooOol097oo00<07gooOol0L7oo0026Ool00`0OOomoo`0TOol00`0OOomoo`1`Ool0
08Eoo`0301moogoo02Eoo`0301moogoo071oo`00QGoo00<07gooOol09Goo00<07gooOol0L7oo0024
Ool00`0OOomoo`0VOol00`0OOomoo`1`Ool008Aoo`0301moogoo02Ioo`0301moogoo071oo`00Q7oo
00<07gooOol09goo00<07gooOol0Kgoo0023Ool00`0OOomoo`0XOol00`0OOomoo`1_Ool008=oo`03
01moogoo02Qoo`0301moogoo06moo`00Pgoo00<07gooOol0:7oo00<07gooOol0Kgoo0022Ool00`0O
Oomoo`0YOol00`0OOomoo`1_Ool0089oo`0301moogoo02Uoo`0301moogoo06moo`00PWoo00<07goo
Ool0:Goo00<07gooOol0Kgoo0021Ool00`0OOomoo`0ZOol00`0OOomoo`1_Ool0085oo`0301moogoo
02Yoo`0301moogoo06moo`00PGoo00<07gooOol0:Woo00<07gooOol0Kgoo0020Ool00`0OOomoo`0[
Ool00`0OOomoo`1_Ool0081oo`0301moogoo02]oo`0301moogoo06moo`00P7oo00<07gooOol0:goo
00<07gooOol0Kgoo0020Ool00`0OOomoo`0[Ool00`0OOomoo`1_Ool0081oo`0301moogoo02]oo`03
01moogoo06moo`00Ogoo00<07gooOol0;7oo00<07gooOol0Kgoo001oOol00`0OOomoo`0/Ool00`0O
Oomoo`1_Ool007moo`0301moogoo02aoo`0301moogoo06moo`00Ogoo00<07gooOol0;7oo00<07goo
Ool0Kgoo001oOol00`0OOomoo`0/Ool00`0OOomoo`1_Ool007ioo`0301moogoo02eoo`0301moogoo
06moo`00OWoo00<07gooOol0;Goo00<07gooOol0Kgoo001nOol00`0OOomoo`0]Ool00`0OOomoo`1_
Ool007eoo`0301moogoo02ioo`0301moogoo06moo`00OGoo00<07gooOol0;goo00<07gooOol0KWoo
001mOol00`0OOomoo`0_Ool00`0OOomoo`1^Ool007eoo`0301moogoo02moo`0301moogoo06ioo`00
OGoo00<07gooOol0;goo00<07gooOol0KWoo001lOol00`0OOomoo`0`Ool00`0OOomoo`1^Ool007ao
o`0301moogoo031oo`0301moogoo06ioo`00O7oo00<07gooOol0<7oo00<07gooOol0KWoo001lOol0
0`0OOomoo`0`Ool00`0OOomoo`1^Ool007aoo`0301moogoo02moo`0301moogoo06moo`00O7oo00<0
7gooOol0;goo00<07gooOol0Kgoo001lOol00`0OOomoo`0_Ool00`0OOomoo`1_Ool007]oo`0301mo
ogoo031oo`0301moogoo06moo`00Ngoo00<07gooOol0<7oo00<07gooOol0Kgoo001kOol00`0OOomo
o`0`Ool00`0OOomoo`1_Ool007]oo`0301moogoo031oo`0301moogoo06moo`00Ngoo00<07gooOol0
<7oo00<07gooOol0Kgoo001kOol00`0OOomoo`0`Ool00`0OOomoo`1_Ool007]oo`0301moogoo031o
o`0301moogoo06moo`00NWoo00<07gooOol0<Goo00<07gooOol0Kgoo001jOol00`0OOomoo`0aOol0
0`0OOomoo`1_Ool007Yoo`0301moogoo035oo`0301moogoo06moo`00NWoo00<07gooOol0<Goo00<0
7gooOol0Kgoo001jOol00`0OOomoo`0aOol00`0OOomoo`1_Ool007Yoo`0301moogoo035oo`0301mo
ogoo06moo`00NWoo00<07gooOol0<Goo00<07gooOol0Kgoo001iOol00`0OOomoo`0bOol00`0OOomo
o`1_Ool007Uoo`0301moogoo035oo`0301moogoo071oo`00NGoo00<07gooOol0<Goo00<07gooOol0
L7oo001iOol00`0OOomoo`0aOol00`0OOomoo`1`Ool007Uoo`0301moogoo035oo`0301moogoo071o
o`00NGoo00<07gooOol0<Goo00<07gooOol0L7oo001iOol00`0OOomoo`0aOol00`0OOomoo`1`Ool0
07Qoo`0301moogoo039oo`0301moogoo071oo`00N7oo00<07gooOol0<Woo00<07gooOol0L7oo001h
Ool00`0OOomoo`0bOol00`0OOomoo`1`Ool007Qoo`0301moogoo035oo`0301moogoo075oo`00N7oo
00<07gooOol0<Goo00<07gooOol0LGoo001hOol00`0OOomoo`0aOol00`0OOomoo`1aOol007Qoo`03
01moogoo035oo`0301moogoo075oo`00N7oo00<07gooOol0<Goo00<07gooOol0LGoo001hOol00`0O
Oomoo`0aOol00`0OOomoo`1aOol007Qoo`0301moogoo035oo`0301moogoo075oo`00N7oo00<07goo
Ool0<Goo00<07gooOol0LGoo001hOol00`0OOomoo`0aOol00`0OOomoo`1aOol007Qoo`0301moogoo
035oo`0301moogoo075oo`00N7oo00<07gooOol0<7oo00<07gooOol0LWoo001gOol00`0OOomoo`0a
Ool00`0OOomoo`1bOol007Moo`0301moogoo035oo`0301moogoo079oo`00Mgoo00<07gooOol0<Goo
00<07gooOol0LWoo001gOol00`0OOomoo`0aOol00`0OOomoo`1bOol007Moo`0301moogoo035oo`03
01moogoo079oo`00Mgoo00<07gooOol0<Goo00<07gooOol0LWoo001gOol00`0OOomoo`0`Ool00`0O
Oomoo`1cOol007Moo`0301moogoo031oo`0301moogoo07=oo`00Mgoo00<07gooOol0<7oo00<07goo
Ool0Lgoo001gOol00`0OOomoo`0`Ool00`0OOomoo`1cOol007Moo`0301moogoo02moo`0301moogoo
07Aoo`00Mgoo00<07gooOol0;goo00<07gooOol0M7oo001gOol00`0OOomoo`0_Ool00`0OOomoo`1d
Ool007Moo`0301moogoo02moo`0301moogoo07Aoo`00Mgoo00<07gooOol0;goo00<07gooOol0M7oo
001gOol00`0OOomoo`0_Ool00`0OOomoo`1dOol007Moo`0301moogoo02moo`0301moogoo07Aoo`00
Mgoo00<07gooOol0;Woo00<07gooOol0MGoo001gOol00`0OOomoo`0^Ool00`0OOomoo`1eOol007Mo
o`0301moogoo02ioo`0301moogoo07Eoo`00Mgoo00<07gooOol0;Woo00<07gooOol0MGoo001gOol0
0`0OOomoo`0^Ool00`0OOomoo`1eOol007Moo`0301moogoo02ioo`0301moogoo07Eoo`00Mgoo00<0
7gooOol0;Goo00<07gooOol0MWoo001gOol00`0OOomoo`0]Ool00`0OOomoo`1fOol007Moo`0301mo
ogoo02eoo`0301moogoo07Ioo`00Mgoo00<07gooOol0;Goo00<07gooOol0MWoo001gOol00`0OOomo
o`0/Ool00`0OOomoo`1gOol007Moo`0301moogoo02aoo`0301moogoo07Moo`00Mgoo00<07gooOol0
;7oo00<07gooOol0Mgoo001gOol00`0OOomoo`0/Ool00`0OOomoo`1gOol007Moo`0301moogoo02]o
o`0301moogoo07Qoo`00Mgoo00<07gooOol0:goo00<07gooOol0N7oo001gOol00`0OOomoo`0[Ool0
0`0OOomoo`1hOol007Moo`0301moogoo02]oo`0301moogoo07Qoo`00Mgoo00<07gooOol0:Woo00<0
7gooOol0NGoo001gOol00`0OOomoo`0ZOol00`0OOomoo`1iOol007Moo`0301moogoo02Yoo`0301mo
ogoo07Uoo`00Mgoo00<07gooOol0:Woo00<07gooOol0NGoo001gOol00`0OOomoo`0YOol00`0OOomo
o`1jOol007Moo`0301moogoo02Uoo`0301moogoo07Yoo`00Mgoo00<07gooOol0:Goo00<07gooOol0
NWoo001gOol00`0OOomoo`0YOol00`0OOomoo`1jOol007Moo`0301moogoo02Qoo`0301moogoo07]o
o`00Mgoo00<07gooOol0:7oo00<07gooOol0Ngoo001gOol00`0OOomoo`0XOol00`0OOomoo`1kOol0
07Qoo`0301moogoo02Ioo`0301moogoo07aoo`00N7oo00<07gooOol09Woo00<07gooOol0O7oo001h
Ool00`0OOomoo`0UOol00`0OOomoo`1mOol007Qoo`0301moogoo02Eoo`0301moogoo07eoo`00N7oo
00<07gooOol097oo00<07gooOol0OWoo001iOol00`0OOomoo`0SOol00`0OOomoo`1nOol007Uoo`03
01moogoo02=oo`0301moogoo07ioo`00NGoo00<07gooOol08Woo00<07gooOol0Ogoo001iOol00`0O
Oomoo`0ROol00`0OOomoo`1oOol007Uoo`0301moogoo029oo`0301moogoo07moo`00NWoo00<07goo
Ool08Goo00<07gooOol0Ogoo001jOol00`0OOomoo`0POol00`0OOomoo`20Ool007Yoo`0301moogoo
021oo`0301moogoo081oo`00NWoo00<07gooOol07goo00<07gooOol0PGoo001jOol00`0OOomoo`0O
Ool00`0OOomoo`21Ool007]oo`0301moogoo01eoo`0301moogoo089oo`00Ngoo00<07gooOol07Goo
00<07gooOol0PWoo001kOol00`0OOomoo`0LOol00`0OOomoo`23Ool007]oo`0301moogoo01aoo`03
01moogoo08=oo`00Ngoo00<07gooOol06goo00<07gooOol0Q7oo001lOol00`0OOomoo`0JOol00`0O
Oomoo`24Ool007aoo`0301moogoo01Uoo`0301moogoo08Eoo`00O7oo00<07gooOol06Goo00<07goo
Ool0QGoo001mOol00`0OOomoo`0GOol00`0OOomoo`26Ool007eoo`0301moogoo01Ioo`0301moogoo
08Moo`00OWoo00<07gooOol05Goo00<07gooOol0Qgoo001nOol00`0OOomoo`0DOol00`0OOomoo`28
Ool007ioo`0301moogoo01=oo`0301moogoo08Uoo`00Ogoo00<07gooOol04Woo00<07gooOol0RGoo
001oOol00`0OOomoo`0AOol00`0OOomoo`2:Ool0081oo`0301moogoo011oo`0301moogoo08Yoo`00
PGoo00<07gooOol03Woo00<07gooOol0Rgoo0022Ool00`0OOomoo`0<Ool00`0OOomoo`2<Ool0089o
o`0301moogoo00]oo`0301moogoo08eoo`00Pgoo00<07gooOol02Goo00<07gooOol0SWoo0024Ool2
01l7Ool201nAOol008Ioo`L07i=oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.412 .48451 m
.41362 .46 L
s
.41093 .5091 m
.412 .48451 L
s
.41043 .53365 m
.41093 .5091 L
s
.41362 .46 m
.4158 .43568 L
s
.4105 .55806 m
.41043 .53365 L
s
.4158 .43568 m
.41852 .41167 L
s
.41114 .5822 m
.4105 .55806 L
s
.41852 .41167 m
.42179 .38808 L
s
.41235 .60596 m
.41114 .5822 L
s
.42179 .38808 m
.42558 .36503 L
s
.41414 .62922 m
.41235 .60596 L
s
.42558 .36503 m
.42988 .34264 L
s
.41649 .65186 m
.41414 .62922 L
s
.42988 .34264 m
.43469 .32103 L
s
.41942 .67376 m
.41649 .65186 L
s
.43469 .32103 m
.43998 .30032 L
s
.4229 .6948 m
.41942 .67376 L
s
.43998 .30032 m
.44575 .28064 L
s
.42695 .71485 m
.4229 .6948 L
s
.44575 .28064 m
.45196 .26212 L
s
.43154 .73378 m
.42695 .71485 L
s
.45196 .26212 m
.45859 .24489 L
s
.43667 .75146 m
.43154 .73378 L
s
.45859 .24489 m
.46563 .22907 L
s
.44232 .76775 m
.43667 .75146 L
s
.46563 .22907 m
.47303 .21479 L
s
.44846 .78253 m
.44232 .76775 L
s
.47303 .21479 m
.48076 .2022 L
s
.45509 .79566 m
.44846 .78253 L
s
.48076 .2022 m
.48879 .19142 L
s
.46217 .807 m
.45509 .79566 L
s
.48879 .19142 m
.49708 .18258 L
s
.46967 .81642 m
.46217 .807 L
s
.49708 .18258 m
.50557 .1758 L
s
.47755 .8238 m
.46967 .81642 L
s
.50557 .1758 m
.51421 .1712 L
s
.48578 .82902 m
.47755 .8238 L
s
.51421 .1712 m
.52296 .16889 L
s
.4943 .83195 m
.48578 .82902 L
s
.52296 .16889 m
.53173 .16896 L
s
.50306 .83251 m
.4943 .83195 L
s
.53173 .16896 m
.54048 .17151 L
s
.51201 .8306 m
.50306 .83251 L
s
.54048 .17151 m
.54913 .17659 L
s
.52107 .82615 m
.51201 .8306 L
s
.54913 .17659 m
.55759 .18426 L
s
.53018 .81911 m
.52107 .82615 L
s
.55759 .18426 m
.56581 .19453 L
s
.53926 .80945 m
.53018 .81911 L
s
.56581 .19453 m
.57369 .20741 L
s
.54823 .79716 m
.53926 .80945 L
s
.57369 .20741 m
.58116 .22286 L
s
.55701 .78228 m
.54823 .79716 L
s
.58116 .22286 m
.58812 .24082 L
s
.56551 .76486 m
.55701 .78228 L
s
.58812 .24082 m
.59451 .26119 L
s
.57364 .745 m
.56551 .76486 L
s
.59451 .26119 m
.60025 .28384 L
s
.58131 .72282 m
.57364 .745 L
s
.60025 .28384 m
.60525 .30859 L
s
.58844 .69848 m
.58131 .72282 L
s
.60525 .30859 m
.60947 .33526 L
s
.59494 .67218 m
.58844 .69848 L
s
.60947 .33526 m
.61283 .3636 L
s
.60073 .64415 m
.59494 .67218 L
s
.61283 .3636 m
.61529 .39336 L
s
.60575 .61465 m
.60073 .64415 L
s
.61529 .39336 m
.61681 .42423 L
s
.60993 .58397 m
.60575 .61465 L
s
.61681 .42423 m
.61737 .4559 L
s
.61321 .55243 m
.60993 .58397 L
s
.61737 .4559 m
.61695 .48805 L
s
.61556 .52034 m
.61321 .55243 L
s
.61695 .48805 m
.61556 .52034 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.40349 .51215 m
.40289 .48758 L
s
.40471 .53667 m
.40349 .51215 L
s
.40289 .48758 m
.4029 .46306 L
s
.40653 .561 m
.40471 .53667 L
s
.4029 .46306 m
.40353 .4387 L
s
.40896 .58505 m
.40653 .561 L
s
.40353 .4387 m
.40478 .41463 L
s
.41199 .6087 m
.40896 .58505 L
s
.40478 .41463 m
.40665 .39096 L
s
.4156 .63182 m
.41199 .6087 L
s
.40665 .39096 m
.40913 .3678 L
s
.41979 .65431 m
.4156 .63182 L
s
.40913 .3678 m
.41222 .34527 L
s
.42455 .67603 m
.41979 .65431 L
s
.41222 .34527 m
.41591 .3235 L
s
.42985 .69687 m
.42455 .67603 L
s
.41591 .3235 m
.42021 .30262 L
s
.4357 .7167 m
.42985 .69687 L
s
.42021 .30262 m
.42508 .28273 L
s
.44205 .73539 m
.4357 .7167 L
s
.42508 .28273 m
.43054 .26399 L
s
.4489 .75282 m
.44205 .73539 L
s
.43054 .26399 m
.43655 .24651 L
s
.45622 .76886 m
.4489 .75282 L
s
.43655 .24651 m
.44309 .23043 L
s
.46397 .78336 m
.45622 .76886 L
s
.44309 .23043 m
.45016 .21588 L
s
.47213 .7962 m
.46397 .78336 L
s
.45016 .21588 m
.4577 .203 L
s
.48065 .80725 m
.47213 .7962 L
s
.4577 .203 m
.46571 .19192 L
s
.48949 .81638 m
.48065 .80725 L
s
.46571 .19192 m
.47413 .18277 L
s
.49861 .82346 m
.48949 .81638 L
s
.47413 .18277 m
.48292 .17568 L
s
.50794 .82838 m
.49861 .82346 L
s
.48292 .17568 m
.49204 .17076 L
s
.51743 .83102 m
.50794 .82838 L
s
.49204 .17076 m
.50143 .16813 L
s
.52702 .83129 m
.51743 .83102 L
s
.50143 .16813 m
.51103 .16789 L
s
.53663 .82909 m
.52702 .83129 L
s
.51103 .16789 m
.52078 .17012 L
s
.54619 .82437 m
.53663 .82909 L
s
.52078 .17012 m
.53059 .1749 L
s
.55562 .81706 m
.54619 .82437 L
s
.53059 .1749 m
.5404 .18227 L
s
.56484 .80714 m
.55562 .81706 L
s
.5404 .18227 m
.55011 .19227 L
s
.57375 .79461 m
.56484 .80714 L
s
.55011 .19227 m
.55965 .20488 L
s
.58226 .7795 m
.57375 .79461 L
s
.55965 .20488 m
.56891 .22008 L
s
.5903 .76187 m
.58226 .7795 L
s
.56891 .22008 m
.5778 .23781 L
s
.59776 .74181 m
.5903 .76187 L
s
.5778 .23781 m
.58624 .25797 L
s
.60455 .71945 m
.59776 .74181 L
s
.58624 .25797 m
.59411 .28044 L
s
.61061 .69496 m
.60455 .71945 L
s
.59411 .28044 m
.60135 .30503 L
s
.61584 .66852 m
.61061 .69496 L
s
.60135 .30503 m
.60784 .33156 L
s
.62018 .64037 m
.61584 .66852 L
s
.60784 .33156 m
.61353 .35979 L
s
.62357 .61078 m
.62018 .64037 L
s
.61353 .35979 m
.61833 .38945 L
s
.62596 .58003 m
.62357 .61078 L
s
.61833 .38945 m
.62218 .42026 L
s
.62732 .54844 m
.62596 .58003 L
s
.62218 .42026 m
.62503 .45189 L
s
.62761 .51632 m
.62732 .54844 L
s
.62503 .45189 m
.62685 .48403 L
s
.62685 .48403 m
.62761 .51632 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo002?Ool701n:Ool008aoo`<07`Moo`807hQoo`00RWoo0P0O37oo00<0
7gooOol0QGoo0029Ool00`0OOomoo`0=Ool201n5Ool008Qoo`0301moogoo011oo`0301moogoo089o
o`00Qgoo00<07gooOol04Woo00<07gooOol0PGoo0026Ool00`0OOomoo`0COol00`0OOomoo`21Ool0
08Eoo`0301moogoo01Eoo`0301moogoo081oo`00Q7oo00<07gooOol05goo00<07gooOol0Ogoo0024
Ool00`0OOomoo`0HOol00`0OOomoo`1nOol008=oo`0301moogoo01Yoo`0301moogoo07eoo`00PWoo
00<07gooOol077oo00<07gooOol0O7oo0022Ool00`0OOomoo`0LOol00`0OOomoo`1lOol0085oo`03
01moogoo01ioo`0301moogoo07]oo`00PGoo00<07gooOol07Woo00<07gooOol0Ngoo0020Ool00`0O
Oomoo`0POol00`0OOomoo`1jOol0081oo`0301moogoo021oo`0301moogoo07Yoo`00Ogoo00<07goo
Ool08Woo00<07gooOol0NGoo001oOol00`0OOomoo`0ROol00`0OOomoo`1iOol007ioo`0301moogoo
02Aoo`0301moogoo07Qoo`00OWoo00<07gooOol097oo00<07gooOol0N7oo001mOol00`0OOomoo`0U
Ool00`0OOomoo`1hOol007eoo`0301moogoo02Ioo`0301moogoo07Moo`00OGoo00<07gooOol09Woo
00<07gooOol0Mgoo001lOol00`0OOomoo`0XOol00`0OOomoo`1fOol007aoo`0301moogoo02Qoo`03
01moogoo07Ioo`00Ngoo00<07gooOol0:Woo00<07gooOol0MGoo001kOol00`0OOomoo`0ZOol00`0O
Oomoo`1eOol007]oo`0301moogoo02]oo`0301moogoo07Aoo`00Ngoo00<07gooOol0:goo00<07goo
Ool0M7oo001jOol00`0OOomoo`0/Ool00`0OOomoo`1dOol007Yoo`0301moogoo02eoo`0301moogoo
07=oo`00NWoo00<07gooOol0;Goo00<07gooOol0Lgoo001jOol00`0OOomoo`0]Ool00`0OOomoo`1c
Ool007Yoo`0301moogoo02ioo`0301moogoo079oo`00NGoo00<07gooOol0;goo00<07gooOol0LWoo
001iOol00`0OOomoo`0_Ool00`0OOomoo`1bOol007Qoo`0301moogoo031oo`0301moogoo079oo`00
N7oo00<07gooOol0<Goo00<07gooOol0LGoo001hOol00`0OOomoo`0aOol00`0OOomoo`1aOol007Qo
o`0301moogoo035oo`0301moogoo075oo`00Mgoo00<07gooOol0<Woo00<07gooOol0LGoo001gOol0
0`0OOomoo`0cOol00`0OOomoo`1`Ool007Moo`0301moogoo03=oo`0301moogoo071oo`00Mgoo00<0
7gooOol0<goo00<07gooOol0L7oo001gOol00`0OOomoo`0cOol00`0OOomoo`1`Ool007Moo`0301mo
ogoo03Aoo`0301moogoo06moo`00Mgoo00<07gooOol0=7oo00<07gooOol0Kgoo001fOol00`0OOomo
o`0eOol00`0OOomoo`1_Ool007Ioo`0301moogoo03Eoo`0301moogoo06moo`00MWoo00<07gooOol0
=Woo00<07gooOol0KWoo001fOol00`0OOomoo`0fOol00`0OOomoo`1^Ool007Ioo`0301moogoo03Io
o`0301moogoo06ioo`00MWoo00<07gooOol0=Woo00<07gooOol0KWoo001eOol00`0OOomoo`0hOol0
0`0OOomoo`1]Ool007Eoo`0301moogoo03Qoo`0301moogoo06eoo`00MGoo00<07gooOol0>7oo00<0
7gooOol0KGoo001eOol00`0OOomoo`0hOol00`0OOomoo`1]Ool007Eoo`0301moogoo03Qoo`0301mo
ogoo06eoo`00MGoo00<07gooOol0>7oo00<07gooOol0KGoo001eOol00`0OOomoo`0iOol00`0OOomo
o`1/Ool007Aoo`0301moogoo03Yoo`0301moogoo06aoo`00M7oo00<07gooOol0>Woo00<07gooOol0
K7oo001dOol00`0OOomoo`0jOol00`0OOomoo`1/Ool007Aoo`0301moogoo03Yoo`0301moogoo06ao
o`00M7oo00<07gooOol0>Woo00<07gooOol0K7oo001dOol00`0OOomoo`0jOol00`0OOomoo`1/Ool0
07Aoo`0301moogoo03Yoo`0301moogoo06aoo`00M7oo00<07gooOol0>goo00<07gooOol0Jgoo001d
Ool00`0OOomoo`0kOol00`0OOomoo`1[Ool007Aoo`0301moogoo03]oo`0301moogoo06]oo`00M7oo
00<07gooOol0>goo00<07gooOol0Jgoo001dOol00`0OOomoo`0kOol00`0OOomoo`1[Ool007Aoo`03
01moogoo03]oo`0301moogoo06]oo`00Lgoo00<07gooOol0?7oo00<07gooOol0Jgoo001cOol00`0O
Oomoo`0lOol00`0OOomoo`1[Ool007=oo`0301moogoo03aoo`0301moogoo06]oo`00Lgoo00<07goo
Ool0?Goo00<07gooOol0JWoo001cOol00`0OOomoo`0mOol00`0OOomoo`1ZOol007=oo`0301moogoo
03eoo`0301moogoo06Yoo`00Lgoo00<07gooOol0?Goo00<07gooOol0JWoo001cOol00`0OOomoo`0m
Ool00`0OOomoo`1ZOol007=oo`0301moogoo03eoo`0301moogoo06Yoo`00Lgoo00<07gooOol0?Goo
00<07gooOol0JWoo001cOol00`0OOomoo`0mOol00`0OOomoo`1ZOol007=oo`0301moogoo03eoo`03
01moogoo06Yoo`00Lgoo00<07gooOol0?Goo00<07gooOol0JWoo001cOol00`0OOomoo`0mOol00`0O
Oomoo`1ZOol007=oo`0301moogoo03eoo`0301moogoo06Yoo`00Lgoo00<07gooOol0?Goo00<07goo
Ool0JWoo001cOol00`0OOomoo`0mOol00`0OOomoo`1ZOol007=oo`0301moogoo03eoo`0301moogoo
06Yoo`00Lgoo00<07gooOol0?Goo00<07gooOol0JWoo001cOol00`0OOomoo`0mOol00`0OOomoo`1Z
Ool007=oo`0301moogoo03eoo`0301moogoo06Yoo`00Lgoo00<07gooOol0?Goo00<07gooOol0JWoo
001cOol00`0OOomoo`0nOol00`0OOomoo`1YOol007=oo`0301moogoo03ioo`0301moogoo06Uoo`00
Lgoo00<07gooOol0?Woo00<07gooOol0JGoo001cOol00`0OOomoo`0nOol00`0OOomoo`1YOol007=o
o`0301moogoo03ioo`0301moogoo06Uoo`00Lgoo00<07gooOol0?Woo00<07gooOol0JGoo001cOol0
0`0OOomoo`0nOol00`0OOomoo`1YOol007Aoo`0301moogoo03eoo`0301moogoo06Uoo`00M7oo00<0
7gooOol0?Goo00<07gooOol0JGoo001dOol00`0OOomoo`0mOol00`0OOomoo`1YOol007Aoo`0301mo
ogoo03eoo`0301moogoo06Uoo`00M7oo00<07gooOol0?Goo00<07gooOol0JGoo001dOol00`0OOomo
o`0mOol00`0OOomoo`1YOol007Aoo`0301moogoo03eoo`0301moogoo06Uoo`00M7oo00<07gooOol0
?Goo00<07gooOol0JGoo001dOol00`0OOomoo`0mOol00`0OOomoo`1YOol007Aoo`0301moogoo03eo
o`0301moogoo06Uoo`00M7oo00<07gooOol0?Goo00<07gooOol0JGoo001dOol00`0OOomoo`0lOol0
0`0OOomoo`1ZOol007Aoo`0301moogoo03aoo`0301moogoo06Yoo`00M7oo00<07gooOol0?7oo00<0
7gooOol0JWoo001eOol00`0OOomoo`0kOol00`0OOomoo`1ZOol007Eoo`0301moogoo03]oo`0301mo
ogoo06Yoo`00MGoo00<07gooOol0>goo00<07gooOol0JWoo001eOol00`0OOomoo`0kOol00`0OOomo
o`1ZOol007Eoo`0301moogoo03]oo`0301moogoo06Yoo`00MGoo00<07gooOol0>goo00<07gooOol0
JWoo001fOol00`0OOomoo`0iOol00`0OOomoo`1[Ool007Ioo`0301moogoo03Uoo`0301moogoo06]o
o`00MWoo00<07gooOol0>Goo00<07gooOol0Jgoo001fOol00`0OOomoo`0iOol00`0OOomoo`1[Ool0
07Ioo`0301moogoo03Uoo`0301moogoo06]oo`00MWoo00<07gooOol0>Goo00<07gooOol0Jgoo001f
Ool00`0OOomoo`0iOol00`0OOomoo`1[Ool007Moo`0301moogoo03Qoo`0301moogoo06]oo`00Mgoo
00<07gooOol0=goo00<07gooOol0K7oo001gOol00`0OOomoo`0gOol00`0OOomoo`1/Ool007Moo`03
01moogoo03Moo`0301moogoo06aoo`00Mgoo00<07gooOol0=goo00<07gooOol0K7oo001gOol00`0O
Oomoo`0gOol00`0OOomoo`1/Ool007Moo`0301moogoo03Moo`0301moogoo06aoo`00N7oo00<07goo
Ool0=Woo00<07gooOol0K7oo001hOol00`0OOomoo`0fOol00`0OOomoo`1/Ool007Qoo`0301moogoo
03Eoo`0301moogoo06eoo`00N7oo00<07gooOol0=Goo00<07gooOol0KGoo001hOol00`0OOomoo`0e
Ool00`0OOomoo`1]Ool007Qoo`0301moogoo03Eoo`0301moogoo06eoo`00NGoo00<07gooOol0=7oo
00<07gooOol0KGoo001iOol00`0OOomoo`0dOol00`0OOomoo`1]Ool007Uoo`0301moogoo03Aoo`03
01moogoo06eoo`00NGoo00<07gooOol0=7oo00<07gooOol0KGoo001iOol00`0OOomoo`0cOol00`0O
Oomoo`1^Ool007Yoo`0301moogoo039oo`0301moogoo06ioo`00NWoo00<07gooOol0<Woo00<07goo
Ool0KWoo001kOol00`0OOomoo`0aOol00`0OOomoo`1^Ool007]oo`0301moogoo035oo`0301moogoo
06ioo`00Ngoo00<07gooOol0<Goo00<07gooOol0KWoo001lOol00`0OOomoo`0_Ool00`0OOomoo`1_
Ool007aoo`0301moogoo02moo`0301moogoo06moo`00O7oo00<07gooOol0;goo00<07gooOol0Kgoo
001mOol00`0OOomoo`0^Ool00`0OOomoo`1_Ool007eoo`0301moogoo02eoo`0301moogoo071oo`00
OGoo00<07gooOol0;Goo00<07gooOol0L7oo001mOol00`0OOomoo`0]Ool00`0OOomoo`1`Ool007eo
o`0301moogoo02aoo`0301moogoo075oo`00OWoo00<07gooOol0:goo00<07gooOol0LGoo001nOol0
0`0OOomoo`0[Ool00`0OOomoo`1aOol007ioo`0301moogoo02Yoo`0301moogoo079oo`00OWoo00<0
7gooOol0:Woo00<07gooOol0LWoo001oOol00`0OOomoo`0YOol00`0OOomoo`1bOol007moo`0301mo
ogoo02Qoo`0301moogoo07=oo`00P7oo00<07gooOol09goo00<07gooOol0Lgoo0020Ool00`0OOomo
o`0WOol00`0OOomoo`1cOol0081oo`0301moogoo02Ioo`0301moogoo07Aoo`00PGoo00<07gooOol0
9Goo00<07gooOol0M7oo0021Ool00`0OOomoo`0UOol00`0OOomoo`1dOol0089oo`0301moogoo02=o
o`0301moogoo07Eoo`00Pgoo00<07gooOol08Woo00<07gooOol0MGoo0023Ool00`0OOomoo`0QOol0
0`0OOomoo`1fOol008Aoo`0301moogoo021oo`0301moogoo07Ioo`00QGoo00<07gooOol07Woo00<0
7gooOol0Mgoo0025Ool00`0OOomoo`0NOol00`0OOomoo`1gOol008Ioo`0301moogoo01aoo`0301mo
ogoo07Qoo`00QWoo00<07gooOol077oo00<07gooOol0N7oo0027Ool00`0OOomoo`0JOol00`0OOomo
o`1iOol008Qoo`0301moogoo01Qoo`0301moogoo07Yoo`00R7oo00<07gooOol067oo00<07gooOol0
NWoo0029Ool00`0OOomoo`0FOol00`0OOomoo`1kOol008Yoo`0301moogoo01Aoo`0301moogoo07ao
o`00Rgoo00<07gooOol04Woo00<07gooOol0OGoo002<Ool00`0OOomoo`0@Ool00`0OOomoo`1nOol0
08eoo`807`ioo`807h5oo`00Sgoo00<07gooOol02Woo00<07gooOol0PGoo002@Ool301l6Ool301n4
Ool009=oo`H07hMoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.39805 .51563 m
.39574 .49121 L
s
.40101 .53995 m
.39805 .51563 L
s
.39574 .49121 m
.39408 .46681 L
s
.40461 .56408 m
.40101 .53995 L
s
.39408 .46681 m
.3931 .44255 L
s
.40883 .58789 m
.40461 .56408 L
s
.3931 .44255 m
.39278 .41853 L
s
.41365 .61127 m
.40883 .58789 L
s
.39278 .41853 m
.39316 .39489 L
s
.41906 .63411 m
.41365 .61127 L
s
.39316 .39489 m
.39422 .37172 L
s
.42504 .65629 m
.41906 .63411 L
s
.39422 .37172 m
.39598 .34915 L
s
.43157 .67769 m
.42504 .65629 L
s
.39598 .34915 m
.39843 .32731 L
s
.43862 .69819 m
.43157 .67769 L
s
.39843 .32731 m
.40158 .30631 L
s
.44617 .71767 m
.43862 .69819 L
s
.40158 .30631 m
.40542 .28628 L
s
.4542 .736 m
.44617 .71767 L
s
.40542 .28628 m
.40996 .26736 L
s
.46266 .75306 m
.4542 .736 L
s
.40996 .26736 m
.41518 .24967 L
s
.47152 .76872 m
.46266 .75306 L
s
.41518 .24967 m
.42106 .23336 L
s
.48074 .78284 m
.47152 .76872 L
s
.42106 .23336 m
.4276 .21854 L
s
.49028 .79531 m
.48074 .78284 L
s
.4276 .21854 m
.43478 .20537 L
s
.50009 .80598 m
.49028 .79531 L
s
.43478 .20537 m
.44257 .19397 L
s
.51011 .81474 m
.50009 .80598 L
s
.44257 .19397 m
.45093 .18449 L
s
.52028 .82147 m
.51011 .81474 L
s
.45093 .18449 m
.45984 .17704 L
s
.53055 .82604 m
.52028 .82147 L
s
.45984 .17704 m
.46925 .17175 L
s
.54083 .82835 m
.53055 .82604 L
s
.46925 .17175 m
.4791 .16873 L
s
.55106 .8283 m
.54083 .82835 L
s
.4791 .16873 m
.48934 .1681 L
s
.56114 .82581 m
.55106 .8283 L
s
.48934 .1681 m
.4999 .16994 L
s
.57101 .8208 m
.56114 .82581 L
s
.4999 .16994 m
.51072 .17432 L
s
.58057 .81324 m
.57101 .8208 L
s
.51072 .17432 m
.5217 .1813 L
s
.58973 .80309 m
.58057 .81324 L
s
.5217 .1813 m
.53276 .1909 L
s
.59839 .79036 m
.58973 .80309 L
s
.53276 .1909 m
.54381 .20313 L
s
.60647 .77508 m
.59839 .79036 L
s
.54381 .20313 m
.55474 .21797 L
s
.61386 .7573 m
.60647 .77508 L
s
.55474 .21797 m
.56544 .23535 L
s
.62048 .73711 m
.61386 .7573 L
s
.56544 .23535 m
.57582 .25518 L
s
.62625 .71466 m
.62048 .73711 L
s
.57582 .25518 m
.58576 .27732 L
s
.63108 .69009 m
.62625 .71466 L
s
.58576 .27732 m
.59514 .30163 L
s
.63491 .66361 m
.63108 .69009 L
s
.59514 .30163 m
.60387 .32789 L
s
.63767 .63545 m
.63491 .66361 L
s
.60387 .32789 m
.61184 .35588 L
s
.63932 .60586 m
.63767 .63545 L
s
.61184 .35588 m
.61896 .38532 L
s
.63983 .57515 m
.63932 .60586 L
s
.61896 .38532 m
.62513 .41594 L
s
.63918 .54361 m
.63983 .57515 L
s
.62513 .41594 m
.6303 .44741 L
s
.63736 .51159 m
.63918 .54361 L
s
.6303 .44741 m
.63439 .4794 L
s
.63439 .4794 m
.63736 .51159 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.39471 .51924 m
.39068 .49514 L
s
.39942 .54322 m
.39471 .51924 L
s
.39068 .49514 m
.38732 .47103 L
s
.40477 .56697 m
.39942 .54322 L
s
.38732 .47103 m
.38467 .44702 L
s
.41074 .59037 m
.40477 .56697 L
s
.38467 .44702 m
.38274 .42321 L
s
.41732 .61333 m
.41074 .59037 L
s
.38274 .42321 m
.38155 .39974 L
s
.42446 .63572 m
.41732 .61333 L
s
.38155 .39974 m
.38111 .3767 L
s
.43216 .65744 m
.42446 .63572 L
s
.38111 .3767 m
.38143 .35422 L
s
.44037 .67836 m
.43216 .65744 L
s
.38143 .35422 m
.38252 .33242 L
s
.44907 .69837 m
.44037 .67836 L
s
.38252 .33242 m
.3844 .31142 L
s
.45822 .71736 m
.44907 .69837 L
s
.3844 .31142 m
.38707 .29135 L
s
.46778 .7352 m
.45822 .71736 L
s
.38707 .29135 m
.39053 .27233 L
s
.47772 .75176 m
.46778 .7352 L
s
.39053 .27233 m
.39479 .25451 L
s
.48798 .76693 m
.47772 .75176 L
s
.39479 .25451 m
.39984 .23802 L
s
.49851 .78058 m
.48798 .76693 L
s
.39984 .23802 m
.40568 .22299 L
s
.50927 .79258 m
.49851 .78058 L
s
.40568 .22299 m
.4123 .20955 L
s
.52019 .80281 m
.50927 .79258 L
s
.4123 .20955 m
.41968 .19786 L
s
.53121 .81115 m
.52019 .80281 L
s
.41968 .19786 m
.42779 .18804 L
s
.54226 .81747 m
.53121 .81115 L
s
.42779 .18804 m
.43661 .18022 L
s
.55327 .82166 m
.54226 .81747 L
s
.43661 .18022 m
.4461 .17453 L
s
.56415 .82363 m
.55327 .82166 L
s
.4461 .17453 m
.45622 .1711 L
s
.57482 .82327 m
.56415 .82363 L
s
.45622 .1711 m
.4669 .17002 L
s
.5852 .82049 m
.57482 .82327 L
s
.4669 .17002 m
.47809 .1714 L
s
.59519 .81525 m
.5852 .82049 L
s
.47809 .1714 m
.48971 .1753 L
s
.60469 .80748 m
.59519 .81525 L
s
.48971 .1753 m
.50169 .18179 L
s
.61361 .79717 m
.60469 .80748 L
s
.50169 .18179 m
.51392 .19091 L
s
.62185 .78431 m
.61361 .79717 L
s
.51392 .19091 m
.52632 .20266 L
s
.62931 .76893 m
.62185 .78431 L
s
.52632 .20266 m
.53877 .21701 L
s
.63591 .7511 m
.62931 .76893 L
s
.53877 .21701 m
.55115 .23391 L
s
.64154 .7309 m
.63591 .7511 L
s
.55115 .23391 m
.56334 .25327 L
s
.64614 .70846 m
.64154 .7309 L
s
.56334 .25327 m
.57523 .27497 L
s
.64962 .68395 m
.64614 .70846 L
s
.57523 .27497 m
.58668 .29885 L
s
.65192 .65756 m
.64962 .68395 L
s
.58668 .29885 m
.59756 .3247 L
s
.653 .62951 m
.65192 .65756 L
s
.59756 .3247 m
.60776 .3523 L
s
.65283 .60008 m
.653 .62951 L
s
.60776 .3523 m
.61715 .38138 L
s
.65138 .56955 m
.65283 .60008 L
s
.61715 .38138 m
.62563 .41165 L
s
.64865 .53822 m
.65138 .56955 L
s
.62563 .41165 m
.6331 .44281 L
s
.64467 .50643 m
.64865 .53822 L
s
.6331 .44281 m
.63947 .47451 L
s
.63947 .47451 m
.64467 .50643 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0025Ool301nHOol0089oo`<07`=oo`<07iEoo`00Ogoo0`0O2Goo0P0O
Tgoo001mOol201l>Ool201nAOol007]oo`807a9oo`0301moogoo08ioo`00NWoo00<07gooOol04goo
0P0OSWoo001iOol00`0OOomoo`0FOol201n<Ool007Uoo`0301moogoo01Qoo`0301moogoo08Uoo`00
N7oo00<07gooOol06Woo00<07gooOol0R7oo001gOol00`0OOomoo`0LOol00`0OOomoo`27Ool007Mo
o`0301moogoo01eoo`0301moogoo08Ioo`00MWoo00<07gooOol07goo00<07gooOol0QGoo001fOol0
0`0OOomoo`0OOol00`0OOomoo`25Ool007Eoo`0301moogoo025oo`0301moogoo08Aoo`00MGoo00<0
7gooOol08Woo00<07gooOol0Pgoo001dOol00`0OOomoo`0TOol00`0OOomoo`22Ool007Aoo`0301mo
ogoo02Eoo`0301moogoo085oo`00Lgoo00<07gooOol09Woo00<07gooOol0PGoo001cOol00`0OOomo
o`0WOol00`0OOomoo`20Ool0079oo`0301moogoo02Uoo`0301moogoo07moo`00LWoo00<07gooOol0
:Woo00<07gooOol0OWoo001bOol00`0OOomoo`0ZOol00`0OOomoo`1nOol0079oo`0301moogoo02]o
o`0301moogoo07eoo`00LGoo00<07gooOol0;7oo00<07gooOol0OGoo001aOol00`0OOomoo`0]Ool0
0`0OOomoo`1lOol0075oo`0301moogoo02ioo`0301moogoo07]oo`00LGoo00<07gooOol0;Woo00<0
7gooOol0Ngoo001aOol00`0OOomoo`0_Ool00`0OOomoo`1jOol0071oo`0301moogoo035oo`0301mo
ogoo07Uoo`00L7oo00<07gooOol0<Goo00<07gooOol0NGoo001`Ool00`0OOomoo`0bOol00`0OOomo
o`1hOol0071oo`0301moogoo039oo`0301moogoo07Qoo`00L7oo00<07gooOol0<goo00<07gooOol0
Mgoo001_Ool00`0OOomoo`0dOol00`0OOomoo`1gOol006moo`0301moogoo03Eoo`0301moogoo07Io
o`00Kgoo00<07gooOol0=Goo00<07gooOol0MWoo001_Ool00`0OOomoo`0fOol00`0OOomoo`1eOol0
06moo`0301moogoo03Ioo`0301moogoo07Eoo`00KWoo00<07gooOol0=goo00<07gooOol0MGoo001^
Ool00`0OOomoo`0hOol00`0OOomoo`1dOol006ioo`0301moogoo03Qoo`0301moogoo07Aoo`00KWoo
00<07gooOol0>7oo00<07gooOol0M7oo001^Ool00`0OOomoo`0iOol00`0OOomoo`1cOol006ioo`03
01moogoo03Uoo`0301moogoo07=oo`00KGoo00<07gooOol0>goo00<07gooOol0LWoo001]Ool00`0O
Oomoo`0kOol00`0OOomoo`1bOol006eoo`0301moogoo03]oo`0301moogoo079oo`00KGoo00<07goo
Ool0?7oo00<07gooOol0LGoo001]Ool00`0OOomoo`0lOol00`0OOomoo`1aOol006eoo`0301moogoo
03aoo`0301moogoo075oo`00KGoo00<07gooOol0?Goo00<07gooOol0L7oo001]Ool00`0OOomoo`0m
Ool00`0OOomoo`1`Ool006eoo`0301moogoo03ioo`0301moogoo06moo`00KGoo00<07gooOol0?Woo
00<07gooOol0Kgoo001]Ool00`0OOomoo`0nOol00`0OOomoo`1_Ool006eoo`0301moogoo03moo`03
01moogoo06ioo`00KGoo00<07gooOol0?goo00<07gooOol0KWoo001]Ool00`0OOomoo`0oOol00`0O
Oomoo`1^Ool006eoo`0301moogoo041oo`0301moogoo06eoo`00KGoo00<07gooOol0@7oo00<07goo
Ool0KGoo001]Ool00`0OOomoo`11Ool00`0OOomoo`1/Ool006eoo`0301moogoo045oo`0301moogoo
06aoo`00KGoo00<07gooOol0@Goo00<07gooOol0K7oo001]Ool00`0OOomoo`11Ool00`0OOomoo`1/
Ool006eoo`0301moogoo049oo`0301moogoo06]oo`00KGoo00<07gooOol0@Woo00<07gooOol0Jgoo
001]Ool00`0OOomoo`12Ool00`0OOomoo`1[Ool006eoo`0301moogoo049oo`0301moogoo06]oo`00
KGoo00<07gooOol0@goo00<07gooOol0JWoo001]Ool00`0OOomoo`13Ool00`0OOomoo`1ZOol006eo
o`0301moogoo04=oo`0301moogoo06Yoo`00KGoo00<07gooOol0@goo00<07gooOol0JWoo001]Ool0
0`0OOomoo`13Ool00`0OOomoo`1ZOol006eoo`0301moogoo04Aoo`0301moogoo06Uoo`00KGoo00<0
7gooOol0A7oo00<07gooOol0JGoo001]Ool00`0OOomoo`14Ool00`0OOomoo`1YOol006eoo`0301mo
ogoo04Aoo`0301moogoo06Uoo`00KWoo00<07gooOol0A7oo00<07gooOol0J7oo001^Ool00`0OOomo
o`14Ool00`0OOomoo`1XOol006ioo`0301moogoo04Aoo`0301moogoo06Qoo`00KWoo00<07gooOol0
A7oo00<07gooOol0J7oo001^Ool00`0OOomoo`14Ool00`0OOomoo`1XOol006ioo`0301moogoo04Eo
o`0301moogoo06Moo`00KWoo00<07gooOol0AGoo00<07gooOol0Igoo001_Ool00`0OOomoo`14Ool0
0`0OOomoo`1WOol006moo`0301moogoo04Aoo`0301moogoo06Moo`00Kgoo00<07gooOol0AGoo00<0
7gooOol0IWoo001_Ool00`0OOomoo`15Ool00`0OOomoo`1VOol006moo`0301moogoo04Eoo`0301mo
ogoo06Ioo`00Kgoo00<07gooOol0AGoo00<07gooOol0IWoo001_Ool00`0OOomoo`15Ool00`0OOomo
o`1VOol0071oo`0301moogoo04Eoo`0301moogoo06Eoo`00L7oo00<07gooOol0AGoo00<07gooOol0
IGoo001`Ool00`0OOomoo`15Ool00`0OOomoo`1UOol0071oo`0301moogoo04Eoo`0301moogoo06Eo
o`00L7oo00<07gooOol0AWoo00<07gooOol0I7oo001`Ool00`0OOomoo`16Ool00`0OOomoo`1TOol0
071oo`0301moogoo04Ioo`0301moogoo06Aoo`00LGoo00<07gooOol0AGoo00<07gooOol0I7oo001a
Ool00`0OOomoo`15Ool00`0OOomoo`1TOol0075oo`0301moogoo04Eoo`0301moogoo06Aoo`00LGoo
00<07gooOol0AGoo00<07gooOol0I7oo001aOol00`0OOomoo`16Ool00`0OOomoo`1SOol0075oo`03
01moogoo04Ioo`0301moogoo06=oo`00LGoo00<07gooOol0AWoo00<07gooOol0Hgoo001bOol00`0O
Oomoo`15Ool00`0OOomoo`1SOol0079oo`0301moogoo04Eoo`0301moogoo06=oo`00LWoo00<07goo
Ool0AGoo00<07gooOol0Hgoo001bOol00`0OOomoo`15Ool00`0OOomoo`1SOol007=oo`0301moogoo
04Aoo`0301moogoo06=oo`00Lgoo00<07gooOol0A7oo00<07gooOol0Hgoo001cOol00`0OOomoo`14
Ool00`0OOomoo`1SOol007=oo`0301moogoo04Aoo`0301moogoo06=oo`00M7oo00<07gooOol0@goo
00<07gooOol0Hgoo001dOol00`0OOomoo`13Ool00`0OOomoo`1SOol007Aoo`0301moogoo04=oo`03
01moogoo06=oo`00M7oo00<07gooOol0@goo00<07gooOol0Hgoo001dOol00`0OOomoo`13Ool00`0O
Oomoo`1SOol007Eoo`0301moogoo049oo`0301moogoo06=oo`00MGoo00<07gooOol0@Woo00<07goo
Ool0Hgoo001eOol00`0OOomoo`13Ool00`0OOomoo`1ROol007Eoo`0301moogoo04=oo`0301moogoo
069oo`00MGoo00<07gooOol0@goo00<07gooOol0HWoo001fOol00`0OOomoo`12Ool00`0OOomoo`1R
Ool007Ioo`0301moogoo049oo`0301moogoo069oo`00MWoo00<07gooOol0@Woo00<07gooOol0HWoo
001fOol00`0OOomoo`12Ool00`0OOomoo`1ROol007Moo`0301moogoo045oo`0301moogoo069oo`00
Mgoo00<07gooOol0@Goo00<07gooOol0HWoo001gOol00`0OOomoo`11Ool00`0OOomoo`1ROol007Qo
o`0301moogoo041oo`0301moogoo069oo`00N7oo00<07gooOol0@7oo00<07gooOol0HWoo001hOol0
0`0OOomoo`10Ool00`0OOomoo`1ROol007Uoo`0301moogoo03moo`0301moogoo069oo`00NGoo00<0
7gooOol0?goo00<07gooOol0HWoo001iOol00`0OOomoo`0oOol00`0OOomoo`1ROol007Yoo`0301mo
ogoo03ioo`0301moogoo069oo`00NWoo00<07gooOol0?Woo00<07gooOol0HWoo001kOol00`0OOomo
o`0mOol00`0OOomoo`1ROol007]oo`0301moogoo03eoo`0301moogoo069oo`00O7oo00<07gooOol0
?7oo00<07gooOol0HWoo001lOol00`0OOomoo`0lOol00`0OOomoo`1ROol007eoo`0301moogoo03]o
o`0301moogoo069oo`00OGoo00<07gooOol0>goo00<07gooOol0HWoo001mOol00`0OOomoo`0jOol0
0`0OOomoo`1SOol007ioo`0301moogoo03Uoo`0301moogoo06=oo`00OWoo00<07gooOol0>Goo00<0
7gooOol0Hgoo001nOol00`0OOomoo`0iOol00`0OOomoo`1SOol007moo`0301moogoo03Qoo`0301mo
ogoo06=oo`00Ogoo00<07gooOol0>7oo00<07gooOol0Hgoo001oOol00`0OOomoo`0hOol00`0OOomo
o`1SOol0081oo`0301moogoo03Moo`0301moogoo06=oo`00P7oo00<07gooOol0=Woo00<07gooOol0
I7oo0021Ool00`0OOomoo`0eOol00`0OOomoo`1TOol0085oo`0301moogoo03Eoo`0301moogoo06Ao
o`00PWoo00<07gooOol0=7oo00<07gooOol0I7oo0022Ool00`0OOomoo`0dOol00`0OOomoo`1TOol0
08=oo`0301moogoo03=oo`0301moogoo06Aoo`00Q7oo00<07gooOol0<Goo00<07gooOol0IGoo0024
Ool00`0OOomoo`0aOol00`0OOomoo`1UOol008Eoo`0301moogoo031oo`0301moogoo06Eoo`00QGoo
00<07gooOol0<7oo00<07gooOol0IGoo0026Ool00`0OOomoo`0_Ool00`0OOomoo`1UOol008Moo`03
01moogoo02eoo`0301moogoo06Ioo`00Qgoo00<07gooOol0;Goo00<07gooOol0IWoo0028Ool00`0O
Oomoo`0/Ool00`0OOomoo`1VOol008Qoo`0301moogoo02]oo`0301moogoo06Moo`00RGoo00<07goo
Ool0:Woo00<07gooOol0Igoo002:Ool00`0OOomoo`0YOol00`0OOomoo`1WOol008Yoo`0301moogoo
02Qoo`0301moogoo06Qoo`00Rgoo00<07gooOol09goo00<07gooOol0J7oo002;Ool00`0OOomoo`0V
Ool00`0OOomoo`1YOol008aoo`0301moogoo02Eoo`0301moogoo06Uoo`00SGoo00<07gooOol097oo
00<07gooOol0JGoo002=Ool00`0OOomoo`0SOol00`0OOomoo`1ZOol008ioo`0301moogoo029oo`03
01moogoo06Yoo`00Sgoo00<07gooOol087oo00<07gooOol0Jgoo002@Ool00`0OOomoo`0OOol00`0O
Oomoo`1[Ool0095oo`0301moogoo01eoo`0301moogoo06aoo`00TWoo00<07gooOol077oo00<07goo
Ool0K7oo002COol00`0OOomoo`0JOol00`0OOomoo`1]Ool009Aoo`0301moogoo01Qoo`0301moogoo
06ioo`00UGoo00<07gooOol05Woo00<07gooOol0Kgoo002FOol201lEOol00`0OOomoo`1`Ool009Qo
o`0301moogoo011oo`807g=oo`00VGoo0P0O3goo00<07gooOol0Lgoo002KOol201l;Ool201mfOol0
09eoo`<07`Ioo`807gQoo`00X7oo1P0ONWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.3934 .52273 m
.38764 .4991 L
s
.39982 .54621 m
.3934 .52273 L
s
.40688 .56943 m
.39982 .54621 L
s
.38764 .4991 m
.38259 .47543 L
s
.41455 .59228 m
.40688 .56943 L
s
.38259 .47543 m
.37826 .45181 L
s
.42281 .61466 m
.41455 .59228 L
s
.37826 .45181 m
.37467 .42837 L
s
.43161 .63646 m
.42281 .61466 L
s
.37467 .42837 m
.37186 .40521 L
s
.44093 .65758 m
.43161 .63646 L
s
.37186 .40521 m
.36985 .38244 L
s
.45072 .6779 m
.44093 .65758 L
s
.36985 .38244 m
.36865 .36017 L
s
.46094 .6973 m
.45072 .6779 L
s
.36865 .36017 m
.36829 .33854 L
s
.47156 .71569 m
.46094 .6973 L
s
.36829 .33854 m
.36879 .31765 L
s
.48252 .73293 m
.47156 .71569 L
s
.36879 .31765 m
.37016 .29765 L
s
.49379 .74891 m
.48252 .73293 L
s
.37016 .29765 m
.37242 .27864 L
s
.50529 .76351 m
.49379 .74891 L
s
.37242 .27864 m
.37557 .26077 L
s
.51698 .77662 m
.50529 .76351 L
s
.37557 .26077 m
.37963 .24417 L
s
.52879 .7881 m
.51698 .77662 L
s
.37963 .24417 m
.3846 .22898 L
s
.54065 .79784 m
.52879 .7881 L
s
.3846 .22898 m
.39049 .21534 L
s
.5525 .80572 m
.54065 .79784 L
s
.39049 .21534 m
.39727 .20339 L
s
.56425 .81162 m
.5525 .80572 L
s
.39727 .20339 m
.40494 .19325 L
s
.57582 .81544 m
.56425 .81162 L
s
.40494 .19325 m
.41347 .18508 L
s
.58712 .81708 m
.57582 .81544 L
s
.41347 .18508 m
.42285 .179 L
s
.59806 .81643 m
.58712 .81708 L
s
.42285 .179 m
.43302 .17512 L
s
.60855 .81342 m
.59806 .81643 L
s
.43302 .17512 m
.44395 .17357 L
s
.61849 .80798 m
.60855 .81342 L
s
.44395 .17357 m
.45557 .17445 L
s
.62777 .80008 m
.61849 .80798 L
s
.45557 .17445 m
.46781 .17783 L
s
.63629 .78967 m
.62777 .80008 L
s
.46781 .17783 m
.48059 .18378 L
s
.64396 .77678 m
.63629 .78967 L
s
.48059 .18378 m
.49383 .19233 L
s
.65067 .76141 m
.64396 .77678 L
s
.49383 .19233 m
.5074 .20351 L
s
.65633 .74363 m
.65067 .76141 L
s
.5074 .20351 m
.52121 .21729 L
s
.66085 .72353 m
.65633 .74363 L
s
.52121 .21729 m
.53512 .23362 L
s
.66416 .70124 m
.66085 .72353 L
s
.53512 .23362 m
.54901 .25241 L
s
.66618 .67691 m
.66416 .70124 L
s
.54901 .25241 m
.56273 .27356 L
s
.66688 .65074 m
.66618 .67691 L
s
.56273 .27356 m
.57614 .29689 L
s
.6662 .62295 m
.66688 .65074 L
s
.57614 .29689 m
.5891 .32221 L
s
.66413 .59381 m
.6662 .62295 L
s
.5891 .32221 m
.60146 .3493 L
s
.66067 .56359 m
.66413 .59381 L
s
.60146 .3493 m
.61307 .37789 L
s
.65583 .53261 m
.66067 .56359 L
s
.61307 .37789 m
.62382 .40769 L
s
.64966 .50119 m
.65583 .53261 L
s
.62382 .40769 m
.63357 .43839 L
s
.64221 .46967 m
.64966 .50119 L
s
.63357 .43839 m
.64221 .46967 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.3941 .5258 m
.38667 .50281 L
s
.40218 .54861 m
.3941 .5258 L
s
.41088 .57114 m
.40218 .54861 L
s
.38667 .50281 m
.37994 .47974 L
s
.42018 .59328 m
.41088 .57114 L
s
.37994 .47974 m
.37394 .45669 L
s
.43001 .61494 m
.42018 .59328 L
s
.37394 .45669 m
.3687 .43377 L
s
.44036 .63602 m
.43001 .61494 L
s
.3687 .43377 m
.36425 .41109 L
s
.45117 .6564 m
.44036 .63602 L
s
.36425 .41109 m
.36062 .38874 L
s
.46241 .67599 m
.45117 .6564 L
s
.36062 .38874 m
.35785 .36686 L
s
.47402 .69467 m
.46241 .67599 L
s
.35785 .36686 m
.35597 .34554 L
s
.48596 .71235 m
.47402 .69467 L
s
.35597 .34554 m
.355 .32492 L
s
.49816 .7289 m
.48596 .71235 L
s
.355 .32492 m
.35496 .30511 L
s
.51058 .74422 m
.49816 .7289 L
s
.35496 .30511 m
.35589 .28624 L
s
.52316 .75819 m
.51058 .74422 L
s
.35589 .28624 m
.35781 .26845 L
s
.53583 .77069 m
.52316 .75819 L
s
.35781 .26845 m
.36073 .25185 L
s
.54851 .78161 m
.53583 .77069 L
s
.36073 .25185 m
.36467 .23661 L
s
.56114 .79084 m
.54851 .78161 L
s
.36467 .23661 m
.36964 .22284 L
s
.57363 .79826 m
.56114 .79084 L
s
.36964 .22284 m
.37565 .2107 L
s
.5859 .80375 m
.57363 .79826 L
s
.37565 .2107 m
.38268 .20031 L
s
.59785 .80722 m
.5859 .80375 L
s
.38268 .20031 m
.39074 .19183 L
s
.6094 .80855 m
.59785 .80722 L
s
.39074 .19183 m
.39979 .18538 L
s
.62045 .80767 m
.6094 .80855 L
s
.39979 .18538 m
.40982 .18109 L
s
.63088 .80449 m
.62045 .80767 L
s
.40982 .18109 m
.42078 .17907 L
s
.64061 .79895 m
.63088 .80449 L
s
.42078 .17907 m
.43261 .17943 L
s
.64951 .791 m
.64061 .79895 L
s
.43261 .17943 m
.44527 .18226 L
s
.65749 .78062 m
.64951 .791 L
s
.44527 .18226 m
.45866 .18762 L
s
.66445 .7678 m
.65749 .78062 L
s
.45866 .18762 m
.47269 .19556 L
s
.67027 .75257 m
.66445 .7678 L
s
.47269 .19556 m
.48726 .2061 L
s
.67488 .73499 m
.67027 .75257 L
s
.48726 .2061 m
.50225 .21923 L
s
.67819 .71514 m
.67488 .73499 L
s
.50225 .21923 m
.51753 .2349 L
s
.68011 .69314 m
.67819 .71514 L
s
.51753 .2349 m
.53296 .25304 L
s
.6806 .66916 m
.68011 .69314 L
s
.53296 .25304 m
.54838 .27352 L
s
.67961 .64337 m
.6806 .66916 L
s
.54838 .27352 m
.56363 .29619 L
s
.67711 .616 m
.67961 .64337 L
s
.56363 .29619 m
.57855 .32086 L
s
.6731 .58731 m
.67711 .616 L
s
.57855 .32086 m
.59297 .3473 L
s
.66759 .55758 m
.6731 .58731 L
s
.59297 .3473 m
.60674 .37526 L
s
.66063 .52711 m
.66759 .55758 L
s
.60674 .37526 m
.6197 .40445 L
s
.65226 .49623 m
.66063 .52711 L
s
.6197 .40445 m
.63169 .43456 L
s
.64258 .46526 m
.65226 .49623 L
s
.63169 .43456 m
.64258 .46526 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.40571 .55052 m
.39598 .52837 L
s
.41603 .57236 m
.40571 .55052 L
s
.39598 .52837 m
.38689 .50602 L
s
.42691 .5938 m
.41603 .57236 L
s
.38689 .50602 m
.37849 .48355 L
s
.4383 .61475 m
.42691 .5938 L
s
.37849 .48355 m
.37081 .46109 L
s
.45015 .63509 m
.4383 .61475 L
s
.37081 .46109 m
.3639 .43871 L
s
.46241 .65474 m
.45015 .63509 L
s
.3639 .43871 m
.3578 .41653 L
s
.47502 .67359 m
.46241 .65474 L
s
.3578 .41653 m
.35255 .39466 L
s
.48795 .69154 m
.47502 .67359 L
s
.35255 .39466 m
.34818 .37321 L
s
.50112 .70849 m
.48795 .69154 L
s
.34818 .37321 m
.34474 .35228 L
s
.51448 .72432 m
.50112 .70849 L
s
.34474 .35228 m
.34226 .332 L
s
.52796 .73894 m
.51448 .72432 L
s
.34226 .332 m
.34078 .31248 L
s
.5415 .75223 m
.52796 .73894 L
s
.34078 .31248 m
.34033 .29386 L
s
.55501 .76409 m
.5415 .75223 L
s
.34033 .29386 m
.34096 .27626 L
s
.56844 .77439 m
.55501 .76409 L
s
.34096 .27626 m
.34267 .25981 L
s
.58168 .78304 m
.56844 .77439 L
s
.34267 .25981 m
.34551 .24466 L
s
.59465 .78993 m
.58168 .78304 L
s
.34551 .24466 m
.34948 .23093 L
s
.60727 .79494 m
.59465 .78993 L
s
.34948 .23093 m
.35462 .21877 L
s
.61944 .79798 m
.60727 .79494 L
s
.35462 .21877 m
.36091 .20832 L
s
.63105 .79895 m
.61944 .79798 L
s
.36091 .20832 m
.36837 .19971 L
s
.64199 .79778 m
.63105 .79895 L
s
.36837 .19971 m
.37698 .19308 L
s
.65218 .79437 m
.64199 .79778 L
s
.37698 .19308 m
.38672 .18855 L
s
.66149 .78868 m
.65218 .79437 L
s
.38672 .18855 m
.39757 .18624 L
s
.66981 .78067 m
.66149 .78868 L
s
.39757 .18624 m
.40946 .18626 L
s
.67705 .7703 m
.66981 .78067 L
s
.40946 .18626 m
.42236 .18868 L
s
.68309 .75757 m
.67705 .7703 L
s
.42236 .18868 m
.43617 .1936 L
s
.68785 .74253 m
.68309 .75757 L
s
.43617 .1936 m
.45081 .20103 L
s
.69122 .72521 m
.68785 .74253 L
s
.45081 .20103 m
.46618 .21102 L
s
.69314 .7057 m
.69122 .72521 L
s
.46618 .21102 m
.48216 .22355 L
s
.69353 .68413 m
.69314 .7057 L
s
.48216 .22355 m
.4986 .23858 L
s
.69235 .66064 m
.69353 .68413 L
s
.4986 .23858 m
.51535 .25602 L
s
.68957 .63542 m
.69235 .66064 L
s
.51535 .25602 m
.53226 .27577 L
s
.68517 .60869 m
.68957 .63542 L
s
.53226 .27577 m
.54916 .29768 L
s
.67916 .58068 m
.68517 .60869 L
s
.54916 .29768 m
.56585 .32156 L
s
.67159 .55169 m
.67916 .58068 L
s
.56585 .32156 m
.58217 .34719 L
s
.6625 .52199 m
.67159 .55169 L
s
.58217 .34719 m
.59793 .37431 L
s
.65198 .49192 m
.6625 .52199 L
s
.59793 .37431 m
.61295 .40266 L
s
.64013 .46178 m
.65198 .49192 L
s
.61295 .40266 m
.62707 .43192 L
s
.62707 .43192 m
.64013 .46178 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.41033 .55171 m
.39897 .53022 L
s
.42226 .57288 m
.41033 .55171 L
s
.39897 .53022 m
.38822 .50851 L
s
.43471 .59363 m
.42226 .57288 L
s
.38822 .50851 m
.37814 .48666 L
s
.44762 .61387 m
.43471 .59363 L
s
.37814 .48666 m
.36878 .46479 L
s
.46093 .6335 m
.44762 .61387 L
s
.36878 .46479 m
.3602 .44299 L
s
.47459 .65243 m
.46093 .6335 L
s
.3602 .44299 m
.35243 .42136 L
s
.48854 .67055 m
.47459 .65243 L
s
.35243 .42136 m
.34553 .40001 L
s
.50271 .68777 m
.48854 .67055 L
s
.34553 .40001 m
.33954 .37905 L
s
.51705 .70399 m
.50271 .68777 L
s
.33954 .37905 m
.33452 .35858 L
s
.53147 .71911 m
.51705 .70399 L
s
.33452 .35858 m
.33051 .33874 L
s
.54591 .73302 m
.53147 .71911 L
s
.33051 .33874 m
.32756 .31963 L
s
.56029 .74561 m
.54591 .73302 L
s
.32756 .31963 m
.3257 .30138 L
s
.57454 .7568 m
.56029 .74561 L
s
.3257 .30138 m
.32499 .28412 L
s
.58856 .76646 m
.57454 .7568 L
s
.32499 .28412 m
.32546 .26798 L
s
.60226 .7745 m
.58856 .76646 L
s
.32546 .26798 m
.32715 .25309 L
s
.61556 .78082 m
.60226 .7745 L
s
.32715 .25309 m
.33007 .23959 L
s
.62835 .78532 m
.61556 .78082 L
s
.33007 .23959 m
.33427 .22761 L
s
.64054 .7879 m
.62835 .78532 L
s
.33427 .22761 m
.33976 .21729 L
s
.65201 .78848 m
.64054 .7879 L
s
.33976 .21729 m
.34654 .20876 L
s
.66266 .78698 m
.65201 .78848 L
s
.34654 .20876 m
.35461 .20216 L
s
.67238 .78333 m
.66266 .78698 L
s
.35461 .20216 m
.36396 .1976 L
s
.68106 .77748 m
.67238 .78333 L
s
.36396 .1976 m
.37457 .1952 L
s
.6886 .7694 m
.68106 .77748 L
s
.37457 .1952 m
.3864 .19506 L
s
.69488 .75906 m
.6886 .7694 L
s
.3864 .19506 m
.39939 .19726 L
s
.69981 .74647 m
.69488 .75906 L
s
.39939 .19726 m
.41347 .20187 L
s
.7033 .73167 m
.69981 .74647 L
s
.41347 .20187 m
.42855 .20893 L
s
.70526 .7147 m
.7033 .73167 L
s
.42855 .20893 m
.44453 .21847 L
s
.70563 .69565 m
.70526 .7147 L
s
.44453 .21847 m
.46129 .23046 L
s
.70435 .67463 m
.70563 .69565 L
s
.46129 .23046 m
.47868 .24487 L
s
.70138 .65181 m
.70435 .67463 L
s
.47868 .24487 m
.49656 .26161 L
s
.69672 .62734 m
.70138 .65181 L
s
.49656 .26161 m
.51474 .28059 L
s
.69036 .60144 m
.69672 .62734 L
s
.51474 .28059 m
.53306 .30165 L
s
.68233 .57436 m
.69036 .60144 L
s
.53306 .30165 m
.55132 .32462 L
s
.6727 .54634 m
.68233 .57436 L
s
.55132 .32462 m
.56933 .34927 L
s
.66152 .51768 m
.6727 .54634 L
s
.56933 .34927 m
.58689 .37538 L
s
.64891 .48867 m
.66152 .51768 L
s
.58689 .37538 m
.60381 .40267 L
s
.63499 .45962 m
.64891 .48867 L
s
.60381 .40267 m
.61991 .43085 L
s
.61991 .43085 m
.63499 .45962 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol006eoo`<07k1oo`00J7oo1@0O0goo100O[7oo001VOol201l<Ool301nYOol0
06Eoo`0301moogoo00moo`807jMoo`00Hgoo0P0O57oo0P0OYGoo001ROol00`0OOomoo`0FOol201nS
Ool0069oo`0301moogoo01Qoo`807j5oo`00HGoo00<07gooOol06goo00<07gooOol0WWoo001POol0
0`0OOomoo`0MOol00`0OOomoo`2MOol0061oo`0301moogoo01ioo`807ieoo`00Ggoo00<07gooOol0
8Goo00<07gooOol0VWoo001OOol00`0OOomoo`0ROol00`0OOomoo`2IOol005ioo`0301moogoo02Ao
o`0301moogoo09Qoo`00GWoo00<07gooOol09Goo0P0OV7oo001NOol00`0OOomoo`0WOol00`0OOomo
o`2EOol005eoo`0301moogoo02Uoo`0301moogoo09Aoo`00GGoo00<07gooOol0:Woo00<07gooOol0
Tgoo001MOol00`0OOomoo`0[Ool00`0OOomoo`2BOol005eoo`0301moogoo02aoo`0301moogoo095o
o`00GGoo00<07gooOol0;Goo00<07gooOol0T7oo001MOol00`0OOomoo`0^Ool00`0OOomoo`2?Ool0
05eoo`0301moogoo02moo`0301moogoo08ioo`00GGoo00<07gooOol0<7oo00<07gooOol0SGoo001M
Ool00`0OOomoo`0aOol00`0OOomoo`2<Ool005eoo`0301moogoo039oo`0301moogoo08]oo`00GGoo
00<07gooOol0<goo00<07gooOol0RWoo001MOol00`0OOomoo`0dOol00`0OOomoo`29Ool005eoo`03
01moogoo03Eoo`0301moogoo08Qoo`00GGoo00<07gooOol0=Goo00<07gooOol0R7oo001MOol00`0O
Oomoo`0fOol00`0OOomoo`27Ool005eoo`0301moogoo03Moo`0301moogoo08Ioo`00GGoo00<07goo
Ool0>7oo00<07gooOol0QGoo001MOol00`0OOomoo`0iOol00`0OOomoo`24Ool005eoo`0301moogoo
03Yoo`0301moogoo08=oo`00GWoo00<07gooOol0>Woo00<07gooOol0PWoo001NOol00`0OOomoo`0j
Ool00`0OOomoo`22Ool005ioo`0301moogoo03]oo`0301moogoo085oo`00GWoo00<07gooOol0?7oo
00<07gooOol0P7oo001NOol00`0OOomoo`0mOol00`0OOomoo`1oOol005ioo`0301moogoo03ioo`03
01moogoo07ioo`00GWoo00<07gooOol0?Woo00<07gooOol0OWoo001NOol00`0OOomoo`0oOol00`0O
Oomoo`1mOol005ioo`0301moogoo041oo`0301moogoo07aoo`00GWoo00<07gooOol0@Goo00<07goo
Ool0Ngoo001OOol00`0OOomoo`10Ool00`0OOomoo`1kOol005moo`0301moogoo045oo`0301moogoo
07Yoo`00H7oo00<07gooOol0@Goo00<07gooOol0NGoo001POol00`0OOomoo`11Ool00`0OOomoo`1i
Ool0061oo`0301moogoo049oo`0301moogoo07Qoo`00H7oo00<07gooOol0@goo00<07gooOol0Mgoo
001POol00`0OOomoo`14Ool00`0OOomoo`1fOol0065oo`0301moogoo04=oo`0301moogoo07Ioo`00
HGoo00<07gooOol0A7oo00<07gooOol0MGoo001QOol00`0OOomoo`15Ool00`0OOomoo`1dOol0065o
o`0301moogoo04Eoo`0301moogoo07Aoo`00HWoo00<07gooOol0AGoo00<07gooOol0Lgoo001ROol0
0`0OOomoo`15Ool00`0OOomoo`1cOol0069oo`0301moogoo04Ioo`0301moogoo079oo`00Hgoo00<0
7gooOol0AWoo00<07gooOol0LGoo001SOol00`0OOomoo`16Ool00`0OOomoo`1aOol006=oo`0301mo
ogoo04Moo`0301moogoo071oo`00I7oo00<07gooOol0AWoo00<07gooOol0L7oo001TOol00`0OOomo
o`17Ool00`0OOomoo`1_Ool006Aoo`0301moogoo04Moo`0301moogoo06moo`00IGoo00<07gooOol0
Agoo00<07gooOol0KWoo001UOol00`0OOomoo`17Ool00`0OOomoo`1^Ool006Eoo`0301moogoo04Qo
o`0301moogoo06eoo`00IWoo00<07gooOol0Agoo00<07gooOol0KGoo001VOol00`0OOomoo`18Ool0
0`0OOomoo`1/Ool006Ioo`0301moogoo04Uoo`0301moogoo06]oo`00IWoo00<07gooOol0BGoo00<0
7gooOol0Jgoo001WOol00`0OOomoo`19Ool00`0OOomoo`1ZOol006Moo`0301moogoo04Uoo`0301mo
ogoo06Yoo`00Igoo00<07gooOol0BWoo00<07gooOol0JGoo001XOol00`0OOomoo`1:Ool00`0OOomo
o`1XOol006Qoo`0301moogoo04Yoo`0301moogoo06Qoo`00J7oo00<07gooOol0Bgoo00<07gooOol0
Igoo001YOol00`0OOomoo`1:Ool00`0OOomoo`1WOol006Uoo`0301moogoo04]oo`0301moogoo06Io
o`00JGoo00<07gooOol0Bgoo00<07gooOol0IWoo001ZOol00`0OOomoo`1;Ool00`0OOomoo`1UOol0
06Yoo`0301moogoo04]oo`0301moogoo06Eoo`00Jgoo00<07gooOol0Bgoo00<07gooOol0I7oo001[
Ool00`0OOomoo`1;Ool00`0OOomoo`1TOol006aoo`0301moogoo04]oo`0301moogoo06=oo`00K7oo
00<07gooOol0Bgoo00<07gooOol0Hgoo001]Ool00`0OOomoo`1:Ool00`0OOomoo`1SOol006eoo`03
01moogoo04]oo`0301moogoo069oo`00KWoo00<07gooOol0BWoo00<07gooOol0HWoo001^Ool00`0O
Oomoo`1:Ool00`0OOomoo`1ROol006moo`0301moogoo04Yoo`0301moogoo065oo`00Kgoo00<07goo
Ool0BWoo00<07gooOol0HGoo001`Ool00`0OOomoo`1:Ool00`0OOomoo`1POol0071oo`0301moogoo
04Yoo`0301moogoo061oo`00LGoo00<07gooOol0BGoo00<07gooOol0H7oo001aOol00`0OOomoo`1:
Ool00`0OOomoo`1OOol0079oo`0301moogoo04Uoo`0301moogoo05moo`00LWoo00<07gooOol0BWoo
00<07gooOol0GWoo001bOol00`0OOomoo`1:Ool00`0OOomoo`1NOol007=oo`0301moogoo04Yoo`03
01moogoo05eoo`00Lgoo00<07gooOol0BWoo00<07gooOol0GGoo001dOol00`0OOomoo`1:Ool00`0O
Oomoo`1LOol007Aoo`0301moogoo04Yoo`0301moogoo05aoo`00MGoo00<07gooOol0BGoo00<07goo
Ool0G7oo001fOol00`0OOomoo`19Ool00`0OOomoo`1KOol007Ioo`0301moogoo04Uoo`0301moogoo
05]oo`00Mgoo00<07gooOol0B7oo00<07gooOol0Fgoo001hOol00`0OOomoo`17Ool00`0OOomoo`1K
Ool007Qoo`0301moogoo04Qoo`0301moogoo05Yoo`00NGoo00<07gooOol0Agoo00<07gooOol0FWoo
001iOol00`0OOomoo`17Ool00`0OOomoo`1JOol007Yoo`0301moogoo04Moo`0301moogoo05Uoo`00
NWoo00<07gooOol0Agoo00<07gooOol0FGoo001kOol00`0OOomoo`16Ool00`0OOomoo`1IOol007]o
o`0301moogoo04Moo`0301moogoo05Qoo`00O7oo00<07gooOol0AWoo00<07gooOol0F7oo001mOol0
0`0OOomoo`16Ool00`0OOomoo`1GOol007eoo`0301moogoo04Ioo`0301moogoo05Moo`00OWoo00<0
7gooOol0AGoo00<07gooOol0Egoo001oOol00`0OOomoo`14Ool00`0OOomoo`1GOol007moo`0301mo
ogoo04Aoo`0301moogoo05Moo`00P7oo00<07gooOol0@goo00<07gooOol0Egoo0021Ool00`0OOomo
o`13Ool00`0OOomoo`1FOol0089oo`0301moogoo049oo`0301moogoo05Ioo`00PWoo00<07gooOol0
@Woo00<07gooOol0EWoo0023Ool00`0OOomoo`11Ool00`0OOomoo`1FOol008Aoo`0301moogoo041o
o`0301moogoo05Ioo`00QGoo00<07gooOol0@7oo00<07gooOol0EGoo0025Ool00`0OOomoo`10Ool0
0`0OOomoo`1EOol008Ioo`0301moogoo03moo`0301moogoo05Eoo`00Qgoo00<07gooOol0?Woo00<0
7gooOol0EGoo0027Ool00`0OOomoo`0oOol00`0OOomoo`1DOol008Qoo`0301moogoo03ioo`0301mo
ogoo05Aoo`00RGoo00<07gooOol0?Goo00<07gooOol0E7oo002:Ool00`0OOomoo`0lOol00`0OOomo
o`1DOol008Yoo`0301moogoo03aoo`0301moogoo05Aoo`00Rgoo00<07gooOol0?7oo00<07gooOol0
Dgoo002<Ool00`0OOomoo`0kOol00`0OOomoo`1COol008eoo`0301moogoo03Yoo`0301moogoo05=o
o`00SWoo00<07gooOol0>Goo00<07gooOol0Dgoo002>Ool00`0OOomoo`0iOol00`0OOomoo`1COol0
08moo`0301moogoo03Qoo`0301moogoo05=oo`00T7oo00<07gooOol0=goo00<07gooOol0Dgoo002A
Ool00`0OOomoo`0fOol00`0OOomoo`1COol0099oo`0301moogoo03Eoo`0301moogoo05=oo`00TWoo
00<07gooOol0=Goo00<07gooOol0Dgoo002COol00`0OOomoo`0dOol00`0OOomoo`1COol009Aoo`03
01moogoo03=oo`0301moogoo05=oo`00UGoo00<07gooOol0<Woo00<07gooOol0Dgoo002FOol00`0O
Oomoo`0aOol00`0OOomoo`1COol009Moo`0301moogoo031oo`0301moogoo05=oo`00V7oo00<07goo
Ool0;goo00<07gooOol0Dgoo002IOol00`0OOomoo`0]Ool00`0OOomoo`1DOol009Yoo`0301moogoo
02aoo`0301moogoo05Aoo`00Vgoo00<07gooOol0:goo00<07gooOol0E7oo002LOol00`0OOomoo`0Z
Ool00`0OOomoo`1DOol009eoo`0301moogoo02Uoo`0301moogoo05Aoo`00WWoo0P0O:7oo00<07goo
Ool0EGoo002POol00`0OOomoo`0UOol00`0OOomoo`1EOol00:5oo`0301moogoo02Aoo`0301moogoo
05Eoo`00XWoo00<07gooOol08goo00<07gooOol0EGoo002SOol00`0OOomoo`0QOol00`0OOomoo`1F
Ool00:Aoo`0301moogoo021oo`0301moogoo05Ioo`00YGoo0P0O7goo00<07gooOol0Egoo002WOol2
01lMOol00`0OOomoo`1GOol00:Uoo`0301moogoo01Uoo`0301moogoo05Qoo`00ZWoo0P0O67oo00<0
7gooOol0FGoo002/Ool00`0OOomoo`0EOol00`0OOomoo`1IOol00:eoo`807a=oo`807eaoo`00[goo
0`0O3Woo0P0OGWoo002bOol401l7Ool301mPOol00;Ioo`L07f=oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.4166 .55161 m
.40368 .53092 L
s
.43004 .57198 m
.4166 .55161 L
s
.44394 .59192 m
.43004 .57198 L
s
.40368 .53092 m
.39135 .50999 L
s
.45825 .61135 m
.44394 .59192 L
s
.39135 .50999 m
.37966 .48892 L
s
.4729 .63018 m
.45825 .61135 L
s
.37966 .48892 m
.36867 .4678 L
s
.48782 .6483 m
.4729 .63018 L
s
.36867 .4678 m
.35845 .44674 L
s
.50295 .66563 m
.48782 .6483 L
s
.35845 .44674 m
.34904 .42583 L
s
.51822 .68208 m
.50295 .66563 L
s
.34904 .42583 m
.3405 .40518 L
s
.53355 .69754 m
.51822 .68208 L
s
.3405 .40518 m
.3329 .38489 L
s
.54887 .71191 m
.53355 .69754 L
s
.3329 .38489 m
.32628 .36508 L
s
.5641 .72511 m
.54887 .71191 L
s
.32628 .36508 m
.32071 .34585 L
s
.57916 .73703 m
.5641 .72511 L
s
.32071 .34585 m
.31623 .32733 L
s
.59395 .74758 m
.57916 .73703 L
s
.31623 .32733 m
.31291 .30963 L
s
.60839 .75665 m
.59395 .74758 L
s
.31291 .30963 m
.3108 .29288 L
s
.62239 .76415 m
.60839 .75665 L
s
.3108 .29288 m
.30993 .2772 L
s
.63583 .76998 m
.62239 .76415 L
s
.30993 .2772 m
.31037 .26274 L
s
.64862 .77406 m
.63583 .76998 L
s
.31037 .26274 m
.31214 .24961 L
s
.66066 .77629 m
.64862 .77406 L
s
.31214 .24961 m
.31528 .23795 L
s
.67183 .7766 m
.66066 .77629 L
s
.31528 .23795 m
.31983 .22789 L
s
.68203 .77491 m
.67183 .7766 L
s
.31983 .22789 m
.32578 .21957 L
s
.69114 .77116 m
.68203 .77491 L
s
.32578 .21957 m
.33317 .2131 L
s
.69905 .76531 m
.69114 .77116 L
s
.33317 .2131 m
.34197 .20861 L
s
.70567 .75733 m
.69905 .76531 L
s
.34197 .20861 m
.35218 .20619 L
s
.71088 .74719 m
.70567 .75733 L
s
.35218 .20619 m
.36376 .20596 L
s
.71459 .73492 m
.71088 .74719 L
s
.36376 .20596 m
.37667 .20798 L
s
.71672 .72053 m
.71459 .73492 L
s
.37667 .20798 m
.39083 .21233 L
s
.7172 .70409 m
.71672 .72053 L
s
.39083 .21233 m
.40617 .21904 L
s
.71596 .68568 m
.7172 .70409 L
s
.40617 .21904 m
.42258 .22812 L
s
.71297 .6654 m
.71596 .68568 L
s
.42258 .22812 m
.43994 .23957 L
s
.70819 .64341 m
.71297 .6654 L
s
.43994 .23957 m
.4581 .25334 L
s
.70164 .61987 m
.70819 .64341 L
s
.4581 .25334 m
.47692 .26936 L
s
.69332 .59498 m
.70164 .61987 L
s
.47692 .26936 m
.49621 .28752 L
s
.6833 .56897 m
.69332 .59498 L
s
.49621 .28752 m
.51579 .30768 L
s
.67163 .54208 m
.6833 .56897 L
s
.51579 .30768 m
.53546 .32966 L
s
.65843 .51459 m
.67163 .54208 L
s
.53546 .32966 m
.55501 .35327 L
s
.6438 .48678 m
.65843 .51459 L
s
.55501 .35327 m
.57424 .37826 L
s
.6279 .45895 m
.6438 .48678 L
s
.57424 .37826 m
.59293 .40439 L
s
.61088 .43138 m
.6279 .45895 L
s
.59293 .40439 m
.61088 .43138 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.42428 .55004 m
.40991 .53024 L
s
.43912 .56951 m
.42428 .55004 L
s
.45437 .58857 m
.43912 .56951 L
s
.40991 .53024 m
.39609 .51021 L
s
.46995 .60712 m
.45437 .58857 L
s
.39609 .51021 m
.38286 .49004 L
s
.4858 .62508 m
.46995 .60712 L
s
.38286 .49004 m
.37031 .46982 L
s
.50185 .64237 m
.4858 .62508 L
s
.37031 .46982 m
.3585 .44964 L
s
.51802 .65888 m
.50185 .64237 L
s
.3585 .44964 m
.34749 .4296 L
s
.53423 .67453 m
.51802 .65888 L
s
.34749 .4296 m
.33735 .4098 L
s
.55041 .68924 m
.53423 .67453 L
s
.33735 .4098 m
.32814 .39035 L
s
.56647 .70289 m
.55041 .68924 L
s
.32814 .39035 m
.31993 .37134 L
s
.58233 .71542 m
.56647 .70289 L
s
.31993 .37134 m
.31279 .3529 L
s
.5979 .72671 m
.58233 .71542 L
s
.31279 .3529 m
.30677 .33513 L
s
.61308 .73668 m
.5979 .72671 L
s
.30677 .33513 m
.30195 .31814 L
s
.62778 .74524 m
.61308 .73668 L
s
.30195 .31814 m
.29838 .30207 L
s
.6419 .75229 m
.62778 .74524 L
s
.29838 .30207 m
.29612 .28703 L
s
.65534 .75775 m
.6419 .75229 L
s
.29612 .28703 m
.29523 .27314 L
s
.66799 .76153 m
.65534 .75775 L
s
.29523 .27314 m
.29575 .26054 L
s
.67973 .76354 m
.66799 .76153 L
s
.29575 .26054 m
.29774 .24935 L
s
.69046 .76372 m
.67973 .76354 L
s
.29774 .24935 m
.30123 .2397 L
s
.70007 .762 m
.69046 .76372 L
s
.30123 .2397 m
.30624 .23171 L
s
.70845 .75832 m
.70007 .762 L
s
.30624 .23171 m
.3128 .2255 L
s
.71548 .75263 m
.70845 .75832 L
s
.3128 .2255 m
.32091 .22118 L
s
.72108 .74492 m
.71548 .75263 L
s
.32091 .22118 m
.33057 .21886 L
s
.72513 .73517 m
.72108 .74492 L
s
.33057 .21886 m
.34174 .21863 L
s
.72754 .72338 m
.72513 .73517 L
s
.34174 .21863 m
.3544 .22056 L
s
.72825 .70959 m
.72754 .72338 L
s
.3544 .22056 m
.36848 .22471 L
s
.72719 .69385 m
.72825 .70959 L
s
.36848 .22471 m
.38389 .23112 L
s
.7243 .67625 m
.72719 .69385 L
s
.38389 .23112 m
.40056 .2398 L
s
.71957 .65688 m
.7243 .67625 L
s
.40056 .2398 m
.41834 .25074 L
s
.71297 .63588 m
.71957 .65688 L
s
.41834 .25074 m
.43711 .26389 L
s
.70453 .61342 m
.71297 .63588 L
s
.43711 .26389 m
.4567 .27919 L
s
.69428 .58968 m
.70453 .61342 L
s
.4567 .27919 m
.47693 .29653 L
s
.68229 .56488 m
.69428 .58968 L
s
.47693 .29653 m
.49761 .31577 L
s
.66865 .53925 m
.68229 .56488 L
s
.49761 .31577 m
.51853 .33674 L
s
.65348 .51305 m
.66865 .53925 L
s
.51853 .33674 m
.53948 .35926 L
s
.63691 .48654 m
.65348 .51305 L
s
.53948 .35926 m
.56023 .3831 L
s
.61911 .46001 m
.63691 .48654 L
s
.56023 .3831 m
.58057 .40801 L
s
.60026 .43374 m
.61911 .46001 L
s
.58057 .40801 m
.60026 .43374 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.43325 .5468 m
.41755 .528 L
s
.44936 .56529 m
.43325 .5468 L
s
.4658 .58339 m
.44936 .56529 L
s
.41755 .528 m
.40234 .50898 L
s
.48252 .60102 m
.4658 .58339 L
s
.40234 .50898 m
.38769 .48982 L
s
.49942 .61808 m
.48252 .60102 L
s
.38769 .48982 m
.37367 .47061 L
s
.51644 .6345 m
.49942 .61808 L
s
.37367 .47061 m
.36035 .45145 L
s
.53348 .65018 m
.51644 .6345 L
s
.36035 .45145 m
.34781 .43243 L
s
.55048 .66505 m
.53348 .65018 L
s
.34781 .43243 m
.33612 .41364 L
s
.56734 .67902 m
.55048 .66505 L
s
.33612 .41364 m
.32536 .39518 L
s
.58398 .692 m
.56734 .67902 L
s
.32536 .39518 m
.31559 .37715 L
s
.60031 .7039 m
.58398 .692 L
s
.31559 .37715 m
.30689 .35966 L
s
.61622 .71464 m
.60031 .7039 L
s
.30689 .35966 m
.29934 .34281 L
s
.63164 .72412 m
.61622 .71464 L
s
.29934 .34281 m
.293 .32671 L
s
.64644 .73226 m
.63164 .72412 L
s
.293 .32671 m
.28795 .31149 L
s
.66054 .73898 m
.64644 .73226 L
s
.28795 .31149 m
.28425 .29725 L
s
.67382 .74418 m
.66054 .73898 L
s
.28425 .29725 m
.28198 .28412 L
s
.68617 .7478 m
.67382 .74418 L
s
.28198 .28412 m
.28119 .27222 L
s
.69749 .74974 m
.68617 .7478 L
s
.28119 .27222 m
.28193 .26167 L
s
.70766 .74995 m
.69749 .74974 L
s
.28193 .26167 m
.28426 .25258 L
s
.71656 .74837 m
.70766 .74995 L
s
.28426 .25258 m
.28822 .24508 L
s
.7241 .74492 m
.71656 .74837 L
s
.28822 .24508 m
.29383 .23927 L
s
.73016 .73959 m
.7241 .74492 L
s
.29383 .23927 m
.30111 .23527 L
s
.73464 .73234 m
.73016 .73959 L
s
.30111 .23527 m
.31006 .23317 L
s
.73746 .72315 m
.73464 .73234 L
s
.31006 .23317 m
.32067 .23306 L
s
.73852 .71204 m
.73746 .72315 L
s
.32067 .23306 m
.33291 .235 L
s
.73776 .69904 m
.73852 .71204 L
s
.33291 .235 m
.34673 .23905 L
s
.73513 .68419 m
.73776 .69904 L
s
.34673 .23905 m
.36205 .24524 L
s
.73058 .66758 m
.73513 .68419 L
s
.36205 .24524 m
.37878 .25359 L
s
.7241 .64929 m
.73058 .66758 L
s
.37878 .25359 m
.39681 .26408 L
s
.71569 .62946 m
.7241 .64929 L
s
.39681 .26408 m
.41599 .27666 L
s
.70539 .60824 m
.71569 .62946 L
s
.41599 .27666 m
.43616 .29126 L
s
.69325 .5858 m
.70539 .60824 L
s
.43616 .29126 m
.45715 .30779 L
s
.67935 .56235 m
.69325 .5858 L
s
.45715 .30779 m
.47875 .32612 L
s
.6638 .5381 m
.67935 .56235 L
s
.47875 .32612 m
.50075 .34607 L
s
.64674 .5133 m
.6638 .5381 L
s
.50075 .34607 m
.52293 .36748 L
s
.62833 .48821 m
.64674 .5133 L
s
.52293 .36748 m
.54506 .39012 L
s
.60875 .46307 m
.62833 .48821 L
s
.54506 .39012 m
.56689 .41377 L
s
.58819 .43817 m
.60875 .46307 L
s
.56689 .41377 m
.58819 .43817 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001HOol601o2Ool005Ioo`80
7`Ioo`<07kmoo`00E7oo0P0O2goo0`0O_7oo001COol00`0OOomoo`0>Ool201njOol0059oo`0301mo
ogoo015oo`<07kMoo`00DGoo00<07gooOol05Goo0P0O]Goo001AOol00`0OOomoo`0GOol201ncOol0
055oo`0301moogoo01Uoo`807k5oo`00D7oo00<07gooOol077oo0P0O[goo001@Ool00`0OOomoo`0N
Ool00`0OOomoo`2/Ool0051oo`0301moogoo01moo`807jaoo`00D7oo00<07gooOol08Goo00<07goo
Ool0ZGoo001@Ool00`0OOomoo`0ROol201nYOol0051oo`0301moogoo02Aoo`0301moogoo0:Ioo`00
D7oo00<07gooOol09Goo0P0OYWoo001@Ool00`0OOomoo`0WOol00`0OOomoo`2SOol0051oo`0301mo
ogoo02Qoo`807j=oo`00D7oo00<07gooOol0:Woo00<07gooOol0X7oo001AOol00`0OOomoo`0ZOol0
0`0OOomoo`2OOol0055oo`0301moogoo02]oo`0301moogoo09ioo`00DGoo00<07gooOol0;7oo0P0O
WWoo001AOol00`0OOomoo`0^Ool00`0OOomoo`2KOol0059oo`0301moogoo02ioo`0301moogoo09Yo
o`00DWoo00<07gooOol0;goo00<07gooOol0VGoo001BOol00`0OOomoo`0`Ool00`0OOomoo`2HOol0
05=oo`0301moogoo031oo`807iQoo`00Dgoo00<07gooOol0<Woo00<07gooOol0UGoo001DOol00`0O
Oomoo`0bOol00`0OOomoo`2DOol005Aoo`0301moogoo03=oo`0301moogoo09=oo`00E7oo00<07goo
Ool0=7oo00<07gooOol0TWoo001EOol00`0OOomoo`0dOol00`0OOomoo`2AOol005Eoo`0301moogoo
03Eoo`0301moogoo091oo`00EGoo00<07gooOol0=Woo00<07gooOol0Sgoo001FOol00`0OOomoo`0f
Ool00`0OOomoo`2>Ool005Ioo`0301moogoo03Moo`0301moogoo08eoo`00Egoo00<07gooOol0=goo
00<07gooOol0S7oo001GOol00`0OOomoo`0hOol201n<Ool005Qoo`0301moogoo03Uoo`0301moogoo
08Uoo`00F7oo00<07gooOol0>Woo00<07gooOol0R7oo001IOol00`0OOomoo`0jOol00`0OOomoo`27
Ool005Uoo`0301moogoo03]oo`0301moogoo08Ioo`00FWoo00<07gooOol0>goo00<07gooOol0QGoo
001JOol00`0OOomoo`0lOol00`0OOomoo`24Ool005]oo`0301moogoo03aoo`0301moogoo08=oo`00
Fgoo00<07gooOol0?Goo00<07gooOol0PWoo001LOol00`0OOomoo`0mOol00`0OOomoo`21Ool005ao
o`0301moogoo03ioo`0301moogoo081oo`00GGoo00<07gooOol0?Woo00<07gooOol0Ogoo001NOol0
0`0OOomoo`0nOol00`0OOomoo`1nOol005ioo`0301moogoo03ioo`0301moogoo07ioo`00Ggoo00<0
7gooOol0?Woo00<07gooOol0OGoo001OOol00`0OOomoo`0oOol00`0OOomoo`1lOol0061oo`0301mo
ogoo03moo`0301moogoo07]oo`00H7oo00<07gooOol0@7oo00<07gooOol0NWoo001QOol00`0OOomo
o`10Ool00`0OOomoo`1iOol0065oo`0301moogoo045oo`0301moogoo07Qoo`00HWoo00<07gooOol0
@7oo00<07gooOol0N7oo001ROol00`0OOomoo`11Ool00`0OOomoo`1gOol006=oo`0301moogoo045o
o`0301moogoo07Ioo`00I7oo00<07gooOol0@Goo00<07gooOol0MGoo001UOol00`0OOomoo`11Ool0
0`0OOomoo`1dOol006Eoo`0301moogoo049oo`0301moogoo07=oo`00IWoo00<07gooOol0@Woo00<0
7gooOol0LWoo001WOol00`0OOomoo`11Ool00`0OOomoo`1bOol006Qoo`0301moogoo045oo`0301mo
ogoo075oo`00J7oo00<07gooOol0@Woo00<07gooOol0L7oo001YOol00`0OOomoo`12Ool00`0OOomo
o`1_Ool006Yoo`0301moogoo049oo`0301moogoo06ioo`00JWoo00<07gooOol0@Woo00<07gooOol0
KWoo001[Ool00`0OOomoo`12Ool00`0OOomoo`1]Ool006aoo`0301moogoo049oo`0301moogoo06ao
o`00KGoo00<07gooOol0@Woo00<07gooOol0Jgoo001]Ool00`0OOomoo`12Ool00`0OOomoo`1[Ool0
06ioo`0301moogoo049oo`0301moogoo06Yoo`00Kgoo00<07gooOol0@Woo00<07gooOol0JGoo001`
Ool00`0OOomoo`12Ool00`0OOomoo`1XOol0071oo`0301moogoo049oo`0301moogoo06Qoo`00LGoo
00<07gooOol0@Woo00<07gooOol0Igoo001bOol00`0OOomoo`12Ool00`0OOomoo`1VOol0079oo`03
01moogoo04=oo`0301moogoo06Eoo`00Lgoo00<07gooOol0@Woo00<07gooOol0IGoo001dOol00`0O
Oomoo`12Ool00`0OOomoo`1TOol007Eoo`0301moogoo049oo`0301moogoo06=oo`00MGoo00<07goo
Ool0@Woo00<07gooOol0Hgoo001fOol00`0OOomoo`12Ool00`0OOomoo`1ROol007Moo`0301moogoo
049oo`0301moogoo065oo`00N7oo00<07gooOol0@Woo00<07gooOol0H7oo001iOol00`0OOomoo`11
Ool00`0OOomoo`1POol007Yoo`0301moogoo045oo`0301moogoo05moo`00Ngoo00<07gooOol0@Goo
00<07gooOol0GWoo001lOol00`0OOomoo`10Ool00`0OOomoo`1NOol007eoo`0301moogoo041oo`03
01moogoo05eoo`00OGoo00<07gooOol0@7oo00<07gooOol0GGoo001nOol00`0OOomoo`10Ool00`0O
Oomoo`1LOol007moo`0301moogoo03moo`0301moogoo05aoo`00Ogoo00<07gooOol0@7oo00<07goo
Ool0Fgoo0020Ool00`0OOomoo`10Ool00`0OOomoo`1JOol0085oo`0301moogoo03moo`0301moogoo
05Yoo`00PWoo00<07gooOol0?goo00<07gooOol0FGoo0023Ool00`0OOomoo`0nOol00`0OOomoo`1I
Ool008Aoo`0301moogoo03ioo`0301moogoo05Qoo`00QGoo00<07gooOol0?Goo00<07gooOol0F7oo
0026Ool00`0OOomoo`0mOol00`0OOomoo`1GOol008Moo`0301moogoo03eoo`0301moogoo05Ioo`00
R7oo00<07gooOol0?7oo00<07gooOol0EWoo0029Ool00`0OOomoo`0lOol00`0OOomoo`1EOol008Yo
o`0301moogoo03aoo`0301moogoo05Aoo`00Rgoo00<07gooOol0>goo00<07gooOol0E7oo002<Ool0
0`0OOomoo`0kOol00`0OOomoo`1COol008eoo`0301moogoo03Yoo`0301moogoo05=oo`00SWoo00<0
7gooOol0>Woo00<07gooOol0DWoo002?Ool00`0OOomoo`0iOol00`0OOomoo`1BOol0091oo`0301mo
ogoo03Uoo`0301moogoo055oo`00TGoo00<07gooOol0>7oo00<07gooOol0DGoo002BOol00`0OOomo
o`0hOol00`0OOomoo`1@Ool009=oo`0301moogoo03Moo`0301moogoo051oo`00U7oo00<07gooOol0
=goo00<07gooOol0Cgoo002EOol00`0OOomoo`0fOol00`0OOomoo`1?Ool009Ioo`807cIoo`0301mo
ogoo04moo`00V7oo00<07gooOol0=7oo00<07gooOol0CWoo002IOol00`0OOomoo`0cOol00`0OOomo
o`1>Ool009Yoo`0301moogoo039oo`0301moogoo04ioo`00Vgoo00<07gooOol0<Woo00<07gooOol0
CGoo002LOol00`0OOomoo`0aOol00`0OOomoo`1=Ool009eoo`0301moogoo035oo`0301moogoo04ao
o`00WWoo00<07gooOol0<7oo00<07gooOol0C7oo002OOol201l`Ool00`0OOomoo`1<Ool00:5oo`03
01moogoo02eoo`0301moogoo04aoo`00XWoo00<07gooOol0;Goo00<07gooOol0Bgoo002SOol00`0O
Oomoo`0/Ool00`0OOomoo`1;Ool00:Aoo`807baoo`0301moogoo04]oo`00YWoo00<07gooOol0:Goo
00<07gooOol0Bgoo002WOol00`0OOomoo`0XOol00`0OOomoo`1;Ool00:Qoo`0301moogoo02Qoo`03
01moogoo04Yoo`00ZGoo0P0O:7oo00<07gooOol0BWoo002[Ool00`0OOomoo`0UOol00`0OOomoo`1:
Ool00:aoo`0301moogoo02Aoo`0301moogoo04Yoo`00[Goo00<07gooOol08goo00<07gooOol0BWoo
002^Ool201lSOol00`0OOomoo`1:Ool00;1oo`807b5oo`0301moogoo04Yoo`00/Woo0P0O7goo00<0
7gooOol0BWoo002dOol201lMOol00`0OOomoo`1:Ool00;Ioo`0301moogoo01Yoo`0301moogoo04Yo
o`00]goo0P0O6Goo00<07gooOol0Bgoo002iOol00`0OOomoo`0FOol00`0OOomoo`1;Ool00;Yoo`80
7aEoo`0301moogoo04aoo`00_7oo0`0O4Woo00<07gooOol0C7oo002oOol401l<Ool201m?Ool00<=o
o`<07`Moo`807e5oo`00aWoo1`0ODgoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.44323 .54182 m
.42633 .52407 L
s
.46048 .5593 m
.44323 .54182 L
s
.478 .57642 m
.46048 .5593 L
s
.42633 .52407 m
.40985 .50612 L
s
.49571 .5931 m
.478 .57642 L
s
.40985 .50612 m
.39388 .48805 L
s
.51352 .60926 m
.49571 .5931 L
s
.39388 .48805 m
.37849 .46996 L
s
.53136 .62483 m
.51352 .60926 L
s
.37849 .46996 m
.36376 .45192 L
s
.54914 .63972 m
.53136 .62483 L
s
.36376 .45192 m
.34977 .43402 L
s
.56677 .65385 m
.54914 .63972 L
s
.34977 .43402 m
.33661 .41635 L
s
.58417 .66714 m
.56677 .65385 L
s
.33661 .41635 m
.32434 .39901 L
s
.60124 .67951 m
.58417 .66714 L
s
.32434 .39901 m
.31306 .3821 L
s
.61789 .69087 m
.60124 .67951 L
s
.31306 .3821 m
.30285 .3657 L
s
.63401 .70114 m
.61789 .69087 L
s
.30285 .3657 m
.29377 .34992 L
s
.64952 .71025 m
.63401 .70114 L
s
.29377 .34992 m
.28593 .33487 L
s
.66429 .7181 m
.64952 .71025 L
s
.28593 .33487 m
.27939 .32065 L
s
.67824 .72461 m
.66429 .7181 L
s
.27939 .32065 m
.27424 .30738 L
s
.69124 .72971 m
.67824 .72461 L
s
.27424 .30738 m
.27055 .29517 L
s
.70318 .73332 m
.69124 .72971 L
s
.27055 .29517 m
.26839 .28413 L
s
.71396 .73536 m
.70318 .73332 L
s
.26839 .28413 m
.26783 .27438 L
s
.72346 .73577 m
.71396 .73536 L
s
.26783 .27438 m
.26893 .26602 L
s
.73157 .73449 m
.72346 .73577 L
s
.26893 .26602 m
.27174 .25916 L
s
.73819 .73147 m
.73157 .73449 L
s
.27174 .25916 m
.27629 .25392 L
s
.7432 .72667 m
.73819 .73147 L
s
.27629 .25392 m
.28263 .25039 L
s
.74651 .72006 m
.7432 .72667 L
s
.28263 .25039 m
.29075 .24865 L
s
.74804 .71163 m
.74651 .72006 L
s
.29075 .24865 m
.30066 .2488 L
s
.74771 .70138 m
.74804 .71163 L
s
.30066 .2488 m
.31234 .25088 L
s
.74545 .68934 m
.74771 .70138 L
s
.31234 .25088 m
.32574 .25496 L
s
.74123 .67556 m
.74545 .68934 L
s
.32574 .25496 m
.3408 .26105 L
s
.73501 .66009 m
.74123 .67556 L
s
.3408 .26105 m
.35743 .26917 L
s
.7268 .64304 m
.73501 .66009 L
s
.35743 .26917 m
.37552 .2793 L
s
.7166 .62453 m
.7268 .64304 L
s
.37552 .2793 m
.39494 .29139 L
s
.70447 .60468 m
.7166 .62453 L
s
.39494 .29139 m
.41553 .30538 L
s
.69049 .58366 m
.70447 .60468 L
s
.41553 .30538 m
.4371 .32116 L
s
.67474 .56167 m
.69049 .58366 L
s
.4371 .32116 m
.45945 .33861 L
s
.65736 .5389 m
.67474 .56167 L
s
.45945 .33861 m
.48238 .35759 L
s
.6385 .51559 m
.65736 .5389 L
s
.48238 .35759 m
.50563 .3779 L
s
.61834 .49197 m
.6385 .51559 L
s
.50563 .3779 m
.52898 .39936 L
s
.59709 .46828 m
.61834 .49197 L
s
.52898 .39936 m
.55216 .42173 L
s
.57495 .44479 m
.59709 .46828 L
s
.55216 .42173 m
.57495 .44479 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00DGoo1`0Ob7oo001?Ool201l7Ool301o5Ool004ioo`0301mo
ogoo00Yoo`@07l5oo`00CGoo00<07gooOol03goo0`0O_Woo001=Ool00`0OOomoo`0BOol201nlOol0
04eoo`0301moogoo01Aoo`807kYoo`00C7oo00<07gooOol05goo00<07gooOol0]goo001<Ool00`0O
Oomoo`0HOol201ngOol004aoo`0301moogoo01Yoo`807kEoo`00CGoo00<07gooOol06goo00<07goo
Ool0/Woo001=Ool00`0OOomoo`0LOol201nbOol004eoo`0301moogoo01ioo`807k1oo`00CGoo00<0
7gooOol087oo0P0O[Woo001=Ool00`0OOomoo`0ROol201n/Ool004eoo`0301moogoo02Aoo`0301mo
ogoo0:Uoo`00CGoo00<07gooOol09Goo0P0OZGoo001>Ool00`0OOomoo`0VOol00`0OOomoo`2VOol0
04ioo`0301moogoo02Moo`0301moogoo0:Eoo`00CWoo00<07gooOol0:7oo00<07gooOol0Y7oo001?
Ool00`0OOomoo`0XOol201nTOol004moo`0301moogoo02Yoo`0301moogoo0:5oo`00D7oo00<07goo
Ool0:Woo00<07gooOol0X7oo001@Ool00`0OOomoo`0[Ool00`0OOomoo`2OOol0055oo`0301moogoo
02]oo`0301moogoo09ioo`00DGoo00<07gooOol0;7oo0P0OWWoo001BOol00`0OOomoo`0]Ool00`0O
Oomoo`2KOol0059oo`0301moogoo02ioo`0301moogoo09Yoo`00Dgoo00<07gooOol0;Woo0P0OVWoo
001COol00`0OOomoo`0`Ool00`0OOomoo`2GOol005Aoo`0301moogoo031oo`0301moogoo09Ioo`00
E7oo00<07gooOol0<Goo0P0OUWoo001EOol00`0OOomoo`0bOol00`0OOomoo`2COol005Eoo`0301mo
ogoo03=oo`0301moogoo099oo`00EWoo00<07gooOol0<goo00<07gooOol0TGoo001GOol00`0OOomo
o`0cOol201nAOol005Moo`0301moogoo03Eoo`0301moogoo08ioo`00F7oo00<07gooOol0=Goo00<0
7gooOol0SGoo001HOol00`0OOomoo`0fOol00`0OOomoo`2<Ool005Uoo`0301moogoo03Ioo`0301mo
ogoo08]oo`00FWoo00<07gooOol0=Woo00<07gooOol0RWoo001KOol00`0OOomoo`0fOol00`0OOomo
o`29Ool005]oo`0301moogoo03Moo`0301moogoo08Qoo`00G7oo00<07gooOol0=goo00<07gooOol0
Qgoo001MOol00`0OOomoo`0gOol00`0OOomoo`26Ool005ioo`0301moogoo03Moo`0301moogoo08Eo
o`00GWoo00<07gooOol0>7oo00<07gooOol0Q7oo001OOol00`0OOomoo`0hOol00`0OOomoo`23Ool0
05moo`0301moogoo03Uoo`0301moogoo089oo`00H7oo00<07gooOol0>Goo00<07gooOol0PGoo001Q
Ool00`0OOomoo`0iOol00`0OOomoo`20Ool0069oo`0301moogoo03Uoo`0301moogoo07moo`00HWoo
00<07gooOol0>Woo00<07gooOol0OWoo001SOol00`0OOomoo`0jOol00`0OOomoo`1mOol006Aoo`03
01moogoo03Yoo`807geoo`00IGoo00<07gooOol0>goo00<07gooOol0NWoo001VOol00`0OOomoo`0k
Ool00`0OOomoo`1iOol006Ioo`0301moogoo03aoo`0301moogoo07Qoo`00Igoo00<07gooOol0?7oo
00<07gooOol0Mgoo001XOol00`0OOomoo`0lOol00`0OOomoo`1fOol006Uoo`0301moogoo03aoo`03
01moogoo07Eoo`00JWoo00<07gooOol0>goo00<07gooOol0MGoo001ZOol00`0OOomoo`0lOol00`0O
Oomoo`1dOol006]oo`0301moogoo03aoo`0301moogoo07=oo`00K7oo00<07gooOol0?7oo00<07goo
Ool0LWoo001]Ool00`0OOomoo`0lOol00`0OOomoo`1aOol006ioo`0301moogoo03aoo`0301moogoo
071oo`00KWoo00<07gooOol0?Goo00<07gooOol0Kgoo001_Ool00`0OOomoo`0lOol00`0OOomoo`1_
Ool0071oo`0301moogoo03aoo`0301moogoo06ioo`00LGoo00<07gooOol0?7oo00<07gooOol0KGoo
001bOol00`0OOomoo`0lOol00`0OOomoo`1/Ool007=oo`0301moogoo03aoo`0301moogoo06]oo`00
Lgoo00<07gooOol0?Goo00<07gooOol0JWoo001dOol00`0OOomoo`0mOol00`0OOomoo`1YOol007Eo
o`0301moogoo03eoo`0301moogoo06Qoo`00MWoo00<07gooOol0?Goo00<07gooOol0Igoo001gOol0
0`0OOomoo`0mOol00`0OOomoo`1VOol007Qoo`0301moogoo03eoo`0301moogoo06Eoo`00NGoo00<0
7gooOol0?7oo00<07gooOol0IGoo001jOol00`0OOomoo`0lOol00`0OOomoo`1TOol007]oo`0301mo
ogoo03aoo`0301moogoo06=oo`00O7oo00<07gooOol0?7oo00<07gooOol0HWoo001mOol00`0OOomo
o`0kOol00`0OOomoo`1ROol007ioo`0301moogoo03]oo`0301moogoo065oo`00Ogoo00<07gooOol0
>goo00<07gooOol0H7oo0020Ool00`0OOomoo`0jOol00`0OOomoo`1POol0085oo`0301moogoo03Yo
o`0301moogoo05moo`00PWoo00<07gooOol0>Woo00<07gooOol0GWoo0023Ool00`0OOomoo`0jOol0
0`0OOomoo`1MOol008Aoo`0301moogoo03Uoo`0301moogoo05eoo`00QGoo00<07gooOol0>Goo00<0
7gooOol0G7oo0026Ool00`0OOomoo`0iOol00`0OOomoo`1KOol008Moo`0301moogoo03Uoo`0301mo
ogoo05Yoo`00R7oo00<07gooOol0>7oo00<07gooOol0FWoo0029Ool00`0OOomoo`0hOol00`0OOomo
o`1IOol008Yoo`0301moogoo03Qoo`0301moogoo05Qoo`00Rgoo00<07gooOol0>7oo00<07gooOol0
Egoo002<Ool00`0OOomoo`0hOol00`0OOomoo`1FOol008eoo`0301moogoo03Moo`0301moogoo05Io
o`00SWoo00<07gooOol0=goo00<07gooOol0EGoo002?Ool00`0OOomoo`0gOol00`0OOomoo`1DOol0
091oo`807cMoo`0301moogoo05Aoo`00TWoo00<07gooOol0=Goo00<07gooOol0Dgoo002COol00`0O
Oomoo`0dOol00`0OOomoo`1COol009Aoo`0301moogoo03Aoo`0301moogoo059oo`00UGoo00<07goo
Ool0<goo00<07gooOol0DWoo002FOol00`0OOomoo`0cOol00`0OOomoo`1AOol009Moo`0301moogoo
039oo`0301moogoo055oo`00V7oo00<07gooOol0<Woo00<07gooOol0D7oo002IOol00`0OOomoo`0b
Ool00`0OOomoo`1?Ool009Yoo`807c9oo`0301moogoo04moo`00W7oo00<07gooOol0<7oo00<07goo
Ool0CWoo002MOol00`0OOomoo`0_Ool00`0OOomoo`1>Ool009ioo`0301moogoo02moo`0301moogoo
04eoo`00Wgoo0P0O;goo00<07gooOol0CGoo002QOol00`0OOomoo`0]Ool00`0OOomoo`1<Ool00:9o
o`0301moogoo02aoo`0301moogoo04aoo`00Xgoo00<07gooOol0;7oo00<07gooOol0Bgoo002TOol2
01l/Ool00`0OOomoo`1;Ool00:Ioo`0301moogoo02Uoo`0301moogoo04]oo`00Ygoo00<07gooOol0
:Goo00<07gooOol0BWoo002XOol00`0OOomoo`0XOol00`0OOomoo`1:Ool00:Uoo`807bUoo`0301mo
ogoo04Uoo`00Zgoo00<07gooOol09Woo00<07gooOol0BGoo002/Ool00`0OOomoo`0UOol00`0OOomo
o`19Ool00:eoo`807bIoo`0301moogoo04Qoo`00[goo0P0O97oo00<07gooOol0B7oo002aOol00`0O
Oomoo`0QOol00`0OOomoo`18Ool00;9oo`0301moogoo021oo`0301moogoo04Qoo`00/goo0P0O8Goo
00<07gooOol0Agoo002eOol201lOOol00`0OOomoo`17Ool00;Moo`807aeoo`0301moogoo04Moo`00
^Goo0P0O6goo00<07gooOol0Agoo002kOol00`0OOomoo`0HOol00`0OOomoo`17Ool00;aoo`807aQo
o`0301moogoo04Moo`00_Woo0P0O5Woo00<07gooOol0Agoo0030Ool301lBOol00`0OOomoo`18Ool0
0<=oo`807a1oo`0301moogoo04Qoo`00aGoo0`0O2goo0P0OBgoo0038Ool301l6Ool201m=Ool00<]o
o`H07dmoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.45406 .53503 m
.43609 .51836 L
s
.47231 .55147 m
.45406 .53503 L
s
.49075 .5676 m
.47231 .55147 L
s
.43609 .51836 m
.41848 .50153 L
s
.5093 .58334 m
.49075 .5676 L
s
.41848 .50153 m
.40131 .48462 L
s
.52787 .59862 m
.5093 .58334 L
s
.40131 .48462 m
.38468 .46771 L
s
.54638 .61337 m
.52787 .59862 L
s
.38468 .46771 m
.36865 .45087 L
s
.56474 .6275 m
.54638 .61337 L
s
.36865 .45087 m
.35332 .4342 L
s
.58286 .64095 m
.56474 .6275 L
s
.35332 .4342 m
.33877 .41776 L
s
.60065 .65364 m
.58286 .64095 L
s
.33877 .41776 m
.32509 .40166 L
s
.618 .66548 m
.60065 .65364 L
s
.32509 .40166 m
.31237 .38598 L
s
.63482 .67641 m
.618 .66548 L
s
.31237 .38598 m
.30069 .37081 L
s
.65102 .68633 m
.63482 .67641 L
s
.30069 .37081 m
.29015 .35624 L
s
.66648 .69518 m
.65102 .68633 L
s
.29015 .35624 m
.28084 .34238 L
s
.6811 .70287 m
.66648 .69518 L
s
.28084 .34238 m
.27283 .32933 L
s
.69476 .70933 m
.6811 .70287 L
s
.27283 .32933 m
.26623 .31719 L
s
.70737 .71448 m
.69476 .70933 L
s
.26623 .31719 m
.26111 .30606 L
s
.7188 .71824 m
.70737 .71448 L
s
.26111 .30606 m
.25756 .29604 L
s
.72894 .72055 m
.7188 .71824 L
s
.25756 .29604 m
.25565 .28725 L
s
.73769 .72135 m
.72894 .72055 L
s
.25565 .28725 m
.25546 .27979 L
s
.74493 .72056 m
.73769 .72135 L
s
.25546 .27979 m
.25705 .27375 L
s
.75055 .71814 m
.74493 .72056 L
s
.25705 .27375 m
.26046 .26924 L
s
.75445 .71406 m
.75055 .71814 L
s
.26046 .26924 m
.26574 .26634 L
s
.75655 .70828 m
.75445 .71406 L
s
.26574 .26634 m
.27292 .26513 L
s
.75676 .70079 m
.75655 .70828 L
s
.27292 .26513 m
.282 .26569 L
s
.75501 .69158 m
.75676 .70079 L
s
.282 .26569 m
.29297 .26807 L
s
.75125 .68069 m
.75501 .69158 L
s
.29297 .26807 m
.3058 .27231 L
s
.74544 .66814 m
.75125 .68069 L
s
.3058 .27231 m
.32044 .27844 L
s
.73757 .654 m
.74544 .66814 L
s
.32044 .27844 m
.3368 .28646 L
s
.72764 .63834 m
.73757 .654 L
s
.3368 .28646 m
.35478 .29635 L
s
.7157 .62128 m
.72764 .63834 L
s
.35478 .29635 m
.37426 .30806 L
s
.70181 .60293 m
.7157 .62128 L
s
.37426 .30806 m
.39508 .32152 L
s
.68604 .58346 m
.70181 .60293 L
s
.39508 .32152 m
.41705 .33665 L
s
.66852 .56303 m
.68604 .58346 L
s
.41705 .33665 m
.43998 .3533 L
s
.64941 .54183 m
.66852 .56303 L
s
.43998 .3533 m
.46364 .37135 L
s
.62886 .52008 m
.64941 .54183 L
s
.46364 .37135 m
.48779 .39061 L
s
.60707 .49799 m
.62886 .52008 L
s
.48779 .39061 m
.51219 .4109 L
s
.58427 .47579 m
.60707 .49799 L
s
.51219 .4109 m
.53658 .43201 L
s
.56069 .45372 m
.58427 .47579 L
s
.53658 .43201 m
.56069 .45372 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool004aoo`T07l]oo`00BWoo0P0O2Goo0P0ObGoo0019Ool00`0OOomoo`0;Ool201o7Ool004Uoo`03
01moogoo00eoo`<07lAoo`00BGoo00<07gooOol047oo0P0O`Woo0019Ool00`0OOomoo`0BOol201o0
Ool004Uoo`0301moogoo01Aoo`0301moogoo0;eoo`00BGoo00<07gooOol05Goo0P0O_Goo0019Ool0
0`0OOomoo`0GOol201nkOol004Uoo`0301moogoo01Uoo`0301moogoo0;Qoo`00BWoo00<07gooOol0
6Goo0P0O^7oo001:Ool00`0OOomoo`0KOol201nfOol004Yoo`0301moogoo01eoo`807kAoo`00Bgoo
00<07gooOol07Woo0P0O/Woo001;Ool00`0OOomoo`0POol00`0OOomoo`2_Ool004aoo`0301moogoo
021oo`807jmoo`00CGoo00<07gooOol08Goo00<07gooOol0[7oo001=Ool00`0OOomoo`0ROol201n/
Ool004ioo`0301moogoo02=oo`0301moogoo0:Uoo`00CWoo00<07gooOol097oo0P0OZGoo001?Ool0
0`0OOomoo`0UOol00`0OOomoo`2VOol004moo`0301moogoo02Ioo`807jIoo`00D7oo00<07gooOol0
9goo00<07gooOol0Xgoo001AOol00`0OOomoo`0WOol00`0OOomoo`2ROol0055oo`0301moogoo02Qo
o`807j9oo`00DWoo00<07gooOol0:Goo00<07gooOol0Wgoo001COol00`0OOomoo`0YOol201nOOol0
05Aoo`0301moogoo02Yoo`0301moogoo09aoo`00E7oo00<07gooOol0:goo00<07gooOol0Vgoo001E
Ool00`0OOomoo`0[Ool201nKOol005Ioo`0301moogoo02aoo`0301moogoo09Qoo`00Egoo00<07goo
Ool0;7oo00<07gooOol0Ugoo001GOol00`0OOomoo`0]Ool00`0OOomoo`2FOol005Qoo`0301moogoo
02eoo`0301moogoo09Eoo`00FGoo00<07gooOol0;Goo00<07gooOol0U7oo001JOol00`0OOomoo`0]
Ool00`0OOomoo`2COol005]oo`0301moogoo02eoo`0301moogoo099oo`00Fgoo00<07gooOol0;Woo
0P0OTWoo001LOol00`0OOomoo`0_Ool00`0OOomoo`2?Ool005eoo`0301moogoo02moo`807hmoo`00
GWoo00<07gooOol0<7oo0P0OSGoo001OOol00`0OOomoo`0aOol00`0OOomoo`2:Ool0061oo`0301mo
ogoo035oo`0301moogoo08Uoo`00HGoo00<07gooOol0<Goo00<07gooOol0R7oo001ROol00`0OOomo
o`0aOol201n8Ool006=oo`0301moogoo039oo`0301moogoo08Eoo`00Hgoo00<07gooOol0<goo00<0
7gooOol0Q7oo001TOol00`0OOomoo`0cOol00`0OOomoo`23Ool006Eoo`0301moogoo03=oo`0301mo
ogoo089oo`00IWoo00<07gooOol0<goo00<07gooOol0PGoo001WOol00`0OOomoo`0cOol00`0OOomo
o`20Ool006Moo`0301moogoo03=oo`0301moogoo081oo`00J7oo00<07gooOol0<goo00<07gooOol0
Ogoo001YOol00`0OOomoo`0cOol00`0OOomoo`1nOol006Yoo`0301moogoo03=oo`0301moogoo07eo
o`00Jgoo00<07gooOol0<goo00<07gooOol0O7oo001/Ool00`0OOomoo`0cOol00`0OOomoo`1kOol0
06eoo`0301moogoo03=oo`807g]oo`00KWoo00<07gooOol0=7oo00<07gooOol0N7oo001_Ool00`0O
Oomoo`0dOol00`0OOomoo`1gOol0071oo`0301moogoo03Aoo`0301moogoo07Ioo`00LGoo00<07goo
Ool0=7oo00<07gooOol0MGoo001bOol00`0OOomoo`0dOol00`0OOomoo`1dOol007=oo`0301moogoo
03Aoo`807gAoo`00M7oo00<07gooOol0=Goo00<07gooOol0LGoo001eOol201lfOol00`0OOomoo`1`
Ool007Moo`0301moogoo03Aoo`0301moogoo06moo`00N7oo00<07gooOol0=7oo00<07gooOol0KWoo
001iOol00`0OOomoo`0dOol00`0OOomoo`1]Ool007Yoo`0301moogoo03Aoo`0301moogoo06aoo`00
Ngoo00<07gooOol0<goo00<07gooOol0K7oo001lOol00`0OOomoo`0cOol00`0OOomoo`1[Ool007eo
o`0301moogoo03=oo`0301moogoo06Yoo`00OWoo00<07gooOol0<goo00<07gooOol0JGoo001oOol0
0`0OOomoo`0cOol00`0OOomoo`1XOol0081oo`0301moogoo03=oo`0301moogoo06Moo`00PGoo00<0
7gooOol0<goo00<07gooOol0IWoo0022Ool00`0OOomoo`0cOol00`0OOomoo`1UOol008=oo`0301mo
ogoo03=oo`0301moogoo06Aoo`00Q7oo00<07gooOol0<goo00<07gooOol0Hgoo0025Ool00`0OOomo
o`0cOol00`0OOomoo`1ROol008Ioo`0301moogoo03=oo`0301moogoo065oo`00Qgoo00<07gooOol0
<Woo00<07gooOol0HGoo0028Ool00`0OOomoo`0bOol00`0OOomoo`1POol008Uoo`807c=oo`0301mo
ogoo05moo`00Rgoo00<07gooOol0<Goo00<07gooOol0GWoo002<Ool00`0OOomoo`0aOol00`0OOomo
o`1MOol008eoo`0301moogoo035oo`0301moogoo05aoo`00SWoo00<07gooOol0<7oo00<07gooOol0
G7oo002?Ool201laOol00`0OOomoo`1KOol0095oo`0301moogoo02moo`0301moogoo05Yoo`00TWoo
00<07gooOol0;goo00<07gooOol0FGoo002COol00`0OOomoo`0_Ool00`0OOomoo`1HOol009Aoo`80
7c1oo`0301moogoo05Moo`00UWoo00<07gooOol0;Goo00<07gooOol0Egoo002GOol00`0OOomoo`0]
Ool00`0OOomoo`1FOol009Qoo`0301moogoo02eoo`0301moogoo05Eoo`00VGoo00<07gooOol0;Goo
00<07gooOol0E7oo002JOol00`0OOomoo`0]Ool00`0OOomoo`1COol009]oo`0301moogoo02eoo`03
01moogoo059oo`00W7oo00<07gooOol0;7oo00<07gooOol0DWoo002MOol201l]Ool00`0OOomoo`1A
Ool009moo`0301moogoo02]oo`0301moogoo051oo`00X7oo0P0O;7oo00<07gooOol0Cgoo002ROol0
0`0OOomoo`0YOol00`0OOomoo`1?Ool00:=oo`807bYoo`0301moogoo04ioo`00YGoo0P0O:7oo00<0
7gooOol0CWoo002WOol00`0OOomoo`0VOol00`0OOomoo`1=Ool00:Qoo`0301moogoo02Ioo`0301mo
ogoo04aoo`00ZGoo0P0O9Woo00<07gooOol0C7oo002[Ool00`0OOomoo`0TOol00`0OOomoo`1;Ool0
0:aoo`0301moogoo02Aoo`0301moogoo04Yoo`00[Goo0P0O97oo00<07gooOol0BWoo002_Ool201lS
Ool00`0OOomoo`19Ool00;5oo`0301moogoo021oo`0301moogoo04Uoo`00/Woo00<07gooOol087oo
00<07gooOol0B7oo002cOol201lPOol00`0OOomoo`18Ool00;Eoo`0301moogoo01ioo`0301moogoo
04Moo`00]Woo00<07gooOol07Goo00<07gooOol0Agoo002gOol201lNOol00`0OOomoo`16Ool00;Uo
o`807aaoo`0301moogoo04Ioo`00^goo0P0O6goo00<07gooOol0AGoo002mOol201lIOol00`0OOomo
o`15Ool00;moo`0301moogoo01Ioo`0301moogoo04Eoo`00`7oo0P0O5goo00<07gooOol0A7oo0032
Ool201lEOol00`0OOomoo`14Ool00<Aoo`807a=oo`0301moogoo04Aoo`00aWoo0P0O4Goo00<07goo
Ool0A7oo0038Ool201l>Ool00`0OOomoo`15Ool00<Yoo`<07`Yoo`0301moogoo04Ioo`00cGoo1@0O
0goo0`0OB7oo003BOol301m;Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}]
}, Closed]]
}, Closed]],

Cell[TextData[{
  StyleBox["The transformation matrix about ",
    FontFamily->"New York"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`i\_x\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`i\_y\)]],
  ",0",
  Cell[BoxData[
      \(TraditionalForm\`i\_z\)]],
  ")",
  StyleBox[" is given by multiplication of the output of the matrix given by \
Eq. (1) by the matrix corresponding to a rotation about the z-axis of ",
    FontFamily->"New York"],
  Cell[BoxData[
      \(TraditionalForm\`\(-\(\[Pi]\/4\)\)\)]],
  StyleBox[".  The output of the matrix given by Eq. (1) is shown in Figure 1 \
(consisting of parts A-C in the ",
    FontFamily->"New York"],
  StyleBox["Mathematica",
    FontFamily->"New York",
    FontSlant->"Italic"],
  StyleBox[" notebook ) wherein \[Theta] is varied from 0 to ",
    FontFamily->"New York"],
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]],
  StyleBox[". Shown with 6 degree increments of the angle \[Theta]. ",
    FontFamily->"New York"],
  StyleBox["(Electric field lines blue; Magnetic field lines red).  ",
    FontFamily->"New York"]
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig1A\  = 
        Show[Array[p, {15}], ViewPoint \[Rule] {0, 0, 2}];\)\)], "Input",
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.49375 .50625 m
.50625 .49375 L
s
.48127 .51873 m
.49375 .50625 L
s
.50625 .49375 m
.51873 .48127 L
s
.49375 .48446 m
.50626 .47199 L
s
.48129 .49701 m
.49375 .48446 L
s
.46891 .50959 m
.48129 .49701 L
s
.46885 .53115 m
.48127 .51873 L
s
.51873 .48127 m
.53115 .46885 L
s
.50626 .47199 m
.51878 .45964 L
s
.48126 .4753 m
.49373 .46275 L
s
.46891 .48799 m
.48126 .4753 L
s
.45666 .52218 m
.46891 .50959 L
s
.45671 .50078 m
.46891 .48799 L
s
.49373 .46275 m
.50628 .45036 L
s
.4447 .51363 m
.45671 .50078 L
s
.45652 .54348 m
.46885 .53115 L
s
.53115 .46885 m
.54348 .45652 L
s
.51878 .45964 m
.53128 .44743 L
s
.46884 .46645 m
.48119 .45371 L
s
.45667 .47938 m
.46884 .46645 L
s
.44472 .49245 m
.45667 .47938 L
s
.44457 .53474 m
.45666 .52218 L
s
.48119 .45371 m
.4937 .4412 L
s
.50628 .45036 m
.51888 .43818 L
s
.43303 .50564 m
.44472 .49245 L
s
.43292 .52649 m
.4447 .51363 L
s
.4937 .4412 m
.50632 .42895 L
s
.45653 .45806 m
.4687 .44505 L
s
.44462 .47132 m
.45653 .45806 L
s
.53128 .44743 m
.54372 .43541 L
s
.44431 .55569 m
.45652 .54348 L
s
.54348 .45652 m
.55569 .44431 L
s
.433 .48477 m
.44462 .47132 L
s
.4687 .44505 m
.48109 .43232 L
s
.51888 .43818 m
.53148 .42625 L
s
.43267 .54722 m
.44457 .53474 L
s
.42164 .51891 m
.43303 .50564 L
s
.42171 .49838 m
.433 .48477 L
s
.48109 .43232 m
.49366 .41991 L
s
.50632 .42895 m
.51902 .41701 L
s
.42141 .53934 m
.43292 .52649 L
s
.4444 .45031 m
.4563 .43694 L
s
.43282 .46396 m
.4444 .45031 L
s
.42161 .47786 m
.43282 .46396 L
s
.4563 .43694 m
.46849 .42391 L
s
.54372 .43541 m
.55606 .42363 L
s
.41079 .51212 m
.42171 .49838 L
s
.43228 .56772 m
.44431 .55569 L
s
.55569 .44431 m
.56772 .43228 L
s
.53148 .42625 m
.54405 .41462 L
s
.49366 .41991 m
.50637 .40787 L
s
.41059 .5322 m
.42164 .51891 L
s
.4108 .49197 m
.42161 .47786 L
s
.42102 .55959 m
.43267 .54722 L
s
.46849 .42391 m
.48094 .41125 L
s
.51902 .41701 m
.53175 .40542 L
s
.41021 .55213 m
.42141 .53934 L
s
.43251 .44333 m
.44406 .42954 L
s
.42136 .45745 m
.43251 .44333 L
s
.41064 .47186 m
.42136 .45745 L
s
.40044 .50623 m
.4108 .49197 L
s
.44406 .42954 m
.45598 .41612 L
s
.40027 .52593 m
.41079 .51212 L
s
.48094 .41125 m
.4936 .399 L
s
.50637 .40787 m
.5192 .39623 L
s
.4004 .48651 m
.41064 .47186 L
s
.45598 .41612 m
.46822 .40312 L
s
.55606 .42363 m
.56825 .41211 L
s
.39991 .54549 m
.41059 .5322 L
s
.42046 .57954 m
.43228 .56772 L
s
.56772 .43228 m
.57954 .42046 L
s
.54405 .41462 m
.55655 .40331 L
s
.40965 .5718 m
.42102 .55959 L
s
.39055 .52061 m
.40044 .50623 L
s
.53175 .40542 m
.54448 .39423 L
s
.39067 .50135 m
.4004 .48651 L
s
.42094 .43725 m
.43205 .42297 L
s
.4103 .45189 m
.42094 .43725 L
s
.4936 .399 m
.50644 .38722 L
s
.40016 .46685 m
.4103 .45189 L
s
.46822 .40312 m
.48075 .39059 L
s
.43205 .42297 m
.44361 .4091 L
s
.39021 .53977 m
.40027 .52593 L
s
.39936 .56482 m
.41021 .55213 L
s
.39058 .48208 m
.40016 .46685 L
s
.5192 .39623 m
.53209 .38505 L
s
.44361 .4091 m
.45556 .3957 L
s
.38148 .51633 m
.39067 .50135 L
s
.38967 .55872 m
.39991 .54549 L
s
.38157 .49752 m
.39058 .48208 L
s
.48075 .39059 m
.49353 .37858 L
s
.56825 .41211 m
.58026 .40092 L
s
.38118 .53506 m
.39055 .52061 L
s
.55655 .40331 m
.56893 .39238 L
s
.4089 .5911 m
.42046 .57954 L
s
.57954 .42046 m
.5911 .4089 L
s
.40977 .43216 m
.42036 .41735 L
s
.39973 .44736 m
.40977 .43216 L
s
.50644 .38722 m
.51942 .37596 L
s
.39027 .4629 m
.39973 .44736 L
s
.45556 .3957 m
.46787 .38281 L
s
.54448 .39423 m
.55716 .38348 L
s
.42036 .41735 m
.43146 .40299 L
s
.3986 .58381 m
.40965 .5718 L
s
.38143 .47872 m
.39027 .4629 L
s
.38065 .5536 m
.39021 .53977 L
s
.37318 .51313 m
.38157 .49752 L
s
.43146 .40299 m
.44303 .38912 L
s
.53209 .38505 m
.545 .37437 L
s
.3729 .53142 m
.38148 .51633 L
s
.38891 .57736 m
.39936 .56482 L
s
.37323 .49478 m
.38143 .47872 L
s
.46787 .38281 m
.48051 .37048 L
s
.49353 .37858 m
.50652 .36714 L
s
.38976 .44391 m
.3991 .42814 L
s
.38106 .46003 m
.38976 .44391 L
s
.3991 .42814 m
.40907 .41278 L
s
.37238 .54953 m
.38118 .53506 L
s
.44303 .38912 m
.45504 .3758 L
s
.37989 .57185 m
.38967 .55872 L
s
.37305 .47645 m
.38106 .46003 L
s
.51942 .37596 m
.53249 .36525 L
s
.40907 .41278 m
.41962 .39788 L
s
.36572 .51101 m
.37323 .49478 L
s
.36545 .52886 m
.37318 .51313 L
s
.58026 .40092 m
.59203 .39009 L
s
.56893 .39238 m
.58114 .38189 L
s
.39765 .60235 m
.4089 .5911 L
s
.5911 .4089 m
.60235 .39765 L
s
.36575 .49311 m
.37305 .47645 L
s
.55716 .38348 m
.56974 .37322 L
s
.41962 .39788 m
.43072 .3835 L
s
.37162 .56737 m
.38065 .5536 L
s
.36494 .54655 m
.3729 .53142 L
s
.48051 .37048 m
.49344 .35877 L
s
.38794 .59557 m
.3986 .58381 L
s
.45504 .3758 m
.46746 .36308 L
s
.50652 .36714 m
.51968 .35631 L
s
.38047 .44156 m
.38903 .42522 L
s
.37263 .45825 m
.38047 .44156 L
s
.545 .37437 m
.55789 .36425 L
s
.38903 .42522 m
.39827 .4093 L
s
.36554 .47523 m
.37263 .45825 L
s
.35921 .50994 m
.36575 .49311 L
s
.35894 .52737 m
.36572 .51101 L
s
.37891 .5897 m
.38891 .57736 L
s
.43072 .3835 m
.44233 .36971 L
s
.39827 .4093 m
.40818 .39386 L
s
.35923 .49245 m
.36554 .47523 L
s
.36419 .56397 m
.37238 .54953 L
s
.35843 .54465 m
.36545 .52886 L
s
.53249 .36525 m
.54562 .35517 L
s
.37064 .58482 m
.37989 .57185 L
s
.40818 .39386 m
.41871 .37895 L
s
.46746 .36308 m
.48024 .35103 L
s
.35372 .50984 m
.35923 .49245 L
s
.35345 .5269 m
.35921 .50994 L
s
.37198 .44028 m
.37965 .42341 L
s
.36508 .4575 m
.37198 .44028 L
s
.49344 .35877 m
.50661 .34774 L
s
.35899 .47501 m
.36508 .4575 L
s
.44233 .36971 m
.45443 .35655 L
s
.37965 .42341 m
.38809 .40694 L
s
.35767 .56167 m
.36494 .54655 L
s
.35374 .49273 m
.35899 .47501 L
s
.58114 .38189 m
.59313 .37187 L
s
.59203 .39009 m
.60351 .37968 L
s
.35293 .5438 m
.35894 .52737 L
s
.56974 .37322 m
.58218 .36351 L
s
.38675 .61325 m
.39765 .60235 L
s
.60235 .39765 m
.61325 .38675 L
s
.36319 .58102 m
.37162 .56737 L
s
.51968 .35631 m
.53297 .34617 L
s
.38809 .40694 m
.39725 .39096 L
s
.41871 .37895 m
.42983 .36464 L
s
.34935 .5106 m
.35374 .49273 L
s
.34906 .52734 m
.35372 .50984 L
s
.37771 .60703 m
.38794 .59557 L
s
.55789 .36425 m
.5707 .35474 L
s
.35852 .4577 m
.36438 .44001 L
s
.35351 .47565 m
.35852 .4577 L
s
.36438 .44001 m
.37109 .42265 L
s
.35215 .56044 m
.35843 .54465 L
s
.34938 .4938 m
.35351 .47565 L
s
.34852 .54391 m
.35345 .5269 L
s
.39725 .39096 m
.40711 .37551 L
s
.35667 .57832 m
.36419 .56397 L
s
.48024 .35103 m
.49334 .33971 L
s
.37109 .42265 m
.37861 .40568 L
s
.45443 .35655 m
.46698 .34409 L
s
.36942 .60178 m
.37891 .5897 L
s
.34615 .51206 m
.34938 .4938 L
s
.34584 .52855 m
.34935 .5106 L
s
.54562 .35517 m
.55874 .34577 L
s
.50661 .34774 m
.51999 .33744 L
s
.42983 .36464 m
.44152 .35099 L
s
.34916 .47703 m
.35302 .45872 L
s
.34621 .4955 m
.34916 .47703 L
s
.35302 .45872 m
.35779 .44064 L
s
.34527 .54487 m
.34906 .52734 L
s
.34772 .56022 m
.35293 .5438 L
s
.37861 .40568 m
.38693 .38919 L
s
.3442 .51405 m
.34621 .4955 L
s
.35779 .44064 m
.36345 .42287 L
s
.34385 .53038 m
.34615 .51206 L
s
.36196 .59758 m
.37064 .58482 L
s
.35113 .57671 m
.35767 .56167 L
s
.40711 .37551 m
.41764 .36068 L
s
.34601 .47896 m
.34868 .4604 L
s
.34429 .49764 m
.34601 .47896 L
s
.34352 .51636 m
.34429 .49764 L
s
.34868 .4604 m
.35229 .44204 L
s
.34313 .53262 m
.3442 .51405 L
s
.34324 .54652 m
.34584 .52855 L
s
.36345 .42287 m
.36997 .40546 L
s
.53297 .34617 m
.54633 .33677 L
s
.3437 .53505 m
.34352 .51636 L
s
.34444 .56092 m
.34852 .54391 L
s
.38693 .38919 m
.39602 .37323 L
s
.59313 .37187 m
.60486 .3624 L
s
.35229 .44204 m
.35682 .42394 L
s
.60351 .37968 m
.61464 .36974 L
s
.35541 .59449 m
.36319 .58102 L
s
.34249 .54867 m
.34385 .53038 L
s
.58218 .36351 m
.59443 .3544 L
s
.46698 .34409 m
.47992 .3324 L
s
.34667 .57617 m
.35215 .56044 L
s
.44152 .35099 m
.45373 .33808 L
s
.37628 .62372 m
.38675 .61325 L
s
.61325 .38675 m
.62372 .37628 L
s
.34485 .55363 m
.3437 .53505 L
s
.34302 .55112 m
.34313 .53262 L
s
.49334 .33971 m
.50672 .32917 L
s
.36997 .40546 m
.37735 .38851 L
s
.34238 .56238 m
.34527 .54487 L
s
.5707 .35474 m
.5834 .34591 L
s
.41764 .36068 m
.42881 .34653 L
s
.35682 .42394 m
.36227 .40618 L
s
.36796 .61812 m
.37771 .60703 L
s
.34986 .59252 m
.35667 .57832 L
s
.34159 .56443 m
.34324 .54652 L
s
.34336 .57658 m
.34772 .56022 L
s
.51999 .33744 m
.53351 .32795 L
s
.39602 .37323 m
.40585 .35788 L
s
.34697 .57204 m
.34485 .55363 L
s
.34209 .56688 m
.34249 .54867 L
s
.55874 .34577 m
.57181 .3371 L
s
.34389 .56949 m
.34302 .55112 L
s
.36048 .61355 m
.36942 .60178 L
s
.37735 .38851 m
.38557 .37208 L
s
.36227 .40618 m
.36862 .38884 L
s
.34127 .57784 m
.34444 .56092 L
s
.34537 .59163 m
.35113 .57671 L
s
.45373 .33808 m
.46642 .32597 L
s
.47992 .3324 m
.49323 .32155 L
s
.35392 .61008 m
.36196 .59758 L
s
.35006 .59018 m
.34697 .57204 L
s
.42881 .34653 m
.44058 .33313 L
s
.34043 .57978 m
.34238 .56238 L
s
.54633 .33677 m
.55971 .32817 L
s
.40585 .35788 m
.4164 .34322 L
s
.34574 .58764 m
.34389 .56949 L
s
.50672 .32917 m
.52034 .31949 L
s
.3409 .58221 m
.34159 .56443 L
s
.34203 .59176 m
.34667 .57617 L
s
.34267 .5849 m
.34209 .56688 L
s
.38557 .37208 m
.39459 .35624 L
s
.36862 .38884 m
.37586 .372 L
s
.34834 .60773 m
.35541 .59449 L
s
.60486 .3624 m
.61625 .35353 L
s
.61464 .36974 m
.62537 .36035 L
s
.59443 .3544 m
.60641 .34596 L
s
.3399 .59281 m
.34336 .57658 L
s
.35414 .60798 m
.35006 .59018 L
s
.36628 .63372 m
.37628 .62372 L
s
.62372 .37628 m
.63372 .36628 L
s
.5834 .34591 m
.5959 .33781 L
s
.53351 .32795 m
.54714 .31932 L
s
.34382 .6065 m
.34986 .59252 L
s
.33903 .59462 m
.34127 .57784 L
s
.44058 .33313 m
.45293 .32055 L
s
.35877 .62879 m
.36796 .61812 L
s
.46642 .32597 m
.47956 .31474 L
s
.34858 .60549 m
.34574 .58764 L
s
.4164 .34322 m
.42763 .32932 L
s
.57181 .3371 m
.58477 .32924 L
s
.39459 .35624 m
.40441 .34109 L
s
.37586 .372 m
.38399 .35574 L
s
.33946 .59701 m
.34043 .57978 L
s
.49323 .32155 m
.50685 .3116 L
s
.34425 .60267 m
.34267 .5849 L
s
.3412 .59977 m
.3409 .58221 L
s
.34045 .60634 m
.34537 .59163 L
s
.35218 .62494 m
.36048 .61355 L
s
.35919 .62536 m
.35414 .60798 L
s
.52034 .31949 m
.53413 .31074 L
s
.55971 .32817 m
.57306 .32044 L
s
.33828 .60716 m
.34203 .59176 L
s
.34657 .62223 m
.35392 .61008 L
s
.35243 .62296 m
.34858 .60549 L
s
.33737 .60882 m
.3399 .59281 L
s
.38399 .35574 m
.39297 .34015 L
s
.42763 .32932 m
.43952 .31626 L
s
.40441 .34109 m
.415 .32671 L
s
.45293 .32055 m
.4658 .30889 L
s
.34203 .62066 m
.34834 .60773 L
s
.47956 .31474 m
.4931 .30445 L
s
.34685 .6201 m
.34425 .60267 L
s
.33776 .61116 m
.33903 .59462 L
s
.54714 .31932 m
.5608 .31163 L
s
.61625 .35353 m
.62725 .34533 L
s
.60641 .34596 m
.61807 .33826 L
s
.34252 .61703 m
.3412 .59977 L
s
.33948 .61397 m
.33946 .59701 L
s
.62537 .36035 m
.63563 .35156 L
s
.5959 .33781 m
.60816 .33051 L
s
.50685 .3116 m
.52073 .30264 L
s
.36522 .64221 m
.35919 .62536 L
s
.33862 .6202 m
.34382 .6065 L
s
.35683 .64317 m
.36628 .63372 L
s
.63372 .36628 m
.64317 .35683 L
s
.58477 .32924 m
.59756 .32224 L
s
.3502 .63897 m
.35877 .62879 L
s
.33641 .62077 m
.34045 .60634 L
s
.35729 .63995 m
.35243 .62296 L
s
.53413 .31074 m
.54804 .30299 L
s
.39297 .34015 m
.40279 .32531 L
s
.415 .32671 m
.42632 .31317 L
s
.43952 .31626 m
.45203 .30413 L
s
.34456 .63589 m
.35218 .62494 L
s
.57306 .32044 m
.58631 .31366 L
s
.33547 .62227 m
.33828 .60716 L
s
.4658 .30889 m
.47916 .29821 L
s
.35049 .6371 m
.34685 .6201 L
s
.4931 .30445 m
.50698 .2952 L
s
.33583 .62454 m
.33737 .60882 L
s
.37223 .65846 m
.36522 .64221 L
s
.33999 .63397 m
.34657 .62223 L
s
.34488 .6339 m
.34252 .61703 L
s
.33752 .62738 m
.33776 .61116 L
s
.34054 .63058 m
.33948 .61397 L
s
.5608 .31163 m
.57445 .30494 L
s
.52073 .30264 m
.53481 .29473 L
s
.33654 .6332 m
.34203 .62066 L
s
.36318 .65637 m
.35729 .63995 L
s
.40279 .32531 m
.41344 .31131 L
s
.61807 .33826 m
.62933 .33136 L
s
.62725 .34533 m
.63777 .33786 L
s
.42632 .31317 m
.43834 .30057 L
s
.60816 .33051 m
.62009 .32408 L
s
.63563 .35156 m
.64535 .34344 L
s
.3343 .63353 m
.33862 .6202 L
s
.45203 .30413 m
.46511 .29302 L
s
.34799 .65201 m
.35683 .64317 L
s
.64317 .35683 m
.65201 .34799 L
s
.59756 .32224 m
.6101 .3162 L
s
.54804 .30299 m
.56202 .29631 L
s
.35517 .65357 m
.35049 .6371 L
s
.47916 .29821 m
.49296 .2886 L
s
.33332 .63484 m
.33641 .62077 L
s
.3802 .67401 m
.37223 .65846 L
s
.34232 .64858 m
.3502 .63897 L
s
.34831 .65029 m
.34488 .6339 L
s
.50698 .2952 m
.52116 .28705 L
s
.33365 .63702 m
.33547 .62227 L
s
.58631 .31366 m
.59939 .30789 L
s
.33532 .63987 m
.33583 .62454 L
s
.34267 .64674 m
.34054 .63058 L
s
.33833 .64319 m
.33752 .62738 L
s
.33771 .64632 m
.34456 .63589 L
s
.41344 .31131 m
.42486 .29826 L
s
.37008 .67212 m
.36318 .65637 L
s
.53481 .29473 m
.54904 .28796 L
s
.33424 .64523 m
.33999 .63397 L
s
.43834 .30057 m
.45103 .28901 L
s
.57445 .30494 m
.58801 .29935 L
s
.46511 .29302 m
.47871 .28301 L
s
.33196 .64528 m
.33654 .6332 L
s
.36092 .66942 m
.35517 .65357 L
s
.38914 .68875 m
.3802 .67401 L
s
.49296 .2886 m
.50713 .28015 L
s
.62933 .33136 m
.64013 .32534 L
s
.63777 .33786 m
.64775 .33121 L
s
.33095 .6464 m
.3343 .63353 L
s
.56202 .29631 m
.57598 .29078 L
s
.62009 .32408 m
.63163 .31861 L
s
.35282 .66609 m
.34831 .65029 L
s
.64535 .34344 m
.65445 .33608 L
s
.52116 .28705 m
.53557 .28011 L
s
.6101 .3162 m
.62232 .31117 L
s
.33124 .64847 m
.33332 .63484 L
s
.33985 .66015 m
.34799 .65201 L
s
.65201 .34799 m
.66015 .33985 L
s
.3459 .66236 m
.34267 .64674 L
s
.42486 .29826 m
.43705 .28624 L
s
.33289 .6513 m
.33365 .63702 L
s
.37801 .6871 m
.37008 .67212 L
s
.34024 .65849 m
.33833 .64319 L
s
.33589 .65472 m
.33532 .63987 L
s
.59939 .30789 m
.61223 .30321 L
s
.45103 .28901 m
.46435 .27857 L
s
.33521 .65754 m
.34232 .64858 L
s
.54904 .28796 m
.56334 .28241 L
s
.47871 .28301 m
.4928 .2742 L
s
.3317 .65613 m
.33771 .64632 L
s
.39903 .70258 m
.38914 .68875 L
s
.58801 .29935 m
.6014 .29492 L
s
.36773 .68452 m
.36092 .66942 L
s
.50713 .28015 m
.52163 .27295 L
s
.32939 .65591 m
.33424 .64523 L
s
.35844 .68119 m
.35282 .66609 L
s
.32835 .65681 m
.33196 .64528 L
s
.57598 .29078 m
.58986 .28649 L
s
.53557 .28011 m
.55013 .27444 L
s
.43705 .28624 m
.44995 .27537 L
s
.38694 .7012 m
.37801 .6871 L
s
.32861 .65874 m
.33095 .6464 L
s
.35025 .67733 m
.3459 .66236 L
s
.64013 .32534 m
.65037 .32029 L
s
.63163 .31861 m
.64269 .31417 L
s
.46435 .27857 m
.47823 .26936 L
s
.64775 .33121 m
.6571 .32545 L
s
.33023 .66154 m
.33124 .64847 L
s
.62232 .31117 m
.63413 .30725 L
s
.34328 .67317 m
.34024 .65849 L
s
.65445 .33608 m
.66283 .32955 L
s
.33323 .66503 m
.33289 .6513 L
s
.33758 .66899 m
.33589 .65472 L
s
.4928 .2742 m
.5073 .26668 L
s
.40983 .71538 m
.39903 .70258 L
s
.33249 .66751 m
.33985 .66015 L
s
.66015 .33985 m
.66751 .33249 L
s
.61223 .30321 m
.62474 .29971 L
s
.56334 .28241 m
.57765 .27816 L
s
.37561 .69878 m
.36773 .68452 L
s
.32895 .66577 m
.33521 .65754 L
s
.52163 .27295 m
.53639 .26708 L
s
.6014 .29492 m
.61454 .29173 L
s
.32661 .66526 m
.3317 .65613 L
s
.36517 .69549 m
.35844 .68119 L
s
.44995 .27537 m
.46352 .26574 L
s
.39688 .7143 m
.38694 .7012 L
s
.55013 .27444 m
.56479 .27014 L
s
.32554 .66593 m
.32939 .65591 L
s
.58986 .28649 m
.60357 .28352 L
s
.47823 .26936 m
.49263 .26147 L
s
.35576 .69152 m
.35025 .67733 L
s
.32578 .66769 m
.32835 .65681 L
s
.5073 .26668 m
.52215 .26055 L
s
.42154 .72706 m
.40983 .71538 L
s
.34748 .68713 m
.34328 .67317 L
s
.32737 .67043 m
.32861 .65874 L
s
.64269 .31417 m
.65318 .31084 L
s
.65037 .32029 m
.65996 .31627 L
s
.33035 .67396 m
.33023 .66154 L
s
.34044 .68256 m
.33758 .66899 L
s
.38457 .71208 m
.37561 .69878 L
s
.33472 .67809 m
.33323 .66503 L
s
.63413 .30725 m
.64546 .30451 L
s
.6571 .32545 m
.66573 .32068 L
s
.57765 .27816 m
.59186 .27531 L
s
.66283 .32955 m
.67043 .32395 L
s
.53639 .26708 m
.55132 .26265 L
s
.62474 .29971 m
.63683 .29746 L
s
.326 .674 m
.33249 .66751 L
s
.66751 .33249 m
.674 .326 L
s
.46352 .26574 m
.47771 .25746 L
s
.37303 .70886 m
.36517 .69549 L
s
.61454 .29173 m
.62734 .28988 L
s
.40781 .72629 m
.39688 .7143 L
s
.32363 .67318 m
.32895 .66577 L
s
.49263 .26147 m
.50748 .25501 L
s
.56479 .27014 m
.57944 .2673 L
s
.32253 .67359 m
.32661 .66526 L
s
.36243 .70483 m
.35576 .69152 L
s
.60357 .28352 m
.61702 .28196 L
s
.43412 .73748 m
.42154 .72706 L
s
.52215 .26055 m
.53727 .25589 L
s
.32274 .67518 m
.32554 .66593 L
s
.35288 .70024 m
.34748 .68713 L
s
.39458 .72429 m
.38457 .71208 L
s
.32432 .67782 m
.32578 .66769 L
s
.34452 .69532 m
.34044 .68256 L
s
.32729 .68137 m
.32737 .67043 L
s
.59186 .27531 m
.6059 .27392 L
s
.55132 .26265 m
.56634 .25973 L
s
.33742 .69036 m
.33472 .67809 L
s
.33167 .68563 m
.33035 .67396 L
s
.65318 .31084 m
.66301 .3087 L
s
.47771 .25746 m
.49244 .25064 L
s
.65996 .31627 m
.66881 .31339 L
s
.64546 .30451 m
.65619 .30304 L
s
.66573 .32068 m
.67354 .31697 L
s
.41969 .73704 m
.40781 .72629 L
s
.38202 .72117 m
.37303 .70886 L
s
.63683 .29746 m
.64841 .29655 L
s
.67043 .32395 m
.67713 .31935 L
s
.50748 .25501 m
.5227 .25008 L
s
.62734 .28988 m
.63971 .28943 L
s
.57944 .2673 m
.59401 .266 L
s
.32047 .67953 m
.326 .674 L
s
.674 .326 m
.67953 .32047 L
s
.44751 .74654 m
.43412 .73748 L
s
.37028 .71713 m
.36243 .70483 L
s
.53727 .25589 m
.55258 .25282 L
s
.31934 .67967 m
.32363 .67318 L
s
.61702 .28196 m
.63012 .28187 L
s
.40564 .73528 m
.39458 .72429 L
s
.31953 .68104 m
.32253 .67359 L
s
.35951 .71237 m
.35288 .70024 L
s
.3211 .68355 m
.32274 .67518 L
s
.56634 .25973 m
.58136 .25842 L
s
.49244 .25064 m
.50767 .24538 L
s
.34984 .70715 m
.34452 .69532 L
s
.6059 .27392 m
.61967 .2741 L
s
.32406 .68708 m
.32432 .67782 L
s
.43249 .74643 m
.41969 .73704 L
s
.34138 .70173 m
.33742 .69036 L
s
.32844 .69144 m
.32729 .68137 L
s
.33422 .69641 m
.33167 .68563 L
s
.39213 .7323 m
.38202 .72117 L
s
.5227 .25008 m
.53821 .24677 L
s
.66301 .3087 m
.67206 .30785 L
s
.65619 .30304 m
.66623 .30291 L
s
.66881 .31339 m
.67681 .31172 L
s
.64841 .29655 m
.65937 .29706 L
s
.46168 .75411 m
.44751 .74654 L
s
.59401 .266 m
.60838 .26633 L
s
.67354 .31697 m
.68043 .31442 L
s
.63971 .28943 m
.65153 .29048 L
s
.55258 .25282 m
.56799 .25141 L
s
.37932 .72827 m
.37028 .71713 L
s
.67713 .31935 m
.68284 .31586 L
s
.41772 .74493 m
.40564 .73528 L
s
.316 .684 m
.32047 .67953 L
s
.67953 .32047 m
.684 .316 L
s
.63012 .28187 m
.64274 .28335 L
s
.36737 .72339 m
.35951 .71237 L
s
.50767 .24538 m
.52329 .2418 L
s
.31618 .68513 m
.31934 .67967 L
s
.58136 .25842 m
.59629 .25881 L
s
.44617 .75433 m
.43249 .74643 L
s
.31772 .68749 m
.31953 .68104 L
s
.61967 .2741 m
.63305 .27591 L
s
.35643 .7179 m
.34984 .70715 L
s
.53821 .24677 m
.55393 .24519 L
s
.40334 .74212 m
.39213 .7323 L
s
.32068 .69095 m
.3211 .68355 L
s
.34663 .71206 m
.34138 .70173 L
s
.32506 .69536 m
.32406 .68708 L
s
.47655 .76006 m
.46168 .75411 L
s
.33809 .70618 m
.33422 .69641 L
s
.33088 .70052 m
.32844 .69144 L
s
.60838 .26633 m
.62246 .26836 L
s
.56799 .25141 m
.58339 .25176 L
s
.66623 .30291 m
.67545 .30422 L
s
.67206 .30785 m
.68023 .30836 L
s
.65937 .29706 m
.66959 .29907 L
s
.38954 .73814 m
.37932 .72827 L
s
.67681 .31172 m
.68386 .31136 L
s
.43077 .7531 m
.41772 .74493 L
s
.65153 .29048 m
.66269 .2931 L
s
.68043 .31442 m
.68629 .31312 L
s
.52329 .2418 m
.53921 .23999 L
s
.64274 .28335 m
.65479 .28647 L
s
.68284 .31586 m
.68746 .31357 L
s
.59629 .25881 m
.61099 .26097 L
s
.37648 .73317 m
.36737 .72339 L
s
.46067 .76062 m
.44617 .75433 L
s
.3127 .6873 m
.316 .684 L
s
.684 .316 m
.6873 .3127 L
s
.55393 .24519 m
.56974 .24543 L
s
.63305 .27591 m
.64592 .27943 L
s
.41564 .75048 m
.40334 .74212 L
s
.31423 .68946 m
.31618 .68513 L
s
.36433 .72744 m
.35643 .7179 L
s
.49204 .76429 m
.47655 .76006 L
s
.31718 .69282 m
.31772 .68749 L
s
.35322 .72123 m
.34663 .71206 L
s
.58339 .25176 m
.59868 .25396 L
s
.32157 .69725 m
.32068 .69095 L
s
.62246 .26836 m
.63611 .27218 L
s
.3433 .71481 m
.33809 .70618 L
s
.32741 .70254 m
.32506 .69536 L
s
.33467 .70849 m
.33088 .70052 L
s
.44476 .75967 m
.43077 .7531 L
s
.40094 .74658 m
.38954 .73814 L
s
.67545 .30422 m
.68375 .30704 L
s
.66959 .29907 m
.67896 .30266 L
s
.53921 .23999 m
.55534 .24004 L
s
.68023 .30836 m
.6874 .31032 L
s
.66269 .2931 m
.67307 .29735 L
s
.68386 .31136 m
.68984 .31239 L
s
.61099 .26097 m
.62537 .26498 L
s
.47592 .76517 m
.46067 .76062 L
s
.65479 .28647 m
.66613 .2913 L
s
.38684 .74156 m
.37648 .73317 L
s
.68629 .31312 m
.69102 .31316 L
s
.56974 .24543 m
.58552 .24757 L
s
.42897 .75726 m
.41564 .75048 L
s
.68746 .31357 m
.69087 .31258 L
s
.50808 .76669 m
.49204 .76429 L
s
.64592 .27943 m
.65817 .28472 L
s
.37353 .73564 m
.36433 .72744 L
s
.31065 .68935 m
.3127 .6873 L
s
.6873 .3127 m
.68935 .31065 L
s
.59868 .25396 m
.61371 .25806 L
s
.3136 .69256 m
.31423 .68946 L
s
.63611 .27218 m
.64921 .27784 L
s
.45962 .7645 m
.44476 .75967 L
s
.36117 .72908 m
.35322 .72123 L
s
.318 .69694 m
.31718 .69282 L
s
.41347 .75346 m
.40094 .74658 L
s
.55534 .24004 m
.57156 .24205 L
s
.34991 .72217 m
.3433 .71481 L
s
.32386 .70232 m
.32157 .69725 L
s
.33987 .7152 m
.33467 .70849 L
s
.33116 .70849 m
.32741 .70254 L
s
.49183 .76786 m
.47592 .76517 L
s
.62537 .26498 m
.63928 .2709 L
s
.67896 .30266 m
.68735 .30788 L
s
.68375 .30704 m
.691 .31143 L
s
.67307 .29735 m
.68255 .30331 L
s
.58552 .24757 m
.60116 .25169 L
s
.6874 .31032 m
.69344 .31381 L
s
.39844 .74842 m
.38684 .74156 L
s
.66613 .2913 m
.67664 .29789 L
s
.52456 .76713 m
.50808 .76669 L
s
.44329 .76231 m
.42897 .75726 L
s
.68984 .31239 m
.69463 .3149 L
s
.65817 .28472 m
.66965 .29185 L
s
.69102 .31316 m
.69449 .31463 L
s
.61371 .25806 m
.62838 .26414 L
s
.38405 .74234 m
.37353 .73564 L
s
.69087 .31258 m
.69297 .31298 L
s
.47526 .76747 m
.45962 .7645 L
s
.64921 .27784 m
.66163 .28539 L
s
.57156 .24205 m
.58773 .2461 L
s
.30997 .69003 m
.31065 .68935 L
s
.68935 .31065 m
.69003 .30997 L
s
.4271 .75863 m
.41347 .75346 L
s
.3705 .73548 m
.36117 .72908 L
s
.5083 .76859 m
.49183 .76786 L
s
.31437 .6943 m
.3136 .69256 L
s
.35794 .72811 m
.34991 .72217 L
s
.63928 .2709 m
.65258 .27877 L
s
.60116 .25169 m
.61652 .25784 L
s
.32025 .69971 m
.318 .69694 L
s
.34652 .72054 m
.33987 .7152 L
s
.3276 .70605 m
.32386 .70232 L
s
.54135 .76554 m
.52456 .76713 L
s
.33638 .71309 m
.33116 .70849 L
s
.68735 .30788 m
.69463 .3148 L
s
.68255 .30331 m
.69098 .31102 L
s
.45852 .7655 m
.44329 .76231 L
s
.41123 .75361 m
.39844 .74842 L
s
.691 .31143 m
.69707 .31747 L
s
.67664 .29789 m
.68617 .3063 L
s
.69344 .31381 m
.69825 .31889 L
s
.62838 .26414 m
.64252 .27225 L
s
.66965 .29185 m
.68024 .30084 L
s
.69463 .3149 m
.69811 .31896 L
s
.4916 .76847 m
.47526 .76747 L
s
.58773 .2461 m
.60372 .25223 L
s
.39587 .74741 m
.38405 .74234 L
s
.66163 .28539 m
.67322 .29487 L
s
.69449 .31463 m
.69659 .31761 L
s
.44177 .76198 m
.4271 .75863 L
s
.52523 .76725 m
.5083 .76859 L
s
.69297 .31298 m
.69365 .31486 L
s
.61652 .25784 m
.63145 .26607 L
s
.3812 .74028 m
.3705 .73548 L
s
.65258 .27877 m
.66513 .28864 L
s
.55834 .76183 m
.54135 .76554 L
s
.31075 .68925 m
.30997 .69003 L
s
.69003 .30997 m
.68925 .31075 L
s
.36741 .7325 m
.35794 .72811 L
s
.47459 .76672 m
.45852 .7655 L
s
.31665 .6946 m
.31437 .6943 L
s
.42518 .75699 m
.41123 .75361 L
s
.32403 .70103 m
.32025 .69971 L
s
.35467 .72436 m
.34652 .72054 L
s
.69098 .31102 m
.69824 .32052 L
s
.64252 .27225 m
.65599 .28239 L
s
.68617 .3063 m
.69459 .31654 L
s
.69463 .3148 m
.70067 .32346 L
s
.33287 .70831 m
.3276 .70605 L
s
.34311 .71619 m
.33638 .71309 L
s
.69707 .31747 m
.70183 .32521 L
s
.68024 .30084 m
.68979 .31173 L
s
.60372 .25223 m
.61938 .2605 L
s
.50853 .76738 m
.4916 .76847 L
s
.69825 .31889 m
.70169 .32562 L
s
.67322 .29487 m
.68384 .3063 L
s
.54247 .76376 m
.52523 .76725 L
s
.40895 .75072 m
.39587 .74741 L
s
.69811 .31896 m
.70017 .32463 L
s
.45741 .76336 m
.44177 .76198 L
s
.63145 .26607 m
.64579 .2764 L
s
.57537 .75593 m
.55834 .76183 L
s
.66513 .28864 m
.67679 .3005 L
s
.69659 .31761 m
.69723 .32218 L
s
.39326 .74336 m
.3812 .74028 L
s
.49137 .76586 m
.47459 .76672 L
s
.69365 .31486 m
.69281 .31831 L
s
.65599 .28239 m
.66864 .29459 L
s
.44023 .75844 m
.42518 .75699 L
s
.37832 .7352 m
.36741 .7325 L
s
.31309 .68691 m
.31075 .68925 L
s
.68925 .31075 m
.68691 .31309 L
s
.61938 .2605 m
.63455 .27092 L
s
.52591 .76413 m
.50853 .76738 L
s
.69459 .31654 m
.70177 .32863 L
s
.69824 .32052 m
.70418 .33182 L
s
.3205 .69334 m
.31665 .6946 L
s
.68979 .31173 m
.69814 .3245 L
s
.36431 .72653 m
.35467 .72436 L
s
.70067 .32346 m
.70533 .33388 L
s
.32939 .70079 m
.32403 .70103 L
s
.55989 .75806 m
.54247 .76376 L
s
.35139 .71768 m
.34311 .71619 L
s
.33972 .709 m
.33287 .70831 L
s
.68384 .3063 m
.69334 .31966 L
s
.70183 .32521 m
.70517 .33467 L
s
.64579 .2764 m
.65939 .28883 L
s
.59229 .74781 m
.57537 .75593 L
s
.4739 .76267 m
.45741 .76336 L
s
.42324 .75212 m
.40895 .75072 L
s
.70169 .32562 m
.70364 .33405 L
s
.67679 .3005 m
.68739 .31435 L
s
.70017 .32463 m
.70069 .33197 L
s
.50876 .76282 m
.49137 .76586 L
s
.66864 .29459 m
.6803 .30881 L
s
.40665 .74458 m
.39326 .74336 L
s
.63455 .27092 m
.64906 .28349 L
s
.69723 .32218 m
.69628 .3284 L
s
.5436 .75863 m
.52591 .76413 L
s
.45627 .75784 m
.44023 .75844 L
s
.69281 .31831 m
.69036 .3234 L
s
.57732 .75009 m
.55989 .75806 L
s
.39066 .73608 m
.37832 .7352 L
s
.70177 .32863 m
.70756 .34255 L
s
.69814 .3245 m
.70517 .33915 L
s
.65939 .28883 m
.67209 .30333 L
s
.70418 .33182 m
.70868 .34492 L
s
.60894 .73745 m
.59229 .74781 L
s
.69334 .31966 m
.70157 .33493 L
s
.31707 .68293 m
.31309 .68691 L
s
.68691 .31309 m
.68293 .31707 L
s
.70533 .33388 m
.70849 .34608 L
s
.37546 .72693 m
.36431 .72653 L
s
.49114 .75981 m
.4739 .76267 L
s
.326 .69044 m
.3205 .69334 L
s
.68739 .31435 m
.69678 .33014 L
s
.36124 .71745 m
.35139 .71768 L
s
.43867 .7515 m
.42324 .75212 L
s
.70517 .33467 m
.70695 .34587 L
s
.33639 .69888 m
.32939 .70079 L
s
.34817 .70799 m
.33972 .709 L
s
.5266 .75754 m
.50876 .76282 L
s
.64906 .28349 m
.66274 .29817 L
s
.6803 .30881 m
.69082 .32502 L
s
.70364 .33405 m
.70399 .3442 L
s
.56144 .75086 m
.5436 .75863 L
s
.4213 .74382 m
.40665 .74458 L
s
.59459 .73985 m
.57732 .75009 L
s
.70069 .33197 m
.69957 .34101 L
s
.47321 .75509 m
.45627 .75784 L
s
.67209 .30333 m
.6837 .31985 L
s
.62512 .72486 m
.60894 .73745 L
s
.69628 .3284 m
.69365 .33632 L
s
.70517 .33915 m
.71074 .35561 L
s
.70157 .33493 m
.70839 .35204 L
s
.70756 .34255 m
.71182 .35826 L
s
.40437 .73504 m
.39066 .73608 L
s
.70868 .34492 m
.71161 .35979 L
s
.50899 .7547 m
.49114 .75981 L
s
.69678 .33014 m
.70482 .34779 L
s
.69036 .3234 m
.68621 .33018 L
s
.66274 .29817 m
.67543 .3149 L
s
.70849 .34608 m
.71004 .36001 L
s
.54473 .74996 m
.5266 .75754 L
s
.69082 .32502 m
.70005 .34312 L
s
.45514 .74877 m
.43867 .7515 L
s
.38808 .72545 m
.37546 .72693 L
s
.32274 .67726 m
.31707 .68293 L
s
.68293 .31707 m
.67726 .32274 L
s
.57925 .74078 m
.56144 .75086 L
s
.70695 .34587 m
.70707 .3588 L
s
.33319 .68581 m
.326 .69044 L
s
.37265 .71538 m
.36124 .71745 L
s
.61152 .72735 m
.59459 .73985 L
s
.34506 .69522 m
.33639 .69888 L
s
.35826 .70519 m
.34817 .70799 L
s
.64066 .71008 m
.62512 .72486 L
s
.6837 .31985 m
.69409 .33829 L
s
.70399 .3442 m
.70264 .35606 L
s
.49091 .75012 m
.47321 .75509 L
s
.43713 .74098 m
.4213 .74382 L
s
.70839 .35204 m
.71366 .3709 L
s
.71074 .35561 m
.7147 .3738 L
s
.70482 .34779 m
.71136 .36721 L
s
.69957 .34101 m
.69672 .35177 L
s
.67543 .3149 m
.68694 .33358 L
s
.71182 .35826 m
.71444 .37569 L
s
.52728 .74731 m
.50899 .7547 L
s
.70005 .34312 m
.70783 .363 L
s
.56298 .74007 m
.54473 .74996 L
s
.71161 .35979 m
.71285 .37636 L
s
.41939 .73196 m
.40437 .73504 L
s
.69365 .33632 m
.68928 .34595 L
s
.59685 .72842 m
.57925 .74078 L
s
.62791 .71264 m
.61152 .72735 L
s
.65537 .69319 m
.64066 .71008 L
s
.47253 .74383 m
.45514 .74877 L
s
.69409 .33829 m
.70308 .35852 L
s
.71004 .36001 m
.70985 .37565 L
s
.68621 .33018 m
.68031 .3387 L
s
.40214 .72199 m
.38808 .72545 L
s
.33017 .66983 m
.32274 .67726 L
s
.67726 .32274 m
.66983 .33017 L
s
.70707 .3588 m
.70542 .37342 L
s
.68694 .33358 m
.69712 .35407 L
s
.50922 .74286 m
.49091 .75012 L
s
.38559 .71139 m
.37265 .71538 L
s
.34211 .6794 m
.33319 .68581 L
s
.71366 .3709 m
.71726 .39137 L
s
.71136 .36721 m
.71627 .38826 L
s
.36996 .70052 m
.35826 .70519 L
s
.35541 .68974 m
.34506 .69522 L
s
.45403 .73599 m
.43713 .74098 L
s
.7147 .3738 m
.71695 .39361 L
s
.70783 .363 m
.71402 .38451 L
s
.54584 .7376 m
.52728 .74731 L
s
.70264 .35606 m
.6995 .36962 L
s
.58115 .72789 m
.56298 .74007 L
s
.64356 .6958 m
.62791 .71264 L
s
.61402 .71384 m
.59685 .72842 L
s
.66905 .67431 m
.65537 .69319 L
s
.71444 .37569 m
.71531 .39473 L
s
.70308 .35852 m
.71053 .3804 L
s
.69672 .35177 m
.69206 .36423 L
s
.71285 .37636 m
.7123 .39454 L
s
.43563 .72679 m
.41939 .73196 L
s
.49069 .73666 m
.47253 .74383 L
s
.69712 .35407 m
.70581 .37621 L
s
.68928 .34595 m
.68309 .3573 L
s
.70985 .37565 m
.70785 .39289 L
s
.71627 .38826 m
.71943 .41075 L
s
.71402 .38451 m
.7185 .40746 L
s
.52795 .73332 m
.50922 .74286 L
s
.71726 .39137 m
.71907 .4133 L
s
.68154 .6536 m
.66905 .67431 L
s
.65829 .67695 m
.64356 .6958 L
s
.41755 .71649 m
.40214 .72199 L
s
.63057 .69711 m
.61402 .71384 L
s
.71053 .3804 m
.71631 .40372 L
s
.56447 .72561 m
.54584 .7376 L
s
.68031 .3387 m
.67259 .34895 L
s
.59903 .71347 m
.58115 .72789 L
s
.71695 .39361 m
.71739 .41487 L
s
.70542 .37342 m
.70193 .38966 L
s
.47187 .7288 m
.45403 .73599 L
s
.40001 .70542 m
.38559 .71139 L
s
.33938 .66062 m
.33017 .66983 L
s
.66983 .33017 m
.66062 .33938 L
s
.70581 .37621 m
.71287 .39979 L
s
.71531 .39473 m
.71434 .41523 L
s
.38323 .69393 m
.36996 .70052 L
s
.35275 .67117 m
.34211 .6794 L
s
.36742 .68239 m
.35541 .68974 L
s
.6995 .36962 m
.6945 .38481 L
s
.69265 .63123 m
.68154 .6536 L
s
.67189 .65626 m
.65829 .67695 L
s
.7185 .40746 m
.72118 .43165 L
s
.7123 .39454 m
.70988 .4142 L
s
.71943 .41075 m
.72076 .43448 L
s
.50944 .72721 m
.49069 .73666 L
s
.71631 .40372 m
.72032 .42825 L
s
.64629 .67836 m
.63057 .69711 L
s
.45297 .71946 m
.43563 .72679 L
s
.71907 .4133 m
.71902 .43648 L
s
.61641 .6969 m
.59903 .71347 L
s
.71287 .39979 m
.71819 .42457 L
s
.69206 .36423 m
.68554 .37834 L
s
.54692 .72149 m
.52795 .73332 L
s
.58296 .71138 m
.56447 .72561 L
s
.70785 .39289 m
.70397 .41163 L
s
.71739 .41487 m
.71594 .4374 L
s
.70224 .60744 m
.69265 .63123 L
s
.68419 .63391 m
.67189 .65626 L
s
.68309 .3573 m
.67505 .37033 L
s
.72032 .42825 m
.72246 .45375 L
s
.4342 .7089 m
.41755 .71649 L
s
.72118 .43165 m
.72197 .45682 L
s
.71819 .42457 m
.72167 .45029 L
s
.66098 .65777 m
.64629 .67836 L
s
.49047 .71938 m
.47187 .7288 L
s
.71434 .41523 m
.71146 .43703 L
s
.72076 .43448 m
.72018 .45922 L
s
.70193 .38966 m
.69655 .40742 L
s
.67259 .34895 m
.66306 .36093 L
s
.71015 .58246 m
.70224 .60744 L
s
.63307 .67832 m
.61641 .6969 L
s
.41581 .69742 m
.40001 .70542 L
s
.71902 .43648 m
.71705 .46069 L
s
.69501 .61015 m
.68419 .63391 L
s
.52859 .71553 m
.50944 .72721 L
s
.72246 .45375 m
.72268 .47992 L
s
.72167 .45029 m
.72324 .47666 L
s
.35036 .64964 m
.33938 .66062 L
s
.66062 .33938 m
.64964 .35036 L
s
.60109 .69501 m
.58296 .71138 L
s
.70988 .4142 m
.70555 .43517 L
s
.5659 .70745 m
.54692 .72149 L
s
.39802 .68538 m
.38323 .69393 L
s
.72197 .45682 m
.72082 .48269 L
s
.6945 .38481 m
.68761 .40155 L
s
.36511 .66111 m
.35275 .67117 L
s
.71628 .5566 m
.71015 .58246 L
s
.38105 .67315 m
.36742 .68239 L
s
.67444 .63554 m
.66098 .65777 L
s
.71594 .4374 m
.71255 .46099 L
s
.72324 .47666 m
.72287 .50338 L
s
.47124 .70997 m
.45297 .71946 L
s
.70421 .58523 m
.69501 .61015 L
s
.72018 .45922 m
.71765 .48469 L
s
.72268 .47992 m
.72094 .50647 L
s
.72054 .53013 m
.71628 .5566 L
s
.72287 .50338 m
.72054 .53013 L
s
.64879 .6579 m
.63307 .67832 L
s
.70397 .41163 m
.69815 .43171 L
s
.68554 .37834 m
.67714 .39403 L
s
.72082 .48269 m
.71772 .50897 L
s
.71166 .55944 m
.70421 .58523 L
s
.72094 .50647 m
.71726 .53308 L
s
.68649 .6119 m
.67444 .63554 L
s
.71146 .43703 m
.70664 .4599 L
s
.71705 .46069 m
.71312 .48566 L
s
.71726 .53308 m
.71166 .55944 L
s
.61862 .67663 m
.60109 .69501 L
s
.50965 .70776 m
.49047 .71938 L
s
.45196 .69921 m
.4342 .7089 L
s
.71765 .48469 m
.71316 .5106 L
s
.71772 .50897 m
.71267 .53535 L
s
.67505 .37033 m
.66517 .38499 L
s
.58466 .69129 m
.5659 .70745 L
s
.69696 .58712 m
.68649 .6119 L
s
.54793 .70165 m
.52859 .71553 L
s
.69655 .40742 m
.68924 .42655 L
s
.66338 .63585 m
.64879 .6579 L
s
.71255 .46099 m
.70721 .48537 L
s
.71267 .53535 m
.70572 .5615 L
s
.70555 .43517 m
.69926 .45726 L
s
.70572 .5615 m
.69696 .58712 L
s
.43288 .68739 m
.41581 .69742 L
s
.66306 .36093 m
.65173 .37458 L
s
.71312 .48566 m
.70724 .51111 L
s
.71316 .5106 m
.70674 .53665 L
s
.63533 .65644 m
.61862 .67663 L
s
.67663 .61241 m
.66338 .63585 L
s
.49027 .69833 m
.47124 .70997 L
s
.68761 .40155 m
.67881 .4197 L
s
.36307 .63693 m
.35036 .64964 L
s
.64964 .35036 m
.63693 .36307 L
s
.41422 .67488 m
.39802 .68538 L
s
.70664 .4599 m
.69986 .48361 L
s
.37911 .64926 m
.36511 .66111 L
s
.39622 .66203 m
.38105 .67315 L
s
.70674 .53665 m
.69845 .56251 L
s
.69815 .43171 m
.6904 .45294 L
s
.68837 .58787 m
.67663 .61241 L
s
.60298 .67315 m
.58466 .69129 L
s
.69845 .56251 m
.68837 .58787 L
s
.52919 .694 m
.50965 .70776 L
s
.70721 .48537 m
.69992 .51027 L
s
.70724 .51111 m
.69945 .53673 L
s
.56721 .68569 m
.54793 .70165 L
s
.651 .63463 m
.63533 .65644 L
s
.67714 .39403 m
.66687 .41119 L
s
.47066 .68744 m
.45196 .69921 L
s
.69926 .45726 m
.69104 .48022 L
s
.68924 .42655 m
.68002 .44688 L
s
.69945 .53673 m
.6898 .56221 L
s
.66543 .61147 m
.651 .63463 L
s
.6206 .65321 m
.60298 .67315 L
s
.66517 .38499 m
.65346 .40116 L
s
.69986 .48361 m
.69115 .50788 L
s
.69992 .51027 m
.69074 .53538 L
s
.6898 .56221 m
.67842 .58723 L
s
.67842 .58723 m
.66543 .61147 L
s
.45105 .67537 m
.43288 .68739 L
s
.50984 .68461 m
.49027 .69833 L
s
.58621 .66779 m
.56721 .68569 L
s
.65173 .37458 m
.63865 .38982 L
s
.54885 .6782 m
.52919 .694 L
s
.6904 .45294 m
.68073 .47509 L
s
.67881 .4197 m
.66813 .43909 L
s
.63731 .6317 m
.6206 .65321 L
s
.43168 .66246 m
.41422 .67488 L
s
.69074 .53538 m
.67975 .5604 L
s
.63693 .36307 m
.62256 .37744 L
s
.37744 .62256 m
.36307 .63693 L
s
.41281 .64909 m
.39622 .66203 L
s
.39465 .63566 m
.37911 .64926 L
s
.69104 .48022 m
.68092 .50379 L
s
.69115 .50788 m
.68059 .53241 L
s
.65287 .60887 m
.63731 .6317 L
s
.49008 .67366 m
.47066 .68744 L
s
.67975 .5604 m
.66707 .585 L
s
.66687 .41119 m
.65477 .42966 L
s
.60466 .64813 m
.58621 .66779 L
s
.68002 .44688 m
.66892 .46819 L
s
.66707 .585 m
.65287 .60887 L
s
.52973 .66892 m
.50984 .68461 L
s
.5684 .66052 m
.54885 .6782 L
s
.68059 .53241 m
.66827 .5569 L
s
.65346 .40116 m
.63999 .41872 L
s
.68073 .47509 m
.66921 .49791 L
s
.47014 .66142 m
.45105 .67537 L
s
.62232 .62694 m
.60466 .64813 L
s
.68092 .50379 m
.66899 .52768 L
s
.66813 .43909 m
.65564 .45954 L
s
.66827 .5569 m
.65434 .58103 L
s
.63865 .38982 m
.6239 .40652 L
s
.63895 .60447 m
.62232 .62694 L
s
.45024 .64821 m
.43168 .66246 L
s
.58756 .64113 m
.5684 .66052 L
s
.65434 .58103 m
.63895 .60447 L
s
.51001 .65799 m
.49008 .67366 L
s
.62256 .37744 m
.60664 .39336 L
s
.39336 .60664 m
.37744 .62256 L
s
.43065 .63441 m
.41281 .64909 L
s
.66892 .46819 m
.65603 .49023 L
s
.41161 .62042 m
.39465 .63566 L
s
.54967 .6514 m
.52973 .66892 L
s
.66899 .52768 m
.65537 .55159 L
s
.65477 .42966 m
.64093 .44924 L
s
.66921 .49791 m
.65594 .52113 L
s
.60608 .62027 m
.58756 .64113 L
s
.48992 .64567 m
.47014 .66142 L
s
.65537 .55159 m
.64022 .5752 L
s
.63999 .41872 m
.62488 .43748 L
s
.65564 .45954 m
.64142 .48079 L
s
.62371 .5982 m
.60608 .62027 L
s
.56941 .63225 m
.54967 .6514 L
s
.64022 .5752 m
.62371 .5982 L
s
.53019 .64058 m
.51001 .65799 L
s
.65594 .52113 m
.64106 .54442 L
s
.46969 .63226 m
.45024 .64821 L
s
.65603 .49023 m
.64147 .51274 L
s
.6239 .40652 m
.60762 .42452 L
s
.44957 .61813 m
.43065 .63441 L
s
.60664 .39336 m
.58932 .41068 L
s
.41068 .58932 m
.39336 .60664 L
s
.64093 .44924 m
.62547 .46973 L
s
.42982 .60368 m
.41161 .62042 L
s
.58868 .61171 m
.56941 .63225 L
s
.64106 .54442 m
.62475 .56749 L
s
.51016 .62827 m
.48992 .64567 L
s
.55036 .62162 m
.53019 .64058 L
s
.64142 .48079 m
.62564 .5026 L
s
.60721 .59002 m
.58868 .61171 L
s
.64147 .51274 m
.6254 .53541 L
s
.62475 .56749 m
.60721 .59002 L
s
.62488 .43748 m
.60827 .45724 L
s
.48979 .61476 m
.46969 .63226 L
s
.57024 .60134 m
.55036 .62162 L
s
.60762 .42452 m
.58998 .44361 L
s
.6254 .53541 m
.60802 .55794 L
s
.62547 .46973 m
.60855 .49085 L
s
.53058 .60941 m
.51016 .62827 L
s
.46933 .60041 m
.44957 .61813 L
s
.58932 .41068 m
.5708 .4292 L
s
.4292 .5708 m
.41068 .58932 L
s
.62564 .5026 m
.60847 .52466 L
s
.44905 .58562 m
.42982 .60368 L
s
.58954 .58002 m
.57024 .60134 L
s
.60802 .55794 m
.58954 .58002 L
s
.60827 .45724 m
.59034 .47774 L
s
.51027 .59592 m
.48979 .61476 L
s
.5509 .58935 m
.53058 .60941 L
s
.60847 .52466 m
.59012 .54667 L
s
.60855 .49085 m
.59039 .51234 L
s
.58998 .44361 m
.57119 .46357 L
s
.48969 .58147 m
.46933 .60041 L
s
.57084 .56834 m
.5509 .58935 L
s
.59012 .54667 m
.57084 .56834 L
s
.5708 .4292 m
.5513 .4487 L
s
.4487 .5513 m
.4292 .5708 L
s
.46908 .56645 m
.44905 .58562 L
s
.53086 .57598 m
.51027 .59592 L
s
.59034 .47774 m
.57132 .49871 L
s
.59039 .51234 m
.5712 .53389 L
s
.51036 .56155 m
.48969 .58147 L
s
.55127 .5552 m
.53086 .57598 L
s
.57119 .46357 m
.55148 .48411 L
s
.5712 .53389 m
.55127 .5552 L
s
.48962 .54644 m
.46908 .56645 L
s
.46892 .53108 m
.4487 .5513 L
s
.5513 .4487 m
.53108 .46892 L
s
.57132 .49871 m
.55147 .51987 L
s
.53105 .54092 m
.51036 .56155 L
s
.55147 .51987 m
.53105 .54092 L
s
.55148 .48411 m
.53112 .50497 L
s
.5104 .52585 m
.48962 .54644 L
s
.53108 .46892 m
.51041 .48959 L
s
.48959 .51041 m
.46892 .53108 L
s
.53112 .50497 m
.5104 .52585 L
s
.51041 .48959 m
.48959 .51041 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
VGoo2@0OOWoo002DOol501l9Ool401mjOol0091oo`@07`Eooa407gIoo`00SGoo0`0O1Goo100O3Goo
1P0OM7oo002;Ool201l6Ool201l8OolA01mbOol008Uoo`807`Ioo`807`Eoo`D07a1oo`@07fmoo`00
R7oo00<07gooOol017oo0P0O17oo0`0O2Goo4P0OKGoo0026Ool201l5Ool201l4Ool201l7Ool501l?
Ool501m[Ool008Eoo`0301moogoo00=oo`807`Aoo`807`Ioo`<07`Uoo`/07`9oo`@07fYoo`00Q7oo
00<07gooOol00Woo0P0O17oo0P0O1Woo0P0O1goo1@0O2goo100O00Aoo`0O01l07fQoo`00PWoo0P0O
0goo0P0O17oo0P0O1Woo0P0O1Woo0`0O37oo1`0O00=oo`0O01l00`0OIgoo0021Ool0100OOomoogoo
0P0O1Goo00<07gooOol017oo0P0O1Woo0P0O27oo1`0O1goo100O00Aoo`0O01l07fEoo`00P7oo00D0
7gooOomoo`0O00Eoo`807`Eoo`807`Ioo`807`Qoo`807`]oo`H07`03Ool07`0O00@07f=oo`00OWoo
0P0O0Woo0P0O1Goo00<07gooOol00goo0P0O1Woo0P0O1goo0`0O2Goo100O1Woo200OHWoo001mOol0
1@0OOomoogoo01l01Woo00<07gooOol00Woo0P0O1Woo0P0O1Woo0`0O27oo100O3Woo1@0OHGoo001l
Ool01@0OOomoogoo01l01Goo0P0O17oo00<07gooOol017oo0P0O1Woo0P0O27oo0`0O1goo4P0OGgoo
001jOol201l3Ool00`0OOomoo`03Ool00`0OOomoo`02Ool201l5Ool201l6Ool201l8Ool201l6Ool4
01l=Ool601mNOol007Uoo`0301moogoo009oo`0301moogoo00=oo`0301moogoo009oo`0301moogoo
00Aoo`0301moogoo00Aoo`807`Moo`<07`Eoo`<07`Yoo`h07eeoo`00N7oo00<07gooOol00Woo00<0
7gooOol00Woo0P0O17oo00<07gooOol00goo0P0O1Goo0P0O1Woo0`0O1Woo0P0O2Woo0`0O1Woo1@0O
00Aoo`0O01l07eaoo`00Mgoo00<07gooOol00Woo00<07gooOol00Woo00<07gooOol00Woo0P0O1Goo
00<07gooOol017oo00<07gooOol01Goo00<07gooOol01Goo0P0O27oo100O1Woo0`0O17oo1P0OFgoo
001gOol01@0OOomoogoo01l017oo00<07gooOol00Woo00<07gooOol017oo00<07gooOol00goo0P0O
1Woo0P0O1Woo0P0O27oo0P0O1Woo100O1Goo2P0OFGoo001fOol01@0OOomoogoo01l017oo00<07goo
Ool00Woo00<07gooOol00goo0P0O1Goo00<07gooOol01Goo00<07gooOol017oo0P0O27oo0P0O1Goo
0`0O1Woo0`0O0Woo200OFGoo001eOol01@0OOomoogoo01l017oo00@07gooOomoo`807`Eoo`0301mo
ogoo00Aoo`0301moogoo00Aoo`807`Eoo`807`Moo`<07`Eoo`807`Ioo`<07`9oo`<07`9oo`L07eQo
o`00M7oo00D07gooOomoo`0O00Aoo`0501moogooOol07`06Ool00`0OOomoo`03Ool201l5Ool201l6
Ool00`0OOomoo`04Ool301l6Ool201l6Ool201l3Ool201l4Ool00`0OOol07`0601mGOol007Aoo`05
01moogooOol07`03Ool01@0OOomoogoo01l01Goo0P0O1Goo00<07gooOol017oo00<07gooOol01Goo
00<07gooOol017oo00<07gooOol01Goo0P0O1Woo0P0O0goo0P0O17oo300OEWoo001cOol01@0OOomo
ogoo01l00goo00D07gooOomoo`0O00Eoo`0301moogoo00Aoo`0301moogoo00=oo`807`Ioo`807`Eo
o`807`Ioo`807`Eoo`<07`Aoo`0301moogoo009oo`807`07Ool07goo01moo`0OOol01@0OEWoo001b
Ool01@0OOomoogoo01l00goo00<07gooOol00Woo00<07gooOol00Woo00<07gooOol00goo0P0O1Goo
00<07gooOol01Goo00<07gooOol017oo00<07gooOol017oo0P0O1Goo0P0O1Goo0P0O0goo0P0O0Woo
00<07goo01l00goo1`0OEGoo001aOol01@0OOomoogoo01l00goo00<07gooOol00Woo00<07gooOol0
0Woo00<07gooOol00goo00<07gooOol017oo00<07gooOol017oo0P0O1Goo0P0O1Goo0P0O1Goo0P0O
1Woo00<07gooOol00Woo00<07gooOol00P0O00=oo`0OOol00goo1`0OEGoo001aOol01@0OOomoogoo
01l00Woo00<07gooOol00Woo00<07gooOol00goo00<07gooOol00Woo00<07gooOol00goo0P0O1Goo
0P0O1Goo0P0O1Woo00<07gooOol017oo00<07gooOol017oo0P0O0goo0P0O0Woo00@07gooOol07`Ao
o`0301moo`0O00D07eEoo`00L7oo00D07gooOomoo`0O00=oo`0501moogooOol07`05Ool00`0OOomo
o`02Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`05Ool00`0OOomo
o`04Ool00`0OOomoo`04Ool00`0OOomoo`02Ool01@0OOomoogoo01l00Woo00<07gooOol00goo00<0
7gooOol01P0OE7oo001`Ool0100OOomoo`0O0goo00<07gooOol00Woo00<07gooOol00Woo00<07goo
Ool00Woo00<07gooOol00goo00<07gooOol00goo0P0O1Goo0P0O1Woo0P0O1Goo0P0O1Goo0P0O17oo
00D07gooOomoo`0O009oo`0301moogoo00=oo`0401moogooOol601mDOol006moo`0501moogooOol0
7`02Ool00`0OOomoo`02Ool0100OOomoogoo0P0O17oo00<07gooOol00Woo0P0O1Goo00<07gooOol0
17oo00<07gooOol01Goo00<07gooOol017oo00<07gooOol017oo00<07gooOol00goo00<07gooOol0
0P0O0Woo00<07gooOol017oo00D07gooOol07goo00807`03Ool07`0O05Aoo`00Kgoo00@07gooOol0
7`9oo`0301moogoo009oo`0501moogooOol07`05Ool00`0OOomoo`02Ool00`0OOomoo`04Ool00`0O
Oomoo`04Ool00`0OOomoo`04Ool201l5Ool201l5Ool201l4Ool201l2Ool01@0OOomoogoo01l01Woo
00H07gooOomoo`0OOol501mDOol006ioo`0501moogooOol07`02Ool01@0OOomoogoo01l00goo00<0
7gooOol00goo00<07gooOol00Woo00<07gooOol00goo0P0O1Woo00<07gooOol00goo0P0O1Goo0P0O
1Goo0P0O17oo0P0O0goo00D07gooOomoo`0O00Ioo`0501moogooOol07`02Ool601mCOol006ioo`04
01moogoo01l2Ool01@0OOomoogoo01l00goo00<07gooOol00goo00<07gooOol00Woo00<07gooOol0
0goo00<07gooOol01Goo00<07gooOol00goo00<07gooOol017oo00<07gooOol017oo00<07gooOol0
0goo00<07gooOol00Woo00D07gooOomoo`0O00Ioo`0301moogoo009oo`0401moo`0OOol501mCOol0
06eoo`0401moogoo01l2Ool01@0OOomoogoo01l017oo00<07gooOol00Woo00<07gooOol00goo00<0
7gooOol00Woo00<07gooOol01Goo00<07gooOol00Woo0P0O1Woo00<07gooOol017oo00<07gooOol0
0goo00<07gooOol00Woo00D07gooOomoo`0O00Ioo`0301moogoo009oo`0401moogoo01l2Ool401mC
Ool006aoo`0401moogoo01l3Ool0100OOomoo`0O17oo00<07gooOol00Woo00<07gooOol00goo00<0
7gooOol00Woo00<07gooOol017oo0P0O17oo00<07gooOol01Goo00<07gooOol017oo00<07gooOol0
0goo00<07gooOol00Woo00D07gooOomoo`0O00Ioo`0301moogoo009oo`0601moogooOol07goo1@0O
Dgoo001/Ool0100OOomoo`0O0Woo00@07gooOol07`Aoo`0301moogoo009oo`0301moogoo00=oo`03
01moogoo009oo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00Eoo`0301moogoo00Aoo`03
01moogoo009oo`807`Aoo`0501moogooOol07`06Ool00`0OOomoo`03Ool0100OOomoo`0O0Woo1P0O
DWoo001[Ool0100OOomoo`0O0goo00@07gooOol07`=oo`0301moogoo009oo`0301moogoo009oo`80
7`Aoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00Aoo`807`Eoo`807`Aoo`0301moogoo
00=oo`0501moogooOol07`07Ool00`0OOomoo`02Ool01@0OOomoogoo01l00Woo00<07goo01l00`0O
DWoo001[Ool0100OOomoo`0O0Woo00@07gooOol07`Aoo`0501moogooOol07`04Ool00`0OOomoo`03
Ool00`0OOomoo`03Ool201l5Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0O
Oomoo`02Ool201l3Ool00`0OOomoo`05Ool00`0OOomoo`02Ool01@0OOomoogoo01l00goo00<07goo
01l00`0ODWoo001ZOol0100OOomoo`0O0Woo00D07gooOomoo`0O00=oo`0501moogooOol07`04Ool0
0`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`04Ool0
0`0OOomoo`02Ool201l4Ool00`0OOomoo`02Ool00`0OOomoo`05Ool00`0OOomoo`02Ool00`0OOomo
o`02Ool0100OOomoo`0O0Woo100ODWoo001ZOol0100OOomoo`0O0Woo00@07gooOol07`=oo`0301mo
ogoo009oo`0501moogooOol07`05Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`03Ool2
01l5Ool201l4Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`05Ool00`0OOomoo`03Ool0
0`0OOomoo`02Ool01`0OOomoo`0OOol07goo00<07e9oo`00JGoo00@07gooOol07`9oo`0501moogoo
Ool07`03Ool01@0OOomoogoo01l017oo00<07gooOol00Woo00<07gooOol00goo00<07gooOol017oo
00<07gooOol00goo00<07gooOol017oo00<07gooOol00goo00<07gooOol00Woo0P0O17oo00<07goo
Ool01Goo00<07gooOol00goo00<07gooOol00Woo00P07gooOomoo`0OOol07goo0`0ODWoo001YOol0
100OOomoo`0O0Woo00@07gooOol07`=oo`0501moogooOol07`04Ool00`0OOomoo`02Ool00`0OOomo
o`03Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomo
o`02Ool00`0OOomoo`03Ool00`0OOomoo`05Ool00`0OOomoo`03Ool00`0OOomoo`03Ool0200OOomo
ogoo01moo`0OOol301mBOol006Uoo`0601moogoo01moo`0O0goo00D07gooOomoo`0O009oo`0301mo
ogoo009oo`0301moogoo009oo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo00=oo`0301mo
ogoo00Aoo`0301moogoo00=oo`0301moogoo009oo`0301moogoo00=oo`0301moogoo00Eoo`0301mo
ogoo00Aoo`0301moogoo009oo`0501moogooOol07`02Ool00`0OOol07`0201mBOol006Qoo`0401mo
ogoo01l2Ool0100OOomoo`0O0goo00D07gooOomoo`0O00=oo`0301moogoo009oo`0301moogoo00=o
o`0301moogoo00=oo`807`Eoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo009oo`0301mo
ogoo00=oo`0301moogoo00Eoo`0301moogoo00Aoo`0301moogoo00=oo`0701moogooOol07goo01l0
0Woo0`0ODWoo001XOol01P0OOomoo`0OOol07`9oo`0501moogooOol07`03Ool01@0OOomoogoo01l0
17oo00<07gooOol00goo00<07gooOol00goo00<07gooOol017oo00<07gooOol017oo00<07gooOol0
0Woo0P0O1Goo00<07gooOol00Woo00<07gooOol01Woo00<07gooOol017oo00<07gooOol00Woo00D0
7gooOomoo`0O009oo`0301moogoo00<07e9oo`00Igoo00@07gooOol07`9oo`0401moogoo01l2Ool0
1@0OOomoogoo01l00goo00<07gooOol00Woo00<07gooOol00goo00<07gooOol00goo00<07gooOol0
17oo00<07gooOol00goo0P0O17oo00<07gooOol017oo00<07gooOol00Woo00<07gooOol01Woo00<0
7gooOol017oo00<07gooOol00goo00L07gooOomoo`0OOol07`02Ool00`0OOol07`0201mAOol006Mo
o`0601moogoo01moo`0O0Woo00D07gooOomoo`0O009oo`0501moogooOol07`05Ool00`0OOomoo`02
Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`04
Ool00`0OOomoo`02Ool00`0OOomoo`06Ool00`0OOomoo`04Ool00`0OOomoo`03Ool01@0OOomoogoo
01l00Woo00<07gooOol00P0O00=oo`0O01l0DGoo001WOol0200OOomoo`0OOol07goo01l3Ool01@0O
Oomoogoo01l00Woo00<07gooOol00goo00<07gooOol00Woo00<07gooOol017oo00<07gooOol00goo
00<07gooOol00goo00<07gooOol00goo00<07gooOol017oo00<07gooOol00Woo00<07gooOol01Woo
00<07gooOol017oo00<07gooOol017oo00D07gooOomoo`0O009oo`0301moogoo00807`03Ool07`0O
055oo`00Igoo00D07goo01moo`0O009oo`0401moogoo01l3Ool01@0OOomoogoo01l017oo00<07goo
Ool00Woo00<07gooOol017oo00<07gooOol00goo00<07gooOol00Woo0P0O1Goo00<07gooOol017oo
00<07gooOol00Woo00<07gooOol01Woo00<07gooOol01Goo00<07gooOol00goo00D07gooOomoo`0O
009oo`0401moogooOol201l00goo01l07`1AOol006Ioo`0801moogoo01moo`0OOol07`=oo`0401mo
ogoo01l3Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomoo`04Ool00`0OOomoo`02Ool201l4
Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`02Ool00`0OOomoo`06Ool00`0OOomoo`05
Ool00`0OOomoo`03Ool00`0OOomoo`02Ool0100OOomoo`0O0goo0P0O00=oo`0O01l0DGoo001VOol0
1@0OOol07goo01l00Woo00@07gooOol07`9oo`0501moogooOol07`05Ool01@0OOomoogoo01l01Goo
0P0O17oo00<07gooOol00goo00<07gooOol017oo00<07gooOol00goo0P0O17oo00<07gooOol01Woo
00<07gooOol01Goo00<07gooOol00goo00<07gooOol00Woo00D07gooOomoo`0O009oo`0401moo`0O
Ool201mAOol006Ioo`0701moo`0OOol07goo01l00goo00@07gooOol07`=oo`0301moogoo009oo`05
01moogooOol07`05Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`03
Ool00`0OOomoo`03Ool00`0OOomoo`06Ool00`0OOomoo`05Ool00`0OOomoo`04Ool01@0OOomoogoo
01l00goo00@07gooOomoo`807`9oo`807e5oo`00IWoo00L07goo01moo`0OOol07`02Ool0100OOomo
o`0O0goo00<07gooOol00Woo00<07gooOol00Woo00<07gooOol00Woo00<07gooOol00goo00<07goo
Ool017oo00<07gooOol00goo00<07gooOol00goo00<07gooOol00goo00<07gooOol01Woo00<07goo
Ool01Goo00<07gooOol017oo00<07gooOol00Woo00D07gooOomoo`0O009oo`0401moo`0OOol301mA
Ool006Ioo`807`04Ool07goo01l2Ool0100OOomoo`0O17oo00D07gooOomoo`0O00Aoo`0301moogoo
009oo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo
00=oo`0301moogoo00Ioo`0301moogoo00Ioo`0301moogoo00=oo`0301moogoo009oo`0301moogoo
009oo`0701moogoo01moo`0OOol00`0ODGoo001UOol01`0OOol07goo01moo`0O009oo`0401moogoo
01l3Ool01@0OOomoogoo01l017oo00<07gooOol00Woo00<07gooOol017oo00<07gooOol00goo00<0
7gooOol00Woo0P0O1Goo00<07gooOol00goo00<07gooOol01Woo00<07gooOol01Woo00<07gooOol0
0goo00<07gooOol00goo00D07gooOomoo`0O00=oo`0401moo`0OOol301mAOol006Eoo`807`04Ool0
7goo01l2Ool0100OOomoo`0O0goo00D07gooOomoo`0O00Aoo`0301moogoo009oo`0301moogoo00Ao
o`0301moogoo009oo`807`Aoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00Moo`0301mo
ogoo00Eoo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo009oo`0401moogoo01l2Ool00`0O
Ool07`0201mAOol006Eoo`807`04Ool07goo01l2Ool0100OOomoo`0O0Woo00D07gooOomoo`0O00Eo
o`0501moogooOol07`05Ool201l4Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`03Ool0
0`0OOomoo`07Ool00`0OOomoo`05Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`02Ool0
1P0OOomoo`0OOol07`9oo`@07e1oo`00IGoo0P0O00Ioo`0OOol07goo01l2Ool01@0OOomoogoo01l0
0Woo00<07gooOol00goo00D07gooOomoo`0O00Eoo`0301moogoo00=oo`0301moogoo00=oo`0301mo
ogoo00Aoo`0301moogoo00=oo`0301moogoo00Moo`0301moogoo00Eoo`0301moogoo00Aoo`0301mo
ogoo00=oo`0301moogoo009oo`0:01moogooOol07goo01moo`0OOol301m@Ool006Eoo`<07`05Ool0
7gooOol07`02Ool0100OOomoo`0O0goo00<07gooOol00Woo00<07gooOol00Woo00<07gooOol00Woo
00<07gooOol00goo00<07gooOol017oo00<07gooOol00goo00<07gooOol00goo00<07gooOol01goo
00<07gooOol01Goo00<07gooOol017oo00<07gooOol017oo00<07gooOol00Woo00@07gooOol07`9o
o`0401moo`0OOol301m@Ool006Aoo`807`06Ool07goo01moo`0O0Woo00@07gooOol07`=oo`0301mo
ogoo009oo`0301moogoo009oo`0301moogoo009oo`0301moogoo00Aoo`0301moogoo00=oo`0301mo
ogoo00=oo`0301moogoo00=oo`0301moogoo00Moo`0301moogoo00Ioo`0301moogoo00=oo`0301mo
ogoo00Aoo`0301moogoo009oo`0501moogooOol07`02Ool00`0OOol07`0401m@Ool006Aoo`<07`05
Ool07gooOol07`02Ool0100OOomoo`0O0Woo00<07gooOol00Woo00<07gooOol00Woo00<07gooOol0
0goo00<07gooOol00goo00<07gooOol00goo00<07gooOol00Woo0P0O1Goo00<07gooOol01goo00<0
7gooOol01Woo00<07gooOol017oo00<07gooOol017oo00<07gooOol00Woo00X07gooOomoo`0OOol0
7goo01moo`@07e1oo`00I7oo0`0O00Aoo`0OOol07`9oo`0401moogoo01l2Ool00`0OOomoo`02Ool0
0`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`02Ool201l4Ool00`0OOomo
o`04Ool00`0OOomoo`07Ool00`0OOomoo`06Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomo
o`02Ool01@0OOomoogoo01l00Woo00@07goo01moo`@07e1oo`00I7oo0`0O00Aoo`0OOol07`9oo`04
01moogoo01l2Ool01@0OOomoogoo01l01Goo00<07gooOol00Woo00<07gooOol00Woo0P0O17oo00<0
7gooOol00goo00<07gooOol017oo00<07gooOol01goo00<07gooOol01Woo00<07gooOol017oo00<0
7gooOol017oo00<07gooOol00Woo00<07gooOol00Woo00L07gooOol07goo01moo`0401m@Ool006Ao
o`<07`03Ool07`0O009oo`0401moogoo01l2Ool01@0OOomoogoo01l01Goo00<07gooOol00Woo00<0
7gooOol00Woo00<07gooOol00goo00<07gooOol00goo00<07gooOol017oo00<07gooOol01goo00<0
7gooOol01Woo00<07gooOol01Goo00<07gooOol017oo00<07gooOol00Woo00D07gooOomoo`0O009o
o`0301moo`0O009oo`@07e1oo`00I7oo0P0O00Aoo`0OOol07`9oo`0401moogoo01l2Ool01@0OOomo
ogoo01l017oo00<07gooOol00Woo00<07gooOol00Woo00<07gooOol00goo00<07gooOol017oo00<0
7gooOol00goo00<07gooOol01goo00<07gooOol01Woo00<07gooOol01Goo00<07gooOol017oo00<0
7gooOol00Woo00<07gooOol00Woo00T07gooOol07goo01moo`0OOol00`0OD7oo001SOol301l00goo
01l07`02Ool0100OOomoo`0O0Woo00D07gooOomoo`0O00Aoo`0301moogoo009oo`0301moogoo009o
o`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo00Moo`0301moogoo00Mo
o`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo009oo`0301moogoo009oo`0:01moogooOol0
7goo01moo`0OOol301m@Ool006=oo`<07`03Ool07`0O009oo`0401moogoo01l2Ool0100OOomoo`0O
1Goo00D07gooOomoo`0O00Eoo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo00=oo`0301mo
ogoo00Moo`0301moogoo00Moo`0301moogoo00Aoo`0301moogoo00Eoo`0301moogoo009oo`0301mo
ogoo009oo`0401moogoo01l2Ool00`0OOol07`0401m@Ool006=oo`<07`05Ool07`0OOol07`02Ool0
100OOomoo`0O0Woo00<07gooOol00goo00D07gooOomoo`0O00Eoo`0301moogoo00=oo`0301moogoo
00=oo`0301moogoo00=oo`0301moogoo00Moo`0301moogoo00Moo`0301moogoo00Aoo`0301moogoo
00Eoo`0301moogoo009oo`0301moogoo009oo`0701moogooOol07goo01l00Woo1@0OD7oo001SOol4
01l01Woo01moo`0OOol07`=oo`0401moogoo01l4Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`0O
Oomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0O
Oomoo`05Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`02Ool02P0OOomoogoo01moo`0O
Ool07goo100OD7oo001SOol201l01Goo01l07goo01l00Woo00@07gooOol07`9oo`0301moogoo009o
o`0301moogoo009oo`0301moogoo009oo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo00=o
o`0301moogoo00Moo`0301moogoo00Moo`0301moogoo00Eoo`0301moogoo00Eoo`0301moogoo009o
o`0301moogoo009oo`0501moogooOol07`02Ool0100OOol07goo100OD7oo001ROol401l01Woo01mo
o`0OOol07`9oo`0401moogoo01l4Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomoo`03Ool0
0`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`05Ool0
0`0OOomoo`05Ool00`0OOomoo`03Ool00`0OOomoo`02Ool01`0OOomoogoo01moo`0O009oo`0301mo
o`0O00<07e1oo`00HWoo100O00=oo`0O01l00Woo00@07gooOol07`9oo`0501moogooOol07`04Ool0
0`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`07Ool0
0`0OOomoo`07Ool00`0OOomoo`05Ool00`0OOomoo`05Ool00`0OOomoo`03Ool00`0OOomoo`02Ool0
1@0OOomoogoo01l00Woo00H07goo01moo`0OOol301m@Ool0069oo`@07`05Ool07`0OOol07`02Ool0
100OOomoo`0O0goo00<07gooOol00goo00D07gooOomoo`0O00Eoo`0301moogoo00=oo`0301moogoo
00=oo`0301moogoo00Moo`0301moogoo00Moo`0301moogoo00Ioo`0301moogoo00Aoo`0301moogoo
00Aoo`0301moogoo009oo`0501moogooOol07`02Ool01P0OOol07goo01moo`<07e1oo`00HWoo1@0O
00Aoo`0OOol07`9oo`0401moogoo01l2Ool00`0OOomoo`03Ool01@0OOomoogoo01l01Goo00<07goo
Ool00goo00<07gooOol00goo00<07gooOol01goo00<07gooOol01goo00<07gooOol01Woo00<07goo
Ool01Goo00<07gooOol00goo00<07gooOol00Woo00D07gooOomoo`0O00=oo`0401moo`0OOol501m@
Ool0069oo`<07`05Ool07`0OOol07`02Ool0100OOomoo`0O0goo00<07gooOol00Woo00<07gooOol0
0Woo00<07gooOol00Woo00<07gooOol00goo00<07gooOol00goo00<07gooOol01goo00<07gooOol0
1goo00<07gooOol01Woo00<07gooOol01Goo00<07gooOol017oo00<07gooOol00Woo00D07gooOomo
o`0O009oo`0501moogoo01moo`0501m@Ool0069oo`@07`04Ool07goo01l2Ool0100OOomoo`0O0Woo
00@07gooOomoo`807`Aoo`0301moogoo009oo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo
00Moo`0301moogoo00Moo`0301moogoo00Ioo`0301moogoo00Eoo`0301moogoo00Aoo`0301moogoo
009oo`0301moogoo009oo`0901moogoo01moo`0OOol07goo00@07e1oo`00HWoo100O00=oo`0O01l0
0Woo00@07gooOol07`9oo`0501moogooOol07`05Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00`0O
Oomoo`03Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`04Ool00`0O
Oomoo`05Ool00`0OOomoo`02Ool01@0OOomoogoo01l00goo00H07goo01moo`0OOol401m@Ool0069o
o`@07`03Ool07`0O009oo`0401moogoo01l2Ool0100OOomoo`0O1Goo00<07gooOol00Woo00<07goo
Ool00goo00<07gooOol00goo00<07gooOol01goo00<07gooOol027oo00<07gooOol01Woo00<07goo
Ool017oo00<07gooOol01Goo00<07gooOol00Woo00<07gooOol00Woo00@07gooOol07`9oo`0401mo
o`0OOol401m@Ool0069oo`D07`04Ool07goo01l2Ool0100OOomoo`0O0Woo00<07gooOol00goo00<0
7gooOol00Woo00<07gooOol00goo00<07gooOol00goo00<07gooOol01goo00<07gooOol027oo00<0
7gooOol01Woo00<07gooOol01Goo00<07gooOol017oo00<07gooOol00goo00D07gooOomoo`0O00=o
o`0801moo`0OOol07goo01moo`807e5oo`00HWoo0`0O00Eoo`0O01moo`0O009oo`0501moogooOol0
7`02Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomo
o`07Ool00`0OOomoo`08Ool00`0OOomoo`06Ool00`0OOomoo`05Ool00`0OOomoo`04Ool00`0OOomo
o`03Ool00`0OOomoo`02Ool0100OOomoo`0O0Woo00H07goo01moo`0OOol201mAOol0069oo`@07`04
Ool07goo01l2Ool0100OOomoo`0O0Woo00<07gooOol00Woo00<07gooOol00goo00<07gooOol00Woo
00<07gooOol00goo00<07gooOol01goo00<07gooOol027oo00<07gooOol01Woo00<07gooOol01Goo
00<07gooOol017oo00<07gooOol00goo00<07gooOol00Woo00D07gooOomoo`0O009oo`0401moo`0O
Ool401mAOol0069oo`@07`03Ool07`0O009oo`0401moogoo01l2Ool00`0OOomoo`02Ool00`0OOomo
o`03Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`07Ool00`0OOomoo`08Ool00`0OOomo
o`06Ool00`0OOomoo`05Ool00`0OOomoo`05Ool00`0OOomoo`03Ool00`0OOomoo`02Ool0100OOomo
o`0O0goo00@07goo01moo`@07e5oo`00HWoo100O00=oo`0O01l00Woo00H07gooOol07goo01l4Ool0
0`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`07Ool00`0OOomoo`08Ool0
0`0OOomoo`06Ool00`0OOomoo`05Ool00`0OOomoo`05Ool00`0OOomoo`03Ool00`0OOomoo`02Ool0
1@0OOomoogoo01l00Woo00H07goo01moo`0OOol301mAOol0069oo`H07`9oo`0401moogoo01l2Ool0
1@0OOomoogoo01l017oo0P0O17oo00<07gooOol00goo00<07gooOol01goo00<07gooOol027oo00<0
7gooOol01Woo00<07gooOol01Goo00<07gooOol01Goo00<07gooOol00goo00<07gooOol00goo00@0
7gooOol07`=oo`0601moo`0OOol07goo0`0ODGoo001ROol301l01Goo01l07goo01l00Woo00@07goo
Ool07`=oo`0301moogoo009oo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo00Moo`0301mo
ogoo00Qoo`0301moogoo00Ioo`0301moogoo00Ioo`0301moogoo00Aoo`0301moogoo00=oo`0301mo
ogoo00=oo`0501moogooOol07`03Ool01P0OOol07goo01moo`<07e5oo`00HWoo1@0O0Woo00<07goo
01l00Woo00<07gooOol00Woo00D07gooOomoo`0O00Eoo`0301moogoo00=oo`0301moogoo00Moo`03
01moogoo00Qoo`0301moogoo00Ioo`0301moogoo00Ioo`0301moogoo00Eoo`0301moogoo00=oo`03
01moogoo00=oo`0401moogoo01l3Ool01@0OOomoo`0OOol00P0O00=oo`0O01l0DGoo001ROol501l0
1Goo01moogoo01l00Woo00D07gooOomoo`0O00=oo`0301moogoo00Aoo`0301moogoo009oo`0301mo
ogoo00Moo`0301moogoo00Qoo`0301moogoo00Ioo`0301moogoo00Ioo`0301moogoo00Eoo`0301mo
ogoo00=oo`0301moogoo00=oo`0501moogooOol07`03Ool01P0OOol07goo01moo`<07e9oo`00HWoo
0`0O00Ioo`0OOol07goo01l2Ool01@0OOomoogoo01l017oo00<07gooOol00goo00<07gooOol00Woo
00<07gooOol01goo00<07gooOol027oo00<07gooOol01goo00<07gooOol01Goo00<07gooOol01Goo
00<07gooOol00goo00<07gooOol017oo00@07gooOol07`=oo`0701moogoo01moo`0OOol00`0ODWoo
001ROol401l017oo01moo`0O0goo00@07gooOol07`Aoo`0301moogoo00=oo`0301moogoo009oo`03
01moogoo00Moo`0301moogoo00Qoo`0301moogoo00Moo`0301moogoo00Eoo`0301moogoo00Eoo`03
01moogoo00Aoo`0301moogoo00=oo`0501moogooOol07`03Ool00`0OOol07`02Ool00`0OOol07`02
01mBOol0069oo`807`06Ool07goo01moo`0O0Woo00D07gooOomoo`0O00=oo`0301moogoo009oo`80
7`Aoo`0301moogoo00Moo`0301moogoo00Qoo`0301moogoo00Moo`0301moogoo00Eoo`0301moogoo
00Ioo`0301moogoo00=oo`0301moogoo00=oo`0501moogooOol07`03Ool0100OOomoo`0O0Woo0P0O
00=oo`0O01l0DWoo001ROol201l01Goo01l07goo01l00Woo00D07gooOomoo`0O00=oo`0301moogoo
009oo`0301moogoo00=oo`0301moogoo00Moo`0301moogoo00Qoo`0301moogoo00Moo`0301moogoo
00Ioo`0301moogoo00Eoo`0301moogoo00=oo`0301moogoo00Aoo`0401moogoo01l4Ool00`0OOol0
7`02Ool0100OOol07goo0P0ODWoo001ROol201l01Goo01l07goo01l00Woo00@07gooOol07`Aoo`05
01moogooOol07`05Ool00`0OOomoo`07Ool00`0OOomoo`08Ool00`0OOomoo`07Ool00`0OOomoo`06
Ool00`0OOomoo`05Ool00`0OOomoo`04Ool00`0OOomoo`03Ool01@0OOomoogoo01l00goo00@07goo
Ool07`9oo`0501moo`0OOol07`1COol0069oo`@07`05Ool07gooOol07`03Ool01@0OOomoogoo01l0
0goo00<07gooOol00goo00<07gooOol01goo00<07gooOol027oo00<07gooOol01goo00<07gooOol0
1Woo00<07gooOol01Goo00<07gooOol017oo00<07gooOol00goo00D07gooOomoo`0O00Aoo`0401mo
ogoo01l2Ool00`0OOol07`0201mCOol0065oo`D07`04Ool07goo01l3Ool01@0OOomoogoo01l017oo
00<07gooOol00Woo00<07gooOol01goo00<07gooOol027oo00<07gooOol01goo00<07gooOol01Woo
00<07gooOol01Goo00<07gooOol017oo00<07gooOol00goo00<07gooOol00Woo00D07gooOomoo`0O
009oo`0701moogoo01moo`0OOol00P0ODgoo001QOol401l01Goo01moogoo01l00goo00@07gooOol0
7`Aoo`0301moogoo009oo`0301moogoo00Moo`0301moogoo00Moo`807`Uoo`0301moogoo00Ioo`03
01moogoo00Ioo`0301moogoo00Aoo`0301moogoo00=oo`0501moogooOol07`04Ool0100OOomoo`0O
0Woo00@07goo01moo`807e=oo`00HGoo100O00Aoo`0OOol07`=oo`0401moogoo01l4Ool00`0OOomo
o`02Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`08Ool00`0OOomoo`06Ool00`0OOomo
o`06Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`02Ool01@0OOomoogoo01l00Woo00@0
7gooOol07`9oo`0301moo`0O05Aoo`00HGoo100O00Aoo`0OOol07`9oo`0401moogoo01l4Ool00`0O
Oomoo`02Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`08Ool00`0OOomoo`06Ool00`0O
Oomoo`06Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`02Ool0100O
Oomoo`0O0Woo00<07gooOol00`0OE7oo001QOol501l01Goo01moogoo01l00Woo00<07gooOol00Woo
00<07gooOol00Woo00<07gooOol01goo00<07gooOol01goo00<07gooOol027oo00<07gooOol01goo
00<07gooOol01Goo00<07gooOol017oo00<07gooOol017oo00D07gooOomoo`0O00Aoo`0401moogoo
01l2Ool01@0OOomoo`0OOol00P0OE7oo001QOol501l017oo01moo`0O0goo00D07gooOomoo`0O00Ao
o`0301moogoo00Moo`0301moogoo00Moo`0301moogoo00Qoo`0301moogoo00Moo`0301moogoo00Eo
o`0301moogoo00Eoo`0301moogoo00=oo`0301moogoo009oo`0501moogooOol07`03Ool0100OOomo
o`0O0Woo00@07goo01l07eAoo`00HGoo100O00Aoo`0OOol07`=oo`0501moogooOol07`04Ool00`0O
Oomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`08Ool00`0OOomoo`07Ool00`0OOomoo`05Ool00`0O
Oomoo`05Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`02Ool0100OOomoo`0O0goo00<0
7gooOol00`0OEGoo001QOol401l017oo01moo`0O0Woo00D07gooOomoo`0O00Aoo`0301moogoo00Mo
o`0301moogoo00Moo`0301moogoo00Qoo`0301moogoo00Moo`0301moogoo00Eoo`0301moogoo00Eo
o`0301moogoo00Aoo`0301moogoo009oo`0501moogooOol07`03Ool0100OOomoo`0O0Woo00@07goo
01l07eEoo`00HGoo1@0O00=oo`0OOol00Woo00@07gooOol07`Aoo`0301moogoo00Moo`0301moogoo
00Moo`0301moogoo00Qoo`0301moogoo00Moo`0301moogoo00Eoo`0301moogoo00Eoo`0301moogoo
00Aoo`0301moogoo009oo`0301moogoo009oo`0401moogoo01l3Ool00`0OOomoo`0201l00goo01mo
o`1DOol0061oo`L07`=oo`0401moogoo01l4Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomo
o`08Ool00`0OOomoo`06Ool201l7Ool00`0OOomoo`05Ool00`0OOomoo`04Ool00`0OOomoo`03Ool0
1@0OOomoogoo01l00goo00@07gooOol07`9oo`0501moo`0OOol07`1EOol0061oo`<07`04Ool07`0O
01l2Ool01@0OOomoogoo01l00goo00<07gooOol01goo00<07gooOol01goo00<07gooOol027oo00<0
7gooOol01Woo00<07gooOol01Woo00<07gooOol01Goo00<07gooOol017oo00<07gooOol00goo00<0
7gooOol00Woo00@07gooOol07`=oo`0501moogoo01moo`0201mFOol0061oo`H07`9oo`0501moogoo
Ool07`03Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`07Ool201l8Ool00`0OOomoo`06
Ool00`0OOomoo`05Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`02Ool01@0OOomoogoo
01l00Woo00P07gooOol07goo01moo`0OEWoo001POol601l2Ool0100OOomoo`0O0goo00<07gooOol0
1goo00<07gooOol01goo00<07gooOol01goo00<07gooOol01goo00<07gooOol01Woo00<07gooOol0
1Goo00<07gooOol01Goo00<07gooOol00Woo00<07gooOol00Woo00D07gooOomoo`0O00=oo`0801mo
ogoo01moo`0OOol07eIoo`00H7oo200O0Woo00D07gooOomoo`0O00Uoo`0301moogoo00Moo`0301mo
ogoo00Moo`0301moogoo00Moo`0301moogoo00Ioo`0301moogoo00Eoo`0301moogoo00Eoo`0301mo
ogoo009oo`0301moogoo00=oo`0401moogoo01l3Ool0200OOomoo`0OOol07goo01mGOol0061oo`L0
7`9oo`0501moogooOol07`09Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0O
Oomoo`06Ool00`0OOomoo`05Ool00`0OOomoo`05Ool00`0OOomoo`03Ool00`0OOomoo`02Ool01@0O
Oomoogoo01l00goo00P07gooOol07goo01moo`0OEgoo001POol401l00goo01l07`0201l3Ool00`0O
Oomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`06Ool00`0O
Oomoo`05Ool00`0OOomoo`05Ool00`0OOomoo`03Ool00`0OOomoo`02Ool01@0OOomoogoo01l00goo
00P07gooOol07goo01moo`0OF7oo001POol401l017oo01moo`0O0goo00<07gooOol01goo00<07goo
Ool01goo00<07gooOol01Woo0P0O2Goo00<07gooOol01Woo00<07gooOol01Woo00<07gooOol017oo
00<07gooOol00goo00<07gooOol00Woo00<07gooOol00Woo00D07gooOomoo`0O009oo`0501moo`0O
Ool07`1HOol005moo`@07`03Ool07`0O00807`9oo`0301moogoo00Ioo`807`Qoo`807`Qoo`0301mo
ogoo00Qoo`0301moogoo00Ioo`0301moogoo00Ioo`0301moogoo00Aoo`0301moogoo00=oo`0301mo
ogoo00=oo`0501moogooOol07`03Ool0200OOomoo`0OOol07goo01mIOol005moo`T07`03Ool07goo
00Moo`0301moogoo00Moo`0301moogoo00Moo`0301moogoo00Qoo`0301moogoo00Ioo`0301moogoo
00Ioo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo009oo`0301moogoo009oo`0501moogoo
Ool07`02Ool01@0OOol07goo01l0FGoo001OOol401l01Woo01l07`0OOol07`Qoo`0301moogoo00Mo
o`0301moogoo00Moo`0301moogoo00Qoo`0301moogoo00Ioo`0301moogoo00Ioo`0301moogoo00Eo
o`0301moogoo00=oo`0301moogoo009oo`0301moogoo009oo`0501moogooOol07`02Ool01@0OOol0
7goo01l0FWoo001NOol501l00goo01moo`0301l7Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0O
Oomoo`07Ool201l8Ool00`0OOomoo`06Ool00`0OOomoo`05Ool00`0OOomoo`03Ool00`0OOomoo`03
Ool01@0OOomoogoo01l00goo00@07gooOol07`9oo`0301moo`0O05Yoo`00GWoo1`0O00Aoo`0OOol0
7`Eoo`807`Qoo`807`Uoo`0301moogoo00Moo`0301moogoo00Moo`0301moogoo00Eoo`807`Moo`03
01moogoo00=oo`0301moogoo00=oo`0301moogoo009oo`0501moogooOol07`02Ool01@0OOol07goo
01l0Fgoo001NOol601l00goo01moo`0201l4Ool00`0OOomoo`07Ool00`0OOomoo`08Ool00`0OOomo
o`07Ool00`0OOomoo`07Ool00`0OOomoo`05Ool00`0OOomoo`06Ool00`0OOomoo`04Ool00`0OOomo
o`02Ool00`0OOomoo`02Ool01@0OOomoogoo01l00Woo00H07gooOol07goo01mKOol005ioo`P07`04
Ool07goo01l2Ool00`0OOomoo`07Ool00`0OOomoo`08Ool00`0OOomoo`06Ool201l8Ool201l7Ool0
0`0OOomoo`06Ool00`0OOomoo`04Ool00`0OOomoo`03Ool01@0OOomoogoo01l00goo00@07gooOol0
7`9oo`0301moo`0O05aoo`00GWoo1P0O00Aoo`0OOomoo`807`03Ool07goo00Qoo`0301moogoo00Mo
o`807`Qoo`0301moogoo00Moo`0301moogoo00Ioo`0301moogoo00Ioo`0301moogoo00Aoo`0301mo
ogoo00=oo`0301moogoo009oo`0501moogooOol07`02Ool01P0OOomoo`0OOol07eaoo`00GWoo200O
0Woo0`0O27oo0P0O2Goo00<07gooOol01Woo0P0O2Goo00<07gooOol01Woo00<07gooOol01Woo00<0
7gooOol017oo00<07gooOol00goo00<07gooOol00Woo00D07gooOomoo`0O009oo`0601moogoo01mo
o`0OGGoo001NOol401l01goo01l07goo01moo`0O009oo`0301moogoo00Aoo`0301moogoo00Moo`80
7`Qoo`0301moogoo00Qoo`0301moogoo00Ioo`0301moogoo00Ioo`0301moogoo00Aoo`0301moogoo
00=oo`0301moogoo009oo`0501moogooOol07`02Ool0100OOomoo`0O0Woo00<07gooOol0Fgoo001M
Ool501l00goo01moo`0301l017oo01moo`0O1Goo00<07gooOol01goo00<07gooOol01goo00<07goo
Ool027oo00<07gooOol01Woo00<07gooOol01Woo00<07gooOol017oo00<07gooOol00goo00<07goo
Ool00Woo00D07gooOomoo`0O00=oo`0601moogoo01moo`0OGWoo001MOol401l017oo01l07goo0`0O
00Eoo`0OOomoo`0O00=oo`0301moogoo00Ioo`807`Qoo`807`Uoo`807`Qoo`0301moogoo00Ioo`03
01moogoo00Aoo`0301moogoo00Aoo`0501moogooOol07`03Ool01@0OOomoogoo01l00Woo00@07goo
Ool07eioo`00G7oo1@0O00Moo`0O01moo`0OOol07`02Ool0100OOol07goo0P0O1goo0P0O2Goo00<0
7gooOol027oo00<07gooOol01goo00<07gooOol01Goo0P0O1Woo00<07gooOol017oo00<07gooOol0
0Woo00D07gooOomoo`0O009oo`0401moogoo01l2Ool00`0OOomoo`1MOol005aoo`<07`03Ool07goo
00@07`05Ool07gooOol07`02Ool00`0OOomoo`06Ool00`0OOomoo`08Ool00`0OOomoo`08Ool00`0O
Oomoo`07Ool00`0OOomoo`05Ool00`0OOomoo`05Ool00`0OOomoo`04Ool00`0OOomoo`02Ool01@0O
Oomoogoo01l00goo00@07gooOol07`9oo`0301moogoo05eoo`00Fgoo100O00Yoo`0O01l07goo01mo
o`0OOol07`9oo`<07`Moo`0301moogoo00Qoo`0301moogoo00Qoo`0301moogoo00Ioo`807`Moo`03
01moogoo00Aoo`807`Ioo`0301moogoo009oo`0501moogooOol07`03Ool0100OOomoo`0O0Woo00<0
7gooOol0GWoo001KOol301l00goo01l07`0201l01Goo01moo`0OOol0100O0Woo00<07gooOol00Woo
0P0O2Goo0P0O2Goo0P0O27oo00<07gooOol01Woo00<07gooOol017oo00<07gooOol01Goo00<07goo
Ool00Woo00D07gooOomoo`0O00=oo`0401moogoo01l2Ool00`0OOomoo`1OOol005Yoo`@07`07Ool0
7`0O01moo`0OOol01@0O0Woo00<07goo01l00goo00<07gooOol027oo00<07gooOol027oo00<07goo
Ool01goo00<07gooOol01Woo00<07gooOol017oo00<07gooOol017oo0P0O17oo00D07gooOomoo`0O
00=oo`0401moogoo01l3Ool00`0OOomoo`1OOol005Uoo`T07`03Ool07goo00<07`05Ool07gooOol0
7`02Ool301l:Ool00`0OOomoo`08Ool00`0OOomoo`06Ool201l7Ool201l6Ool00`0OOomoo`04Ool0
0`0OOomoo`03Ool01@0OOomoogoo01l00goo00D07gooOomoo`0O009oo`0301moogoo061oo`00F7oo
00<07goo01l01P0O00=oo`0OOol0100O0Woo00<07gooOol0100O2Goo0P0O2Goo0P0O27oo00<07goo
Ool01Woo00<07gooOol01Goo00<07gooOol017oo00<07gooOol00goo00<07gooOol00Woo00D07goo
Oomoo`0O009oo`0401moogoo01mSOol005Yoo`L07`0:Ool07`0O01moo`0OOol07goo01l2Ool0100O
Oomoo`0O1goo0P0O2Goo0P0O27oo0P0O27oo00<07gooOol01Goo00<07gooOol017oo00<07gooOol0
0goo00<07gooOol00Woo00D07gooOomoo`0O009oo`0401moogoo01mTOol005]oo`@07`0<Ool07`0O
Ool07goo01moo`0OOol07goo0P0O00Eoo`0OOomoo`0O00Aoo`807`Uoo`807`Uoo`0301moogoo00Mo
o`0301moogoo00Eoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo009oo`0501moogooOol0
7`02Ool0100OOomoo`0OIGoo001LOol601l01goo01moo`0OOol07goo00807`05Ool07gooOol07`02
Ool0100OOol07`0O2Goo0P0O2Goo0P0O27oo0P0O1goo00<07gooOol017oo00<07gooOol00goo00<0
7gooOol00Woo00D07gooOomoo`0O009oo`0401moogoo01mVOol005eoo`<07`04Ool07`0OOol501l0
17oo01moo`0O0Woo00<07gooOol00P0O2Goo0P0O2Goo0P0O2Goo00<07gooOol01Goo0P0O1Woo00<0
7gooOol00goo00@07gooOomoo`807`=oo`0701moogooOol07goo01l0Igoo001OOol601l02Goo01mo
ogoo01moo`0OOol07`02Ool201l00goo01moo`06Ool201l:Ool00`0OOomoo`08Ool00`0OOomoo`05
Ool00`0OOomoo`05Ool00`0OOomoo`03Ool01@0OOomoogoo01l017oo00L07gooOomoo`0OOol07`1X
Ool0061oo`0:01moo`0O01moo`0OOol07goo01l2Ool501l3Ool00`0OOomoo`02Ool201l:Ool201l9
Ool201l6Ool201l6Ool201l5Ool01@0OOomoogoo01l017oo00L07gooOomoo`0OOol07`1YOol0065o
o``07`9oo`0301moo`0O00=oo`0401moo`0O01l:Ool201l9Ool201l7Ool00`0OOomoo`05Ool00`0O
Oomoo`04Ool01@0OOomoogoo01l017oo00L07gooOomoo`0OOol07`1ZOol0069oo`807`07Ool07`0O
Ool07goo01l00Woo00H07gooOol07goo01l2Ool201l:Ool201l9Ool201l7Ool201l6Ool201l5Ool2
01l2Ool201l4Ool00`0OOomoo`0201l2Ool00`0OOomoo`1XOol006Aoo`@07`04Ool07goo01l2Ool0
0`0OOomoo`0401l2Ool00`0OOomoo`05Ool201l9Ool201l7Ool201l7Ool00`0OOomoo`04Ool01@0O
Oomoogoo01l01Goo00@07gooOol07`=oo`0301moogoo06Uoo`00IGoo3P0O0Woo00@07gooOol07`=o
o`<07`Uoo`807`Qoo`0301moogoo00Eoo`807`Ioo`0501moogooOol07`05Ool0100OOomoo`0O0goo
00<07gooOol0JWoo001WOol301l00goo01l07`02Ool0100OOomoo`0O0goo00<07gooOol00`0O2Woo
0P0O27oo0P0O1Woo0P0O1Woo0P0O0goo00<07gooOol00goo00@07gooOol07`9oo`807feoo`00J7oo
1`0O00Aoo`0OOomoo`T07`Qoo`807`Qoo`807`Moo`0301moogoo00Aoo`807`=oo`807`Aoo`807`04
Ool07`0OOol201m_Ool006Yoo`807`03Ool07`0O00@07`03Ool07goo009oo`0501moogooOol07`03
Ool401l7Ool301l7Ool201l5Ool201l4Ool00`0OOomoo`02Ool201l2Ool0100OOomoo`0OLGoo001/
Ool501l2Ool0100OOol07`0O0Woo00<07goo01l0100O2Goo0P0O27oo0P0O1Goo0P0O1Goo00<07goo
Ool00Woo00H07gooOomoo`0OOol201mbOol006ioo`h07`9oo`807`Eoo`@07`Qoo`807`Eoo`807`Eo
o`807`=oo`807`9oo`@07gAoo`00L7oo100O00Eoo`0O01moo`0O00=oo`0401moogooOol501l9Ool3
01l5Ool201l5Ool201l3Ool201l2Ool201l00goo01moo`1eOol007=oo`d07`03Ool07`0O00Moo`@0
7`Ioo`807`Eoo`807`=oo`807`9oo`807`03Ool07`0O07Moo`00MGoo1@0O00=oo`0OOol00Woo0P0O
0Woo1`0O1goo0`0O1Goo0P0O0goo0P0O0Woo1@0ONGoo001hOol?01l7Ool301l4Ool401l2Ool301l0
0goo01l07`0301mlOol007aoo`D07`9oo`/07`9oo`D07`=oo`<07`9oo`D07gioo`00PGoo3`0O17oo
100O00=oo`0O01l00`0OPWoo0026OolC01n7Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {681.5, 452.125}} -> {-0.399192, \
1.97113, 0.00348777, 0.00348777}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[\[Theta]];\)\), "\[IndentingNewLine]", 
    \(\(ComponentFunct[Equ1, {0, R\ \ Cos[\[Phi]], R\ \ Sin[\[Phi]]}, 
        Red];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.59119 .32505 m
.61015 .33551 L
s
.57163 .31575 m
.59119 .32505 L
s
.55158 .30765 m
.57163 .31575 L
s
.61015 .33551 m
.62841 .34706 L
s
.53114 .30081 m
.55158 .30765 L
s
.62841 .34706 m
.64587 .35966 L
s
.51043 .29526 m
.53114 .30081 L
s
.64587 .35966 m
.66243 .37323 L
s
.48954 .29104 m
.51043 .29526 L
s
.66243 .37323 m
.67799 .38772 L
s
.46861 .28819 m
.48954 .29104 L
s
.67799 .38772 m
.69247 .40304 L
s
.44773 .28673 m
.46861 .28819 L
s
.69247 .40304 m
.70576 .41912 L
s
.42704 .2867 m
.44773 .28673 L
s
.70576 .41912 m
.71779 .43589 L
s
.40665 .2881 m
.42704 .2867 L
s
.71779 .43589 m
.72846 .45324 L
s
.38668 .29095 m
.40665 .2881 L
s
.72846 .45324 m
.73768 .4711 L
s
.36726 .29526 m
.38668 .29095 L
s
.73768 .4711 m
.74539 .48935 L
s
.34852 .30102 m
.36726 .29526 L
s
.74539 .48935 m
.75151 .5079 L
s
.33058 .30824 m
.34852 .30102 L
s
.75151 .5079 m
.75597 .52664 L
s
.31358 .31689 m
.33058 .30824 L
s
.75597 .52664 m
.7587 .54546 L
s
.29764 .32694 m
.31358 .31689 L
s
.7587 .54546 m
.75966 .56423 L
s
.28289 .33836 m
.29764 .32694 L
s
.75966 .56423 m
.7588 .58282 L
s
.26946 .35111 m
.28289 .33836 L
s
.7588 .58282 m
.75608 .60111 L
s
.25747 .36513 m
.26946 .35111 L
s
.75608 .60111 m
.75147 .61896 L
s
.24705 .38034 m
.25747 .36513 L
s
.75147 .61896 m
.74497 .63623 L
s
.2383 .39667 m
.24705 .38034 L
s
.74497 .63623 m
.73658 .65279 L
s
.23133 .41402 m
.2383 .39667 L
s
.73658 .65279 m
.72632 .66849 L
s
.22624 .43229 m
.23133 .41402 L
s
.72632 .66849 m
.71421 .68319 L
s
.22311 .45134 m
.22624 .43229 L
s
.71421 .68319 m
.70031 .69675 L
s
.22201 .47106 m
.22311 .45134 L
s
.70031 .69675 m
.68469 .70904 L
s
.223 .4913 m
.22201 .47106 L
s
.68469 .70904 m
.66743 .71993 L
s
.22611 .51189 m
.223 .4913 L
s
.66743 .71993 m
.64865 .72929 L
s
.23137 .53267 m
.22611 .51189 L
s
.64865 .72929 m
.62848 .73702 L
s
.23877 .55347 m
.23137 .53267 L
s
.62848 .73702 m
.60706 .74301 L
s
.24829 .5741 m
.23877 .55347 L
s
.60706 .74301 m
.58455 .74718 L
s
.25988 .59438 m
.24829 .5741 L
s
.58455 .74718 m
.56114 .74946 L
s
.27347 .61412 m
.25988 .59438 L
s
.56114 .74946 m
.53702 .74981 L
s
.28896 .63313 m
.27347 .61412 L
s
.53702 .74981 m
.51242 .74819 L
s
.30622 .65123 m
.28896 .63313 L
s
.51242 .74819 m
.48754 .7446 L
s
.32513 .66824 m
.30622 .65123 L
s
.48754 .7446 m
.46263 .73905 L
s
.34551 .68399 m
.32513 .66824 L
s
.46263 .73905 m
.4379 .73157 L
s
.36719 .69834 m
.34551 .68399 L
s
.4379 .73157 m
.4136 .72224 L
s
.38995 .71112 m
.36719 .69834 L
s
.4136 .72224 m
.38995 .71112 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0079ooaMl09Mo
o`00K7oo1W`05goo1W`0TGoo001XOol4O00SOol5O02<Ool006Ioo`9l02aoo`=l08Uoo`00Hgoo0g`0
<Goo0g`0QWoo001POol3O00gOol3O023Ool005eoo`=l03eoo`=l081oo`00Fgoo0W`0@goo0g`0OGoo
001IOol2O018Ool2O01kOol005Qoo`03O01oogoo04Yoo`9l07Uoo`00EWoo0W`0Cgoo0W`0Mgoo001E
Ool00g`0Oomoo`1AOol00g`0Oomoo`1dOol005Aoo`03O01oogoo05=oo`9l07Aoo`00Dgoo00=l07oo
Ool0EWoo0W`0LWoo001BOol00g`0Oomoo`1IOol2O01`Ool0055oo`03O01oogoo05aoo`9l06ioo`00
D7oo00=l07ooOol0Ggoo0W`0K7oo001>Ool2O01TOol00g`0Oomoo`1YOol004eoo`03O01oogoo06Eo
o`03O01oogoo06Qoo`00C7oo00=l07ooOol0Igoo0W`0J7oo001;Ool00g`0Oomoo`1ZOol00g`0Oomo
o`1UOol004Yoo`03O01oogoo06aoo`03O01oogoo06Aoo`00BGoo00=l07ooOol0KWoo00=l07ooOol0
Hgoo0018Ool00g`0Oomoo`1`Ool2O01SOol004Qoo`03O01oogoo079oo`03O01oogoo061oo`00Agoo
00=l07ooOol0M7oo00=l07ooOol0Ggoo0017Ool00g`0Oomoo`1eOol00g`0Oomoo`1NOol004Ioo`03
O01oogoo07Moo`03O01oogoo05eoo`00AGoo00=l07ooOol0NGoo00=l07ooOol0G7oo0015Ool00g`0
Oomoo`1jOol00g`0Oomoo`1KOol004Aoo`03O01oogoo07aoo`03O01oogoo05Yoo`00A7oo00=l07oo
Ool0OGoo00=l07ooOol0FGoo0014Ool00g`0Oomoo`1nOol00g`0Oomoo`1HOol004=oo`03O01oogoo
081oo`03O01oogoo05Moo`00@goo00=l07ooOol0PGoo00=l07ooOol0EWoo0012Ool00g`0Oomoo`23
Ool00g`0Oomoo`1EOol0049oo`03O01oogoo08=oo`03O01oogoo05Eoo`00@Woo00=l07ooOol0Q7oo
00=l07ooOol0E7oo0011Ool00g`0Oomoo`26Ool00g`0Oomoo`1COol0045oo`03O01oogoo08Moo`03
O01oogoo059oo`00@Goo00=l07ooOol0R7oo00=l07ooOol0DGoo0010Ool00g`0Oomoo`29Ool00g`0
Oomoo`1AOol0041oo`03O01oogoo08Yoo`03O01oogoo051oo`00@7oo00=l07ooOol0Rgoo00=l07oo
Ool0Cgoo0010Ool00g`0Oomoo`2<Ool00g`0Oomoo`1>Ool0041oo`03O01oogoo08aoo`03O01oogoo
04ioo`00@7oo00=l07ooOol0SGoo00=l07ooOol0CGoo0010Ool00g`0Oomoo`2=Ool00g`0Oomoo`1=
Ool0041oo`03O01oogoo08ioo`03O01oogoo04aoo`00@7oo00=l07ooOol0SWoo00=l07ooOol0C7oo
000oOol00g`0Oomoo`2@Ool00g`0Oomoo`1;Ool003moo`03O01oogoo091oo`03O01oogoo04]oo`00
?goo00=l07ooOol0TGoo00=l07ooOol0BWoo000oOol00g`0Oomoo`2AOol00g`0Oomoo`1:Ool003mo
o`03O01oogoo095oo`03O01oogoo04Yoo`00?goo00=l07ooOol0TWoo00=l07ooOol0BGoo000oOol0
0g`0Oomoo`2BOol00g`0Oomoo`19Ool0041oo`03O01oogoo099oo`03O01oogoo04Qoo`00@7oo00=l
07ooOol0TWoo00=l07ooOol0B7oo0010Ool00g`0Oomoo`2BOol00g`0Oomoo`18Ool0041oo`03O01o
ogoo09=oo`03O01oogoo04Moo`00@7oo00=l07ooOol0Tgoo00=l07ooOol0Agoo0010Ool00g`0Oomo
o`2DOol00g`0Oomoo`16Ool0041oo`03O01oogoo09Aoo`03O01oogoo04Ioo`00@7oo00=l07ooOol0
U7oo00=l07ooOol0AWoo0010Ool00g`0Oomoo`2DOol00g`0Oomoo`16Ool0045oo`03O01oogoo09=o
o`03O01oogoo04Ioo`00@Goo00=l07ooOol0U7oo00=l07ooOol0AGoo0011Ool00g`0Oomoo`2DOol0
0g`0Oomoo`15Ool0049oo`03O01oogoo09=oo`03O01oogoo04Eoo`00@Woo00=l07ooOol0Tgoo00=l
07ooOol0AGoo0012Ool00g`0Oomoo`2COol00g`0Oomoo`15Ool004=oo`03O01oogoo09=oo`03O01o
ogoo04Aoo`00@goo00=l07ooOol0Tgoo00=l07ooOol0A7oo0013Ool00g`0Oomoo`2COol00g`0Oomo
o`14Ool004Aoo`03O01oogoo099oo`03O01oogoo04Aoo`00A7oo00=l07ooOol0TWoo00=l07ooOol0
A7oo0014Ool00g`0Oomoo`2COol00g`0Oomoo`13Ool004Eoo`03O01oogoo099oo`03O01oogoo04=o
o`00AGoo00=l07ooOol0TWoo00=l07ooOol0@goo0016Ool00g`0Oomoo`2AOol00g`0Oomoo`13Ool0
04Ioo`03O01oogoo095oo`03O01oogoo04=oo`00Agoo00=l07ooOol0Sgoo00=l07ooOol0A7oo0017
Ool00g`0Oomoo`2?Ool00g`0Oomoo`14Ool004Qoo`03O01oogoo08ioo`03O01oogoo04Aoo`00B7oo
00=l07ooOol0SWoo00=l07ooOol0A7oo0019Ool00g`0Oomoo`2=Ool00g`0Oomoo`14Ool004Uoo`03
O01oogoo08eoo`03O01oogoo04Aoo`00BWoo00=l07ooOol0Rgoo00=l07ooOol0AGoo001;Ool00g`0
Oomoo`2:Ool00g`0Oomoo`15Ool004]oo`03O01oogoo08Yoo`03O01oogoo04Eoo`00C7oo00=l07oo
Ool0RGoo00=l07ooOol0AGoo001=Ool00g`0Oomoo`28Ool00g`0Oomoo`15Ool004eoo`03O01oogoo
08Moo`03O01oogoo04Ioo`00CWoo00=l07ooOol0QWoo00=l07ooOol0AWoo001?Ool00g`0Oomoo`25
Ool00g`0Oomoo`16Ool0051oo`03O01oogoo08Aoo`03O01oogoo04Ioo`00D7oo00=l07ooOol0Pgoo
00=l07ooOol0Agoo001AOol00g`0Oomoo`22Ool00g`0Oomoo`17Ool0059oo`03O01oogoo081oo`03
O01oogoo04Qoo`00Dgoo00=l07ooOol0Ogoo00=l07ooOol0B7oo001DOol00g`0Oomoo`1nOol00g`0
Oomoo`18Ool005Eoo`03O01oogoo07aoo`03O01oogoo04Uoo`00EWoo00=l07ooOol0Ngoo00=l07oo
Ool0BGoo001GOol00g`0Oomoo`1iOol00g`0Oomoo`1:Ool005Qoo`03O01oogoo07Qoo`03O01oogoo
04Yoo`00FGoo00=l07ooOol0MWoo00=l07ooOol0Bgoo001JOol2O01eOol00g`0Oomoo`1<Ool005ao
o`03O01oogoo079oo`03O01oogoo04aoo`00GGoo00=l07ooOol0L7oo00=l07ooOol0CGoo001NOol0
0g`0Oomoo`1^Ool00g`0Oomoo`1>Ool005moo`03O01oogoo06aoo`03O01oogoo04moo`00H7oo0W`0
K7oo00=l07ooOol0Cgoo001ROol00g`0Oomoo`1XOol00g`0Oomoo`1@Ool006=oo`03O01oogoo06Io
o`03O01oogoo055oo`00I7oo0W`0IGoo00=l07ooOol0DWoo001VOol00g`0Oomoo`1POol2O01EOol0
06Moo`9l05moo`03O01oogoo05Eoo`00JGoo00=l07ooOol0Fgoo00=l07ooOol0EWoo001ZOol2O01J
Ool00g`0Oomoo`1GOol006aoo`03O01oogoo05Ioo`03O01oogoo05Qoo`00KGoo0W`0EGoo00=l07oo
Ool0FGoo001_Ool2O01AOol2O01LOol0075oo`9l04eoo`9l05ioo`00Lgoo0W`0BWoo00=l07ooOol0
GWoo001eOol3O015Ool2O01QOol007Qoo`Al03moo`9l06=oo`00O7oo0g`0>Woo0W`0IGoo001oOol2
O00eOol3O01WOol0085oo`9l031oo`=l06Yoo`00Pgoo1G`0:7oo0g`0KGoo0028Ool7O00LOol5O01`
Ool008moo`Ql00ioo`Il07Eoo`00Ugoo3W`0Ngoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.61757 .28183 m
.6398 .295 L
s
.59455 .27011 m
.61757 .28183 L
s
.6398 .295 m
.66112 .30955 L
s
.57088 .25991 m
.59455 .27011 L
s
.66112 .30955 m
.6814 .32539 L
s
.54667 .25128 m
.57088 .25991 L
s
.6814 .32539 m
.70053 .34246 L
s
.52206 .24429 m
.54667 .25128 L
s
.70053 .34246 m
.7184 .36064 L
s
.4972 .23899 m
.52206 .24429 L
s
.7184 .36064 m
.73489 .37986 L
s
.47221 .23541 m
.4972 .23899 L
s
.73489 .37986 m
.74989 .40001 L
s
.44725 .23359 m
.47221 .23541 L
s
.74989 .40001 m
.76332 .42097 L
s
.42246 .23357 m
.44725 .23359 L
s
.76332 .42097 m
.77506 .44264 L
s
.39799 .23536 m
.42246 .23357 L
s
.77506 .44264 m
.78503 .4649 L
s
.37399 .23898 m
.39799 .23536 L
s
.78503 .4649 m
.79314 .48761 L
s
.35061 .24443 m
.37399 .23898 L
s
.79314 .48761 m
.79931 .51065 L
s
.32801 .2517 m
.35061 .24443 L
s
.79931 .51065 m
.80348 .53388 L
s
.30635 .26079 m
.32801 .2517 L
s
.80348 .53388 m
.80557 .55714 L
s
.28578 .27166 m
.30635 .26079 L
s
.80557 .55714 m
.80555 .5803 L
s
.26645 .28428 m
.28578 .27166 L
s
.80555 .5803 m
.80336 .60319 L
s
.24853 .2986 m
.26645 .28428 L
s
.80336 .60319 m
.79899 .62565 L
s
.23217 .31455 m
.24853 .2986 L
s
.79899 .62565 m
.79241 .64751 L
s
.2175 .33205 m
.23217 .31455 L
s
.79241 .64751 m
.78363 .66862 L
s
.20467 .35101 m
.2175 .33205 L
s
.78363 .66862 m
.77266 .68879 L
s
.19382 .37133 m
.20467 .35101 L
s
.77266 .68879 m
.75955 .70787 L
s
.18506 .39287 m
.19382 .37133 L
s
.75955 .70787 m
.74434 .72568 L
s
.17851 .41551 m
.18506 .39287 L
s
.74434 .72568 m
.7271 .74206 L
s
.17426 .43908 m
.17851 .41551 L
s
.7271 .74206 m
.70794 .75686 L
s
.1724 .46343 m
.17426 .43908 L
s
.70794 .75686 m
.68696 .76991 L
s
.17298 .48836 m
.1724 .46343 L
s
.68696 .76991 m
.6643 .78109 L
s
.17605 .51369 m
.17298 .48836 L
s
.6643 .78109 m
.64013 .79026 L
s
.18162 .53921 m
.17605 .51369 L
s
.64013 .79026 m
.6146 .79732 L
s
.1897 .56471 m
.18162 .53921 L
s
.6146 .79732 m
.58793 .80216 L
s
.20025 .58997 m
.1897 .56471 L
s
.58793 .80216 m
.56033 .80472 L
s
.21321 .61476 m
.20025 .58997 L
s
.56033 .80472 m
.53202 .80493 L
s
.22851 .63886 m
.21321 .61476 L
s
.53202 .80493 m
.50325 .80278 L
s
.24603 .66205 m
.22851 .63886 L
s
.50325 .80278 m
.47427 .79824 L
s
.26564 .68412 m
.24603 .66205 L
s
.47427 .79824 m
.44533 .79135 L
s
.28718 .70485 m
.26564 .68412 L
s
.44533 .79135 m
.41671 .78215 L
s
.31047 .72404 m
.28718 .70485 L
s
.41671 .78215 m
.38865 .77071 L
s
.33529 .74153 m
.31047 .72404 L
s
.38865 .77071 m
.36143 .75713 L
s
.36143 .75713 m
.33529 .74153 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol006mooaal09Eo
o`00JWoo1G`077oo1G`0T7oo001VOol4O00VOol4O02<Ool006=oo`=l02ioo`=l08Uoo`00H7oo0g`0
=7oo17`0QGoo001MOol3O00kOol3O022Ool005Uoo`Al045oo`Al07ioo`00Egoo0W`0BGoo0g`0Ngoo
001EOol2O01>Ool2O01iOol005=oo`9l059oo`9l07Moo`00DWoo00=l07ooOol0E7oo0g`0M7oo001@
Ool2O01JOol2O01bOol004moo`03O01oogoo05aoo`9l071oo`00CGoo0W`0HGoo0W`0KWoo001<Ool0
0g`0Oomoo`1SOol2O01/Ool004]oo`03O01oogoo06Ioo`03O01oogoo06Uoo`00BGoo0W`0JWoo0W`0
JGoo0018Ool00g`0Oomoo`1/Ool00g`0Oomoo`1VOol004Moo`03O01oogoo06ioo`9l06Ioo`00AWoo
00=l07ooOol0LGoo00=l07ooOol0Hgoo0015Ool00g`0Oomoo`1cOol2O01SOol004Aoo`03O01oogoo
07Ioo`03O01oogoo061oo`00@goo00=l07ooOol0N7oo00=l07ooOol0Ggoo0012Ool00g`0Oomoo`1j
Ool00g`0Oomoo`1NOol0045oo`03O01oogoo07aoo`9l05ioo`00@7oo00=l07ooOol0Ogoo00=l07oo
Ool0Fgoo0010Ool00g`0Oomoo`20Ool00g`0Oomoo`1JOol003moo`03O01oogoo089oo`03O01oogoo
05Uoo`00?Woo00=l07ooOol0Q7oo00=l07ooOol0F7oo000mOol00g`0Oomoo`26Ool2O01HOol003ao
o`03O01oogoo08Uoo`03O01oogoo05Eoo`00?7oo00=l07ooOol0RWoo00=l07ooOol0E7oo000kOol0
0g`0Oomoo`2<Ool00g`0Oomoo`1COol003Yoo`03O01oogoo08ioo`03O01oogoo059oo`00>Goo00=l
07ooOol0T7oo00=l07ooOol0DGoo000iOol00g`0Oomoo`2AOol00g`0Oomoo`1@Ool003Qoo`03O01o
ogoo09=oo`03O01oogoo04moo`00>7oo00=l07ooOol0U7oo00=l07ooOol0CWoo000gOol00g`0Oomo
o`2EOol00g`0Oomoo`1>Ool003Moo`03O01oogoo09Ioo`03O01oogoo04eoo`00=goo00=l07ooOol0
Ugoo00=l07ooOol0C7oo000fOol00g`0Oomoo`2HOol00g`0Oomoo`1<Ool003Ioo`03O01oogoo09Uo
o`03O01oogoo04]oo`00=Woo00=l07ooOol0VWoo00=l07ooOol0BWoo000eOol00g`0Oomoo`2LOol0
0g`0Oomoo`19Ool003Eoo`03O01oogoo09eoo`03O01oogoo04Qoo`00=Goo00=l07ooOol0WWoo00=l
07ooOol0Agoo000dOol00g`0Oomoo`2POol00g`0Oomoo`16Ool003Aoo`03O01oogoo0:5oo`03O01o
ogoo04Eoo`00=7oo00=l07ooOol0XGoo00=l07ooOol0AGoo000dOol00g`0Oomoo`2ROol00g`0Oomo
o`14Ool003=oo`03O01oogoo0:Aoo`03O01oogoo04=oo`00<goo00=l07ooOol0Y7oo00=l07ooOol0
@goo000cOol00g`0Oomoo`2UOol00g`0Oomoo`12Ool003=oo`03O01oogoo0:Eoo`03O01oogoo049o
o`00<goo00=l07ooOol0YWoo00=l07ooOol0@Goo000bOol00g`0Oomoo`2WOol00g`0Oomoo`11Ool0
039oo`03O01oogoo0:Qoo`03O01oogoo041oo`00<Woo00=l07ooOol0Z7oo00=l07ooOol0@7oo000b
Ool00g`0Oomoo`2YOol00g`0Oomoo`0oOol0039oo`03O01oogoo0:Uoo`03O01oogoo03moo`00<Woo
00=l07ooOol0ZGoo00=l07ooOol0?goo000bOol00g`0Oomoo`2ZOol00g`0Oomoo`0nOol0035oo`03
O01oogoo0:]oo`03O01oogoo03ioo`00<Goo00=l07ooOol0[7oo00=l07ooOol0?Goo000aOol00g`0
Oomoo`2/Ool00g`0Oomoo`0mOol0035oo`03O01oogoo0:eoo`03O01oogoo03aoo`00<Goo00=l07oo
Ool0[Goo00=l07ooOol0?7oo000aOol00g`0Oomoo`2^Ool00g`0Oomoo`0kOol0035oo`03O01oogoo
0:ioo`03O01oogoo03]oo`00<Goo00=l07ooOol0[Woo00=l07ooOol0>goo000aOol00g`0Oomoo`2_
Ool00g`0Oomoo`0jOol0035oo`03O01oogoo0:moo`03O01oogoo03Yoo`00<Goo00=l07ooOol0[goo
00=l07ooOol0>Woo000aOol00g`0Oomoo`2`Ool00g`0Oomoo`0iOol0035oo`03O01oogoo0;1oo`03
O01oogoo03Uoo`00<Goo00=l07ooOol0/7oo00=l07ooOol0>Goo000bOol00g`0Oomoo`2_Ool00g`0
Oomoo`0iOol0039oo`03O01oogoo0;1oo`03O01oogoo03Qoo`00<Woo00=l07ooOol0/7oo00=l07oo
Ool0>7oo000bOol00g`0Oomoo`2`Ool00g`0Oomoo`0hOol0039oo`03O01oogoo0;1oo`03O01oogoo
03Qoo`00<goo00=l07ooOol0[goo00=l07ooOol0>7oo000cOol00g`0Oomoo`2`Ool00g`0Oomoo`0g
Ool003=oo`03O01oogoo0;1oo`03O01oogoo03Moo`00<goo00=l07ooOol0/7oo00=l07ooOol0=goo
000dOol00g`0Oomoo`2_Ool00g`0Oomoo`0gOol003Aoo`03O01oogoo0:moo`03O01oogoo03Moo`00
=7oo00=l07ooOol0[goo00=l07ooOol0=goo000dOol00g`0Oomoo`2_Ool00g`0Oomoo`0gOol003Eo
o`03O01oogoo0:moo`03O01oogoo03Ioo`00=Goo00=l07ooOol0[goo00=l07ooOol0=Woo000eOol0
0g`0Oomoo`2_Ool00g`0Oomoo`0fOol003Eoo`03O01oogoo0:moo`03O01oogoo03Ioo`00=Woo00=l
07ooOol0[Woo00=l07ooOol0=Woo000fOol00g`0Oomoo`2^Ool00g`0Oomoo`0fOol003Ioo`03O01o
ogoo0:ioo`03O01oogoo03Ioo`00=goo00=l07ooOol0[Goo00=l07ooOol0=Woo000gOol00g`0Oomo
o`2]Ool00g`0Oomoo`0fOol003Qoo`03O01oogoo0:aoo`03O01oogoo03Ioo`00>7oo00=l07ooOol0
[7oo00=l07ooOol0=Woo000iOol00g`0Oomoo`2[Ool00g`0Oomoo`0fOol003Uoo`03O01oogoo0:]o
o`03O01oogoo03Ioo`00>Woo00=l07ooOol0ZGoo00=l07ooOol0=goo000jOol00g`0Oomoo`2YOol0
0g`0Oomoo`0gOol003]oo`03O01oogoo0:Qoo`03O01oogoo03Moo`00>goo00=l07ooOol0Z7oo00=l
07ooOol0=goo000lOol00g`0Oomoo`2WOol00g`0Oomoo`0gOol003aoo`03O01oogoo0:Moo`03O01o
ogoo03Moo`00?Goo00=l07ooOol0YGoo00=l07ooOol0>7oo000nOol00g`0Oomoo`2TOol00g`0Oomo
o`0hOol003ioo`03O01oogoo0:Aoo`03O01oogoo03Qoo`00?goo00=l07ooOol0Xgoo00=l07ooOol0
>7oo000oOol00g`0Oomoo`2SOol00g`0Oomoo`0hOol0041oo`03O01oogoo0:5oo`03O01oogoo03Uo
o`00@7oo00=l07ooOol0XGoo00=l07ooOol0>Goo0011Ool00g`0Oomoo`2POol00g`0Oomoo`0iOol0
049oo`03O01oogoo09ioo`03O01oogoo03Yoo`00@Woo00=l07ooOol0WWoo00=l07ooOol0>Woo0013
Ool00g`0Oomoo`2LOol00g`0Oomoo`0kOol004Aoo`03O01oogoo09]oo`03O01oogoo03]oo`00AGoo
00=l07ooOol0VGoo00=l07ooOol0?7oo0015Ool00g`0Oomoo`2IOol00g`0Oomoo`0lOol004Ioo`03
O01oogoo09Moo`03O01oogoo03eoo`00Agoo00=l07ooOol0UWoo00=l07ooOol0?Goo0018Ool00g`0
Oomoo`2DOol00g`0Oomoo`0nOol004Uoo`03O01oogoo09=oo`03O01oogoo03ioo`00BWoo00=l07oo
Ool0TGoo00=l07ooOol0?goo001;Ool00g`0Oomoo`2@Ool00g`0Oomoo`0oOol004aoo`03O01oogoo
08ioo`03O01oogoo041oo`00CGoo00=l07ooOol0SGoo00=l07ooOol0@7oo001>Ool00g`0Oomoo`2;
Ool00g`0Oomoo`11Ool004moo`03O01oogoo08Yoo`03O01oogoo045oo`00D7oo00=l07ooOol0R7oo
00=l07ooOol0@Woo001AOol00g`0Oomoo`26Ool00g`0Oomoo`13Ool0059oo`03O01oogoo08Eoo`03
O01oogoo04=oo`00Dgoo0W`0Q7oo00=l07ooOol0A7oo001EOol00g`0Oomoo`20Ool00g`0Oomoo`15
Ool005Ioo`03O01oogoo07ioo`03O01oogoo04Ioo`00Egoo0W`0OWoo00=l07ooOol0AWoo001IOol0
0g`0Oomoo`1jOol00g`0Oomoo`17Ool005Yoo`9l07Uoo`03O01oogoo04Qoo`00G7oo00=l07ooOol0
MGoo00=l07ooOol0BGoo001MOol00g`0Oomoo`1bOol2O01<Ool005ioo`9l075oo`03O01oogoo04ao
o`00H7oo00=l07ooOol0KGoo00=l07ooOol0CGoo001QOol2O01/Ool00g`0Oomoo`1>Ool006=oo`03
O01oogoo06Qoo`03O01oogoo04moo`00I7oo00=l07ooOol0IWoo00=l07ooOol0D7oo001UOol2O01U
Ool00g`0Oomoo`1AOol006Moo`03O01oogoo065oo`03O01oogoo059oo`00J7oo0W`0Ggoo0W`0EGoo
001ZOol2O01KOol2O01GOol006aoo`9l05Moo`9l05Uoo`00KWoo0g`0DWoo0W`0Fgoo001aOol2O01>
Ool2O01MOol007=oo`=l04Uoo`9l05moo`00MWoo0g`0A7oo0W`0HGoo001iOol2O00nOol4O01SOol0
07]oo`=l03Qoo`=l06Moo`00OWoo17`0<7oo17`0JWoo0022Ool4O00YOol3O01^Ool008Ioo`Il01mo
o`Al075oo`00S7oo27`02Goo3W`0MGoo002DOol9O023Ool00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.64881 .28677 m
.66972 .30219 L
s
.6269 .27278 m
.64881 .28677 L
s
.60413 .26031 m
.6269 .27278 L
s
.66972 .30219 m
.68953 .31896 L
s
.58062 .24942 m
.60413 .26031 L
s
.68953 .31896 m
.7081 .33698 L
s
.55649 .24019 m
.58062 .24942 L
s
.7081 .33698 m
.72533 .35615 L
s
.5319 .23267 m
.55649 .24019 L
s
.72533 .35615 m
.74111 .37638 L
s
.50698 .22692 m
.5319 .23267 L
s
.74111 .37638 m
.75534 .39755 L
s
.48186 .223 m
.50698 .22692 L
s
.75534 .39755 m
.76793 .41954 L
s
.45671 .22093 m
.48186 .223 L
s
.76793 .41954 m
.77878 .44223 L
s
.43167 .22075 m
.45671 .22093 L
s
.77878 .44223 m
.7878 .4655 L
s
.40688 .22248 m
.43167 .22075 L
s
.7878 .4655 m
.79493 .4892 L
s
.38252 .22615 m
.40688 .22248 L
s
.79493 .4892 m
.80008 .51319 L
s
.35873 .23174 m
.38252 .22615 L
s
.80008 .51319 m
.80321 .53734 L
s
.33568 .23926 m
.35873 .23174 L
s
.80321 .53734 m
.80425 .56148 L
s
.31353 .24868 m
.33568 .23926 L
s
.80425 .56148 m
.80317 .58546 L
s
.29244 .25999 m
.31353 .24868 L
s
.80317 .58546 m
.79993 .60912 L
s
.27257 .27313 m
.29244 .25999 L
s
.79993 .60912 m
.79453 .63228 L
s
.25407 .28804 m
.27257 .27313 L
s
.79453 .63228 m
.78695 .65479 L
s
.2371 .30467 m
.25407 .28804 L
s
.78695 .65479 m
.77722 .67647 L
s
.22182 .32291 m
.2371 .30467 L
s
.77722 .67647 m
.76535 .69716 L
s
.20836 .34268 m
.22182 .32291 L
s
.76535 .69716 m
.7514 .71667 L
s
.19686 .36385 m
.20836 .34268 L
s
.7514 .71667 m
.73542 .73484 L
s
.18744 .38629 m
.19686 .36385 L
s
.73542 .73484 m
.71751 .75151 L
s
.18022 .40986 m
.18744 .38629 L
s
.71751 .75151 m
.69775 .76652 L
s
.17529 .43439 m
.18022 .40986 L
s
.69775 .76652 m
.67628 .77973 L
s
.17273 .4597 m
.17529 .43439 L
s
.67628 .77973 m
.65323 .79099 L
s
.17261 .48561 m
.17273 .4597 L
s
.65323 .79099 m
.62877 .80018 L
s
.17497 .51191 m
.17261 .48561 L
s
.62877 .80018 m
.60307 .80719 L
s
.17982 .53839 m
.17497 .51191 L
s
.60307 .80719 m
.57633 .81192 L
s
.18717 .56482 m
.17982 .53839 L
s
.57633 .81192 m
.54876 .81431 L
s
.19699 .591 m
.18717 .56482 L
s
.54876 .81431 m
.52058 .8143 L
s
.20921 .61667 m
.19699 .591 L
s
.52058 .8143 m
.49203 .81187 L
s
.22377 .64162 m
.20921 .61667 L
s
.49203 .81187 m
.46337 .80701 L
s
.24056 .66563 m
.22377 .64162 L
s
.46337 .80701 m
.43483 .79973 L
s
.25944 .68846 m
.24056 .66563 L
s
.43483 .79973 m
.40667 .7901 L
s
.28026 .70991 m
.25944 .68846 L
s
.40667 .7901 m
.37915 .77818 L
s
.30285 .72978 m
.28026 .70991 L
s
.37915 .77818 m
.35252 .76407 L
s
.327 .74788 m
.30285 .72978 L
s
.35252 .76407 m
.327 .74788 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.67792 .29676 m
.69715 .31442 L
s
.65751 .28047 m
.67792 .29676 L
s
.63602 .26565 m
.65751 .28047 L
s
.69715 .31442 m
.71506 .33336 L
s
.61358 .25239 m
.63602 .26565 L
s
.71506 .33336 m
.73157 .35347 L
s
.59032 .24077 m
.61358 .25239 L
s
.73157 .35347 m
.74655 .37463 L
s
.56637 .23087 m
.59032 .24077 L
s
.74655 .37463 m
.75993 .39673 L
s
.54187 .22276 m
.56637 .23087 L
s
.75993 .39673 m
.7716 .41964 L
s
.51696 .21649 m
.54187 .22276 L
s
.7716 .41964 m
.78149 .44323 L
s
.49179 .21212 m
.51696 .21649 L
s
.78149 .44323 m
.78951 .46737 L
s
.46651 .2097 m
.49179 .21212 L
s
.78951 .46737 m
.7956 .4919 L
s
.44126 .20925 m
.46651 .2097 L
s
.7956 .4919 m
.7997 .51669 L
s
.41622 .21081 m
.44126 .20925 L
s
.7997 .51669 m
.80176 .54158 L
s
.39154 .21439 m
.41622 .21081 L
s
.80176 .54158 m
.80174 .56641 L
s
.36738 .21999 m
.39154 .21439 L
s
.80174 .56641 m
.7996 .59102 L
s
.3439 .22761 m
.36738 .21999 L
s
.7996 .59102 m
.79533 .61524 L
s
.32128 .23724 m
.3439 .22761 L
s
.79533 .61524 m
.78893 .63891 L
s
.29968 .24883 m
.32128 .23724 L
s
.78893 .63891 m
.78039 .66186 L
s
.27927 .26234 m
.29968 .24883 L
s
.78039 .66186 m
.76975 .68391 L
s
.2602 .2777 m
.27927 .26234 L
s
.76975 .68391 m
.75705 .7049 L
s
.24264 .29485 m
.2602 .2777 L
s
.75705 .7049 m
.74233 .72465 L
s
.22674 .3137 m
.24264 .29485 L
s
.74233 .72465 m
.72568 .74299 L
s
.21264 .33412 m
.22674 .3137 L
s
.72568 .74299 m
.70717 .75977 L
s
.20049 .356 m
.21264 .33412 L
s
.70717 .75977 m
.68692 .77483 L
s
.1904 .37919 m
.20049 .356 L
s
.68692 .77483 m
.66506 .78803 L
s
.1825 .40355 m
.1904 .37919 L
s
.66506 .78803 m
.64172 .79922 L
s
.17688 .42889 m
.1825 .40355 L
s
.64172 .79922 m
.61708 .80829 L
s
.17362 .45503 m
.17688 .42889 L
s
.61708 .80829 m
.5913 .81514 L
s
.17279 .48178 m
.17362 .45503 L
s
.5913 .81514 m
.56458 .81967 L
s
.17443 .50892 m
.17279 .48178 L
s
.56458 .81967 m
.53713 .8218 L
s
.17856 .53623 m
.17443 .50892 L
s
.53713 .8218 m
.50917 .82151 L
s
.18518 .56349 m
.17856 .53623 L
s
.50917 .82151 m
.48093 .81875 L
s
.19425 .59046 m
.18518 .56349 L
s
.48093 .81875 m
.45265 .81352 L
s
.20573 .61691 m
.19425 .59046 L
s
.45265 .81352 m
.42457 .80586 L
s
.21954 .6426 m
.20573 .61691 L
s
.42457 .80586 m
.39694 .79579 L
s
.23558 .66732 m
.21954 .6426 L
s
.39694 .79579 m
.37 .78341 L
s
.25372 .69083 m
.23558 .66732 L
s
.37 .78341 m
.34399 .76879 L
s
.27381 .71292 m
.25372 .69083 L
s
.34399 .76879 m
.31914 .75208 L
s
.29568 .7334 m
.27381 .71292 L
s
.31914 .75208 m
.29568 .7334 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.70433 .31159 m
.7215 .3314 L
s
.68578 .29307 m
.70433 .31159 L
s
.66596 .27593 m
.68578 .29307 L
s
.7215 .3314 m
.73719 .35237 L
s
.64498 .26029 m
.66596 .27593 L
s
.73719 .35237 m
.7513 .37438 L
s
.62297 .24624 m
.64498 .26029 L
s
.7513 .37438 m
.76374 .39731 L
s
.60005 .23387 m
.62297 .24624 L
s
.76374 .39731 m
.77443 .42102 L
s
.57635 .22326 m
.60005 .23387 L
s
.77443 .42102 m
.78329 .44537 L
s
.55202 .21449 m
.57635 .22326 L
s
.78329 .44537 m
.79026 .47023 L
s
.52719 .20764 m
.55202 .21449 L
s
.79026 .47023 m
.79528 .49544 L
s
.50202 .20275 m
.52719 .20764 L
s
.79528 .49544 m
.79829 .52084 L
s
.47666 .19988 m
.50202 .20275 L
s
.79829 .52084 m
.79927 .5463 L
s
.45126 .19907 m
.47666 .19988 L
s
.79927 .5463 m
.79817 .57163 L
s
.42599 .20034 m
.45126 .19907 L
s
.79817 .57163 m
.79498 .59668 L
s
.40102 .20373 m
.42599 .20034 L
s
.79498 .59668 m
.7897 .62128 L
s
.3765 .20923 m
.40102 .20373 L
s
.7897 .62128 m
.78232 .64527 L
s
.35262 .21683 m
.3765 .20923 L
s
.78232 .64527 m
.77287 .66846 L
s
.32954 .22653 m
.35262 .21683 L
s
.77287 .66846 m
.76139 .6907 L
s
.30744 .23828 m
.32954 .22653 L
s
.76139 .6907 m
.7479 .7118 L
s
.28648 .25203 m
.30744 .23828 L
s
.7479 .7118 m
.73249 .73161 L
s
.26683 .26772 m
.28648 .25203 L
s
.73249 .73161 m
.71523 .74996 L
s
.24867 .28527 m
.26683 .26772 L
s
.71523 .74996 m
.69622 .7667 L
s
.23213 .30457 m
.24867 .28527 L
s
.69622 .7667 m
.67556 .78166 L
s
.21738 .32552 m
.23213 .30457 L
s
.67556 .78166 m
.65339 .79472 L
s
.20456 .34798 m
.21738 .32552 L
s
.65339 .79472 m
.62985 .80574 L
s
.19379 .3718 m
.20456 .34798 L
s
.62985 .80574 m
.60511 .8146 L
s
.18519 .39682 m
.19379 .3718 L
s
.60511 .8146 m
.57933 .8212 L
s
.17886 .42285 m
.18519 .39682 L
s
.57933 .8212 m
.55271 .82545 L
s
.17489 .44971 m
.17886 .42285 L
s
.55271 .82545 m
.52546 .82729 L
s
.17334 .47717 m
.17489 .44971 L
s
.52546 .82729 m
.49778 .82667 L
s
.17425 .50503 m
.17334 .47717 L
s
.49778 .82667 m
.46991 .82357 L
s
.17765 .53306 m
.17425 .50503 L
s
.46991 .82357 m
.44207 .81798 L
s
.18352 .56103 m
.17765 .53306 L
s
.44207 .81798 m
.41449 .80993 L
s
.19185 .58868 m
.18352 .56103 L
s
.41449 .80993 m
.38742 .79947 L
s
.20259 .6158 m
.19185 .58868 L
s
.38742 .79947 m
.3611 .78665 L
s
.21565 .64214 m
.20259 .6158 L
s
.3611 .78665 m
.33574 .77159 L
s
.23094 .66747 m
.21565 .64214 L
s
.33574 .77159 m
.31158 .7544 L
s
.24833 .69156 m
.23094 .66747 L
s
.31158 .7544 m
.28883 .73522 L
s
.26768 .71421 m
.24833 .69156 L
s
.28883 .73522 m
.26768 .71421 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.7272 .33104 m
.74197 .35276 L
s
.71088 .31047 m
.7272 .33104 L
s
.74197 .35276 m
.7551 .37549 L
s
.69311 .29116 m
.71088 .31047 L
s
.7551 .37549 m
.76652 .39911 L
s
.67399 .27323 m
.69311 .29116 L
s
.76652 .39911 m
.77615 .42346 L
s
.65364 .25681 m
.67399 .27323 L
s
.77615 .42346 m
.78392 .44841 L
s
.63216 .24199 m
.65364 .25681 L
s
.78392 .44841 m
.78978 .4738 L
s
.60969 .22887 m
.63216 .24199 L
s
.78978 .4738 m
.79368 .49949 L
s
.58636 .21755 m
.60969 .22887 L
s
.79368 .49949 m
.79558 .52532 L
s
.56229 .2081 m
.58636 .21755 L
s
.79558 .52532 m
.79546 .55113 L
s
.53764 .20062 m
.56229 .2081 L
s
.79546 .55113 m
.79329 .57676 L
s
.51256 .19516 m
.53764 .20062 L
s
.79329 .57676 m
.78907 .60205 L
s
.4872 .19178 m
.51256 .19516 L
s
.78907 .60205 m
.7828 .62682 L
s
.46172 .19052 m
.4872 .19178 L
s
.7828 .62682 m
.77449 .65091 L
s
.43629 .19143 m
.46172 .19052 L
s
.77449 .65091 m
.76418 .67415 L
s
.41108 .19453 m
.43629 .19143 L
s
.76418 .67415 m
.75191 .69637 L
s
.38625 .19982 m
.41108 .19453 L
s
.75191 .69637 m
.73773 .71742 L
s
.362 .20729 m
.38625 .19982 L
s
.73773 .71742 m
.72171 .73712 L
s
.33849 .21695 m
.362 .20729 L
s
.72171 .73712 m
.70393 .75532 L
s
.3159 .22873 m
.33849 .21695 L
s
.70393 .75532 m
.68451 .77187 L
s
.29441 .2426 m
.3159 .22873 L
s
.68451 .77187 m
.66354 .78661 L
s
.27419 .25849 m
.29441 .2426 L
s
.66354 .78661 m
.64117 .79942 L
s
.25541 .2763 m
.27419 .25849 L
s
.64117 .79942 m
.61753 .81017 L
s
.23824 .29594 m
.25541 .2763 L
s
.61753 .81017 m
.59279 .81875 L
s
.22283 .31729 m
.23824 .29594 L
s
.59279 .81875 m
.56711 .82505 L
s
.20932 .34019 m
.22283 .31729 L
s
.56711 .82505 m
.54069 .82899 L
s
.19786 .36451 m
.20932 .34019 L
s
.54069 .82899 m
.51373 .83052 L
s
.18855 .39005 m
.19786 .36451 L
s
.51373 .83052 m
.48642 .82958 L
s
.1815 .41664 m
.18855 .39005 L
s
.48642 .82958 m
.45899 .82615 L
s
.1768 .44407 m
.1815 .41664 L
s
.45899 .82615 m
.43166 .82023 L
s
.17451 .47212 m
.1768 .44407 L
s
.43166 .82023 m
.40466 .81185 L
s
.17468 .50056 m
.17451 .47212 L
s
.40466 .81185 m
.37821 .80104 L
s
.17733 .52917 m
.17468 .50056 L
s
.37821 .80104 m
.35254 .78787 L
s
.18245 .55771 m
.17733 .52917 L
s
.35254 .78787 m
.32788 .77245 L
s
.19002 .58592 m
.18245 .55771 L
s
.32788 .77245 m
.30444 .75488 L
s
.2 .61357 m
.19002 .58592 L
s
.30444 .75488 m
.28243 .7353 L
s
.21229 .64042 m
.2 .61357 L
s
.28243 .7353 m
.26203 .71388 L
s
.22682 .66623 m
.21229 .64042 L
s
.26203 .71388 m
.24344 .69079 L
s
.24344 .69079 m
.22682 .66623 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.75803 .37764 m
.76835 .40179 L
s
.74596 .35432 m
.75803 .37764 L
s
.76835 .40179 m
.77684 .42662 L
s
.7322 .33197 m
.74596 .35432 L
s
.77684 .42662 m
.78347 .452 L
s
.71684 .31073 m
.7322 .33197 L
s
.78347 .452 m
.78817 .47775 L
s
.69995 .29073 m
.71684 .31073 L
s
.78817 .47775 m
.79093 .50374 L
s
.68165 .27209 m
.69995 .29073 L
s
.79093 .50374 m
.7917 .52981 L
s
.66203 .25494 m
.68165 .27209 L
s
.7917 .52981 m
.79047 .55579 L
s
.6412 .23938 m
.66203 .25494 L
s
.79047 .55579 m
.78724 .58153 L
s
.61929 .22554 m
.6412 .23938 L
s
.78724 .58153 m
.782 .60685 L
s
.59641 .21351 m
.61929 .22554 L
s
.782 .60685 m
.77477 .63161 L
s
.57271 .20339 m
.59641 .21351 L
s
.77477 .63161 m
.76558 .65563 L
s
.54833 .19526 m
.57271 .20339 L
s
.76558 .65563 m
.75447 .67874 L
s
.52342 .18919 m
.54833 .19526 L
s
.75447 .67874 m
.74147 .7008 L
s
.49814 .18525 m
.52342 .18919 L
s
.74147 .7008 m
.72667 .72164 L
s
.47264 .1835 m
.49814 .18525 L
s
.72667 .72164 m
.71012 .7411 L
s
.4471 .18397 m
.47264 .1835 L
s
.71012 .7411 m
.69192 .75903 L
s
.4217 .1867 m
.4471 .18397 L
s
.69192 .75903 m
.67217 .77528 L
s
.3966 .1917 m
.4217 .1867 L
s
.67217 .77528 m
.65099 .78972 L
s
.372 .19896 m
.3966 .1917 L
s
.65099 .78972 m
.6285 .80221 L
s
.34807 .20847 m
.372 .19896 L
s
.6285 .80221 m
.60485 .81264 L
s
.325 .2202 m
.34807 .20847 L
s
.60485 .81264 m
.5802 .82089 L
s
.30298 .23409 m
.325 .2202 L
s
.5802 .82089 m
.55471 .82687 L
s
.28218 .25007 m
.30298 .23409 L
s
.55471 .82687 m
.52857 .83051 L
s
.26279 .26805 m
.28218 .25007 L
s
.52857 .83051 m
.50196 .83173 L
s
.24496 .28792 m
.26279 .26805 L
s
.50196 .83173 m
.47509 .8305 L
s
.22887 .30955 m
.24496 .28792 L
s
.47509 .8305 m
.44817 .8268 L
s
.21466 .3328 m
.22887 .30955 L
s
.44817 .8268 m
.4214 .82061 L
s
.20247 .35749 m
.21466 .3328 L
s
.4214 .82061 m
.39502 .81196 L
s
.19243 .38346 m
.20247 .35749 L
s
.39502 .81196 m
.36923 .80089 L
s
.18464 .41049 m
.19243 .38346 L
s
.36923 .80089 m
.34425 .78746 L
s
.17919 .43838 m
.18464 .41049 L
s
.34425 .78746 m
.32031 .77177 L
s
.17614 .4669 m
.17919 .43838 L
s
.32031 .77177 m
.29761 .75393 L
s
.17555 .49582 m
.17614 .4669 L
s
.29761 .75393 m
.27636 .73406 L
s
.17743 .5249 m
.17555 .49582 L
s
.27636 .73406 m
.25673 .71234 L
s
.18179 .55389 m
.17743 .5249 L
s
.25673 .71234 m
.23891 .68893 L
s
.18859 .58254 m
.18179 .55389 L
s
.23891 .68893 m
.22306 .66403 L
s
.19779 .6106 m
.18859 .58254 L
s
.22306 .66403 m
.20931 .63785 L
s
.20931 .63785 m
.19779 .6106 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.77625 .43026 m
.78167 .45587 L
s
.76895 .40513 m
.77625 .43026 L
s
.78167 .45587 m
.78518 .48179 L
s
.75981 .38062 m
.76895 .40513 L
s
.78518 .48179 m
.78676 .50788 L
s
.7489 .35687 m
.75981 .38062 L
s
.78676 .50788 m
.78639 .53398 L
s
.73626 .33405 m
.7489 .35687 L
s
.78639 .53398 m
.78406 .55993 L
s
.72196 .31228 m
.73626 .33405 L
s
.78406 .55993 m
.77978 .58557 L
s
.70609 .2917 m
.72196 .31228 L
s
.77978 .58557 m
.77357 .61075 L
s
.68872 .27246 m
.70609 .2917 L
s
.77357 .61075 m
.76543 .6353 L
s
.66996 .25467 m
.68872 .27246 L
s
.76543 .6353 m
.75542 .65907 L
s
.64991 .23846 m
.66996 .25467 L
s
.75542 .65907 m
.74357 .68191 L
s
.62868 .22395 m
.64991 .23846 L
s
.74357 .68191 m
.72994 .70365 L
s
.6064 .21125 m
.62868 .22395 L
s
.72994 .70365 m
.71459 .72414 L
s
.58319 .20047 m
.6064 .21125 L
s
.71459 .72414 m
.69761 .74323 L
s
.5592 .19169 m
.58319 .20047 L
s
.69761 .74323 m
.67909 .76079 L
s
.53457 .18501 m
.5592 .19169 L
s
.67909 .76079 m
.65912 .77667 L
s
.50946 .18049 m
.53457 .18501 L
s
.65912 .77667 m
.63783 .79073 L
s
.48404 .17821 m
.50946 .18049 L
s
.63783 .79073 m
.61533 .80286 L
s
.45848 .1782 m
.48404 .17821 L
s
.61533 .80286 m
.59179 .81293 L
s
.43296 .18051 m
.45848 .1782 L
s
.59179 .81293 m
.56733 .82085 L
s
.40765 .18515 m
.43296 .18051 L
s
.56733 .82085 m
.54213 .82653 L
s
.38275 .19212 m
.40765 .18515 L
s
.54213 .82653 m
.51636 .82988 L
s
.35845 .20142 m
.38275 .19212 L
s
.51636 .82988 m
.4902 .83085 L
s
.33494 .213 m
.35845 .20142 L
s
.4902 .83085 m
.46385 .82938 L
s
.3124 .22682 m
.33494 .213 L
s
.46385 .82938 m
.43751 .82547 L
s
.29104 .24279 m
.3124 .22682 L
s
.43751 .82547 m
.41138 .81909 L
s
.27103 .26084 m
.29104 .24279 L
s
.41138 .81909 m
.38567 .81028 L
s
.25254 .28084 m
.27103 .26084 L
s
.38567 .81028 m
.36059 .79905 L
s
.23576 .30266 m
.25254 .28084 L
s
.36059 .79905 m
.33636 .78548 L
s
.22083 .32614 m
.23576 .30266 L
s
.33636 .78548 m
.31319 .76965 L
s
.20791 .35111 m
.22083 .32614 L
s
.31319 .76965 m
.29127 .75167 L
s
.19711 .37738 m
.20791 .35111 L
s
.29127 .75167 m
.2708 .73166 L
s
.18856 .40475 m
.19711 .37738 L
s
.2708 .73166 m
.25197 .70977 L
s
.18233 .43298 m
.18856 .40475 L
s
.25197 .70977 m
.23495 .68618 L
s
.17851 .46186 m
.18233 .43298 L
s
.23495 .68618 m
.2199 .66107 L
s
.17713 .49113 m
.17851 .46186 L
s
.2199 .66107 m
.20695 .63466 L
s
.17823 .52055 m
.17713 .49113 L
s
.20695 .63466 m
.19622 .60716 L
s
.1818 .54986 m
.17823 .52055 L
s
.19622 .60716 m
.18781 .57881 L
s
.18781 .57881 m
.1818 .54986 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.78201 .48553 m
.7824 .51165 L
s
.77971 .45952 m
.78201 .48553 L
s
.77551 .43376 m
.77971 .45952 L
s
.7824 .51165 m
.78088 .5377 L
s
.76943 .40841 m
.77551 .43376 L
s
.78088 .5377 m
.77745 .56355 L
s
.7615 .38361 m
.76943 .40841 L
s
.77745 .56355 m
.77212 .58903 L
s
.75177 .35952 m
.7615 .38361 L
s
.77212 .58903 m
.76492 .61398 L
s
.74028 .33629 m
.75177 .35952 L
s
.76492 .61398 m
.75588 .63827 L
s
.72708 .31407 m
.74028 .33629 L
s
.75588 .63827 m
.74505 .66173 L
s
.71225 .293 m
.72708 .31407 L
s
.74505 .66173 m
.73247 .68422 L
s
.69587 .27321 m
.71225 .293 L
s
.73247 .68422 m
.7182 .70558 L
s
.67801 .25485 m
.69587 .27321 L
s
.7182 .70558 m
.70233 .72567 L
s
.65877 .23806 m
.67801 .25485 L
s
.70233 .72567 m
.68492 .74436 L
s
.63827 .22295 m
.65877 .23806 L
s
.68492 .74436 m
.66609 .76149 L
s
.61662 .20964 m
.63827 .22295 L
s
.66609 .76149 m
.64592 .77695 L
s
.59395 .19825 m
.61662 .20964 L
s
.64592 .77695 m
.62453 .7906 L
s
.57038 .18889 m
.59395 .19825 L
s
.62453 .7906 m
.60205 .80233 L
s
.54608 .18164 m
.57038 .18889 L
s
.60205 .80233 m
.57862 .81203 L
s
.5212 .17659 m
.54608 .18164 L
s
.57862 .81203 m
.55438 .8196 L
s
.4959 .17382 m
.5212 .17659 L
s
.55438 .8196 m
.52949 .82495 L
s
.47035 .17337 m
.4959 .17382 L
s
.52949 .82495 m
.50413 .82802 L
s
.44475 .17528 m
.47035 .17337 L
s
.50413 .82802 m
.47845 .82873 L
s
.41927 .17959 m
.44475 .17528 L
s
.47845 .82873 m
.45266 .82705 L
s
.39411 .1863 m
.41927 .17959 L
s
.45266 .82705 m
.42694 .82295 L
s
.36947 .19539 m
.39411 .1863 L
s
.42694 .82295 m
.40148 .81643 L
s
.34554 .20683 m
.36947 .19539 L
s
.40148 .81643 m
.3765 .80749 L
s
.32252 .22057 m
.34554 .20683 L
s
.3765 .80749 m
.35219 .79617 L
s
.30062 .23654 m
.32252 .22057 L
s
.35219 .79617 m
.32875 .78252 L
s
.28001 .25463 m
.30062 .23654 L
s
.32875 .78252 m
.30639 .76663 L
s
.26089 .27473 m
.28001 .25463 L
s
.30639 .76663 m
.28531 .74859 L
s
.24344 .29669 m
.26089 .27473 L
s
.28531 .74859 m
.26568 .72852 L
s
.22781 .32035 m
.24344 .29669 L
s
.26568 .72852 m
.2477 .70658 L
s
.21415 .34554 m
.22781 .32035 L
s
.2477 .70658 m
.23153 .68292 L
s
.20261 .37204 m
.21415 .34554 L
s
.23153 .68292 m
.21732 .65772 L
s
.19329 .39966 m
.20261 .37204 L
s
.21732 .65772 m
.20521 .6312 L
s
.18629 .42815 m
.19329 .39966 L
s
.20521 .6312 m
.19532 .60358 L
s
.18168 .45727 m
.18629 .42815 L
s
.19532 .60358 m
.18774 .57507 L
s
.17951 .48678 m
.18168 .45727 L
s
.18774 .57507 m
.18255 .54594 L
s
.1798 .51642 m
.17951 .48678 L
s
.18255 .54594 m
.1798 .51642 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.77519 .5408 m
.77067 .5665 L
s
.77786 .51483 m
.77519 .5408 L
s
.77865 .48875 m
.77786 .51483 L
s
.77067 .5665 m
.7643 .59178 L
s
.77755 .46271 m
.77865 .48875 L
s
.7643 .59178 m
.75613 .61649 L
s
.77457 .43686 m
.77755 .46271 L
s
.75613 .61649 m
.7462 .64049 L
s
.76971 .41136 m
.77457 .43686 L
s
.7462 .64049 m
.73455 .66363 L
s
.763 .38636 m
.76971 .41136 L
s
.73455 .66363 m
.72125 .68575 L
s
.75446 .36201 m
.763 .38636 L
s
.72125 .68575 m
.70637 .70673 L
s
.74414 .33848 m
.75446 .36201 L
s
.70637 .70673 m
.68997 .72642 L
s
.73207 .31589 m
.74414 .33848 L
s
.68997 .72642 m
.67215 .74469 L
s
.71831 .29442 m
.73207 .31589 L
s
.67215 .74469 m
.653 .76141 L
s
.70294 .2742 m
.71831 .29442 L
s
.653 .76141 m
.63264 .77645 L
s
.68602 .25538 m
.70294 .2742 L
s
.63264 .77645 m
.61116 .7897 L
s
.66765 .2381 m
.68602 .25538 L
s
.61116 .7897 m
.5887 .80104 L
s
.64794 .22249 m
.66765 .2381 L
s
.5887 .80104 m
.56539 .81037 L
s
.62698 .20869 m
.64794 .22249 L
s
.56539 .81037 m
.54138 .8176 L
s
.6049 .1968 m
.62698 .20869 L
s
.54138 .8176 m
.51682 .82265 L
s
.58183 .18695 m
.6049 .1968 L
s
.51682 .82265 m
.49186 .82544 L
s
.55793 .17924 m
.58183 .18695 L
s
.49186 .82544 m
.46669 .82591 L
s
.53334 .17375 m
.55793 .17924 L
s
.46669 .82591 m
.44148 .82404 L
s
.50824 .17056 m
.53334 .17375 L
s
.44148 .82404 m
.41641 .81978 L
s
.48279 .16974 m
.50824 .17056 L
s
.41641 .81978 m
.39167 .81313 L
s
.45718 .17133 m
.48279 .16974 L
s
.39167 .81313 m
.36745 .8041 L
s
.4316 .17536 m
.45718 .17133 L
s
.36745 .8041 m
.34395 .79273 L
s
.40626 .18184 m
.4316 .17536 L
s
.34395 .79273 m
.32136 .77905 L
s
.38134 .19076 m
.40626 .18184 L
s
.32136 .77905 m
.29988 .76315 L
s
.35707 .20209 m
.38134 .19076 L
s
.29988 .76315 m
.2797 .74512 L
s
.33363 .21576 m
.35707 .20209 L
s
.2797 .74512 m
.26099 .72507 L
s
.31124 .2317 m
.33363 .21576 L
s
.26099 .72507 m
.24393 .70315 L
s
.29009 .24981 m
.31124 .2317 L
s
.24393 .70315 m
.22869 .67951 L
s
.27037 .26997 m
.29009 .24981 L
s
.22869 .67951 m
.2154 .65432 L
s
.25228 .29202 m
.27037 .26997 L
s
.2154 .65432 m
.20422 .6278 L
s
.23596 .31581 m
.25228 .29202 L
s
.20422 .6278 m
.19524 .60016 L
s
.22159 .34113 m
.23596 .31581 L
s
.19524 .60016 m
.18856 .57162 L
s
.20929 .36778 m
.22159 .34113 L
s
.18856 .57162 m
.18426 .54242 L
s
.1992 .39554 m
.20929 .36778 L
s
.18426 .54242 m
.18238 .51282 L
s
.19139 .42418 m
.1992 .39554 L
s
.18238 .51282 m
.18295 .48308 L
s
.18596 .45344 m
.19139 .42418 L
s
.18295 .48308 m
.18596 .45344 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.76247 .56834 m
.75513 .59331 L
s
.76804 .54291 m
.76247 .56834 L
s
.77182 .51717 m
.76804 .54291 L
s
.75513 .59331 m
.74606 .61768 L
s
.77376 .49127 m
.77182 .51717 L
s
.74606 .61768 m
.73531 .6413 L
s
.77386 .46536 m
.77376 .49127 L
s
.73531 .6413 m
.72294 .66404 L
s
.77211 .4396 m
.77386 .46536 L
s
.72294 .66404 m
.70901 .68576 L
s
.7685 .41412 m
.77211 .4396 L
s
.70901 .68576 m
.6936 .70631 L
s
.76305 .3891 m
.7685 .41412 L
s
.6936 .70631 m
.67678 .72558 L
s
.75577 .36468 m
.76305 .3891 L
s
.67678 .72558 m
.65864 .74343 L
s
.74668 .34101 m
.75577 .36468 L
s
.65864 .74343 m
.63929 .75974 L
s
.73582 .31825 m
.74668 .34101 L
s
.63929 .75974 m
.61882 .77439 L
s
.72324 .29656 m
.73582 .31825 L
s
.61882 .77439 m
.59735 .78727 L
s
.709 .27608 m
.72324 .29656 L
s
.59735 .78727 m
.575 .79827 L
s
.69316 .25696 m
.709 .27608 L
s
.575 .79827 m
.55191 .80729 L
s
.6758 .23936 m
.69316 .25696 L
s
.55191 .80729 m
.52821 .81425 L
s
.65702 .2234 m
.6758 .23936 L
s
.52821 .81425 m
.50405 .81906 L
s
.63691 .20922 m
.65702 .2234 L
s
.50405 .81906 m
.47959 .82167 L
s
.61559 .19696 m
.63691 .20922 L
s
.47959 .82167 m
.455 .822 L
s
.59319 .18673 m
.61559 .19696 L
s
.455 .822 m
.43043 .82002 L
s
.56986 .17864 m
.59319 .18673 L
s
.43043 .82002 m
.40608 .8157 L
s
.54573 .17278 m
.56986 .17864 L
s
.40608 .8157 m
.38212 .80904 L
s
.52098 .16925 m
.54573 .17278 L
s
.38212 .80904 m
.35874 .80003 L
s
.49579 .1681 m
.52098 .16925 L
s
.35874 .80003 m
.33611 .7887 L
s
.47033 .1694 m
.49579 .1681 L
s
.33611 .7887 m
.31444 .77511 L
s
.44479 .17316 m
.47033 .1694 L
s
.31444 .77511 m
.2939 .75931 L
s
.41939 .17942 m
.44479 .17316 L
s
.2939 .75931 m
.27468 .7414 L
s
.39432 .18814 m
.41939 .17942 L
s
.27468 .7414 m
.25695 .72149 L
s
.3698 .19931 m
.39432 .18814 L
s
.25695 .72149 m
.24089 .6997 L
s
.34603 .21287 m
.3698 .19931 L
s
.24089 .6997 m
.22664 .67619 L
s
.32322 .22874 m
.34603 .21287 L
s
.22664 .67619 m
.21435 .65113 L
s
.30158 .2468 m
.32322 .22874 L
s
.21435 .65113 m
.20416 .62473 L
s
.2813 .26694 m
.30158 .2468 L
s
.20416 .62473 m
.19616 .59718 L
s
.26258 .289 m
.2813 .26694 L
s
.19616 .59718 m
.19046 .56871 L
s
.24559 .31281 m
.26258 .289 L
s
.19046 .56871 m
.18712 .53957 L
s
.2305 .33817 m
.24559 .31281 L
s
.18712 .53957 m
.18618 .51 L
s
.21743 .36486 m
.2305 .33817 L
s
.18618 .51 m
.18767 .48027 L
s
.20653 .39267 m
.21743 .36486 L
s
.18767 .48027 m
.19158 .45063 L
s
.19788 .42134 m
.20653 .39267 L
s
.19158 .45063 m
.19788 .42134 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.74475 .59356 m
.73486 .61752 L
s
.75301 .56897 m
.74475 .59356 L
s
.75958 .5439 m
.75301 .56897 L
s
.73486 .61752 m
.72337 .64073 L
s
.76441 .51849 m
.75958 .5439 L
s
.72337 .64073 m
.71036 .66305 L
s
.76748 .49288 m
.76441 .51849 L
s
.71036 .66305 m
.69589 .68434 L
s
.76876 .46723 m
.76748 .49288 L
s
.69589 .68434 m
.68004 .70448 L
s
.76824 .44168 m
.76876 .46723 L
s
.68004 .70448 m
.66289 .72334 L
s
.76589 .41638 m
.76824 .44168 L
s
.66289 .72334 m
.64453 .74079 L
s
.76171 .39148 m
.76589 .41638 L
s
.64453 .74079 m
.62505 .75674 L
s
.75573 .36713 m
.76171 .39148 L
s
.62505 .75674 m
.60457 .77105 L
s
.74793 .3435 m
.75573 .36713 L
s
.60457 .77105 m
.5832 .78362 L
s
.73836 .32072 m
.74793 .3435 L
s
.5832 .78362 m
.56104 .79435 L
s
.72705 .29897 m
.73836 .32072 L
s
.56104 .79435 m
.53825 .80315 L
s
.71404 .27839 m
.72705 .29897 L
s
.53825 .80315 m
.51494 .80992 L
s
.69939 .25914 m
.71404 .27839 L
s
.51494 .80992 m
.49126 .8146 L
s
.68317 .24135 m
.69939 .25914 L
s
.49126 .8146 m
.46737 .81711 L
s
.66545 .22519 m
.68317 .24135 L
s
.46737 .81711 m
.44342 .8174 L
s
.64634 .21079 m
.66545 .22519 L
s
.44342 .8174 m
.41957 .81543 L
s
.62593 .19827 m
.64634 .21079 L
s
.41957 .81543 m
.396 .81116 L
s
.60436 .18778 m
.62593 .19827 L
s
.396 .81116 m
.37288 .80458 L
s
.58175 .17941 m
.60436 .18778 L
s
.37288 .80458 m
.35038 .7957 L
s
.55824 .17329 m
.58175 .17941 L
s
.35038 .7957 m
.32869 .78454 L
s
.53401 .16948 m
.55824 .17329 L
s
.32869 .78454 m
.30799 .77113 L
s
.50922 .16808 m
.53401 .16948 L
s
.30799 .77113 m
.28845 .75555 L
s
.48405 .16913 m
.50922 .16808 L
s
.28845 .75555 m
.27026 .73786 L
s
.4587 .17267 m
.48405 .16913 L
s
.27026 .73786 m
.25358 .71818 L
s
.43337 .17872 m
.4587 .17267 L
s
.25358 .71818 m
.23856 .69663 L
s
.40827 .18727 m
.43337 .17872 L
s
.23856 .69663 m
.22538 .67335 L
s
.3836 .19829 m
.40827 .18727 L
s
.22538 .67335 m
.21415 .64852 L
s
.35958 .21172 m
.3836 .19829 L
s
.21415 .64852 m
.20502 .62232 L
s
.33644 .22749 m
.35958 .21172 L
s
.20502 .62232 m
.19807 .59496 L
s
.31437 .24548 m
.33644 .22749 L
s
.19807 .59496 m
.19341 .56666 L
s
.29358 .26556 m
.31437 .24548 L
s
.19341 .56666 m
.19109 .53766 L
s
.27427 .28758 m
.29358 .26556 L
s
.19109 .53766 m
.19115 .50822 L
s
.25662 .31136 m
.27427 .28758 L
s
.19115 .50822 m
.19362 .47858 L
s
.2408 .33669 m
.25662 .31136 L
s
.19362 .47858 m
.19848 .44901 L
s
.22695 .36337 m
.2408 .33669 L
s
.19848 .44901 m
.2057 .41978 L
s
.21522 .39114 m
.22695 .36337 L
s
.2057 .41978 m
.21522 .39114 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.73302 .59241 m
.72238 .61593 L
s
.74211 .56827 m
.73302 .59241 L
s
.72238 .61593 m
.71025 .63869 L
s
.7496 .54364 m
.74211 .56827 L
s
.71025 .63869 m
.69669 .66057 L
s
.75544 .51864 m
.7496 .54364 L
s
.69669 .66057 m
.68179 .68143 L
s
.7596 .49344 m
.75544 .51864 L
s
.68179 .68143 m
.6656 .70116 L
s
.76203 .46816 m
.7596 .49344 L
s
.6656 .70116 m
.64823 .71963 L
s
.76271 .44295 m
.76203 .46816 L
s
.64823 .71963 m
.62975 .73674 L
s
.76162 .41795 m
.76271 .44295 L
s
.62975 .73674 m
.61027 .75236 L
s
.75874 .39332 m
.76162 .41795 L
s
.61027 .75236 m
.58988 .76639 L
s
.75408 .36921 m
.75874 .39332 L
s
.58988 .76639 m
.56871 .77873 L
s
.74763 .34576 m
.75408 .36921 L
s
.56871 .77873 m
.54686 .78927 L
s
.73941 .32314 m
.74763 .34576 L
s
.54686 .78927 m
.52445 .79793 L
s
.72945 .30149 m
.73941 .32314 L
s
.52445 .79793 m
.50163 .80461 L
s
.71777 .28098 m
.72945 .30149 L
s
.50163 .80461 m
.47853 .80926 L
s
.70442 .26174 m
.71777 .28098 L
s
.47853 .80926 m
.4553 .81179 L
s
.68946 .24395 m
.70442 .26174 L
s
.4553 .81179 m
.43208 .81215 L
s
.67295 .22774 m
.68946 .24395 L
s
.43208 .81215 m
.40904 .81029 L
s
.65499 .21325 m
.67295 .22774 L
s
.40904 .81029 m
.38634 .80619 L
s
.63566 .20063 m
.65499 .21325 L
s
.38634 .80619 m
.36414 .79982 L
s
.61508 .19001 m
.63566 .20063 L
s
.36414 .79982 m
.34261 .79119 L
s
.59337 .1815 m
.61508 .19001 L
s
.34261 .79119 m
.32194 .7803 L
s
.57067 .17521 m
.59337 .1815 L
s
.32194 .7803 m
.30229 .7672 L
s
.54713 .17124 m
.57067 .17521 L
s
.30229 .7672 m
.28384 .75194 L
s
.52293 .16966 m
.54713 .17124 L
s
.28384 .75194 m
.26675 .7346 L
s
.49823 .17054 m
.52293 .16966 L
s
.26675 .7346 m
.25118 .71527 L
s
.47323 .17392 m
.49823 .17054 L
s
.25118 .71527 m
.2373 .69406 L
s
.44814 .17982 m
.47323 .17392 L
s
.2373 .69406 m
.22525 .67113 L
s
.42314 .18822 m
.44814 .17982 L
s
.22525 .67113 m
.21517 .64663 L
s
.39847 .19911 m
.42314 .18822 L
s
.21517 .64663 m
.20716 .62074 L
s
.37434 .21242 m
.39847 .19911 L
s
.20716 .62074 m
.20133 .59367 L
s
.35097 .22808 m
.37434 .21242 L
s
.20133 .59367 m
.19777 .56564 L
s
.32856 .24598 m
.35097 .22808 L
s
.19777 .56564 m
.19653 .53688 L
s
.30734 .26598 m
.32856 .24598 L
s
.19653 .53688 m
.19765 .50764 L
s
.2875 .28792 m
.30734 .26598 L
s
.19765 .50764 m
.20114 .47819 L
s
.26924 .31162 m
.2875 .28792 L
s
.20114 .47819 m
.20698 .44877 L
s
.25272 .33688 m
.26924 .31162 L
s
.20698 .44877 m
.21514 .41967 L
s
.23811 .36347 m
.25272 .33688 L
s
.21514 .41967 m
.22555 .39115 L
s
.22555 .39115 m
.23811 .36347 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo002;Ool?O026Ool008Ioo`El00moo`Il081oo`00PWoo17`06Woo1G`0
Ngoo001oOol3O00SOol4O01gOol007eoo`9l02Yoo`=l07Aoo`00Ngoo0W`0;goo0g`0LGoo001hOol3
O00dOol2O01_Ool007Ioo`9l03Uoo`9l06eoo`00M7oo0W`0?Goo0W`0Jgoo001aOol3O011Ool2O01Y
Ool006moo`9l04Ioo`03O01oogoo06Ioo`00KGoo0W`0BGoo0W`0IWoo001[Ool2O01=Ool00g`0Oomo
o`1SOol006Uoo`9l051oo`03O01oogoo069oo`00J7oo00=l07ooOol0DGoo0W`0HWoo001WOol00g`0
Oomoo`1DOol00g`0Oomoo`1OOol006Eoo`9l05Qoo`9l05moo`00I7oo00=l07ooOol0FWoo00=l07oo
Ool0G7oo001SOol00g`0Oomoo`1LOol00g`0Oomoo`1KOol0069oo`03O01oogoo05ioo`03O01oogoo
05Yoo`00H7oo0W`0HGoo00=l07ooOol0FWoo001OOol00g`0Oomoo`1ROol00g`0Oomoo`1IOol005io
o`03O01oogoo06Aoo`03O01oogoo05Qoo`00GGoo00=l07ooOol0IWoo00=l07ooOol0Egoo001LOol0
0g`0Oomoo`1XOol00g`0Oomoo`1FOol005]oo`03O01oogoo06Yoo`03O01oogoo05Eoo`00FWoo00=l
07ooOol0K7oo00=l07ooOol0E7oo001IOol00g`0Oomoo`1^Ool00g`0Oomoo`1COol005Qoo`03O01o
ogoo071oo`03O01oogoo059oo`00Egoo00=l07ooOol0LWoo00=l07ooOol0DGoo001FOol00g`0Oomo
o`1cOol00g`0Oomoo`1AOol005Eoo`03O01oogoo07Eoo`03O01oogoo051oo`00E7oo00=l07ooOol0
Mgoo00=l07ooOol0Cgoo001COol00g`0Oomoo`1hOol00g`0Oomoo`1?Ool0059oo`03O01oogoo07Yo
o`03O01oogoo04ioo`00DGoo00=l07ooOol0Ngoo00=l07ooOol0CWoo001AOol00g`0Oomoo`1lOol0
0g`0Oomoo`1=Ool0051oo`03O01oogoo07eoo`03O01oogoo04eoo`00Cgoo00=l07ooOol0Ogoo00=l
07ooOol0C7oo001>Ool00g`0Oomoo`20Ool00g`0Oomoo`1<Ool004ioo`03O01oogoo085oo`03O01o
ogoo04]oo`00CGoo00=l07ooOol0PWoo00=l07ooOol0Bgoo001<Ool00g`0Oomoo`24Ool00g`0Oomo
o`1:Ool004aoo`03O01oogoo08Aoo`03O01oogoo04Yoo`00Bgoo00=l07ooOol0QWoo00=l07ooOol0
BGoo001:Ool00g`0Oomoo`27Ool00g`0Oomoo`19Ool004Uoo`03O01oogoo08Uoo`03O01oogoo04Qo
o`00BGoo00=l07ooOol0RGoo00=l07ooOol0B7oo0018Ool00g`0Oomoo`2:Ool00g`0Oomoo`18Ool0
04Moo`03O01oogoo08]oo`03O01oogoo04Qoo`00Agoo00=l07ooOol0S7oo00=l07ooOol0Agoo0016
Ool00g`0Oomoo`2=Ool00g`0Oomoo`17Ool004Ioo`03O01oogoo08eoo`03O01oogoo04Moo`00AGoo
00=l07ooOol0Sgoo00=l07ooOol0AWoo0015Ool00g`0Oomoo`2?Ool00g`0Oomoo`16Ool004Aoo`03
O01oogoo091oo`03O01oogoo04Ioo`00A7oo00=l07ooOol0TGoo00=l07ooOol0AGoo0013Ool00g`0
Oomoo`2BOol00g`0Oomoo`15Ool004=oo`03O01oogoo099oo`03O01oogoo04Eoo`00@Woo00=l07oo
Ool0Tgoo00=l07ooOol0AGoo0012Ool00g`0Oomoo`2COol00g`0Oomoo`15Ool0045oo`03O01oogoo
09Eoo`03O01oogoo04Aoo`00@Goo00=l07ooOol0UGoo00=l07ooOol0A7oo0010Ool00g`0Oomoo`2F
Ool00g`0Oomoo`14Ool0041oo`03O01oogoo09Ioo`03O01oogoo04Aoo`00@7oo00=l07ooOol0UWoo
00=l07ooOol0A7oo000oOol00g`0Oomoo`2GOol00g`0Oomoo`14Ool003moo`03O01oogoo09Moo`03
O01oogoo04Aoo`00?Woo00=l07ooOol0VGoo00=l07ooOol0@goo000nOol00g`0Oomoo`2IOol00g`0
Oomoo`13Ool003ioo`03O01oogoo09Uoo`03O01oogoo04=oo`00?Goo00=l07ooOol0VWoo00=l07oo
Ool0@goo000mOol00g`0Oomoo`2JOol00g`0Oomoo`13Ool003eoo`03O01oogoo09Yoo`03O01oogoo
04=oo`00?7oo00=l07ooOol0Vgoo00=l07ooOol0@goo000lOol00g`0Oomoo`2KOol00g`0Oomoo`13
Ool003aoo`03O01oogoo09]oo`03O01oogoo04=oo`00?7oo00=l07ooOol0Vgoo00=l07ooOol0@goo
000kOol00g`0Oomoo`2LOol00g`0Oomoo`13Ool003]oo`03O01oogoo09aoo`03O01oogoo04=oo`00
>goo00=l07ooOol0W7oo00=l07ooOol0@goo000kOol00g`0Oomoo`2LOol00g`0Oomoo`13Ool003]o
o`03O01oogoo09aoo`03O01oogoo04=oo`00>Woo00=l07ooOol0WGoo00=l07ooOol0@goo000jOol0
0g`0Oomoo`2MOol00g`0Oomoo`13Ool003Yoo`03O01oogoo09eoo`03O01oogoo04=oo`00>Woo00=l
07ooOol0WGoo00=l07ooOol0@goo000iOol00g`0Oomoo`2NOol00g`0Oomoo`13Ool003Uoo`03O01o
ogoo09ioo`03O01oogoo04=oo`00>Goo00=l07ooOol0WWoo00=l07ooOol0@goo000iOol00g`0Oomo
o`2NOol00g`0Oomoo`13Ool003Uoo`03O01oogoo09ioo`03O01oogoo04=oo`00>Goo00=l07ooOol0
WWoo00=l07ooOol0@goo000hOol00g`0Oomoo`2OOol00g`0Oomoo`13Ool003Qoo`03O01oogoo09mo
o`03O01oogoo04=oo`00>7oo00=l07ooOol0WWoo00=l07ooOol0A7oo000hOol00g`0Oomoo`2NOol0
0g`0Oomoo`14Ool003Qoo`03O01oogoo09ioo`03O01oogoo04Aoo`00>7oo00=l07ooOol0WWoo00=l
07ooOol0A7oo000hOol00g`0Oomoo`2MOol00g`0Oomoo`15Ool003Qoo`03O01oogoo09eoo`03O01o
ogoo04Eoo`00>7oo00=l07ooOol0WGoo00=l07ooOol0AGoo000hOol00g`0Oomoo`2MOol00g`0Oomo
o`15Ool003Qoo`03O01oogoo09eoo`03O01oogoo04Eoo`00>7oo00=l07ooOol0W7oo00=l07ooOol0
AWoo000hOol00g`0Oomoo`2LOol00g`0Oomoo`16Ool003Qoo`03O01oogoo09aoo`03O01oogoo04Io
o`00>7oo00=l07ooOol0W7oo00=l07ooOol0AWoo000hOol00g`0Oomoo`2LOol00g`0Oomoo`16Ool0
03Qoo`03O01oogoo09aoo`03O01oogoo04Ioo`00>7oo00=l07ooOol0Vgoo00=l07ooOol0Agoo000h
Ool00g`0Oomoo`2KOol00g`0Oomoo`17Ool003Qoo`03O01oogoo09Yoo`03O01oogoo04Qoo`00>7oo
00=l07ooOol0VWoo00=l07ooOol0B7oo000hOol00g`0Oomoo`2IOol00g`0Oomoo`19Ool003Qoo`03
O01oogoo09Uoo`03O01oogoo04Uoo`00>7oo00=l07ooOol0VGoo00=l07ooOol0BGoo000hOol00g`0
Oomoo`2HOol00g`0Oomoo`1:Ool003Qoo`03O01oogoo09Qoo`03O01oogoo04Yoo`00>Goo00=l07oo
Ool0Ugoo00=l07ooOol0BWoo000iOol00g`0Oomoo`2GOol00g`0Oomoo`1:Ool003Uoo`03O01oogoo
09Ioo`03O01oogoo04]oo`00>Goo00=l07ooOol0UWoo00=l07ooOol0Bgoo000iOol00g`0Oomoo`2E
Ool00g`0Oomoo`1<Ool003Uoo`03O01oogoo09Eoo`03O01oogoo04aoo`00>Woo00=l07ooOol0Tgoo
00=l07ooOol0CGoo000jOol00g`0Oomoo`2COol00g`0Oomoo`1=Ool003Yoo`03O01oogoo099oo`03
O01oogoo04ioo`00>Woo00=l07ooOol0TWoo00=l07ooOol0CWoo000kOol00g`0Oomoo`2@Ool00g`0
Oomoo`1?Ool003]oo`03O01oogoo091oo`03O01oogoo04moo`00>goo00=l07ooOol0Sgoo00=l07oo
Ool0D7oo000lOol00g`0Oomoo`2>Ool00g`0Oomoo`1@Ool003aoo`03O01oogoo08eoo`03O01oogoo
055oo`00?7oo00=l07ooOol0SGoo00=l07ooOol0DGoo000lOol00g`0Oomoo`2<Ool00g`0Oomoo`1B
Ool003eoo`03O01oogoo08Yoo`03O01oogoo05=oo`00?Goo00=l07ooOol0RWoo00=l07ooOol0Dgoo
000mOol00g`0Oomoo`29Ool00g`0Oomoo`1DOol003ioo`03O01oogoo08Moo`03O01oogoo05Eoo`00
?Woo00=l07ooOol0Qgoo00=l07ooOol0EGoo000oOol00g`0Oomoo`25Ool00g`0Oomoo`1FOol003mo
o`03O01oogoo08Aoo`03O01oogoo05Moo`00@7oo00=l07ooOol0Pgoo00=l07ooOol0Egoo0010Ool0
0g`0Oomoo`22Ool00g`0Oomoo`1HOol0045oo`03O01oogoo081oo`03O01oogoo05Uoo`00@Goo00=l
07ooOol0P7oo00=l07ooOol0FGoo0012Ool00g`0Oomoo`1nOol00g`0Oomoo`1JOol0049oo`03O01o
ogoo07eoo`03O01oogoo05]oo`00@goo00=l07ooOol0O7oo00=l07ooOol0Fgoo0013Ool00g`0Oomo
o`1kOol00g`0Oomoo`1LOol004Aoo`03O01oogoo07Uoo`03O01oogoo05eoo`00AGoo00=l07ooOol0
N7oo00=l07ooOol0GGoo0015Ool00g`0Oomoo`1gOol00g`0Oomoo`1NOol004Ioo`03O01oogoo07Eo
o`03O01oogoo05moo`00Agoo00=l07ooOol0Lgoo00=l07ooOol0H7oo0017Ool00g`0Oomoo`1bOol0
0g`0Oomoo`1QOol004Qoo`03O01oogoo071oo`03O01oogoo069oo`00BGoo00=l07ooOol0KWoo00=l
07ooOol0Hgoo001:Ool00g`0Oomoo`1/Ool00g`0Oomoo`1TOol004Yoo`03O01oogoo06]oo`03O01o
ogoo06Eoo`00Bgoo00=l07ooOol0J7oo0W`0J7oo001<Ool00g`0Oomoo`1VOol00g`0Oomoo`1XOol0
04eoo`03O01oogoo06Aoo`03O01oogoo06Uoo`00CWoo00=l07ooOol0HWoo00=l07ooOol0JWoo001?
Ool00g`0Oomoo`1OOol2O01]Ool0051oo`03O01oogoo05eoo`03O01oogoo06eoo`00DGoo00=l07oo
Ool0Fgoo00=l07ooOol0KWoo001BOol00g`0Oomoo`1HOol2O01aOol005=oo`03O01oogoo05Ioo`03
O01oogoo075oo`00E7oo00=l07ooOol0Dgoo0W`0M7oo001EOol00g`0Oomoo`1AOol00g`0Oomoo`1d
Ool005Ioo`03O01oogoo04ioo`9l07Moo`00Egoo0W`0CGoo00=l07ooOol0Mgoo001IOol2O019Ool2
O01jOol005]oo`9l04Eoo`9l07aoo`00GGoo0W`0@Goo0W`0OWoo001OOol00g`0Oomoo`0lOol2O020
Ool0061oo`9l03Yoo`9l089oo`00HWoo0W`0=Woo0W`0Q7oo001TOol3O00aOol2O026Ool006Moo`=l
02Uoo`El08Qoo`00JWoo0g`08Goo1G`0SGoo001]Ool5O00IOol3O02BOol0079oo`Ml00Moo`]l09Eo
o`00NGoo1g`0X7oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.70881 .61301 m
.69613 .63533 L
s
.72011 .58995 m
.70881 .61301 L
s
.72996 .56627 m
.72011 .58995 L
s
.69613 .63533 m
.68213 .65679 L
s
.7383 .54211 m
.72996 .56627 L
s
.68213 .65679 m
.66688 .67725 L
s
.74509 .51758 m
.7383 .54211 L
s
.66688 .67725 m
.65047 .69662 L
s
.75027 .49283 m
.74509 .51758 L
s
.65047 .69662 m
.63297 .71476 L
s
.75381 .46799 m
.75027 .49283 L
s
.63297 .71476 m
.61448 .73158 L
s
.75567 .4432 m
.75381 .46799 L
s
.61448 .73158 m
.59509 .74695 L
s
.75581 .41861 m
.75567 .4432 L
s
.59509 .74695 m
.5749 .76079 L
s
.75423 .39436 m
.75581 .41861 L
s
.5749 .76079 m
.55402 .77298 L
s
.75091 .37059 m
.75423 .39436 L
s
.55402 .77298 m
.53256 .78343 L
s
.74584 .34745 m
.75091 .37059 L
s
.53256 .78343 m
.51065 .79205 L
s
.73901 .32511 m
.74584 .34745 L
s
.51065 .79205 m
.48841 .79876 L
s
.73045 .3037 m
.73901 .32511 L
s
.48841 .79876 m
.46597 .80348 L
s
.72018 .28339 m
.73045 .3037 L
s
.46597 .80348 m
.44348 .80614 L
s
.70822 .26432 m
.72018 .28339 L
s
.44348 .80614 m
.42108 .80669 L
s
.69463 .24666 m
.70822 .26432 L
s
.42108 .80669 m
.39892 .80507 L
s
.67946 .23054 m
.69463 .24666 L
s
.39892 .80507 m
.37716 .80125 L
s
.66277 .21611 m
.67946 .23054 L
s
.37716 .80125 m
.35596 .7952 L
s
.64466 .20352 m
.66277 .21611 L
s
.35596 .7952 m
.33548 .78693 L
s
.62523 .1929 m
.64466 .20352 L
s
.33548 .78693 m
.3159 .77644 L
s
.60458 .18436 m
.62523 .1929 L
s
.3159 .77644 m
.29737 .76375 L
s
.58285 .17803 m
.60458 .18436 L
s
.29737 .76375 m
.28007 .74893 L
s
.56019 .174 m
.58285 .17803 L
s
.28007 .74893 m
.26415 .73202 L
s
.53674 .17235 m
.56019 .174 L
s
.26415 .73202 m
.24978 .71313 L
s
.51268 .17315 m
.53674 .17235 L
s
.24978 .71313 m
.2371 .69237 L
s
.4882 .17645 m
.51268 .17315 L
s
.2371 .69237 m
.22625 .66986 L
s
.4635 .18226 m
.4882 .17645 L
s
.22625 .66986 m
.21737 .64577 L
s
.43877 .19058 m
.4635 .18226 L
s
.21737 .64577 m
.21055 .62028 L
s
.41424 .20139 m
.43877 .19058 L
s
.21055 .62028 m
.2059 .59357 L
s
.39012 .21462 m
.41424 .20139 L
s
.2059 .59357 m
.2035 .56587 L
s
.36663 .23021 m
.39012 .21462 L
s
.2035 .56587 m
.20339 .53741 L
s
.344 .24804 m
.36663 .23021 L
s
.20339 .53741 m
.2056 .50843 L
s
.32243 .26797 m
.344 .24804 L
s
.2056 .50843 m
.21015 .47921 L
s
.30213 .28984 m
.32243 .26797 L
s
.21015 .47921 m
.217 .45 L
s
.28331 .31346 m
.30213 .28984 L
s
.217 .45 m
.22611 .42106 L
s
.26614 .33864 m
.28331 .31346 L
s
.22611 .42106 m
.23741 .39269 L
s
.25079 .36512 m
.26614 .33864 L
s
.23741 .39269 m
.25079 .36512 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol0091ooa9l07ioo`00Rgoo1G`04Woo17`0NWoo0027Ool4
O00KOol4O01fOol008Aoo`=l02=oo`Al079oo`00P7oo17`0:Woo0W`0L7oo001lOol4O00`Ool2O01^
Ool007Yoo`9l03Ioo`9l06aoo`00N7oo0W`0>Woo0W`0JWoo001fOol2O00nOol2O01XOol007Aoo`9l
049oo`9l06Ioo`00LWoo0W`0AWoo00=l07ooOol0Hgoo001`Ool2O019Ool2O01SOol006moo`03O01o
ogoo04]oo`03O01oogoo061oo`00KWoo00=l07ooOol0CGoo00=l07ooOol0Ggoo001]Ool00g`0Oomo
o`1?Ool00g`0Oomoo`1NOol006]oo`9l05=oo`9l05ioo`00JWoo00=l07ooOol0EGoo00=l07ooOol0
Fgoo001YOol00g`0Oomoo`1GOol00g`0Oomoo`1JOol006Moo`9l05]oo`03O01oogoo05Uoo`00IWoo
00=l07ooOol0G7oo00=l07ooOol0F7oo001UOol00g`0Oomoo`1NOol00g`0Oomoo`1GOol006=oo`9l
069oo`03O01oogoo05Ioo`00HWoo00=l07ooOol0Hgoo00=l07ooOol0EGoo001QOol00g`0Oomoo`1U
Ool00g`0Oomoo`1DOol0061oo`03O01oogoo06Ioo`03O01oogoo05Aoo`00GWoo0W`0JWoo00=l07oo
Ool0Dgoo001MOol00g`0Oomoo`1[Ool00g`0Oomoo`1BOol005aoo`03O01oogoo06aoo`03O01oogoo
059oo`00Fgoo00=l07ooOol0KWoo00=l07ooOol0DGoo001JOol00g`0Oomoo`1_Ool00g`0Oomoo`1A
Ool005Uoo`03O01oogoo075oo`03O01oogoo051oo`00FGoo00=l07ooOol0LGoo00=l07ooOol0D7oo
001HOol00g`0Oomoo`1cOol00g`0Oomoo`1?Ool005Moo`03O01oogoo07Aoo`03O01oogoo04moo`00
EWoo00=l07ooOol0MWoo00=l07ooOol0CWoo001EOol00g`0Oomoo`1gOol00g`0Oomoo`1>Ool005Ao
o`03O01oogoo07Uoo`03O01oogoo04eoo`00Dgoo00=l07ooOol0NWoo00=l07ooOol0CGoo001COol0
0g`0Oomoo`1kOol00g`0Oomoo`1<Ool0059oo`03O01oogoo07aoo`03O01oogoo04aoo`00DGoo00=l
07ooOol0OWoo00=l07ooOol0Bgoo001@Ool00g`0Oomoo`1oOol00g`0Oomoo`1;Ool0051oo`03O01o
ogoo081oo`03O01oogoo04Yoo`00Cgoo00=l07ooOol0PGoo00=l07ooOol0BWoo001>Ool00g`0Oomo
o`23Ool00g`0Oomoo`19Ool004ioo`03O01oogoo08=oo`03O01oogoo04Uoo`00CGoo00=l07ooOol0
QGoo00=l07ooOol0B7oo001=Ool00g`0Oomoo`25Ool00g`0Oomoo`18Ool004aoo`03O01oogoo08Io
o`03O01oogoo04Qoo`00Bgoo00=l07ooOol0R7oo00=l07ooOol0Agoo001;Ool00g`0Oomoo`28Ool0
0g`0Oomoo`17Ool004Yoo`03O01oogoo08Uoo`03O01oogoo04Moo`00BGoo00=l07ooOol0RWoo00=l
07ooOol0Agoo0018Ool00g`0Oomoo`2;Ool00g`0Oomoo`17Ool004Qoo`03O01oogoo08aoo`03O01o
ogoo04Ioo`00Agoo00=l07ooOol0SGoo00=l07ooOol0AWoo0017Ool00g`0Oomoo`2=Ool00g`0Oomo
o`16Ool004Ioo`03O01oogoo08ioo`03O01oogoo04Ioo`00AWoo00=l07ooOol0SWoo00=l07ooOol0
AWoo0015Ool00g`0Oomoo`2?Ool00g`0Oomoo`16Ool004Eoo`03O01oogoo08moo`03O01oogoo04Io
o`00AGoo00=l07ooOol0T7oo00=l07ooOol0AGoo0014Ool00g`0Oomoo`2AOol00g`0Oomoo`15Ool0
04Aoo`03O01oogoo095oo`03O01oogoo04Eoo`00@goo00=l07ooOol0TWoo00=l07ooOol0AGoo0013
Ool00g`0Oomoo`2BOol00g`0Oomoo`15Ool0049oo`03O01oogoo09=oo`03O01oogoo04Eoo`00@Woo
00=l07ooOol0Tgoo00=l07ooOol0AGoo0011Ool00g`0Oomoo`2DOol00g`0Oomoo`15Ool0045oo`03
O01oogoo09Aoo`03O01oogoo04Eoo`00@7oo00=l07ooOol0UGoo00=l07ooOol0AGoo0010Ool00g`0
Oomoo`2EOol00g`0Oomoo`15Ool0041oo`03O01oogoo09Eoo`03O01oogoo04Eoo`00@7oo00=l07oo
Ool0UGoo00=l07ooOol0AGoo000oOol00g`0Oomoo`2FOol00g`0Oomoo`15Ool003moo`03O01oogoo
09Ioo`03O01oogoo04Eoo`00?goo00=l07ooOol0UWoo00=l07ooOol0AGoo000oOol00g`0Oomoo`2F
Ool00g`0Oomoo`15Ool003ioo`03O01oogoo09Moo`03O01oogoo04Eoo`00?Woo00=l07ooOol0Ugoo
00=l07ooOol0AGoo000nOol00g`0Oomoo`2GOol00g`0Oomoo`15Ool003ioo`03O01oogoo09Moo`03
O01oogoo04Eoo`00?Goo00=l07ooOol0V7oo00=l07ooOol0AGoo000mOol00g`0Oomoo`2HOol00g`0
Oomoo`15Ool003eoo`03O01oogoo09Qoo`03O01oogoo04Eoo`00?Goo00=l07ooOol0V7oo00=l07oo
Ool0AGoo000lOol00g`0Oomoo`2IOol00g`0Oomoo`15Ool003aoo`03O01oogoo09Uoo`03O01oogoo
04Eoo`00?7oo00=l07ooOol0VGoo00=l07ooOol0AGoo000lOol00g`0Oomoo`2HOol00g`0Oomoo`16
Ool003aoo`03O01oogoo09Qoo`03O01oogoo04Ioo`00?7oo00=l07ooOol0V7oo00=l07ooOol0AWoo
000kOol00g`0Oomoo`2IOol00g`0Oomoo`16Ool003]oo`03O01oogoo09Uoo`03O01oogoo04Ioo`00
>goo00=l07ooOol0V7oo00=l07ooOol0Agoo000kOol00g`0Oomoo`2HOol00g`0Oomoo`17Ool003]o
o`03O01oogoo09Qoo`03O01oogoo04Moo`00>goo00=l07ooOol0V7oo00=l07ooOol0Agoo000kOol0
0g`0Oomoo`2GOol00g`0Oomoo`18Ool003]oo`03O01oogoo09Moo`03O01oogoo04Qoo`00>goo00=l
07ooOol0Ugoo00=l07ooOol0B7oo000jOol00g`0Oomoo`2GOol00g`0Oomoo`19Ool003Yoo`03O01o
ogoo09Moo`03O01oogoo04Uoo`00>Woo00=l07ooOol0Ugoo00=l07ooOol0BGoo000jOol00g`0Oomo
o`2GOol00g`0Oomoo`19Ool003Yoo`03O01oogoo09Ioo`03O01oogoo04Yoo`00>Woo00=l07ooOol0
UWoo00=l07ooOol0BWoo000jOol00g`0Oomoo`2FOol00g`0Oomoo`1:Ool003Yoo`03O01oogoo09Eo
o`03O01oogoo04]oo`00>Woo00=l07ooOol0UGoo00=l07ooOol0Bgoo000jOol00g`0Oomoo`2EOol0
0g`0Oomoo`1;Ool003Yoo`03O01oogoo09Eoo`03O01oogoo04]oo`00>Woo00=l07ooOol0U7oo00=l
07ooOol0C7oo000jOol00g`0Oomoo`2DOol00g`0Oomoo`1<Ool003Yoo`03O01oogoo09Aoo`03O01o
ogoo04aoo`00>Woo00=l07ooOol0Tgoo00=l07ooOol0CGoo000jOol00g`0Oomoo`2COol00g`0Oomo
o`1=Ool003Yoo`03O01oogoo099oo`03O01oogoo04ioo`00>goo00=l07ooOol0TGoo00=l07ooOol0
CWoo000kOol00g`0Oomoo`2@Ool00g`0Oomoo`1?Ool003]oo`03O01oogoo091oo`03O01oogoo04mo
o`00>goo00=l07ooOol0Sgoo00=l07ooOol0D7oo000kOol00g`0Oomoo`2?Ool00g`0Oomoo`1@Ool0
03]oo`03O01oogoo08ioo`03O01oogoo055oo`00>goo00=l07ooOol0SWoo00=l07ooOol0DGoo000k
Ool00g`0Oomoo`2=Ool00g`0Oomoo`1BOol003aoo`03O01oogoo08aoo`03O01oogoo059oo`00?7oo
00=l07ooOol0Rgoo00=l07ooOol0Dgoo000lOol00g`0Oomoo`2;Ool00g`0Oomoo`1COol003aoo`03
O01oogoo08Yoo`03O01oogoo05Aoo`00?7oo00=l07ooOol0RWoo00=l07ooOol0E7oo000mOol00g`0
Oomoo`28Ool00g`0Oomoo`1EOol003eoo`03O01oogoo08Qoo`03O01oogoo05Eoo`00?Goo00=l07oo
Ool0Qgoo00=l07ooOol0EWoo000mOol00g`0Oomoo`26Ool00g`0Oomoo`1GOol003ioo`03O01oogoo
08Eoo`03O01oogoo05Moo`00?Woo00=l07ooOol0Q7oo00=l07ooOol0F7oo000nOol00g`0Oomoo`23
Ool00g`0Oomoo`1IOol003moo`03O01oogoo089oo`03O01oogoo05Uoo`00?goo00=l07ooOol0PGoo
00=l07ooOol0FWoo000oOol00g`0Oomoo`20Ool00g`0Oomoo`1KOol003moo`03O01oogoo081oo`03
O01oogoo05]oo`00@7oo00=l07ooOol0OWoo00=l07ooOol0G7oo0010Ool00g`0Oomoo`1mOol00g`0
Oomoo`1MOol0045oo`03O01oogoo07aoo`03O01oogoo05eoo`00@Goo00=l07ooOol0Ngoo00=l07oo
Ool0GWoo0012Ool00g`0Oomoo`1iOol00g`0Oomoo`1OOol004=oo`03O01oogoo07Moo`03O01oogoo
061oo`00@goo00=l07ooOol0MWoo00=l07ooOol0HGoo0014Ool00g`0Oomoo`1dOol00g`0Oomoo`1R
Ool004Aoo`03O01oogoo07=oo`03O01oogoo06=oo`00AGoo00=l07ooOol0LGoo00=l07ooOol0I7oo
0015Ool00g`0Oomoo`1`Ool00g`0Oomoo`1UOol004Ioo`03O01oogoo06ioo`03O01oogoo06Ioo`00
AWoo00=l07ooOol0KWoo00=l07ooOol0IWoo0017Ool00g`0Oomoo`1/Ool00g`0Oomoo`1WOol004Qo
o`03O01oogoo06Yoo`03O01oogoo06Qoo`00B7oo00=l07ooOol0JGoo00=l07ooOol0JGoo0019Ool0
0g`0Oomoo`1VOol2O01/Ool004Yoo`03O01oogoo06Aoo`03O01oogoo06aoo`00BWoo00=l07ooOol0
Hgoo00=l07ooOol0KGoo001;Ool00g`0Oomoo`1QOol00g`0Oomoo`1^Ool004aoo`03O01oogoo05mo
o`03O01oogoo06moo`00CGoo0W`0GGoo0W`0LWoo001?Ool00g`0Oomoo`1IOol00g`0Oomoo`1bOol0
051oo`03O01oogoo05Moo`03O01oogoo07=oo`00DGoo00=l07ooOol0E7oo0W`0MWoo001BOol00g`0
Oomoo`1BOol00g`0Oomoo`1fOol005=oo`03O01oogoo04moo`9l07Uoo`00E7oo00=l07ooOol0CGoo
00=l07ooOol0NGoo001EOol00g`0Oomoo`1:Ool2O01lOol005Ioo`9l04Qoo`9l07ioo`00F7oo0W`0
A7oo0W`0P7oo001JOol00g`0Oomoo`0oOol2O022Ool005]oo`9l03eoo`9l08Aoo`00GGoo0W`0>Goo
0W`0QWoo001OOol2O00eOol2O028Ool0065oo`9l035oo`9l08Yoo`00Hgoo0W`0;7oo0g`0S7oo001U
Ool4O00UOol3O02?Ool006Uoo`El01]oo`El099oo`00KWoo0g`04Woo1W`0Ugoo001aOolBO02MOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.69408 .60878 m
.68095 .63067 L
s
.70593 .58618 m
.69408 .60878 L
s
.68095 .63067 m
.66662 .65173 L
s
.71644 .56297 m
.70593 .58618 L
s
.66662 .65173 m
.65114 .67184 L
s
.72555 .5393 m
.71644 .56297 L
s
.65114 .67184 m
.63462 .69088 L
s
.7332 .51527 m
.72555 .5393 L
s
.63462 .69088 m
.61711 .70876 L
s
.73934 .49102 m
.7332 .51527 L
s
.61711 .70876 m
.59872 .72535 L
s
.74393 .46669 m
.73934 .49102 L
s
.59872 .72535 m
.57954 .74056 L
s
.74692 .4424 m
.74393 .46669 L
s
.57954 .74056 m
.55967 .75429 L
s
.74828 .41829 m
.74692 .4424 L
s
.55967 .75429 m
.5392 .76643 L
s
.74798 .3945 m
.74828 .41829 L
s
.5392 .76643 m
.51825 .77689 L
s
.74599 .37118 m
.74798 .3945 L
s
.51825 .77689 m
.49694 .78558 L
s
.7423 .34848 m
.74599 .37118 L
s
.49694 .78558 m
.47539 .79242 L
s
.73691 .32653 m
.7423 .34848 L
s
.47539 .79242 m
.45372 .79733 L
s
.72981 .30549 m
.73691 .32653 L
s
.45372 .79733 m
.43208 .80024 L
s
.721 .28551 m
.72981 .30549 L
s
.43208 .80024 m
.41059 .80108 L
s
.71053 .26674 m
.721 .28551 L
s
.41059 .80108 m
.38942 .79982 L
s
.6984 .24934 m
.71053 .26674 L
s
.38942 .79982 m
.3687 .7964 L
s
.68468 .23345 m
.6984 .24934 L
s
.3687 .7964 m
.34859 .79079 L
s
.66941 .21922 m
.68468 .23345 L
s
.34859 .79079 m
.32925 .783 L
s
.65266 .2068 m
.66941 .21922 L
s
.32925 .783 m
.31085 .77301 L
s
.63454 .19631 m
.65266 .2068 L
s
.31085 .77301 m
.29353 .76085 L
s
.61512 .18788 m
.63454 .19631 L
s
.29353 .76085 m
.27747 .74656 L
s
.59454 .18163 m
.61512 .18788 L
s
.27747 .74656 m
.2628 .73021 L
s
.57293 .17765 m
.59454 .18163 L
s
.2628 .73021 m
.2497 .71186 L
s
.55042 .17605 m
.57293 .17765 L
s
.2497 .71186 m
.23829 .69163 L
s
.5272 .17687 m
.55042 .17605 L
s
.23829 .69163 m
.22872 .66964 L
s
.50343 .18017 m
.5272 .17687 L
s
.22872 .66964 m
.2211 .64605 L
s
.4793 .18598 m
.50343 .18017 L
s
.2211 .64605 m
.21554 .62102 L
s
.45502 .19429 m
.4793 .18598 L
s
.21554 .62102 m
.21212 .59474 L
s
.4308 .20508 m
.45502 .19429 L
s
.21212 .59474 m
.21092 .56744 L
s
.40686 .2183 m
.4308 .20508 L
s
.21092 .56744 m
.21198 .53933 L
s
.38341 .23386 m
.40686 .2183 L
s
.21198 .53933 m
.21531 .51068 L
s
.36068 .25165 m
.38341 .23386 L
s
.21531 .51068 m
.22093 .48173 L
s
.33889 .27154 m
.36068 .25165 L
s
.22093 .48173 m
.22879 .45275 L
s
.31824 .29336 m
.33889 .27154 L
s
.22879 .45275 m
.23885 .42402 L
s
.29895 .31691 m
.31824 .29336 L
s
.23885 .42402 m
.25101 .39581 L
s
.2812 .342 m
.29895 .31691 L
s
.25101 .39581 m
.26517 .36838 L
s
.26517 .36838 m
.2812 .342 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00U7oo4W`0NWoo002?Ool5O00BOol3O01g
Ool008]oo`Al01Yoo`Al07=oo`00R7oo0g`08Woo17`0Kgoo0024Ool4O00YOol2O01]Ool0085oo`=l
02moo`9l06]oo`00Ogoo0W`0=7oo0W`0JGoo001mOol2O00hOol2O01WOol007]oo`9l03aoo`9l06Eo
o`00NGoo0W`0@7oo00=l07ooOol0HWoo001gOol2O013Ool2O01ROol007Eoo`9l04Moo`9l061oo`00
M7oo00=l07ooOol0BGoo00=l07ooOol0GGoo001cOol00g`0Oomoo`1;Ool00g`0Oomoo`1LOol0079o
o`03O01oogoo04eoo`03O01oogoo05]oo`00L7oo0W`0DGoo00=l07ooOol0FWoo001_Ool00g`0Oomo
o`1BOol00g`0Oomoo`1IOol006ioo`03O01oogoo05Aoo`03O01oogoo05Qoo`00K7oo0W`0F7oo00=l
07ooOol0Egoo001[Ool00g`0Oomoo`1HOol00g`0Oomoo`1GOol006Yoo`03O01oogoo05Yoo`03O01o
ogoo05Ioo`00J7oo0W`0GWoo00=l07ooOol0EGoo001WOol00g`0Oomoo`1OOol00g`0Oomoo`1DOol0
06Ioo`03O01oogoo061oo`03O01oogoo05Aoo`00IGoo00=l07ooOol0HWoo00=l07ooOol0Dgoo001S
Ool2O01UOol00g`0Oomoo`1COol0069oo`03O01oogoo06Ioo`03O01oogoo059oo`00HGoo00=l07oo
Ool0J7oo00=l07ooOol0DGoo001POol00g`0Oomoo`1YOol00g`0Oomoo`1AOol005moo`03O01oogoo
06]oo`03O01oogoo051oo`00GWoo00=l07ooOol0K7oo00=l07ooOol0D7oo001NOol00g`0Oomoo`1]
Ool00g`0Oomoo`1?Ool005eoo`03O01oogoo06ioo`03O01oogoo04moo`00G7oo00=l07ooOol0L7oo
00=l07ooOol0CWoo001KOol00g`0Oomoo`1aOol00g`0Oomoo`1>Ool005Yoo`03O01oogoo07=oo`03
O01oogoo04eoo`00FGoo00=l07ooOol0M7oo00=l07ooOol0CGoo001HOol00g`0Oomoo`1fOol00g`0
Oomoo`1<Ool005Moo`03O01oogoo07Moo`03O01oogoo04aoo`00EWoo00=l07ooOol0NGoo00=l07oo
Ool0Bgoo001EOol00g`0Oomoo`1jOol00g`0Oomoo`1;Ool005Aoo`03O01oogoo07]oo`03O01oogoo
04]oo`00E7oo00=l07ooOol0O7oo00=l07ooOol0BWoo001COol00g`0Oomoo`1mOol00g`0Oomoo`1:
Ool0059oo`03O01oogoo07ioo`03O01oogoo04Yoo`00DWoo00=l07ooOol0Ogoo00=l07ooOol0BGoo
001AOol00g`0Oomoo`20Ool00g`0Oomoo`19Ool0055oo`03O01oogoo081oo`03O01oogoo04Uoo`00
D7oo00=l07ooOol0PGoo00=l07ooOol0BGoo001?Ool00g`0Oomoo`23Ool00g`0Oomoo`18Ool004mo
o`03O01oogoo08=oo`03O01oogoo04Qoo`00CWoo00=l07ooOol0Q7oo00=l07ooOol0B7oo001>Ool0
0g`0Oomoo`24Ool00g`0Oomoo`18Ool004eoo`03O01oogoo08Eoo`03O01oogoo04Qoo`00CGoo00=l
07ooOol0QWoo00=l07ooOol0Agoo001<Ool00g`0Oomoo`27Ool00g`0Oomoo`17Ool004]oo`03O01o
ogoo08Qoo`03O01oogoo04Moo`00Bgoo00=l07ooOol0R7oo00=l07ooOol0Agoo001:Ool00g`0Oomo
o`29Ool00g`0Oomoo`17Ool004Yoo`03O01oogoo08Uoo`03O01oogoo04Moo`00BGoo00=l07ooOol0
RWoo00=l07ooOol0Agoo0019Ool00g`0Oomoo`2:Ool00g`0Oomoo`17Ool004Qoo`03O01oogoo08]o
o`03O01oogoo04Moo`00B7oo00=l07ooOol0Rgoo00=l07ooOol0Agoo0017Ool00g`0Oomoo`2<Ool0
0g`0Oomoo`17Ool004Moo`03O01oogoo08aoo`03O01oogoo04Moo`00AWoo00=l07ooOol0SGoo00=l
07ooOol0Agoo0016Ool00g`0Oomoo`2=Ool00g`0Oomoo`17Ool004Eoo`03O01oogoo08ioo`03O01o
ogoo04Moo`00AGoo00=l07ooOol0SWoo00=l07ooOol0Agoo0014Ool00g`0Oomoo`2?Ool00g`0Oomo
o`17Ool004Aoo`03O01oogoo08moo`03O01oogoo04Moo`00A7oo00=l07ooOol0Sgoo00=l07ooOol0
Agoo0013Ool00g`0Oomoo`2@Ool00g`0Oomoo`17Ool004=oo`03O01oogoo091oo`03O01oogoo04Mo
o`00@Woo00=l07ooOol0TGoo00=l07ooOol0Agoo0012Ool00g`0Oomoo`2AOol00g`0Oomoo`17Ool0
049oo`03O01oogoo095oo`03O01oogoo04Moo`00@Goo00=l07ooOol0TWoo00=l07ooOol0Agoo0011
Ool00g`0Oomoo`2BOol00g`0Oomoo`17Ool0045oo`03O01oogoo095oo`03O01oogoo04Qoo`00@Goo
00=l07ooOol0TGoo00=l07ooOol0B7oo0010Ool00g`0Oomoo`2BOol00g`0Oomoo`18Ool0041oo`03
O01oogoo099oo`03O01oogoo04Qoo`00@7oo00=l07ooOol0TWoo00=l07ooOol0B7oo0010Ool00g`0
Oomoo`2BOol00g`0Oomoo`18Ool003moo`03O01oogoo09=oo`03O01oogoo04Qoo`00?goo00=l07oo
Ool0TWoo00=l07ooOol0BGoo000oOol00g`0Oomoo`2BOol00g`0Oomoo`19Ool003moo`03O01oogoo
099oo`03O01oogoo04Uoo`00?Woo00=l07ooOol0Tgoo00=l07ooOol0BGoo000nOol00g`0Oomoo`2C
Ool00g`0Oomoo`19Ool003ioo`03O01oogoo099oo`03O01oogoo04Yoo`00?Woo00=l07ooOol0TWoo
00=l07ooOol0BWoo000mOol00g`0Oomoo`2COol00g`0Oomoo`1:Ool003eoo`03O01oogoo09=oo`03
O01oogoo04Yoo`00?Goo00=l07ooOol0TWoo00=l07ooOol0Bgoo000mOol00g`0Oomoo`2BOol00g`0
Oomoo`1;Ool003eoo`03O01oogoo099oo`03O01oogoo04]oo`00?Goo00=l07ooOol0TGoo00=l07oo
Ool0C7oo000lOol00g`0Oomoo`2BOol00g`0Oomoo`1<Ool003aoo`03O01oogoo099oo`03O01oogoo
04aoo`00?7oo00=l07ooOol0TWoo00=l07ooOol0C7oo000lOol00g`0Oomoo`2AOol00g`0Oomoo`1=
Ool003aoo`03O01oogoo095oo`03O01oogoo04eoo`00?7oo00=l07ooOol0TGoo00=l07ooOol0CGoo
000lOol00g`0Oomoo`2@Ool00g`0Oomoo`1>Ool003aoo`03O01oogoo091oo`03O01oogoo04ioo`00
?7oo00=l07ooOol0Sgoo00=l07ooOol0Cgoo000lOol00g`0Oomoo`2?Ool00g`0Oomoo`1?Ool003ao
o`03O01oogoo08ioo`03O01oogoo051oo`00?7oo00=l07ooOol0SWoo00=l07ooOol0D7oo000lOol0
0g`0Oomoo`2>Ool00g`0Oomoo`1@Ool003aoo`03O01oogoo08eoo`03O01oogoo055oo`00?7oo00=l
07ooOol0SGoo00=l07ooOol0DGoo000lOol00g`0Oomoo`2<Ool00g`0Oomoo`1BOol003aoo`03O01o
ogoo08aoo`03O01oogoo059oo`00?7oo00=l07ooOol0Rgoo00=l07ooOol0Dgoo000lOol00g`0Oomo
o`2;Ool00g`0Oomoo`1COol003aoo`03O01oogoo08Yoo`03O01oogoo05Aoo`00?7oo00=l07ooOol0
RWoo00=l07ooOol0E7oo000lOol00g`0Oomoo`29Ool00g`0Oomoo`1EOol003aoo`03O01oogoo08Uo
o`03O01oogoo05Eoo`00?7oo00=l07ooOol0R7oo00=l07ooOol0EWoo000lOol00g`0Oomoo`28Ool0
0g`0Oomoo`1FOol003eoo`03O01oogoo08Ioo`03O01oogoo05Moo`00?Goo00=l07ooOol0QWoo00=l
07ooOol0Egoo000mOol00g`0Oomoo`25Ool00g`0Oomoo`1HOol003eoo`03O01oogoo08Aoo`03O01o
ogoo05Uoo`00?Goo00=l07ooOol0Q7oo00=l07ooOol0FGoo000nOol00g`0Oomoo`22Ool00g`0Oomo
o`1JOol003ioo`03O01oogoo085oo`03O01oogoo05]oo`00?Woo00=l07ooOol0PGoo00=l07ooOol0
Fgoo000nOol00g`0Oomoo`20Ool00g`0Oomoo`1LOol003moo`03O01oogoo07moo`03O01oogoo05ao
o`00?goo00=l07ooOol0OWoo00=l07ooOol0GGoo000oOol00g`0Oomoo`1nOol00g`0Oomoo`1MOol0
041oo`03O01oogoo07aoo`03O01oogoo05ioo`00@7oo00=l07ooOol0Ngoo00=l07ooOol0Ggoo0010
Ool00g`0Oomoo`1jOol00g`0Oomoo`1POol0041oo`03O01oogoo07Uoo`03O01oogoo065oo`00@Goo
00=l07ooOol0Mgoo00=l07ooOol0HWoo0011Ool00g`0Oomoo`1fOol00g`0Oomoo`1SOol0045oo`03
O01oogoo07Eoo`03O01oogoo06Aoo`00@Woo00=l07ooOol0M7oo00=l07ooOol0I7oo0012Ool00g`0
Oomoo`1cOol00g`0Oomoo`1UOol004=oo`03O01oogoo075oo`03O01oogoo06Ioo`00@goo00=l07oo
Ool0LGoo00=l07ooOol0IWoo0014Ool00g`0Oomoo`1_Ool00g`0Oomoo`1WOol004Aoo`03O01oogoo
06ioo`03O01oogoo06Qoo`00AGoo00=l07ooOol0K7oo00=l07ooOol0JGoo0015Ool00g`0Oomoo`1[
Ool00g`0Oomoo`1ZOol004Ioo`03O01oogoo06Uoo`03O01oogoo06]oo`00AWoo00=l07ooOol0J7oo
00=l07ooOol0K7oo0017Ool00g`0Oomoo`1VOol00g`0Oomoo`1]Ool004Qoo`03O01oogoo06Aoo`03
O01oogoo06ioo`00BGoo00=l07ooOol0HGoo0W`0LGoo0019Ool00g`0Oomoo`1POol00g`0Oomoo`1a
Ool004Yoo`03O01oogoo05ioo`03O01oogoo079oo`00Bgoo00=l07ooOol0G7oo00=l07ooOol0Lgoo
001<Ool00g`0Oomoo`1IOol2O01fOol004eoo`03O01oogoo05Moo`03O01oogoo07Ioo`00CGoo00=l
07ooOol0EWoo00=l07ooOol0Mgoo001>Ool00g`0Oomoo`1COol2O01jOol004moo`03O01oogoo055o
o`03O01oogoo07Yoo`00D7oo00=l07ooOol0CWoo0W`0OGoo001AOol2O01=Ool00g`0Oomoo`1mOol0
05=oo`03O01oogoo04Qoo`9l081oo`00E7oo00=l07ooOol0AGoo0W`0PWoo001EOol2O013Ool2O024
Ool005Moo`9l03moo`9l08Ioo`00FGoo00=l07ooOol0>Woo0W`0R7oo001JOol2O00hOol2O02:Ool0
05aoo`9l03Aoo`9l08aoo`00GWoo0W`0<7oo0W`0SWoo001POol3O00ZOol3O02@Ool006=oo`=l02Ao
o`=l09=oo`00IWoo0W`07Woo17`0UWoo001XOol4O00DOol6O02JOol006aooaAl0:1oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig1B\  = \ 
        Show[Array[p, {15}], ViewPoint \[Rule] {0, 0, 2}];\)\)], "Input",
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.49375 .49375 m
.50625 .50625 L
s
.48127 .48127 m
.49375 .49375 L
s
.50625 .50625 m
.51873 .51873 L
s
.50625 .48446 m
.51871 .49701 L
s
.49374 .47199 m
.50625 .48446 L
s
.51871 .49701 m
.53109 .50959 L
s
.46885 .46885 m
.48127 .48127 L
s
.51873 .51873 m
.53115 .53115 L
s
.48122 .45964 m
.49374 .47199 L
s
.51874 .4753 m
.53109 .48799 L
s
.50627 .46275 m
.51874 .4753 L
s
.53109 .50959 m
.54334 .52218 L
s
.53109 .48799 m
.54329 .50078 L
s
.49372 .45036 m
.50627 .46275 L
s
.54329 .50078 m
.5553 .51363 L
s
.45652 .45652 m
.46885 .46885 L
s
.53115 .53115 m
.54348 .54348 L
s
.46872 .44743 m
.48122 .45964 L
s
.53116 .46645 m
.54333 .47938 L
s
.51881 .45371 m
.53116 .46645 L
s
.54333 .47938 m
.55528 .49245 L
s
.54334 .52218 m
.55543 .53474 L
s
.5063 .4412 m
.51881 .45371 L
s
.48112 .43818 m
.49372 .45036 L
s
.55528 .49245 m
.56697 .50564 L
s
.5553 .51363 m
.56708 .52649 L
s
.49368 .42895 m
.5063 .4412 L
s
.54347 .45806 m
.55538 .47132 L
s
.5313 .44505 m
.54347 .45806 L
s
.45628 .43541 m
.46872 .44743 L
s
.44431 .44431 m
.45652 .45652 L
s
.54348 .54348 m
.55569 .55569 L
s
.55538 .47132 m
.567 .48477 L
s
.51891 .43232 m
.5313 .44505 L
s
.46852 .42625 m
.48112 .43818 L
s
.55543 .53474 m
.56733 .54722 L
s
.56697 .50564 m
.57836 .51891 L
s
.567 .48477 m
.57829 .49838 L
s
.50634 .41991 m
.51891 .43232 L
s
.48098 .41701 m
.49368 .42895 L
s
.56708 .52649 m
.57859 .53934 L
s
.5556 .45031 m
.56718 .46396 L
s
.5437 .43694 m
.5556 .45031 L
s
.56718 .46396 m
.57839 .47786 L
s
.53151 .42391 m
.5437 .43694 L
s
.44394 .42363 m
.45628 .43541 L
s
.57829 .49838 m
.58921 .51212 L
s
.43228 .43228 m
.44431 .44431 L
s
.55569 .55569 m
.56772 .56772 L
s
.45595 .41462 m
.46852 .42625 L
s
.49363 .40787 m
.50634 .41991 L
s
.57836 .51891 m
.58941 .5322 L
s
.57839 .47786 m
.5892 .49197 L
s
.56733 .54722 m
.57898 .55959 L
s
.51906 .41125 m
.53151 .42391 L
s
.46825 .40542 m
.48098 .41701 L
s
.57859 .53934 m
.58979 .55213 L
s
.56749 .44333 m
.57864 .45745 L
s
.55594 .42954 m
.56749 .44333 L
s
.57864 .45745 m
.58936 .47186 L
s
.5892 .49197 m
.59956 .50623 L
s
.54402 .41612 m
.55594 .42954 L
s
.58921 .51212 m
.59973 .52593 L
s
.5064 .399 m
.51906 .41125 L
s
.4808 .39623 m
.49363 .40787 L
s
.58936 .47186 m
.5996 .48651 L
s
.53178 .40312 m
.54402 .41612 L
s
.43175 .41211 m
.44394 .42363 L
s
.58941 .5322 m
.60009 .54549 L
s
.42046 .42046 m
.43228 .43228 L
s
.56772 .56772 m
.57954 .57954 L
s
.44345 .40331 m
.45595 .41462 L
s
.57898 .55959 m
.59035 .5718 L
s
.59956 .50623 m
.60945 .52061 L
s
.45552 .39423 m
.46825 .40542 L
s
.5996 .48651 m
.60933 .50135 L
s
.57906 .43725 m
.5897 .45189 L
s
.56795 .42297 m
.57906 .43725 L
s
.49356 .38722 m
.5064 .399 L
s
.5897 .45189 m
.59984 .46685 L
s
.51925 .39059 m
.53178 .40312 L
s
.55639 .4091 m
.56795 .42297 L
s
.59973 .52593 m
.60979 .53977 L
s
.58979 .55213 m
.60064 .56482 L
s
.59984 .46685 m
.60942 .48208 L
s
.46791 .38505 m
.4808 .39623 L
s
.54444 .3957 m
.55639 .4091 L
s
.60933 .50135 m
.61852 .51633 L
s
.60009 .54549 m
.61033 .55872 L
s
.60942 .48208 m
.61843 .49752 L
s
.50647 .37858 m
.51925 .39059 L
s
.41974 .40092 m
.43175 .41211 L
s
.60945 .52061 m
.61882 .53506 L
s
.43107 .39238 m
.44345 .40331 L
s
.4089 .4089 m
.42046 .42046 L
s
.57954 .57954 m
.5911 .5911 L
s
.59023 .43216 m
.60027 .44736 L
s
.57964 .41735 m
.59023 .43216 L
s
.48058 .37596 m
.49356 .38722 L
s
.60027 .44736 m
.60973 .4629 L
s
.53213 .38281 m
.54444 .3957 L
s
.44284 .38348 m
.45552 .39423 L
s
.56854 .40299 m
.57964 .41735 L
s
.59035 .5718 m
.6014 .58381 L
s
.60973 .4629 m
.61857 .47872 L
s
.60979 .53977 m
.61935 .5536 L
s
.61843 .49752 m
.62682 .51313 L
s
.55697 .38912 m
.56854 .40299 L
s
.455 .37437 m
.46791 .38505 L
s
.61852 .51633 m
.6271 .53142 L
s
.60064 .56482 m
.61109 .57736 L
s
.61857 .47872 m
.62677 .49478 L
s
.51949 .37048 m
.53213 .38281 L
s
.49348 .36714 m
.50647 .37858 L
s
.61024 .44391 m
.61894 .46003 L
s
.6009 .42814 m
.61024 .44391 L
s
.59093 .41278 m
.6009 .42814 L
s
.61882 .53506 m
.62762 .54953 L
s
.54496 .3758 m
.55697 .38912 L
s
.61033 .55872 m
.62011 .57185 L
s
.61894 .46003 m
.62695 .47645 L
s
.46751 .36525 m
.48058 .37596 L
s
.58038 .39788 m
.59093 .41278 L
s
.62677 .49478 m
.63428 .51101 L
s
.62682 .51313 m
.63455 .52886 L
s
.40797 .39009 m
.41974 .40092 L
s
.41886 .38189 m
.43107 .39238 L
s
.39765 .39765 m
.4089 .4089 L
s
.5911 .5911 m
.60235 .60235 L
s
.62695 .47645 m
.63425 .49311 L
s
.43026 .37322 m
.44284 .38348 L
s
.56928 .3835 m
.58038 .39788 L
s
.61935 .5536 m
.62838 .56737 L
s
.6271 .53142 m
.63506 .54655 L
s
.50656 .35877 m
.51949 .37048 L
s
.6014 .58381 m
.61206 .59557 L
s
.53254 .36308 m
.54496 .3758 L
s
.48032 .35631 m
.49348 .36714 L
s
.61953 .44156 m
.62737 .45825 L
s
.61097 .42522 m
.61953 .44156 L
s
.44211 .36425 m
.455 .37437 L
s
.60173 .4093 m
.61097 .42522 L
s
.62737 .45825 m
.63446 .47523 L
s
.63425 .49311 m
.64079 .50994 L
s
.63428 .51101 m
.64106 .52737 L
s
.61109 .57736 m
.62109 .5897 L
s
.55767 .36971 m
.56928 .3835 L
s
.59182 .39386 m
.60173 .4093 L
s
.63446 .47523 m
.64077 .49245 L
s
.62762 .54953 m
.63581 .56397 L
s
.63455 .52886 m
.64157 .54465 L
s
.45438 .35517 m
.46751 .36525 L
s
.62011 .57185 m
.62936 .58482 L
s
.58129 .37895 m
.59182 .39386 L
s
.51976 .35103 m
.53254 .36308 L
s
.64077 .49245 m
.64628 .50984 L
s
.64079 .50994 m
.64655 .5269 L
s
.62802 .44028 m
.63492 .4575 L
s
.62035 .42341 m
.62802 .44028 L
s
.49339 .34774 m
.50656 .35877 L
s
.63492 .4575 m
.64101 .47501 L
s
.54557 .35655 m
.55767 .36971 L
s
.61191 .40694 m
.62035 .42341 L
s
.63506 .54655 m
.64233 .56167 L
s
.64101 .47501 m
.64626 .49273 L
s
.40687 .37187 m
.41886 .38189 L
s
.39649 .37968 m
.40797 .39009 L
s
.64106 .52737 m
.64707 .5438 L
s
.41782 .36351 m
.43026 .37322 L
s
.38675 .38675 m
.39765 .39765 L
s
.60235 .60235 m
.61325 .61325 L
s
.62838 .56737 m
.63681 .58102 L
s
.46703 .34617 m
.48032 .35631 L
s
.60275 .39096 m
.61191 .40694 L
s
.57017 .36464 m
.58129 .37895 L
s
.64626 .49273 m
.65065 .5106 L
s
.64628 .50984 m
.65094 .52734 L
s
.61206 .59557 m
.62229 .60703 L
s
.4293 .35474 m
.44211 .36425 L
s
.64148 .4577 m
.64649 .47565 L
s
.63562 .44001 m
.64148 .4577 L
s
.62891 .42265 m
.63562 .44001 L
s
.64157 .54465 m
.64785 .56044 L
s
.64649 .47565 m
.65062 .4938 L
s
.64655 .5269 m
.65148 .54391 L
s
.59289 .37551 m
.60275 .39096 L
s
.63581 .56397 m
.64333 .57832 L
s
.50666 .33971 m
.51976 .35103 L
s
.62139 .40568 m
.62891 .42265 L
s
.53302 .34409 m
.54557 .35655 L
s
.62109 .5897 m
.63058 .60178 L
s
.65062 .4938 m
.65385 .51206 L
s
.65065 .5106 m
.65416 .52855 L
s
.44126 .34577 m
.45438 .35517 L
s
.48001 .33744 m
.49339 .34774 L
s
.55848 .35099 m
.57017 .36464 L
s
.65084 .47703 m
.65379 .4955 L
s
.64698 .45872 m
.65084 .47703 L
s
.64221 .44064 m
.64698 .45872 L
s
.65094 .52734 m
.65473 .54487 L
s
.64707 .5438 m
.65228 .56022 L
s
.61307 .38919 m
.62139 .40568 L
s
.65379 .4955 m
.6558 .51405 L
s
.63655 .42287 m
.64221 .44064 L
s
.65385 .51206 m
.65615 .53038 L
s
.62936 .58482 m
.63804 .59758 L
s
.64233 .56167 m
.64887 .57671 L
s
.58236 .36068 m
.59289 .37551 L
s
.65399 .47896 m
.65571 .49764 L
s
.65132 .4604 m
.65399 .47896 L
s
.65571 .49764 m
.65648 .51636 L
s
.64771 .44204 m
.65132 .4604 L
s
.6558 .51405 m
.65687 .53262 L
s
.65416 .52855 m
.65676 .54652 L
s
.63003 .40546 m
.63655 .42287 L
s
.45367 .33677 m
.46703 .34617 L
s
.65648 .51636 m
.6563 .53505 L
s
.65148 .54391 m
.65556 .56092 L
s
.60398 .37323 m
.61307 .38919 L
s
.39514 .3624 m
.40687 .37187 L
s
.64318 .42394 m
.64771 .44204 L
s
.38536 .36974 m
.39649 .37968 L
s
.63681 .58102 m
.64459 .59449 L
s
.65615 .53038 m
.65751 .54867 L
s
.40557 .3544 m
.41782 .36351 L
s
.52008 .3324 m
.53302 .34409 L
s
.64785 .56044 m
.65333 .57617 L
s
.54627 .33808 m
.55848 .35099 L
s
.37628 .37628 m
.38675 .38675 L
s
.61325 .61325 m
.62372 .62372 L
s
.6563 .53505 m
.65515 .55363 L
s
.65687 .53262 m
.65698 .55112 L
s
.49328 .32917 m
.50666 .33971 L
s
.62265 .38851 m
.63003 .40546 L
s
.65473 .54487 m
.65762 .56238 L
s
.4166 .34591 m
.4293 .35474 L
s
.57119 .34653 m
.58236 .36068 L
s
.63773 .40618 m
.64318 .42394 L
s
.62229 .60703 m
.63204 .61812 L
s
.64333 .57832 m
.65014 .59252 L
s
.65676 .54652 m
.65841 .56443 L
s
.65228 .56022 m
.65664 .57658 L
s
.46649 .32795 m
.48001 .33744 L
s
.59415 .35788 m
.60398 .37323 L
s
.65515 .55363 m
.65303 .57204 L
s
.65751 .54867 m
.65791 .56688 L
s
.42819 .3371 m
.44126 .34577 L
s
.65698 .55112 m
.65611 .56949 L
s
.63058 .60178 m
.63952 .61355 L
s
.61443 .37208 m
.62265 .38851 L
s
.63138 .38884 m
.63773 .40618 L
s
.65556 .56092 m
.65873 .57784 L
s
.64887 .57671 m
.65463 .59163 L
s
.53358 .32597 m
.54627 .33808 L
s
.50677 .32155 m
.52008 .3324 L
s
.63804 .59758 m
.64608 .61008 L
s
.65303 .57204 m
.64994 .59018 L
s
.55942 .33313 m
.57119 .34653 L
s
.65762 .56238 m
.65957 .57978 L
s
.44029 .32817 m
.45367 .33677 L
s
.5836 .34322 m
.59415 .35788 L
s
.65611 .56949 m
.65426 .58764 L
s
.47966 .31949 m
.49328 .32917 L
s
.65841 .56443 m
.6591 .58221 L
s
.65333 .57617 m
.65797 .59176 L
s
.65791 .56688 m
.65733 .5849 L
s
.60541 .35624 m
.61443 .37208 L
s
.62414 .372 m
.63138 .38884 L
s
.64459 .59449 m
.65166 .60773 L
s
.38375 .35353 m
.39514 .3624 L
s
.37463 .36035 m
.38536 .36974 L
s
.39359 .34596 m
.40557 .3544 L
s
.65664 .57658 m
.6601 .59281 L
s
.64994 .59018 m
.64586 .60798 L
s
.36628 .36628 m
.37628 .37628 L
s
.62372 .62372 m
.63372 .63372 L
s
.4041 .33781 m
.4166 .34591 L
s
.45286 .31932 m
.46649 .32795 L
s
.65014 .59252 m
.65618 .6065 L
s
.65873 .57784 m
.66097 .59462 L
s
.54707 .32055 m
.55942 .33313 L
s
.63204 .61812 m
.64123 .62879 L
s
.52044 .31474 m
.53358 .32597 L
s
.65426 .58764 m
.65142 .60549 L
s
.57237 .32932 m
.5836 .34322 L
s
.41523 .32924 m
.42819 .3371 L
s
.59559 .34109 m
.60541 .35624 L
s
.61601 .35574 m
.62414 .372 L
s
.65957 .57978 m
.66054 .59701 L
s
.49315 .3116 m
.50677 .32155 L
s
.65733 .5849 m
.65575 .60267 L
s
.6591 .58221 m
.6588 .59977 L
s
.65463 .59163 m
.65955 .60634 L
s
.63952 .61355 m
.64782 .62494 L
s
.64586 .60798 m
.64081 .62536 L
s
.46587 .31074 m
.47966 .31949 L
s
.42694 .32044 m
.44029 .32817 L
s
.65797 .59176 m
.66172 .60716 L
s
.64608 .61008 m
.65343 .62223 L
s
.65142 .60549 m
.64757 .62296 L
s
.6601 .59281 m
.66263 .60882 L
s
.60703 .34015 m
.61601 .35574 L
s
.56048 .31626 m
.57237 .32932 L
s
.585 .32671 m
.59559 .34109 L
s
.5342 .30889 m
.54707 .32055 L
s
.65166 .60773 m
.65797 .62066 L
s
.5069 .30445 m
.52044 .31474 L
s
.65575 .60267 m
.65315 .6201 L
s
.66097 .59462 m
.66224 .61116 L
s
.4392 .31163 m
.45286 .31932 L
s
.37275 .34533 m
.38375 .35353 L
s
.38193 .33826 m
.39359 .34596 L
s
.6588 .59977 m
.65748 .61703 L
s
.66054 .59701 m
.66052 .61397 L
s
.36437 .35156 m
.37463 .36035 L
s
.39184 .33051 m
.4041 .33781 L
s
.47927 .30264 m
.49315 .3116 L
s
.64081 .62536 m
.63478 .64221 L
s
.65618 .6065 m
.66138 .6202 L
s
.35683 .35683 m
.36628 .36628 L
s
.63372 .63372 m
.64317 .64317 L
s
.40244 .32224 m
.41523 .32924 L
s
.64123 .62879 m
.6498 .63897 L
s
.65955 .60634 m
.66359 .62077 L
s
.64757 .62296 m
.64271 .63995 L
s
.45196 .30299 m
.46587 .31074 L
s
.59721 .32531 m
.60703 .34015 L
s
.57368 .31317 m
.585 .32671 L
s
.54797 .30413 m
.56048 .31626 L
s
.64782 .62494 m
.65544 .63589 L
s
.41369 .31366 m
.42694 .32044 L
s
.66172 .60716 m
.66453 .62227 L
s
.52084 .29821 m
.5342 .30889 L
s
.65315 .6201 m
.64951 .6371 L
s
.49302 .2952 m
.5069 .30445 L
s
.66263 .60882 m
.66417 .62454 L
s
.63478 .64221 m
.62777 .65846 L
s
.65343 .62223 m
.66001 .63397 L
s
.65748 .61703 m
.65512 .6339 L
s
.66224 .61116 m
.66248 .62738 L
s
.66052 .61397 m
.65946 .63058 L
s
.42555 .30494 m
.4392 .31163 L
s
.46519 .29473 m
.47927 .30264 L
s
.65797 .62066 m
.66346 .6332 L
s
.64271 .63995 m
.63682 .65637 L
s
.58656 .31131 m
.59721 .32531 L
s
.37067 .33136 m
.38193 .33826 L
s
.36223 .33786 m
.37275 .34533 L
s
.56166 .30057 m
.57368 .31317 L
s
.37991 .32408 m
.39184 .33051 L
s
.35465 .34344 m
.36437 .35156 L
s
.66138 .6202 m
.6657 .63353 L
s
.53489 .29302 m
.54797 .30413 L
s
.34799 .34799 m
.35683 .35683 L
s
.64317 .64317 m
.65201 .65201 L
s
.3899 .3162 m
.40244 .32224 L
s
.43798 .29631 m
.45196 .30299 L
s
.64951 .6371 m
.64483 .65357 L
s
.50704 .2886 m
.52084 .29821 L
s
.66359 .62077 m
.66668 .63484 L
s
.62777 .65846 m
.6198 .67401 L
s
.6498 .63897 m
.65768 .64858 L
s
.65512 .6339 m
.65169 .65029 L
s
.47884 .28705 m
.49302 .2952 L
s
.66453 .62227 m
.66635 .63702 L
s
.40061 .30789 m
.41369 .31366 L
s
.66417 .62454 m
.66468 .63987 L
s
.65946 .63058 m
.65733 .64674 L
s
.66248 .62738 m
.66167 .64319 L
s
.65544 .63589 m
.66229 .64632 L
s
.57514 .29826 m
.58656 .31131 L
s
.63682 .65637 m
.62992 .67212 L
s
.45096 .28796 m
.46519 .29473 L
s
.66001 .63397 m
.66576 .64523 L
s
.54897 .28901 m
.56166 .30057 L
s
.41199 .29935 m
.42555 .30494 L
s
.52129 .28301 m
.53489 .29302 L
s
.66346 .6332 m
.66804 .64528 L
s
.64483 .65357 m
.63908 .66942 L
s
.6198 .67401 m
.61086 .68875 L
s
.49287 .28015 m
.50704 .2886 L
s
.35987 .32534 m
.37067 .33136 L
s
.35225 .33121 m
.36223 .33786 L
s
.6657 .63353 m
.66905 .6464 L
s
.42402 .29078 m
.43798 .29631 L
s
.36837 .31861 m
.37991 .32408 L
s
.65169 .65029 m
.64718 .66609 L
s
.34555 .33608 m
.35465 .34344 L
s
.46443 .28011 m
.47884 .28705 L
s
.37768 .31117 m
.3899 .3162 L
s
.66668 .63484 m
.66876 .64847 L
s
.33985 .33985 m
.34799 .34799 L
s
.65201 .65201 m
.66015 .66015 L
s
.65733 .64674 m
.6541 .66236 L
s
.56295 .28624 m
.57514 .29826 L
s
.66635 .63702 m
.66711 .6513 L
s
.62992 .67212 m
.62199 .6871 L
s
.66167 .64319 m
.65976 .65849 L
s
.66468 .63987 m
.66411 .65472 L
s
.38777 .30321 m
.40061 .30789 L
s
.53565 .27857 m
.54897 .28901 L
s
.65768 .64858 m
.66479 .65754 L
s
.43666 .28241 m
.45096 .28796 L
s
.5072 .2742 m
.52129 .28301 L
s
.66229 .64632 m
.6683 .65613 L
s
.61086 .68875 m
.60097 .70258 L
s
.3986 .29492 m
.41199 .29935 L
s
.63908 .66942 m
.63227 .68452 L
s
.47837 .27295 m
.49287 .28015 L
s
.66576 .64523 m
.67061 .65591 L
s
.64718 .66609 m
.64156 .68119 L
s
.66804 .64528 m
.67165 .65681 L
s
.41014 .28649 m
.42402 .29078 L
s
.44987 .27444 m
.46443 .28011 L
s
.55005 .27537 m
.56295 .28624 L
s
.62199 .6871 m
.61306 .7012 L
s
.66905 .6464 m
.67139 .65874 L
s
.6541 .66236 m
.64975 .67733 L
s
.34963 .32029 m
.35987 .32534 L
s
.35731 .31417 m
.36837 .31861 L
s
.52177 .26936 m
.53565 .27857 L
s
.3429 .32545 m
.35225 .33121 L
s
.66876 .64847 m
.66977 .66154 L
s
.36587 .30725 m
.37768 .31117 L
s
.65976 .65849 m
.65672 .67317 L
s
.33717 .32955 m
.34555 .33608 L
s
.66711 .6513 m
.66677 .66503 L
s
.66411 .65472 m
.66242 .66899 L
s
.4927 .26668 m
.5072 .2742 L
s
.60097 .70258 m
.59017 .71538 L
s
.33249 .33249 m
.33985 .33985 L
s
.66015 .66015 m
.66751 .66751 L
s
.37526 .29971 m
.38777 .30321 L
s
.42235 .27816 m
.43666 .28241 L
s
.63227 .68452 m
.62439 .69878 L
s
.66479 .65754 m
.67105 .66577 L
s
.46361 .26708 m
.47837 .27295 L
s
.38546 .29173 m
.3986 .29492 L
s
.6683 .65613 m
.67339 .66526 L
s
.64156 .68119 m
.63483 .69549 L
s
.53648 .26574 m
.55005 .27537 L
s
.61306 .7012 m
.60312 .7143 L
s
.43521 .27014 m
.44987 .27444 L
s
.67061 .65591 m
.67446 .66593 L
s
.39643 .28352 m
.41014 .28649 L
s
.50737 .26147 m
.52177 .26936 L
s
.64975 .67733 m
.64424 .69152 L
s
.67165 .65681 m
.67422 .66769 L
s
.47785 .26055 m
.4927 .26668 L
s
.59017 .71538 m
.57846 .72706 L
s
.65672 .67317 m
.65252 .68713 L
s
.67139 .65874 m
.67263 .67043 L
s
.34682 .31084 m
.35731 .31417 L
s
.34004 .31627 m
.34963 .32029 L
s
.66977 .66154 m
.66965 .67396 L
s
.66242 .66899 m
.65956 .68256 L
s
.62439 .69878 m
.61543 .71208 L
s
.66677 .66503 m
.66528 .67809 L
s
.35454 .30451 m
.36587 .30725 L
s
.33427 .32068 m
.3429 .32545 L
s
.40814 .27531 m
.42235 .27816 L
s
.32957 .32395 m
.33717 .32955 L
s
.44868 .26265 m
.46361 .26708 L
s
.36317 .29746 m
.37526 .29971 L
s
.326 .326 m
.33249 .33249 L
s
.66751 .66751 m
.674 .674 L
s
.52229 .25746 m
.53648 .26574 L
s
.63483 .69549 m
.62697 .70886 L
s
.37266 .28988 m
.38546 .29173 L
s
.60312 .7143 m
.59219 .72629 L
s
.67105 .66577 m
.67637 .67318 L
s
.49252 .25501 m
.50737 .26147 L
s
.42056 .2673 m
.43521 .27014 L
s
.67339 .66526 m
.67747 .67359 L
s
.64424 .69152 m
.63757 .70483 L
s
.38298 .28196 m
.39643 .28352 L
s
.57846 .72706 m
.56588 .73748 L
s
.46273 .25589 m
.47785 .26055 L
s
.67446 .66593 m
.67726 .67518 L
s
.65252 .68713 m
.64712 .70024 L
s
.61543 .71208 m
.60542 .72429 L
s
.67422 .66769 m
.67568 .67782 L
s
.65956 .68256 m
.65548 .69532 L
s
.67263 .67043 m
.67271 .68137 L
s
.3941 .27392 m
.40814 .27531 L
s
.43366 .25973 m
.44868 .26265 L
s
.66528 .67809 m
.66258 .69036 L
s
.66965 .67396 m
.66833 .68563 L
s
.33699 .3087 m
.34682 .31084 L
s
.50756 .25064 m
.52229 .25746 L
s
.33119 .31339 m
.34004 .31627 L
s
.34381 .30304 m
.35454 .30451 L
s
.32646 .31697 m
.33427 .32068 L
s
.59219 .72629 m
.58031 .73704 L
s
.62697 .70886 m
.61798 .72117 L
s
.35159 .29655 m
.36317 .29746 L
s
.32287 .31935 m
.32957 .32395 L
s
.4773 .25008 m
.49252 .25501 L
s
.36029 .28943 m
.37266 .28988 L
s
.40599 .266 m
.42056 .2673 L
s
.32047 .32047 m
.326 .326 L
s
.674 .674 m
.67953 .67953 L
s
.56588 .73748 m
.55249 .74654 L
s
.63757 .70483 m
.62972 .71713 L
s
.44742 .25282 m
.46273 .25589 L
s
.67637 .67318 m
.68066 .67967 L
s
.36988 .28187 m
.38298 .28196 L
s
.60542 .72429 m
.59436 .73528 L
s
.67747 .67359 m
.68047 .68104 L
s
.64712 .70024 m
.64049 .71237 L
s
.67726 .67518 m
.6789 .68355 L
s
.41864 .25842 m
.43366 .25973 L
s
.49233 .24538 m
.50756 .25064 L
s
.65548 .69532 m
.65016 .70715 L
s
.38033 .2741 m
.3941 .27392 L
s
.67568 .67782 m
.67594 .68708 L
s
.58031 .73704 m
.56751 .74643 L
s
.66258 .69036 m
.65862 .70173 L
s
.67271 .68137 m
.67156 .69144 L
s
.66833 .68563 m
.66578 .69641 L
s
.61798 .72117 m
.60787 .7323 L
s
.46179 .24677 m
.4773 .25008 L
s
.32794 .30785 m
.33699 .3087 L
s
.33377 .30291 m
.34381 .30304 L
s
.32319 .31172 m
.33119 .31339 L
s
.34063 .29706 m
.35159 .29655 L
s
.55249 .74654 m
.53832 .75411 L
s
.39162 .26633 m
.40599 .266 L
s
.31957 .31442 m
.32646 .31697 L
s
.34847 .29048 m
.36029 .28943 L
s
.43201 .25141 m
.44742 .25282 L
s
.62972 .71713 m
.62068 .72827 L
s
.31716 .31586 m
.32287 .31935 L
s
.59436 .73528 m
.58228 .74493 L
s
.316 .316 m
.32047 .32047 L
s
.67953 .67953 m
.684 .684 L
s
.35726 .28335 m
.36988 .28187 L
s
.64049 .71237 m
.63263 .72339 L
s
.47671 .2418 m
.49233 .24538 L
s
.68066 .67967 m
.68382 .68513 L
s
.40371 .25881 m
.41864 .25842 L
s
.56751 .74643 m
.55383 .75433 L
s
.68047 .68104 m
.68228 .68749 L
s
.36695 .27591 m
.38033 .2741 L
s
.65016 .70715 m
.64357 .7179 L
s
.44607 .24519 m
.46179 .24677 L
s
.60787 .7323 m
.59666 .74212 L
s
.6789 .68355 m
.67932 .69095 L
s
.65862 .70173 m
.65337 .71206 L
s
.67594 .68708 m
.67494 .69536 L
s
.53832 .75411 m
.52345 .76006 L
s
.66578 .69641 m
.66191 .70618 L
s
.67156 .69144 m
.66912 .70052 L
s
.37754 .26836 m
.39162 .26633 L
s
.41661 .25176 m
.43201 .25141 L
s
.32455 .30422 m
.33377 .30291 L
s
.31977 .30836 m
.32794 .30785 L
s
.33041 .29907 m
.34063 .29706 L
s
.62068 .72827 m
.61046 .73814 L
s
.31614 .31136 m
.32319 .31172 L
s
.58228 .74493 m
.56923 .7531 L
s
.33731 .2931 m
.34847 .29048 L
s
.31371 .31312 m
.31957 .31442 L
s
.46079 .23999 m
.47671 .2418 L
s
.34521 .28647 m
.35726 .28335 L
s
.31254 .31357 m
.31716 .31586 L
s
.38901 .26097 m
.40371 .25881 L
s
.63263 .72339 m
.62352 .73317 L
s
.55383 .75433 m
.53933 .76062 L
s
.3127 .3127 m
.316 .316 L
s
.684 .684 m
.6873 .6873 L
s
.43026 .24543 m
.44607 .24519 L
s
.35408 .27943 m
.36695 .27591 L
s
.59666 .74212 m
.58436 .75048 L
s
.68382 .68513 m
.68577 .68946 L
s
.64357 .7179 m
.63567 .72744 L
s
.52345 .76006 m
.50796 .76429 L
s
.68228 .68749 m
.68282 .69282 L
s
.65337 .71206 m
.64678 .72123 L
s
.40132 .25396 m
.41661 .25176 L
s
.67932 .69095 m
.67843 .69725 L
s
.36389 .27218 m
.37754 .26836 L
s
.66191 .70618 m
.6567 .71481 L
s
.67494 .69536 m
.67259 .70254 L
s
.66912 .70052 m
.66533 .70849 L
s
.56923 .7531 m
.55524 .75967 L
s
.61046 .73814 m
.59906 .74658 L
s
.31625 .30704 m
.32455 .30422 L
s
.32104 .30266 m
.33041 .29907 L
s
.44466 .24004 m
.46079 .23999 L
s
.3126 .31032 m
.31977 .30836 L
s
.32693 .29735 m
.33731 .2931 L
s
.31016 .31239 m
.31614 .31136 L
s
.37463 .26498 m
.38901 .26097 L
s
.53933 .76062 m
.52408 .76517 L
s
.33387 .2913 m
.34521 .28647 L
s
.62352 .73317 m
.61316 .74156 L
s
.30898 .31316 m
.31371 .31312 L
s
.41448 .24757 m
.43026 .24543 L
s
.58436 .75048 m
.57103 .75726 L
s
.30913 .31258 m
.31254 .31357 L
s
.50796 .76429 m
.49192 .76669 L
s
.34183 .28472 m
.35408 .27943 L
s
.63567 .72744 m
.62647 .73564 L
s
.31065 .31065 m
.3127 .3127 L
s
.6873 .6873 m
.68935 .68935 L
s
.38629 .25806 m
.40132 .25396 L
s
.68577 .68946 m
.6864 .69256 L
s
.35079 .27784 m
.36389 .27218 L
s
.55524 .75967 m
.54038 .7645 L
s
.64678 .72123 m
.63883 .72908 L
s
.68282 .69282 m
.682 .69694 L
s
.59906 .74658 m
.58653 .75346 L
s
.42844 .24205 m
.44466 .24004 L
s
.6567 .71481 m
.65009 .72217 L
s
.67843 .69725 m
.67614 .70232 L
s
.66533 .70849 m
.66013 .7152 L
s
.67259 .70254 m
.66884 .70849 L
s
.52408 .76517 m
.50817 .76786 L
s
.36072 .2709 m
.37463 .26498 L
s
.31265 .30788 m
.32104 .30266 L
s
.309 .31143 m
.31625 .30704 L
s
.31745 .30331 m
.32693 .29735 L
s
.39884 .25169 m
.41448 .24757 L
s
.30656 .31381 m
.3126 .31032 L
s
.61316 .74156 m
.60156 .74842 L
s
.32336 .29789 m
.33387 .2913 L
s
.49192 .76669 m
.47544 .76713 L
s
.57103 .75726 m
.55671 .76231 L
s
.30537 .3149 m
.31016 .31239 L
s
.33035 .29185 m
.34183 .28472 L
s
.30551 .31463 m
.30898 .31316 L
s
.37162 .26414 m
.38629 .25806 L
s
.62647 .73564 m
.61595 .74234 L
s
.30703 .31298 m
.30913 .31258 L
s
.54038 .7645 m
.52474 .76747 L
s
.33837 .28539 m
.35079 .27784 L
s
.41227 .2461 m
.42844 .24205 L
s
.30997 .30997 m
.31065 .31065 L
s
.68935 .68935 m
.69003 .69003 L
s
.58653 .75346 m
.5729 .75863 L
s
.63883 .72908 m
.6295 .73548 L
s
.50817 .76786 m
.4917 .76859 L
s
.6864 .69256 m
.68563 .6943 L
s
.65009 .72217 m
.64206 .72811 L
s
.34742 .27877 m
.36072 .2709 L
s
.38348 .25784 m
.39884 .25169 L
s
.682 .69694 m
.67975 .69971 L
s
.66013 .7152 m
.65348 .72054 L
s
.67614 .70232 m
.6724 .70605 L
s
.47544 .76713 m
.45865 .76554 L
s
.66884 .70849 m
.66362 .71309 L
s
.30537 .3148 m
.31265 .30788 L
s
.30902 .31102 m
.31745 .30331 L
s
.55671 .76231 m
.54148 .7655 L
s
.60156 .74842 m
.58877 .75361 L
s
.30293 .31747 m
.309 .31143 L
s
.31383 .3063 m
.32336 .29789 L
s
.30175 .31889 m
.30656 .31381 L
s
.35748 .27225 m
.37162 .26414 L
s
.31976 .30084 m
.33035 .29185 L
s
.30189 .31896 m
.30537 .3149 L
s
.52474 .76747 m
.5084 .76847 L
s
.39628 .25223 m
.41227 .2461 L
s
.61595 .74234 m
.60413 .74741 L
s
.32678 .29487 m
.33837 .28539 L
s
.30341 .31761 m
.30551 .31463 L
s
.5729 .75863 m
.55823 .76198 L
s
.4917 .76859 m
.47477 .76725 L
s
.30635 .31486 m
.30703 .31298 L
s
.36855 .26607 m
.38348 .25784 L
s
.6295 .73548 m
.6188 .74028 L
s
.33487 .28864 m
.34742 .27877 L
s
.45865 .76554 m
.44166 .76183 L
s
.31075 .31075 m
.30997 .30997 L
s
.69003 .69003 m
.68925 .68925 L
s
.64206 .72811 m
.63259 .7325 L
s
.54148 .7655 m
.52541 .76672 L
s
.68563 .6943 m
.68335 .6946 L
s
.58877 .75361 m
.57482 .75699 L
s
.67975 .69971 m
.67597 .70103 L
s
.65348 .72054 m
.64533 .72436 L
s
.30176 .32052 m
.30902 .31102 L
s
.34401 .28239 m
.35748 .27225 L
s
.30541 .31654 m
.31383 .3063 L
s
.29933 .32346 m
.30537 .3148 L
s
.6724 .70605 m
.66713 .70831 L
s
.66362 .71309 m
.65689 .71619 L
s
.29817 .32521 m
.30293 .31747 L
s
.31021 .31173 m
.31976 .30084 L
s
.38062 .2605 m
.39628 .25223 L
s
.5084 .76847 m
.49147 .76738 L
s
.29831 .32562 m
.30175 .31889 L
s
.31616 .3063 m
.32678 .29487 L
s
.47477 .76725 m
.45753 .76376 L
s
.60413 .74741 m
.59105 .75072 L
s
.29983 .32463 m
.30189 .31896 L
s
.55823 .76198 m
.54259 .76336 L
s
.35421 .2764 m
.36855 .26607 L
s
.44166 .76183 m
.42463 .75593 L
s
.32321 .3005 m
.33487 .28864 L
s
.30277 .32218 m
.30341 .31761 L
s
.6188 .74028 m
.60674 .74336 L
s
.52541 .76672 m
.50863 .76586 L
s
.30719 .31831 m
.30635 .31486 L
s
.33136 .29459 m
.34401 .28239 L
s
.57482 .75699 m
.55977 .75844 L
s
.63259 .7325 m
.62168 .7352 L
s
.31309 .31309 m
.31075 .31075 L
s
.68925 .68925 m
.68691 .68691 L
s
.36545 .27092 m
.38062 .2605 L
s
.49147 .76738 m
.47409 .76413 L
s
.29823 .32863 m
.30541 .31654 L
s
.29582 .33182 m
.30176 .32052 L
s
.68335 .6946 m
.6795 .69334 L
s
.30186 .3245 m
.31021 .31173 L
s
.64533 .72436 m
.63569 .72653 L
s
.29467 .33388 m
.29933 .32346 L
s
.67597 .70103 m
.67061 .70079 L
s
.45753 .76376 m
.44011 .75806 L
s
.65689 .71619 m
.64861 .71768 L
s
.66713 .70831 m
.66028 .709 L
s
.30666 .31966 m
.31616 .3063 L
s
.29483 .33467 m
.29817 .32521 L
s
.34061 .28883 m
.35421 .2764 L
s
.42463 .75593 m
.40771 .74781 L
s
.54259 .76336 m
.5261 .76267 L
s
.59105 .75072 m
.57676 .75212 L
s
.29636 .33405 m
.29831 .32562 L
s
.31261 .31435 m
.32321 .3005 L
s
.29931 .33197 m
.29983 .32463 L
s
.50863 .76586 m
.49124 .76282 L
s
.3197 .30881 m
.33136 .29459 L
s
.60674 .74336 m
.59335 .74458 L
s
.35094 .28349 m
.36545 .27092 L
s
.30372 .3284 m
.30277 .32218 L
s
.47409 .76413 m
.4564 .75863 L
s
.55977 .75844 m
.54373 .75784 L
s
.30964 .3234 m
.30719 .31831 L
s
.44011 .75806 m
.42268 .75009 L
s
.62168 .7352 m
.60934 .73608 L
s
.29244 .34255 m
.29823 .32863 L
s
.29483 .33915 m
.30186 .3245 L
s
.32791 .30333 m
.34061 .28883 L
s
.29132 .34492 m
.29582 .33182 L
s
.40771 .74781 m
.39106 .73745 L
s
.29843 .33493 m
.30666 .31966 L
s
.31707 .31707 m
.31309 .31309 L
s
.68691 .68691 m
.68293 .68293 L
s
.29151 .34608 m
.29467 .33388 L
s
.63569 .72653 m
.62454 .72693 L
s
.5261 .76267 m
.50886 .75981 L
s
.6795 .69334 m
.674 .69044 L
s
.30322 .33014 m
.31261 .31435 L
s
.64861 .71768 m
.63876 .71745 L
s
.57676 .75212 m
.56133 .7515 L
s
.29305 .34587 m
.29483 .33467 L
s
.67061 .70079 m
.66361 .69888 L
s
.66028 .709 m
.65183 .70799 L
s
.49124 .76282 m
.4734 .75754 L
s
.33726 .29817 m
.35094 .28349 L
s
.30918 .32502 m
.3197 .30881 L
s
.29601 .3442 m
.29636 .33405 L
s
.4564 .75863 m
.43856 .75086 L
s
.59335 .74458 m
.5787 .74382 L
s
.42268 .75009 m
.40541 .73985 L
s
.30043 .34101 m
.29931 .33197 L
s
.54373 .75784 m
.52679 .75509 L
s
.3163 .31985 m
.32791 .30333 L
s
.39106 .73745 m
.37488 .72486 L
s
.30635 .33632 m
.30372 .3284 L
s
.28926 .35561 m
.29483 .33915 L
s
.29161 .35204 m
.29843 .33493 L
s
.28818 .35826 m
.29244 .34255 L
s
.60934 .73608 m
.59563 .73504 L
s
.28839 .35979 m
.29132 .34492 L
s
.50886 .75981 m
.49101 .7547 L
s
.29518 .34779 m
.30322 .33014 L
s
.31379 .33018 m
.30964 .3234 L
s
.32457 .3149 m
.33726 .29817 L
s
.28996 .36001 m
.29151 .34608 L
s
.4734 .75754 m
.45527 .74996 L
s
.29995 .34312 m
.30918 .32502 L
s
.56133 .7515 m
.54486 .74877 L
s
.62454 .72693 m
.61192 .72545 L
s
.32274 .32274 m
.31707 .31707 L
s
.68293 .68293 m
.67726 .67726 L
s
.43856 .75086 m
.42075 .74078 L
s
.29293 .3588 m
.29305 .34587 L
s
.674 .69044 m
.66681 .68581 L
s
.63876 .71745 m
.62735 .71538 L
s
.40541 .73985 m
.38848 .72735 L
s
.66361 .69888 m
.65494 .69522 L
s
.65183 .70799 m
.64174 .70519 L
s
.37488 .72486 m
.35934 .71008 L
s
.30591 .33829 m
.3163 .31985 L
s
.29736 .35606 m
.29601 .3442 L
s
.52679 .75509 m
.50909 .75012 L
s
.5787 .74382 m
.56287 .74098 L
s
.28634 .3709 m
.29161 .35204 L
s
.2853 .3738 m
.28926 .35561 L
s
.28864 .36721 m
.29518 .34779 L
s
.30328 .35177 m
.30043 .34101 L
s
.31306 .33358 m
.32457 .3149 L
s
.28556 .37569 m
.28818 .35826 L
s
.49101 .7547 m
.47272 .74731 L
s
.29217 .363 m
.29995 .34312 L
s
.45527 .74996 m
.43702 .74007 L
s
.28715 .37636 m
.28839 .35979 L
s
.59563 .73504 m
.58061 .73196 L
s
.31072 .34595 m
.30635 .33632 L
s
.42075 .74078 m
.40315 .72842 L
s
.38848 .72735 m
.37209 .71264 L
s
.35934 .71008 m
.34463 .69319 L
s
.54486 .74877 m
.52747 .74383 L
s
.29692 .35852 m
.30591 .33829 L
s
.29015 .37565 m
.28996 .36001 L
s
.31969 .3387 m
.31379 .33018 L
s
.61192 .72545 m
.59786 .72199 L
s
.33017 .33017 m
.32274 .32274 L
s
.67726 .67726 m
.66983 .66983 L
s
.29458 .37342 m
.29293 .3588 L
s
.30288 .35407 m
.31306 .33358 L
s
.50909 .75012 m
.49078 .74286 L
s
.62735 .71538 m
.61441 .71139 L
s
.66681 .68581 m
.65789 .6794 L
s
.28274 .39137 m
.28634 .3709 L
s
.28373 .38826 m
.28864 .36721 L
s
.64174 .70519 m
.63004 .70052 L
s
.65494 .69522 m
.64459 .68974 L
s
.56287 .74098 m
.54597 .73599 L
s
.28305 .39361 m
.2853 .3738 L
s
.28598 .38451 m
.29217 .363 L
s
.47272 .74731 m
.45416 .7376 L
s
.3005 .36962 m
.29736 .35606 L
s
.43702 .74007 m
.41885 .72789 L
s
.37209 .71264 m
.35644 .6958 L
s
.40315 .72842 m
.38598 .71384 L
s
.34463 .69319 m
.33095 .67431 L
s
.28469 .39473 m
.28556 .37569 L
s
.28947 .3804 m
.29692 .35852 L
s
.30794 .36423 m
.30328 .35177 L
s
.2877 .39454 m
.28715 .37636 L
s
.58061 .73196 m
.56437 .72679 L
s
.52747 .74383 m
.50931 .73666 L
s
.29419 .37621 m
.30288 .35407 L
s
.31691 .3573 m
.31072 .34595 L
s
.29215 .39289 m
.29015 .37565 L
s
.28057 .41075 m
.28373 .38826 L
s
.2815 .40746 m
.28598 .38451 L
s
.49078 .74286 m
.47205 .73332 L
s
.28093 .4133 m
.28274 .39137 L
s
.33095 .67431 m
.31846 .6536 L
s
.35644 .6958 m
.34171 .67695 L
s
.59786 .72199 m
.58245 .71649 L
s
.38598 .71384 m
.36943 .69711 L
s
.28369 .40372 m
.28947 .3804 L
s
.45416 .7376 m
.43553 .72561 L
s
.32741 .34895 m
.31969 .3387 L
s
.41885 .72789 m
.40097 .71347 L
s
.28261 .41487 m
.28305 .39361 L
s
.29807 .38966 m
.29458 .37342 L
s
.54597 .73599 m
.52813 .7288 L
s
.61441 .71139 m
.59999 .70542 L
s
.33938 .33938 m
.33017 .33017 L
s
.66983 .66983 m
.66062 .66062 L
s
.28713 .39979 m
.29419 .37621 L
s
.28566 .41523 m
.28469 .39473 L
s
.63004 .70052 m
.61677 .69393 L
s
.65789 .6794 m
.64725 .67117 L
s
.64459 .68974 m
.63258 .68239 L
s
.3055 .38481 m
.3005 .36962 L
s
.31846 .6536 m
.30735 .63123 L
s
.34171 .67695 m
.32811 .65626 L
s
.27882 .43165 m
.2815 .40746 L
s
.29012 .4142 m
.2877 .39454 L
s
.27924 .43448 m
.28057 .41075 L
s
.50931 .73666 m
.49056 .72721 L
s
.27968 .42825 m
.28369 .40372 L
s
.36943 .69711 m
.35371 .67836 L
s
.56437 .72679 m
.54703 .71946 L
s
.28098 .43648 m
.28093 .4133 L
s
.40097 .71347 m
.38359 .6969 L
s
.28181 .42457 m
.28713 .39979 L
s
.31446 .37834 m
.30794 .36423 L
s
.47205 .73332 m
.45308 .72149 L
s
.43553 .72561 m
.41704 .71138 L
s
.29603 .41163 m
.29215 .39289 L
s
.28406 .4374 m
.28261 .41487 L
s
.30735 .63123 m
.29776 .60744 L
s
.32811 .65626 m
.31581 .63391 L
s
.32495 .37033 m
.31691 .3573 L
s
.27754 .45375 m
.27968 .42825 L
s
.58245 .71649 m
.5658 .7089 L
s
.27803 .45682 m
.27882 .43165 L
s
.27833 .45029 m
.28181 .42457 L
s
.35371 .67836 m
.33902 .65777 L
s
.52813 .7288 m
.50953 .71938 L
s
.28854 .43703 m
.28566 .41523 L
s
.27982 .45922 m
.27924 .43448 L
s
.30345 .40742 m
.29807 .38966 L
s
.33694 .36093 m
.32741 .34895 L
s
.29776 .60744 m
.28985 .58246 L
s
.38359 .6969 m
.36693 .67832 L
s
.59999 .70542 m
.58419 .69742 L
s
.28295 .46069 m
.28098 .43648 L
s
.31581 .63391 m
.30499 .61015 L
s
.49056 .72721 m
.47141 .71553 L
s
.27732 .47992 m
.27754 .45375 L
s
.27676 .47666 m
.27833 .45029 L
s
.35036 .35036 m
.33938 .33938 L
s
.66062 .66062 m
.64964 .64964 L
s
.41704 .71138 m
.39891 .69501 L
s
.29445 .43517 m
.29012 .4142 L
s
.45308 .72149 m
.4341 .70745 L
s
.61677 .69393 m
.60198 .68538 L
s
.27918 .48269 m
.27803 .45682 L
s
.31239 .40155 m
.3055 .38481 L
s
.64725 .67117 m
.63489 .66111 L
s
.28985 .58246 m
.28372 .5566 L
s
.63258 .68239 m
.61895 .67315 L
s
.33902 .65777 m
.32556 .63554 L
s
.28745 .46099 m
.28406 .4374 L
s
.27713 .50338 m
.27676 .47666 L
s
.54703 .71946 m
.52876 .70997 L
s
.30499 .61015 m
.29579 .58523 L
s
.28235 .48469 m
.27982 .45922 L
s
.27906 .50647 m
.27732 .47992 L
s
.28372 .5566 m
.27946 .53013 L
s
.27946 .53013 m
.27713 .50338 L
s
.36693 .67832 m
.35121 .6579 L
s
.30185 .43171 m
.29603 .41163 L
s
.32286 .39403 m
.31446 .37834 L
s
.28228 .50897 m
.27918 .48269 L
s
.29579 .58523 m
.28834 .55944 L
s
.28274 .53308 m
.27906 .50647 L
s
.32556 .63554 m
.31351 .6119 L
s
.29336 .4599 m
.28854 .43703 L
s
.28688 .48566 m
.28295 .46069 L
s
.28834 .55944 m
.28274 .53308 L
s
.39891 .69501 m
.38138 .67663 L
s
.50953 .71938 m
.49035 .70776 L
s
.5658 .7089 m
.54804 .69921 L
s
.28684 .5106 m
.28235 .48469 L
s
.28733 .53535 m
.28228 .50897 L
s
.33483 .38499 m
.32495 .37033 L
s
.4341 .70745 m
.41534 .69129 L
s
.31351 .6119 m
.30304 .58712 L
s
.47141 .71553 m
.45207 .70165 L
s
.31076 .42655 m
.30345 .40742 L
s
.35121 .6579 m
.33662 .63585 L
s
.29279 .48537 m
.28745 .46099 L
s
.29428 .5615 m
.28733 .53535 L
s
.30074 .45726 m
.29445 .43517 L
s
.30304 .58712 m
.29428 .5615 L
s
.58419 .69742 m
.56712 .68739 L
s
.34827 .37458 m
.33694 .36093 L
s
.29276 .51111 m
.28688 .48566 L
s
.29326 .53665 m
.28684 .5106 L
s
.38138 .67663 m
.36467 .65644 L
s
.33662 .63585 m
.32337 .61241 L
s
.52876 .70997 m
.50973 .69833 L
s
.32119 .4197 m
.31239 .40155 L
s
.36307 .36307 m
.35036 .35036 L
s
.64964 .64964 m
.63693 .63693 L
s
.60198 .68538 m
.58578 .67488 L
s
.30014 .48361 m
.29336 .4599 L
s
.63489 .66111 m
.62089 .64926 L
s
.61895 .67315 m
.60378 .66203 L
s
.30155 .56251 m
.29326 .53665 L
s
.3096 .45294 m
.30185 .43171 L
s
.32337 .61241 m
.31163 .58787 L
s
.41534 .69129 m
.39702 .67315 L
s
.31163 .58787 m
.30155 .56251 L
s
.49035 .70776 m
.47081 .694 L
s
.30008 .51027 m
.29279 .48537 L
s
.30055 .53673 m
.29276 .51111 L
s
.45207 .70165 m
.43279 .68569 L
s
.36467 .65644 m
.349 .63463 L
s
.33313 .41119 m
.32286 .39403 L
s
.54804 .69921 m
.52934 .68744 L
s
.30896 .48022 m
.30074 .45726 L
s
.31998 .44688 m
.31076 .42655 L
s
.3102 .56221 m
.30055 .53673 L
s
.349 .63463 m
.33457 .61147 L
s
.39702 .67315 m
.3794 .65321 L
s
.34654 .40116 m
.33483 .38499 L
s
.30885 .50788 m
.30014 .48361 L
s
.30926 .53538 m
.30008 .51027 L
s
.32158 .58723 m
.3102 .56221 L
s
.33457 .61147 m
.32158 .58723 L
s
.56712 .68739 m
.54895 .67537 L
s
.50973 .69833 m
.49016 .68461 L
s
.43279 .68569 m
.41379 .66779 L
s
.36135 .38982 m
.34827 .37458 L
s
.47081 .694 m
.45115 .6782 L
s
.31927 .47509 m
.3096 .45294 L
s
.33187 .43909 m
.32119 .4197 L
s
.3794 .65321 m
.36269 .6317 L
s
.58578 .67488 m
.56832 .66246 L
s
.32025 .5604 m
.30926 .53538 L
s
.63693 .63693 m
.62256 .62256 L
s
.37744 .37744 m
.36307 .36307 L
s
.60378 .66203 m
.58719 .64909 L
s
.62089 .64926 m
.60535 .63566 L
s
.31908 .50379 m
.30896 .48022 L
s
.31941 .53241 m
.30885 .50788 L
s
.36269 .6317 m
.34713 .60887 L
s
.52934 .68744 m
.50992 .67366 L
s
.33293 .585 m
.32025 .5604 L
s
.34523 .42966 m
.33313 .41119 L
s
.41379 .66779 m
.39534 .64813 L
s
.33108 .46819 m
.31998 .44688 L
s
.34713 .60887 m
.33293 .585 L
s
.49016 .68461 m
.47027 .66892 L
s
.45115 .6782 m
.4316 .66052 L
s
.33173 .5569 m
.31941 .53241 L
s
.36001 .41872 m
.34654 .40116 L
s
.33079 .49791 m
.31927 .47509 L
s
.54895 .67537 m
.52986 .66142 L
s
.39534 .64813 m
.37768 .62694 L
s
.33101 .52768 m
.31908 .50379 L
s
.34436 .45954 m
.33187 .43909 L
s
.34566 .58103 m
.33173 .5569 L
s
.3761 .40652 m
.36135 .38982 L
s
.37768 .62694 m
.36105 .60447 L
s
.56832 .66246 m
.54976 .64821 L
s
.4316 .66052 m
.41244 .64113 L
s
.36105 .60447 m
.34566 .58103 L
s
.50992 .67366 m
.48999 .65799 L
s
.62256 .62256 m
.60664 .60664 L
s
.39336 .39336 m
.37744 .37744 L
s
.58719 .64909 m
.56935 .63441 L
s
.34397 .49023 m
.33108 .46819 L
s
.60535 .63566 m
.58839 .62042 L
s
.47027 .66892 m
.45033 .6514 L
s
.34463 .55159 m
.33101 .52768 L
s
.35907 .44924 m
.34523 .42966 L
s
.34406 .52113 m
.33079 .49791 L
s
.41244 .64113 m
.39392 .62027 L
s
.52986 .66142 m
.51008 .64567 L
s
.35978 .5752 m
.34463 .55159 L
s
.37512 .43748 m
.36001 .41872 L
s
.35858 .48079 m
.34436 .45954 L
s
.39392 .62027 m
.37629 .5982 L
s
.45033 .6514 m
.43059 .63225 L
s
.37629 .5982 m
.35978 .5752 L
s
.48999 .65799 m
.46981 .64058 L
s
.35894 .54442 m
.34406 .52113 L
s
.54976 .64821 m
.53031 .63226 L
s
.35853 .51274 m
.34397 .49023 L
s
.39238 .42452 m
.3761 .40652 L
s
.56935 .63441 m
.55043 .61813 L
s
.60664 .60664 m
.58932 .58932 L
s
.41068 .41068 m
.39336 .39336 L
s
.37453 .46973 m
.35907 .44924 L
s
.58839 .62042 m
.57018 .60368 L
s
.43059 .63225 m
.41132 .61171 L
s
.37525 .56749 m
.35894 .54442 L
s
.51008 .64567 m
.48984 .62827 L
s
.46981 .64058 m
.44964 .62162 L
s
.37436 .5026 m
.35858 .48079 L
s
.41132 .61171 m
.39279 .59002 L
s
.3746 .53541 m
.35853 .51274 L
s
.39279 .59002 m
.37525 .56749 L
s
.39173 .45724 m
.37512 .43748 L
s
.53031 .63226 m
.51021 .61476 L
s
.44964 .62162 m
.42976 .60134 L
s
.41002 .44361 m
.39238 .42452 L
s
.39198 .55794 m
.3746 .53541 L
s
.39145 .49085 m
.37453 .46973 L
s
.48984 .62827 m
.46942 .60941 L
s
.55043 .61813 m
.53067 .60041 L
s
.58932 .58932 m
.5708 .5708 L
s
.4292 .4292 m
.41068 .41068 L
s
.39153 .52466 m
.37436 .5026 L
s
.57018 .60368 m
.55095 .58562 L
s
.42976 .60134 m
.41046 .58002 L
s
.41046 .58002 m
.39198 .55794 L
s
.40966 .47774 m
.39173 .45724 L
s
.51021 .61476 m
.48973 .59592 L
s
.46942 .60941 m
.4491 .58935 L
s
.40988 .54667 m
.39153 .52466 L
s
.40961 .51234 m
.39145 .49085 L
s
.42881 .46357 m
.41002 .44361 L
s
.53067 .60041 m
.51031 .58147 L
s
.4491 .58935 m
.42916 .56834 L
s
.42916 .56834 m
.40988 .54667 L
s
.5708 .5708 m
.5513 .5513 L
s
.4487 .4487 m
.4292 .4292 L
s
.55095 .58562 m
.53092 .56645 L
s
.48973 .59592 m
.46914 .57598 L
s
.42868 .49871 m
.40966 .47774 L
s
.4288 .53389 m
.40961 .51234 L
s
.51031 .58147 m
.48964 .56155 L
s
.46914 .57598 m
.44873 .5552 L
s
.44852 .48411 m
.42881 .46357 L
s
.44873 .5552 m
.4288 .53389 L
s
.53092 .56645 m
.51038 .54644 L
s
.46892 .46892 m
.4487 .4487 L
s
.5513 .5513 m
.53108 .53108 L
s
.44853 .51987 m
.42868 .49871 L
s
.48964 .56155 m
.46895 .54092 L
s
.46895 .54092 m
.44853 .51987 L
s
.46888 .50497 m
.44852 .48411 L
s
.51038 .54644 m
.4896 .52585 L
s
.53108 .53108 m
.51041 .51041 L
s
.48959 .48959 m
.46892 .46892 L
s
.4896 .52585 m
.46888 .50497 L
s
.51041 .51041 m
.48959 .48959 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
OGoo2G`0VWoo001iOol4O009Ool5O02EOol007Eooa5l00Eoo`Al095oo`00Lgoo1W`03Goo17`01Goo
0g`0SWoo001aOolAO008Ool2O006Ool2O02<Ool006ioo`Al011oo`El00Eoo`9l00Ioo`9l08Yoo`00
K7oo4W`02Goo0g`017oo0W`01Woo00=l07ooOol0Qgoo001ZOol5O00?Ool5O007Ool2O004Ool2O005
Ool2O027Ool006Uoo`Al009oo`]l00Uoo`=l00Ioo`9l00Aoo`9l00Eoo`03O01oogoo08Aoo`00Igoo
0g`000=oog`0O0000W`02goo1G`01goo0W`01Woo0W`017oo0W`017oo00=l07ooOol0Pgoo001VOol5
O0000gooO01l0005O00<Ool3O006Ool2O006Ool2O004Ool2O003Ool2O023Ool006Aoo`=l0003Ooml
07`0009l00Moo`Ml00Qoo`9l00Ioo`9l00Ioo`03O01oogoo00=oo`9l00=oo`03O01oogoo081oo`00
HWoo1W`000=oog`0O00017`02goo0W`027oo0W`01Woo0W`01Goo0W`01Goo00El07ooOomoog`0085o
o`00HGoo27`01Woo17`02Goo0g`01goo0W`01Woo0W`01Goo00=l07ooOol00goo0W`00Woo0W`0Ogoo
001POol5O00>Ool4O008Ool3O006Ool2O006Ool2O004Ool00g`0Oomoo`04Ool01G`0OomoogooO000
OWoo001NOolBO007Ool3O008Ool2O006Ool2O006Ool00g`0Oomoo`02Ool2O005Ool01G`0Oomoogoo
O000OGoo001MOol6O00=Ool4O006Ool2O008Ool2O006Ool2O005Ool2O004Ool00g`0Oomoo`03Ool0
17`0Oomoogoo0W`0Ngoo001LOol>O00:Ool3O005Ool3O007Ool2O006Ool00g`0Oomoo`04Ool00g`0
Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`1hOol005]oo`=l0003Ooml07`0
00=l00Ioo`=l00Yoo`9l00Ioo`=l00Ioo`9l00Eoo`9l00Eoo`03O01oogoo009oo`9l00Aoo`03O01o
ogoo009oo`03O01oogoo07Moo`00FWoo1W`017oo0g`01Woo17`027oo0W`01goo00=l07ooOol01Goo
00=l07ooOol017oo00=l07ooOol00goo0W`017oo00=l07ooOol00Woo00El07ooOomoog`007Uoo`00
F7oo2W`01Goo17`01Woo0W`027oo0W`01Woo0W`01Woo0W`01Goo00=l07ooOol017oo00=l07ooOol0
0Woo00=l07ooOol00Woo00El07ooOomoog`007Qoo`00F7oo27`00Woo0g`01Woo0g`01Goo0W`027oo
0W`01Woo00=l07ooOol01Goo00=l07ooOol00goo0W`01Goo00=l07ooOol00Woo00=l07ooOol00Woo
00El07ooOomoog`007Moo`00Egoo1g`00Woo0g`00Woo0g`01Woo0W`01Goo0g`01goo0W`01Goo0W`0
1Woo00=l07ooOol017oo00=l07ooOol00goo0W`00goo00=l07ooOol00Woo00El07ooOomoog`007Io
o`00EWoo1g`000=oog`0Ool00goo0W`00goo0W`01Woo0W`01Woo0g`01Woo00=l07ooOol017oo0W`0
1Goo0W`01Goo00=l07ooOol017oo00El07ooOomoog`000=oo`05O01oogooOoml001fOol005Eoo`El
0003Ooml07`000Al00Aoo`9l00=oo`9l00Ioo`9l00Moo`03O01oogoo00Aoo`03O01oogoo00Eoo`03
O01oogoo00Aoo`03O01oogoo00=oo`9l00Eoo`05O01oogooOoml0003Ool01G`0OomoogooO000MGoo
001EOol5O0001gooO01oog`0Ooml07oo009l00Aoo`03O01oogoo009oo`=l00Eoo`9l00Ioo`9l00Eo
o`9l00Ioo`9l00Eoo`03O01oogoo00Aoo`03O01oogoo009oo`03O01oogoo009oo`05O01oogooOoml
0003Ool00g`0Oomoo`1bOol005Aoo`El0003Ooml07oo009oo`03O01oog`0009oo`9l00=oo`9l00Eo
o`9l00Eoo`9l00Ioo`03O01oogoo00Aoo`03O01oogoo00Eoo`03O01oogoo00=oo`9l00Eoo`03O01o
ogoo009oo`03O01oogoo009oo`05O01oogooOoml0003Ool00g`0Oomoo`1aOol005Aoo`Ml00Aoo`04
O01oog`0O002Ool00g`0Oomoo`02Ool00g`0Oomoo`04Ool2O005Ool2O005Ool2O005Ool2O006Ool0
0g`0Oomoo`04Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool017`0Oomoog`00goo
00=l07ooOol0LGoo001DOol5O002Ool00g`0Oomoo`02Ool017`0Oomoog`00Woo0W`00goo0W`01Woo
00=l07ooOol017oo00=l07ooOol017oo0W`01Goo0W`01Goo0W`01Goo00=l07ooOol00Woo00=l07oo
Ool00goo00El07ooOomoog`000=oo`05O01oogooOoml001bOol005=oo`Il009oo`03O01oogoo00=o
o`04O01oogooO003Ool00g`0Oomoo`02Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`05
Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02
Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00=l07ooOol0Kgoo001COol6O003Ool00g`0Oomo
o`03Ool017`0Oomoog`00goo00=l07ooOol00Woo0W`01Goo0W`01Goo0W`01Woo0W`01Goo0W`01Goo
00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`0
009oo`03O01oogoo06moo`00Dgoo1G`000Eoog`0Oomoog`000Ioo`03O01oogoo009l009oo`03O01o
ogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Eoo`03O01oogoo00Aoo`03O01o
ogoo00=oo`9l00Aoo`03O01oogoo009oo`9l00=oo`03O01oogoo009oo`04O01oogooO003Ool00g`0
Oomoo`1^Ool0059oo`Il0003Ooml07oo009oo`03O01oogoo00Aoo`05O01oogooOoml0002Ool2O004
Ool2O005Ool2O005Ool2O006Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool00g`0
Oomoo`03Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`03O01oogoo06ioo`00DWoo1W`0
0Woo00El07ooOomoog`000Ioo`05O01oogooOoml0003Ool2O004Ool2O005Ool2O005Ool2O005Ool0
0g`0Oomoo`04Ool2O005Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool01G`0OomoogooO0000goo00Al
07ooOoml00=oo`03O01oogoo06eoo`00DWoo1W`00Woo00=l07ooOol00Woo00=l07ooOol017oo00El
07ooOomoog`000Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=o
o`03O01oogoo00Eoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009o
o`05O01oogooOoml0002Ool017`0Oomoog`0Kgoo001BOol4O002Ool017`0Oomoog`017oo00=l07oo
Ool017oo00El07ooOomoog`000Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`9l
00Aoo`03O01oogoo00Eoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo
009oo`05O01oogooOoml0002Ool017`0Oomoog`0KWoo001BOol4O002Ool017`0Oomoog`01Goo00=l
07ooOol017oo00El07ooOomoog`000Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Eo
o`03O01oogoo009oo`9l00Ioo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo009oo`03O01o
ogoo009oo`04O01oogooO002Ool017`0Oomoog`0KWoo001AOol6O0000gooO01oo`02Ool00g`0Oomo
o`02Ool00g`0Oomoo`05Ool01G`0OomoogooO00017oo0W`017oo00=l07ooOol017oo00=l07ooOol0
1Goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol0
0Woo00El07ooOomoog`000=oo`04O01oogooO002Ool00g`0Oomoo`1[Ool0055oo`Al0005Ooml07oo
Ooml0003Ool00g`0Oomoo`02Ool00g`0Oomoo`05Ool01G`0OomoogooO0001Goo00=l07ooOol00Woo
0W`01Goo0W`01Woo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00Woo0W`017oo00El07oo
Oomoog`000Aoo`04O01oogooO003Ool017`0Oomoog`0K7oo001AOol4O0001GooO01oogooO00017oo
00=l07ooOol00Woo00=l07ooOol01Goo00Al07ooOomoo`9l00Aoo`03O01oogoo00=oo`03O01oogoo
00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`9l00Eoo`03O01oogoo00=oo`03O01oogoo009oo`05
O01oogooOoml0004Ool017`0Oomoog`00Woo00Al07ooOoml06aoo`00DGoo17`000=oog`0Ool00Woo
00El07ooOomoog`000Eoo`03O01oogoo00Eoo`03O01oogoo009oo`03O01oogoo009oo`9l00Aoo`03
O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00=oo`05
O01oogooOoml0004Ool01G`0OomoogooO0000Woo00El07ooOomoog`0009oo`03O01oogoo06Uoo`00
DGoo17`00Woo00Al07ooOoml00Aoo`03O01oogoo00=oo`03O01oogoo00Eoo`03O01oogoo009oo`03
O01oogoo00=oo`03O01oogoo009oo`9l00Eoo`9l00Eoo`03O01oogoo00Aoo`03O01oogoo00=oo`03
O01oogoo009oo`03O01oogoo009oo`03O01oogoo009oo`05O01oogooOoml0002Ool017`0Oomoog`0
0Woo00=l07ooOol0JGoo001AOol3O00017ooO01oog`00goo00=l07ooOol00Woo00=l07ooOol00goo
00=l07ooOol01Goo00=l07ooOol00Woo0W`017oo00=l07ooOol00goo00=l07ooOol017oo00=l07oo
Ool00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00Woo00El07oo
Oomoog`000=oo`04O01oogooO003Ool017`0Oomoog`0JWoo001AOol3O00017ooO01oog`00goo00=l
07ooOol00goo00=l07ooOol00goo00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol00Woo00=l
07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l
07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`000=oo`04O01oogooO002Ool017`0Oomoog`0
JWoo001AOol3O0001GooO01oogooO0000goo00=l07ooOol00Woo00=l07ooOol017oo00=l07ooOol0
1Goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol0
0goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00El07ooOomoog`000=oo`05O01o
ogooOoml0003Ool00g`0Ooml0002Ool00g`0Oomoo`1XOol0055oo`=l009oo`03O01oog`000=oo`03
O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Eoo`03O01oogoo009oo`03O01oogoo00=oo`03
O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`9l00Eoo`03O01oogoo00=oo`03O01oogoo
009oo`05O01oogooOoml0003Ool01G`0OomoogooO0000Woo00Al07ooOoml009oo`03O01oogoo06Mo
o`00D7oo17`00Woo00Al07ooOoml00=oo`03O01oogoo009oo`03O01oogoo00Aoo`03O01oogoo00Io
o`03O01oogoo009oo`03O01oogoo00=oo`9l00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01o
ogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`05O01oogooOoml0003Ool017`0Oomoog`00goo
00=l07ooO0000Woo00=l07ooOol0Igoo001@Ool4O003Ool00g`0Ooml0003Ool00g`0Oomoo`03Ool0
0g`0Oomoo`04Ool00g`0Oomoo`06Ool00g`0Oomoo`02Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool2
O005Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool01G`0Oomo
ogooO0000Woo00El07ooOomoog`0009oo`04O01oogooO002Ool00g`0Oomoo`1VOol0051oo`9l0003
Ooml07`0009oo`04O01oogooO003Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`06Ool0
0g`0Oomoo`02Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool0
0g`0Oomoo`04Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool017`0Oomoog`00goo00El07ooOomoog`0
009oo`03O01oog`0009oo`03O01oogoo06Ioo`00D7oo0W`000=oog`0O0000Woo00Al07ooOoml00=o
o`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Ioo`03O01oogoo009oo`03O01oogoo00Ao
o`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo009o
o`03O01oogoo009oo`05O01oogooOoml0003Ool02G`0OomoogooO01oog`0Ooml0002Ool00g`0Oomo
o`1VOol0051oo`9l0003Ooml07`000=oo`04O01oogooO003Ool00g`0Oomoo`03Ool00g`0Oomoo`05
Ool00g`0Oomoo`06Ool00g`0Oomoo`02Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool2O004Ool00g`0
Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo
00Al07ooOoml009oo`05O01oog`0Ooml001XOol0051oo`9l0003Ooml07`000=oo`04O01oogooO004
Ool00g`0Oomoo`03Ool00g`0Oomoo`05Ool00g`0Oomoo`06Ool00g`0Oomoo`02Ool00g`0Oomoo`04
Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool2O004Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool00g`0
Oomoo`02Ool01G`0OomoogooO0000Woo00Ul07ooOomoog`0Ooml07ooO0000Woo00=l07ooOol0IGoo
001@Ool2O00017ooO01oog`00Woo00El07ooOomoog`000Aoo`03O01oogoo00=oo`03O01oogoo00Eo
o`03O01oogoo00Ioo`03O01oogoo009oo`9l00Eoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01o
ogoo009oo`9l00Eoo`03O01oogoo009oo`03O01oogoo009oo`04O01oogooO003Ool017`0Oomoog`0
0Woo00El07ooO01oog`006Moo`00D7oo0W`000Aoog`0Ooml00=oo`04O01oogooO004Ool00g`0Oomo
o`04Ool00g`0Oomoo`05Ool00g`0Oomoo`06Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomo
o`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool01G`0Oomo
ogooO0000goo00Al07ooOoml00=oo`07O01oog`0Ooml07ooO000Igoo001@Ool2O002Ool00g`0Ooml
0002Ool01G`0OomoogooO00017oo00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol01Woo00=l
07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol017oo00=l
07ooOol00Woo00=l07ooOol00goo00El07ooOomoog`000=oo`04O01oogooO002Ool01g`0Ooml07oo
O01oog`006Moo`00D7oo0g`000Aoog`0Ooml009oo`05O01oogooOoml0005Ool00g`0Oomoo`03Ool0
0g`0Oomoo`06Ool00g`0Oomoo`06Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool0
0g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO000
17oo00=l07ooO0000goo00Al07ooO01oo`9l06Moo`00D7oo0g`000Aoog`0Ooml00=oo`05O01oogoo
Ooml0005Ool00g`0Oomoo`03Ool00g`0Oomoo`05Ool00g`0Oomoo`07Ool00g`0Oomoo`03Ool00g`0
Oomoo`03Ool2O004Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool00g`0Oomoo`02
Ool01G`0OomoogooO0000goo00Al07ooOoml009oo`07O01oog`0Ooml07ooO000IWoo001?Ool4O000
1GooO01oogooO0000Woo00El07ooOomoog`000Ioo`03O01oogoo00=oo`03O01oogoo00Eoo`03O01o
ogoo00Moo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo009oo`9l00Aoo`03O01oogoo00Ao
o`05O01oogooOoml0005Ool01G`0OomoogooO0000goo00=l07ooO0000goo00Al07ooO01oo`9l06Io
o`00Cgoo17`00Woo00=l07ooO0000Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol017oo
00=l07ooOol01Goo00=l07ooOol01goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo
00=l07ooOol00Woo0W`01Goo00El07ooOomoog`000Eoo`04O01oogooO003Ool017`0Oomoog`00Woo
00Al07ooO01oo`9l06Ioo`00Cgoo0g`000Ioog`0Ooml07ooO003Ool00g`0Oomoo`02Ool00g`0Oomo
o`03Ool00g`0Oomoo`04Ool00g`0Oomoo`05Ool00g`0Oomoo`07Ool00g`0Oomoo`03Ool00g`0Oomo
o`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomo
o`02Ool01G`0OomoogooO0000goo00Ul07ooOoml07ooO01oog`0Ool00W`0IWoo001?Ool3O00017oo
O01oog`00Woo00Al07ooOoml00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Ioo`03
O01oogoo00Moo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03
O01oogoo009oo`03O01oogoo009oo`03O01oogoo009oo`05O01oogooOoml0002Ool017`0Oomoog`0
0Woo00=l07ooO0000W`0IWoo001?Ool5O0001GooO01oogooO0000goo00=l07ooOol00Woo00=l07oo
Ool017oo00=l07ooOol00goo00=l07ooOol01Woo00=l07ooOol01goo00=l07ooOol00goo00=l07oo
Ool00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00=l07oo
Ool00Woo00Al07ooOoml00=oo`0:O01oogooO01oog`0Ooml07ooO01VOol004moo`Al0006Ooml07oo
O01oog`00goo00=l07ooOol00Woo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol01Woo00=l
07ooOol01goo00=l07ooOol00goo0W`017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol0
0goo00=l07ooOol00Woo00=l07ooOol00Woo00Al07ooOoml009oo`04O01oogooO002Ool00g`0Ooml
0002O01UOol004moo`Al0004Ooml07ooO002Ool01G`0OomoogooO00017oo00=l07ooOol017oo00=l
07ooOol017oo00=l07ooOol01Woo00=l07ooOol01goo00=l07ooOol017oo00=l07ooOol00Woo0W`0
17oo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo00El07ooOomoog`0009oo`05O01o
ogooOoml0002Ool017`0Ooml07oo0g`0IGoo001?Ool4O00017ooO01oog`00Woo00=l07ooOol00Woo
00=l07ooOol00Woo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol01Woo00=l07ooOol01goo
00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo0W`017oo00=l07ooOol00Woo00=l07oo
Ool00goo00El07ooOomoog`0009oo`04O01oogooO002Ool017`0Ooml07oo0g`0IGoo001?Ool4O002
Ool00g`0Ooml0002Ool01G`0OomoogooO00017oo00=l07ooOol017oo00=l07ooOol01Goo00=l07oo
Ool01Woo00=l07ooOol01goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07oo
Ool00Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00Il07ooOoml07ooO003Ool2
O00017ooO01l07`0IGoo001?Ool3O0001WooO01oog`0Ooml009oo`03O01oogoo009oo`03O01oogoo
009oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Moo`03O01oogoo00Moo`03O01oogoo
00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo
009oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo00Al07ooO01oo`9l06Eoo`00Cgoo0g`000Io
og`0Ooml07ooO003Ool01G`0OomoogooO0001Goo00=l07ooOol017oo00=l07ooOol017oo00=l07oo
Ool01goo00=l07ooOol01goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07oo
Ool00goo00El07ooOomoog`000Eoo`05O01oogooOoml0002Ool00g`0Ooml0003Ool2O00017ooO01l
07`0I7oo001?Ool5O0001GooO01oogooO0000Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l07oo
Ool01Goo00=l07ooOol017oo00=l07ooOol01goo00=l07ooOol01goo00=l07ooOol00goo00=l07oo
Ool00goo00=l07ooOol00goo00=l07ooOol00goo00El07ooOomoog`000Eoo`04O01oogooO002Ool0
17`0Oomoog`00Woo0W`000Aoog`0O01l06Aoo`00Cgoo1G`00Woo00=l07ooO0000Woo00=l07ooOol0
0Woo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol01goo00=l07ooOol0
1goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol0
0Woo00=l07ooOol00Woo00El07ooOomoog`0009oo`05O01oogooO01oo`02O00017ooO01l07`0I7oo
001?Ool4O0001WooO01oog`0Ooml00=oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Ao
o`03O01oogoo00Eoo`03O01oogoo00Moo`03O01oogoo00Moo`03O01oogoo00=oo`03O01oogoo00=o
o`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo009oo`04O01oogooO002
Ool01g`0Oomoog`0Ooml07oo00Al06Aoo`00Cgoo17`000Aoog`0Ooml009oo`04O01oogooO004Ool0
0g`0Oomoo`03Ool00g`0Oomoo`05Ool00g`0Oomoo`05Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool0
0g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool0
0g`0Oomoo`02Ool017`0Oomoog`00Woo00El07ooOoml07oo009l0003Ooml07`006Aoo`00Cgoo17`0
00Moog`0Oomoog`0Ooml0003Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`05Ool00g`0
Oomoo`05Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0
Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00Al07ooOoml009o
o`04O01oog`0Ool4O01SOol004moo`=l0006Ooml07ooO01oog`00Woo00Al07ooOoml00Eoo`03O01o
ogoo00=oo`03O01oogoo00Eoo`03O01oogoo00Eoo`03O01oogoo00Moo`03O01oogoo00Moo`03O01o
ogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`05O01oogooOoml0005Ool01G`0OomoogooO000
0Woo00Al07ooOoml009oo`9l0003Ooml07`0009l06=oo`00Cgoo0g`000Ioog`0Ooml07ooO002Ool0
1G`0OomoogooO00017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol01Woo00=l07ooOol0
1goo00=l07ooOol01goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00El07ooOomo
og`000Eoo`04O01oogooO003Ool01G`0Oomoog`0Ool00W`000=oog`0O0000W`0Hgoo001?Ool5O000
17ooO01oog`00goo00El07ooOomoog`000Aoo`03O01oogoo00=oo`03O01oogoo00Eoo`03O01oogoo
00Ioo`03O01oogoo00Moo`03O01oogoo00Moo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo
009oo`03O01oogoo009oo`03O01oogoo009oo`05O01oogooOoml0002Ool01g`0Oomoog`0Ooml07oo
00El06=oo`00Cgoo1G`000Eoog`0Oomoog`0009oo`05O01oogooOoml0004Ool00g`0Oomoo`04Ool0
0g`0Oomoo`05Ool00g`0Oomoo`06Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`03Ool0
0g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO000
0Woo00El07ooOoml07oo009l0004Ooml07`0O01SOol004moo`Al0006Ooml07ooO01oog`00goo00El
07ooOomoog`000Aoo`03O01oogoo00Aoo`03O01oogoo00Eoo`03O01oogoo00Ioo`03O01oogoo00Mo
o`03O01oogoo00Moo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009o
o`9l00=oo`04O01oogooO002Ool01g`0Oomoog`0Ooml07oo00Al06=oo`00Cgoo17`000Ioog`0Ooml
07ooO003Ool01G`0OomoogooO00017oo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol01Woo
00=l07ooOol027oo00=l07ooOol01goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo
00=l07ooOol00goo00Al07ooOoml00=oo`04O01oogooO002Ool2O0000gooO01l0002O01SOol004mo
o`Al0004Ooml07ooO002Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00=l07ooOol017oo00=l
07ooOol01Goo00=l07ooOol01Woo00=l07ooOol027oo00=l07ooOol01goo00=l07ooOol00goo00=l
07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo00Al07ooOoml009oo`04O01oogooO002Ool2
O0000gooO01l0002O01SOol004moo`Al0007Ooml07ooOoml07ooO0000goo00El07ooOomoog`000Eo
o`03O01oogoo00Aoo`03O01oogoo00Eoo`03O01oogoo00Ioo`03O01oogoo00Qoo`03O01oogoo00Mo
o`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`04O01oogooO003
Ool01g`0Oomoog`0Ooml07oo00El06=oo`00D7oo0W`000Ioog`0Ooml07ooO002Ool01G`0Oomoogoo
O0000goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol01Woo00=l07oo
Ool027oo00=l07ooOol01goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo00=l07oo
Ool00Woo00Al07ooOoml009oo`04O01oogooO002Ool2O00017ooO01l07`0Hgoo001@Ool4O00017oo
O01oog`00Woo00El07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo00Eoo`03O01oogoo00Eo
o`03O01oogoo00Ioo`03O01oogoo00Qoo`03O01oogoo00Moo`03O01oogoo00=oo`03O01oogoo009o
o`03O01oogoo00=oo`03O01oogoo009oo`04O01oogooO002Ool01g`0Oomoog`0Ooml07oo00Al06=o
o`00D7oo17`000Aoog`0Ooml00=oo`05O01oogooOoml0003Ool00g`0Oomoo`03Ool00g`0Oomoo`05
Ool00g`0Oomoo`05Ool00g`0Oomoo`06Ool00g`0Oomoo`08Ool00g`0Oomoo`07Ool00g`0Oomoo`03
Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Ooml0002Ool017`0Oomoogoo
0W`000=oog`0O0000W`0Hgoo001@Ool4O0001GooO01oogooO0000Woo00El07ooOomoog`000Aoo`03
O01oogoo00=oo`03O01oogoo00Eoo`03O01oogoo00Eoo`03O01oogoo00Ioo`03O01oogoo00Qoo`03
O01oogoo00Moo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo00=oo`05O01oogooOoml0002
Ool017`0Oomoog`00Woo0W`000=oog`0O0000W`0Hgoo001@Ool3O0001WooO01oog`0Ooml00=oo`05
O01oogooOoml0004Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`06Ool00g`0Oomoo`06
Ool00g`0Oomoo`08Ool00g`0Oomoo`07Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool2O004Ool01G`0
OomoogooO0000Woo00Al07ooOoml009oo`Il06=oo`00D7oo0g`000Ioog`0Ooml07ooO003Ool01G`0
OomoogooO0001Goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol01Woo00=l07ooOol01Woo
00=l07ooOol027oo00=l07ooOol01goo00=l07ooOol00goo00=l07ooOol00goo00El07ooOomoog`0
00Aoo`06O01oogooO01oog`00Woo0W`000Aoog`0O01l06=oo`00D7oo0g`000Aoog`0Ooml009oo`05
O01oogooOoml0003Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`05Ool00g`0Oomoo`06
Ool00g`0Oomoo`06Ool00g`0Oomoo`08Ool00g`0Oomoo`07Ool00g`0Oomoo`02Ool00g`0Oomoo`04
Ool01G`0OomoogooO0000goo00Al07ooOoml009oo`03O01oogoo00El06=oo`00DGoo00Ul07ooO01o
og`0Ooml07ooO0000goo00El07ooOomoog`000Eoo`03O01oogoo00=oo`03O01oogoo00Eoo`03O01o
ogoo00Eoo`03O01oogoo00Moo`03O01oogoo00Qoo`03O01oogoo00Moo`03O01oogoo009oo`03O01o
ogoo00=oo`03O01oogoo009oo`05O01oogooOoml0002Ool01G`0Oomoog`0Ool01G`0Hgoo001AOol3
O00017ooO01oog`00Woo00El07ooOomoog`000=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01o
ogoo00Eoo`03O01oogoo00Eoo`03O01oogoo00Moo`03O01oogoo00Qoo`03O01oogoo00Moo`03O01o
ogoo009oo`03O01oogoo00=oo`03O01oogoo009oo`04O01oogooO003Ool017`0Ooml07oo1G`0Hgoo
001AOol3O0001gooO01oogooO01oog`000=oo`05O01oogooOoml0005Ool00g`0Oomoo`04Ool00g`0
Oomoo`05Ool00g`0Oomoo`05Ool00g`0Oomoo`07Ool00g`0Oomoo`08Ool00g`0Oomoo`07Ool00g`0
Oomoo`02Ool00g`0Oomoo`03Ool01G`0OomoogooO0000goo00Al07ooOoml009oo`9l0004Ooml07`0
O01SOol0055oo`=l0005Ooml07ooOoml0002Ool01G`0OomoogooO0000goo00=l07ooOol00goo00=l
07ooOol00goo00=l07ooOol01Woo00=l07ooOol01Goo00=l07ooOol01goo00=l07ooOol027oo00=l
07ooOol01goo00=l07ooOol00Woo0W`017oo00El07ooOomoog`000=oo`07O01oogooO01oog`0Ool0
17`0Hgoo001AOol2O00017ooO01oog`00Woo00=l07ooO00017oo00Al07ooOoml00Ioo`03O01oogoo
00=oo`03O01oogoo00Eoo`03O01oogoo00Ioo`03O01oogoo00Moo`03O01oogoo00Qoo`03O01oogoo
00Moo`03O01oogoo00=oo`05O01oogooOoml0004Ool017`0Oomoog`00Woo00=l07ooOol00W`000=o
og`0O000Hgoo001AOol2O00017ooO01oog`00Woo00Al07ooOoml00=oo`05O01oogooOoml0005Ool0
0g`0Oomoo`04Ool00g`0Oomoo`05Ool00g`0Oomoo`06Ool00g`0Oomoo`07Ool00g`0Oomoo`08Ool0
0g`0Oomoo`07Ool00g`0Oomoo`03Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`05O01o
og`0O01oo`02O01SOol0059oo`=l0005Ooml07ooOoml0002Ool00g`0Oomoo`02Ool01G`0Oomoogoo
O0001Goo00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol01Woo00=l07ooOol01goo00=l07oo
Ool027oo00=l07ooOol01goo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`000=oo`06
O01oog`0Ooml07oo0g`0Hgoo001BOol2O00017ooO01oog`00Woo00Al07ooOoml00=oo`03O01oogoo
009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Ioo`03O01oogoo00Ioo`03O01oogoo
00Moo`03O01oogoo00Qoo`03O01oogoo00Moo`03O01oogoo009oo`03O01oogoo009oo`04O01oogoo
O003Ool01G`0Oomoog`0Ool01G`0HWoo001BOol2O00017ooO01oog`00Woo00Al07ooOoml00Aoo`05
O01oogooOoml0005Ool00g`0Oomoo`04Ool00g`0Oomoo`06Ool00g`0Oomoo`06Ool00g`0Oomoo`07
Ool2O009Ool00g`0Oomoo`07Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool017`0Oomoog`00goo00Il
07ooO01oog`0Ool3O01ROol0059oo`9l0005Ooml07ooOoml0002Ool017`0Oomoog`00goo00=l07oo
Ool00Woo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol01Woo00=l07ooOol01Woo00=l07oo
Ool027oo00=l07ooOol01goo00=l07ooOol01goo00=l07ooOol00Woo00=l07ooOol00Woo00Al07oo
Ooml009oo`05O01oogooO01oo`04O01ROol005=oo`=l009oo`04O01oogooO002Ool00g`0Oomoo`02
Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`05Ool00g`0Oomoo`07
Ool00g`0Oomoo`08Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`02Ool00g`0Oomoo`02
Ool017`0Oomoog`00Woo00Al07ooO01oo`Al069oo`00Dgoo0W`000Eoog`0Oomoog`0009oo`04O01o
ogooO004Ool01G`0OomoogooO0001Woo00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol01goo
00=l07ooOol027oo00=l07ooOol01goo00=l07ooOol01goo00=l07ooOol00Woo00El07ooOomoog`0
00=oo`03O01oog`0009oo`El069oo`00Dgoo0W`000Eoog`0Oomoog`0009oo`05O01oogooOoml0003
Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`05Ool00g`0Oomoo`05Ool00g`0Oomoo`07
Ool00g`0Oomoo`08Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`02Ool01G`0Oomoogoo
O0000goo00Al07ooO01oo`El069oo`00E7oo0g`00Woo00El07ooOomoog`0009oo`03O01oogoo009o
o`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Eoo`03O01oogoo00Eoo`03O01oogoo00Mo
o`03O01oogoo00Qoo`03O01oogoo00Moo`03O01oogoo00Moo`03O01oogoo009oo`05O01oogooOoml
0002Ool00g`0Ooml0002Ool4O01ROol005Aoo`9l0005Ooml07ooOoml0002Ool01G`0OomoogooO000
0goo00=l07ooOol00Woo00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol01Goo00=l07ooOol0
1goo00=l07ooOol027oo00=l07ooOol01goo00=l07ooOol01goo00=l07ooOol00Woo00El07ooOomo
og`0009oo`04O01oog`0Ool4O01ROol005Aoo`9l0005Ooml07ooOoml0003Ool017`0Oomoog`017oo
00=l07ooOol00Woo00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol01Goo00=l07ooOol01goo
00=l07ooOol027oo00=l07ooOol01goo00=l07ooOol01goo00=l07ooOol00Woo00Al07ooOoml00=o
o`05O01oog`0O01oo`02O01ROol005Aoo`05O01oog`0Ooml0002Ool017`0Oomoog`00goo00El07oo
Oomoog`000Eoo`03O01oogoo00Aoo`03O01oogoo00Eoo`03O01oogoo00Eoo`9l00Qoo`03O01oogoo
00Qoo`03O01oogoo00Moo`03O01oogoo00Moo`05O01oogooOoml0003Ool01G`0Oomoog`0Ool01G`0
HWoo001EOol2O0001GooO01oogooO0000goo00Al07ooOoml00Aoo`03O01oogoo00=oo`03O01oogoo
00Aoo`03O01oogoo00Eoo`03O01oogoo00Ioo`03O01oogoo00Ioo`03O01oogoo00Qoo`03O01oogoo
00Moo`03O01oogoo00Moo`05O01oogooOoml0003Ool00g`0Oomoo`07O01QOol005Eoo`05O01oog`0
Ooml0002Ool017`0Oomoog`00goo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol017oo00=l
07ooOol01Goo00=l07ooOol01Woo00=l07ooOol01Woo0W`02Goo00=l07ooOol01goo00=l07ooOol0
1goo00El07ooOomoog`0009oo`03O01oogoo00Ml065oo`00EGoo00El07ooO01oog`0009oo`05O01o
ogooOoml0003Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`05Ool00g`0Oomoo`05Ool0
0g`0Oomoo`06Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool0
1G`0OomoogooO0000Woo00=l07ooOol01W`0HGoo001FOol2O002Ool017`0Oomoog`00goo00Al07oo
Ooml00Aoo`03O01oogoo00=oo`03O01oogoo00Eoo`03O01oogoo00Eoo`03O01oogoo00Ioo`03O01o
ogoo00Moo`03O01oogoo00Moo`03O01oogoo00Moo`03O01oogoo00Moo`05O01oogooOoml0002Ool8
O01QOol005Ioo`05O01oog`0Ooml0002Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00=l07oo
Ool00goo00=l07ooOol01Goo00=l07ooOol01Goo00=l07ooOol01Woo00=l07ooOol01goo00=l07oo
Ool01goo00=l07ooOol01goo00=l07ooOol01goo00El07ooOomoog`0009oo`Ml065oo`00Egoo0W`0
0Woo00Al07ooOoml00=oo`05O01oogooOoml0004Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0
Oomoo`06Ool00g`0Oomoo`06Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0
Oomoo`07Ool017`0Oomoogoo17`000=oog`0O0000W`0HGoo001GOol01G`0Ooml07ooO0000Woo00El
07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Io
o`03O01oogoo00Ioo`03O01oogoo00Moo`9l00Qoo`03O01oogoo00Moo`03O01oogoo00Moo`08O01o
ogooOoml07ooO01oo`Al065oo`00F7oo0W`00Woo00Al07ooOoml00=oo`05O01oogooOoml0005Ool0
0g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`06Ool00g`0Oomoo`06Ool00g`0Oomoo`08Ool0
0g`0Oomoo`06Ool2O008Ool2O008Ool00g`0Oomoo`04O00017ooO01l07`0HGoo001HOol01G`0Ooml
07ooO0000Woo00El07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Eo
o`03O01oogoo00Ioo`03O01oogoo00Ioo`03O01oogoo00Qoo`03O01oogoo00Moo`03O01oogoo00Mo
o`03O01oogoo00Ioo`03O01oog`000Ql061oo`00F7oo00Il07ooOoml07ooO002Ool01G`0Oomoogoo
O00017oo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol01Goo00=l07ooOol01Woo00=l07oo
Ool01Woo00=l07ooOol027oo00=l07ooOol01goo00=l07ooOol01goo00=l07ooOol01Woo00=l07oo
O0000W`000=oog`0O0000W`0H7oo001IOol00g`0Ooml0002Ool017`0Oomoog`00goo00El07ooOomo
og`000Eoo`03O01oogoo00=oo`03O01oogoo00Eoo`03O01oogoo00Ioo`03O01oogoo00Ioo`9l00Uo
o`03O01oogoo00Moo`03O01oogoo00Moo`03O01oogoo00Eoo`=l0003Ooml07oo00Al061oo`00FGoo
00Il07ooOoml07ooO002Ool01G`0OomoogooO00017oo00=l07ooOol00goo00=l07ooOol00goo00=l
07ooOol01Goo0W`01goo00=l07ooOol01goo00=l07ooOol01goo00=l07ooOol01goo0W`027oo0W`0
1Goo00Al07ooO01oo`Ml05moo`00FWoo00=l07ooO0000Woo00Al07ooOoml00=oo`03O01oogoo009o
o`03O01oogoo009oo`03O01oogoo00Aoo`03O01oogoo00Ioo`03O01oogoo00Eoo`03O01oogoo00Mo
o`03O01oogoo00Moo`03O01oogoo00Qoo`03O01oogoo00Moo`0:O01oogooOoml07ooO01oog`0Ool6
O01OOol005Yoo`04O01oogooO002Ool017`0Oomoog`00goo00El07ooOomoog`000Eoo`03O01oogoo
00Aoo`03O01oogoo00Ioo`03O01oogoo00Eoo`9l00Qoo`9l00Qoo`03O01oogoo00Qoo`03O01oogoo
00Moo`07O01oogooO01oog`0Ool027`0Ggoo001KOol00g`0Ooml0002Ool017`0Oomoog`00goo00=l
07ooOol00Woo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol01Woo00=l07ooOol01Woo00=l
07ooOol01goo00=l07ooOol01Woo0W`02Goo00=l07ooOol01goo0W`000Ioog`0Oomoog`0Ool6O01O
Ool005]oo`04O01oogooO002Ool017`0Oomoog`00goo00=l07ooOol00Woo00=l07ooOol00goo00=l
07ooOol017oo00=l07ooOol01Woo00=l07ooOol01Woo00=l07ooOol01goo0W`027oo00=l07ooOol0
1goo0W`027oo0g`00Woo27`0Ggoo001LOol017`0Oomoog`00Woo00Al07ooOoml00=oo`03O01oogoo
009oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Ioo`03O01oogoo00Ioo`03O01oogoo
00Qoo`03O01oogoo00Ioo`9l00Uoo`03O01oogoo00Aoo`07O01oog`0O01oog`0Ool00W`000=oog`0
O0000W`0Ggoo001LOol017`0Oomoog`00Woo00El07ooOomoog`000=oo`05O01oogooOoml0006Ool0
0g`0Oomoo`04Ool00g`0Oomoo`06Ool00g`0Oomoo`06Ool00g`0Oomoo`08Ool00g`0Oomoo`07Ool0
0g`0Oomoo`07Ool00g`0Oomoo`03Ool017`0Ooml07oo0g`000=oog`0Ool01G`0GWoo001MOol017`0
Oomoog`00Woo00Al07ooOoml00=oo`03O01oogoo009oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03
O01oogoo00Ioo`03O01oogoo00Ioo`9l00Uoo`9l00Qoo`9l00Qoo`07O01oogooOoml07ooO0000Woo
0g`000Aoog`0O01oo`Al05ioo`00GGoo00El07ooOomoog`0009oo`04O01oogooO003Ool00g`0Oomo
o`02Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool2O007Ool00g`0Oomoo`07Ool00g`0Oomoo`08Ool0
0g`0Oomoo`07Ool2O007Ool2O00017ooO01oog`00Woo00Ul07ooO01l07ooO01oog`0Ool00g`0GGoo
001NOol017`0Oomoog`00Woo00El07ooOomoog`000=oo`03O01oogoo009oo`03O01oogoo00Aoo`03
O01oogoo00Eoo`03O01oogoo00Eoo`03O01oogoo00Moo`03O01oogoo00Qoo`03O01oogoo00Qoo`03
O01oogoo00Ioo`09O01oogooO01oog`0Ooml07oo00El0004Ooml07`0O01MOol005moo`04O01oogoo
O002Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00=l07ooOol017oo0W`01Woo00=l07ooOol0
1Goo0W`027oo00=l07ooOol027oo00=l07ooOol027oo00=l07ooOol017oo00Al07ooO01l009oo`06
O01oog`0Ooml07oo0g`000Aoog`0O01l05eoo`00H7oo00Al07ooOoml009oo`05O01oogooOoml0003
Ool00g`0Oomoo`02Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomoo`06Ool00g`0Oomoo`06
Ool2O009Ool2O009Ool2O004Ool00g`0Oomoo`03O002Ool2O0000gooO01oo`03O0000gooO01l0002
O01KOol0061oo`05O01oogooOoml0002Ool01G`0OomoogooO0000goo00=l07ooOol00Woo0W`01Woo
00=l07ooOol017oo00=l07ooOol01Woo00=l07ooOol01goo00=l07ooOol027oo00=l07ooOol027oo
00Al07ooOoml009oo`03O01oogoo00=l0005Ooml07ooO01oo`03O0000gooO01l0002O01KOol0065o
o`04O01oogooO002Ool01G`0OomoogooO00017oo00=l07ooOol00goo00=l07ooOol017oo00=l07oo
Ool017oo0W`01goo0W`027oo00=l07ooOol027oo00=l07ooOol027oo0g`00Woo00=l07ooO0000Woo
0W`00Woo0W`000=oog`0O0001W`0FWoo001ROol017`0Oomoog`00Woo00El07ooOomoog`000Aoo`03
O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Eoo`03O01oogoo00Ioo`03O01oogoo00Ioo`9l
00Uoo`9l00Uoo`Al009oo`04O01oog`0Ool3O0000gooO01oo`07O0000gooO01oo`1HOol006=oo`04
O01oogooO002Ool01G`0OomoogooO00017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol0
1Goo00=l07ooOol01Woo0W`027oo0W`02Goo0W`01Woo00=l07ooOol00W`000Aoog`0Oomoo`9l009o
o`=l0003Ooml07`000El05]oo`00I7oo00Al07ooOoml009oo`05O01oogooOoml0004Ool00g`0Oomo
o`03Ool00g`0Oomoo`04Ool00g`0Oomoo`05Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool2O009Ool2
O004Ool01G`0Oomoog`0Ool00W`000Uoog`0Ooml07ooO01oog`0Ool00W`000=oog`0O0000W`0G7oo
001UOol017`0Oomoog`00Woo00El07ooOomoog`000Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03
O01oogoo00Eoo`9l00Qoo`9l00Uoo`9l00Uoo`9l0005Ooml07ooOoml0002Ool00g`0Ooml0002O000
1WooO01oogooO01oo`Il05eoo`00IWoo00=l07ooO0000goo00Al07ooOomoo`9l00=oo`03O01oogoo
00=oo`03O01oogoo00Aoo`9l00Moo`03O01oogoo00Moo`9l00Uoo`9l00Uoo`9l0005Ooml07ooOoml
0002Ool00g`0Ooml0004O00017ooO01l07oo0g`0GWoo001WOol00g`0Ooml0003Ool00g`0Oomoo`02
Ool01G`0OomoogooO0001Goo00=l07ooOol01Goo00=l07ooOol01Goo00=l07ooOol027oo00=l07oo
Ool027oo0W`01Woo00=l07ooOol00W`00Woo00Ql07ooO01oog`0Ooml07oo1g`0H7oo001XOol00g`0
Ooml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0001Goo0W`01Woo0W`01Woo0W`02Goo0W`02Woo
0W`017oo00El07ooOoml07oo00Al009oo`06O01oog`0Ooml07oo17`0HGoo001YOol00g`0Ooml0003
Ool00g`0Oomoo`02Ool01G`0OomoogooO0001Woo00=l07ooOol01Goo00=l07ooOol01Goo0W`02Goo
0W`02Woo0W`000=oog`0Ool00Woo00=l07ooO0000Woo37`0HWoo001YOol00g`0Oomoo`02O002Ool0
0g`0Oomoo`02Ool2O002Ool2O005Ool2O006Ool2O007Ool2O009Ool2O00:Ool2O002Ool00g`0Ooml
0002Ool00g`0Ooml0002Ool01G`0Ooml07`0Ool00W`0Hgoo001ZOol01G`0OomoogooO0000Woo00=l
07ooOol00goo00El07ooOomoog`000Ioo`03O01oogoo00Eoo`9l00Moo`9l00Uoo`9l00Moo`03O01o
ogoo00Al009oo`07O01oogooO01oog`0Ool017`0IGoo001[Ool01G`0OomoogooO0000Woo00=l07oo
Ool00goo00El07ooOomoog`000Ioo`9l00Moo`03O01oogoo00Ioo`9l00Uoo`=l00=oo`04O01oogoo
O002Ool>O01VOol006aoo`9l009oo`04O01oogooO005Ool017`0Oomoogoo0W`01Woo0W`01Woo0W`0
27oo0W`02Woo0g`00Woo00Al07ooOoml00=oo`03O01oogoo009l0004Ooml07`0O01XOol006ioo`9l
0004Ooml07`0Ool2O004Ool2O003Ool2O006Ool00g`0Oomoo`05Ool2O008Ool2O008Ool9O002Ool0
0g`0Ooml0006O01YOol0071oo`04O01oogooO002Ool2O004Ool00g`0Oomoo`02Ool2O005Ool2O007
Ool3O007Ool4O003Ool01G`0OomoogooO0000goo00=l07ooO0001G`000=oog`0O000Jgoo001aOol2
O0000gooO01oo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool2O005Ool2O008Ool2O009Ool5O000
17ooO01oogoo0W`000Aoog`0Oomoo`El06eoo`00Lgoo17`00Woo0W`00goo0W`01Goo0W`01Goo0W`0
27oo17`01Goo0W`00Woo3W`0Kgoo001eOol017`0Ooml07`00Woo0W`00goo0W`01Goo0W`01Goo0g`0
2Goo1G`00goo00Il07ooOomoog`0Ool2O0000gooO01l0002O01aOol007Ioo`9l0003Ooml07`0009o
o`9l00=oo`9l00Eoo`9l00Ioo`Al00Moo`9l0003Ooml07`000]l07Aoo`00N7oo1G`00Woo0W`00goo
0W`01Goo0g`01goo1g`00Woo0W`00goo00=l07ooO00017`0MWoo001kOol5O00017ooO01l07`00Woo
17`017oo0g`01goo3g`0NGoo001mOol5O002Ool3O003Ool5O002Ool;O002Ool5O01mOol0085oo`El
0003Ooml07`0009l00Aoo`ml089oo`00QWoo4g`0Qgoo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {324.75, 95.375}} -> {-0.399192, \
0.415803, 0.00348777, 0.00348777}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig1C = Show[Fig1A, Fig1B, ViewPoint \[Rule] {0, 0, 2}];\)\)], "Input",\

  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.49375 .49375 m
.50625 .50625 L
s
.48127 .48127 m
.49375 .49375 L
s
0 0 1 r
.49375 .50625 m
.50625 .49375 L
s
.48127 .51873 m
.49375 .50625 L
s
1 0 0 r
.50625 .50625 m
.51873 .51873 L
s
0 0 1 r
.50625 .49375 m
.51873 .48127 L
s
1 0 0 r
.50625 .48446 m
.51871 .49701 L
s
.49374 .47199 m
.50625 .48446 L
s
0 0 1 r
.49375 .48446 m
.50626 .47199 L
s
.48129 .49701 m
.49375 .48446 L
s
.46891 .50959 m
.48129 .49701 L
s
1 0 0 r
.51871 .49701 m
.53109 .50959 L
s
.46885 .46885 m
.48127 .48127 L
s
0 0 1 r
.46885 .53115 m
.48127 .51873 L
s
1 0 0 r
.51873 .51873 m
.53115 .53115 L
s
0 0 1 r
.51873 .48127 m
.53115 .46885 L
s
1 0 0 r
.48122 .45964 m
.49374 .47199 L
s
0 0 1 r
.50626 .47199 m
.51878 .45964 L
s
1 0 0 r
.51874 .4753 m
.53109 .48799 L
s
.50627 .46275 m
.51874 .4753 L
s
0 0 1 r
.48126 .4753 m
.49373 .46275 L
s
.46891 .48799 m
.48126 .4753 L
s
.45666 .52218 m
.46891 .50959 L
s
1 0 0 r
.53109 .50959 m
.54334 .52218 L
s
0 0 1 r
.45671 .50078 m
.46891 .48799 L
s
1 0 0 r
.53109 .48799 m
.54329 .50078 L
s
.49372 .45036 m
.50627 .46275 L
s
0 0 1 r
.49373 .46275 m
.50628 .45036 L
s
.4447 .51363 m
.45671 .50078 L
s
1 0 0 r
.54329 .50078 m
.5553 .51363 L
s
.45652 .45652 m
.46885 .46885 L
s
0 0 1 r
.45652 .54348 m
.46885 .53115 L
s
1 0 0 r
.53115 .53115 m
.54348 .54348 L
s
0 0 1 r
.53115 .46885 m
.54348 .45652 L
s
1 0 0 r
.46872 .44743 m
.48122 .45964 L
s
0 0 1 r
.51878 .45964 m
.53128 .44743 L
s
1 0 0 r
.53116 .46645 m
.54333 .47938 L
s
.51881 .45371 m
.53116 .46645 L
s
0 0 1 r
.46884 .46645 m
.48119 .45371 L
s
.45667 .47938 m
.46884 .46645 L
s
.44472 .49245 m
.45667 .47938 L
s
1 0 0 r
.54333 .47938 m
.55528 .49245 L
s
0 0 1 r
.44457 .53474 m
.45666 .52218 L
s
1 0 0 r
.54334 .52218 m
.55543 .53474 L
s
.5063 .4412 m
.51881 .45371 L
s
0 0 1 r
.48119 .45371 m
.4937 .4412 L
s
1 0 0 r
.48112 .43818 m
.49372 .45036 L
s
0 0 1 r
.50628 .45036 m
.51888 .43818 L
s
.43303 .50564 m
.44472 .49245 L
s
1 0 0 r
.55528 .49245 m
.56697 .50564 L
s
0 0 1 r
.43292 .52649 m
.4447 .51363 L
s
1 0 0 r
.5553 .51363 m
.56708 .52649 L
s
.49368 .42895 m
.5063 .4412 L
s
0 0 1 r
.4937 .4412 m
.50632 .42895 L
s
1 0 0 r
.54347 .45806 m
.55538 .47132 L
s
.5313 .44505 m
.54347 .45806 L
s
0 0 1 r
.45653 .45806 m
.4687 .44505 L
s
.44462 .47132 m
.45653 .45806 L
s
1 0 0 r
.45628 .43541 m
.46872 .44743 L
s
0 0 1 r
.53128 .44743 m
.54372 .43541 L
s
1 0 0 r
.44431 .44431 m
.45652 .45652 L
s
0 0 1 r
.44431 .55569 m
.45652 .54348 L
s
1 0 0 r
.54348 .54348 m
.55569 .55569 L
s
0 0 1 r
.54348 .45652 m
.55569 .44431 L
s
.433 .48477 m
.44462 .47132 L
s
1 0 0 r
.55538 .47132 m
.567 .48477 L
s
.51891 .43232 m
.5313 .44505 L
s
0 0 1 r
.4687 .44505 m
.48109 .43232 L
s
1 0 0 r
.46852 .42625 m
.48112 .43818 L
s
0 0 1 r
.51888 .43818 m
.53148 .42625 L
s
.43267 .54722 m
.44457 .53474 L
s
1 0 0 r
.55543 .53474 m
.56733 .54722 L
s
0 0 1 r
.42164 .51891 m
.43303 .50564 L
s
1 0 0 r
.56697 .50564 m
.57836 .51891 L
s
0 0 1 r
.42171 .49838 m
.433 .48477 L
s
1 0 0 r
.567 .48477 m
.57829 .49838 L
s
.50634 .41991 m
.51891 .43232 L
s
0 0 1 r
.48109 .43232 m
.49366 .41991 L
s
1 0 0 r
.48098 .41701 m
.49368 .42895 L
s
0 0 1 r
.50632 .42895 m
.51902 .41701 L
s
.42141 .53934 m
.43292 .52649 L
s
1 0 0 r
.56708 .52649 m
.57859 .53934 L
s
.5556 .45031 m
.56718 .46396 L
s
.5437 .43694 m
.5556 .45031 L
s
0 0 1 r
.4444 .45031 m
.4563 .43694 L
s
.43282 .46396 m
.4444 .45031 L
s
.42161 .47786 m
.43282 .46396 L
s
1 0 0 r
.56718 .46396 m
.57839 .47786 L
s
.53151 .42391 m
.5437 .43694 L
s
0 0 1 r
.4563 .43694 m
.46849 .42391 L
s
1 0 0 r
.44394 .42363 m
.45628 .43541 L
s
0 0 1 r
.54372 .43541 m
.55606 .42363 L
s
.41079 .51212 m
.42171 .49838 L
s
1 0 0 r
.57829 .49838 m
.58921 .51212 L
s
.43228 .43228 m
.44431 .44431 L
s
0 0 1 r
.43228 .56772 m
.44431 .55569 L
s
1 0 0 r
.55569 .55569 m
.56772 .56772 L
s
0 0 1 r
.55569 .44431 m
.56772 .43228 L
s
1 0 0 r
.45595 .41462 m
.46852 .42625 L
s
0 0 1 r
.53148 .42625 m
.54405 .41462 L
s
1 0 0 r
.49363 .40787 m
.50634 .41991 L
s
0 0 1 r
.49366 .41991 m
.50637 .40787 L
s
.41059 .5322 m
.42164 .51891 L
s
1 0 0 r
.57836 .51891 m
.58941 .5322 L
s
0 0 1 r
.4108 .49197 m
.42161 .47786 L
s
1 0 0 r
.57839 .47786 m
.5892 .49197 L
s
0 0 1 r
.42102 .55959 m
.43267 .54722 L
s
1 0 0 r
.56733 .54722 m
.57898 .55959 L
s
.51906 .41125 m
.53151 .42391 L
s
0 0 1 r
.46849 .42391 m
.48094 .41125 L
s
1 0 0 r
.46825 .40542 m
.48098 .41701 L
s
0 0 1 r
.51902 .41701 m
.53175 .40542 L
s
.41021 .55213 m
.42141 .53934 L
s
1 0 0 r
.57859 .53934 m
.58979 .55213 L
s
.56749 .44333 m
.57864 .45745 L
s
.55594 .42954 m
.56749 .44333 L
s
0 0 1 r
.43251 .44333 m
.44406 .42954 L
s
.42136 .45745 m
.43251 .44333 L
s
.41064 .47186 m
.42136 .45745 L
s
1 0 0 r
.57864 .45745 m
.58936 .47186 L
s
0 0 1 r
.40044 .50623 m
.4108 .49197 L
s
1 0 0 r
.5892 .49197 m
.59956 .50623 L
s
.54402 .41612 m
.55594 .42954 L
s
0 0 1 r
.44406 .42954 m
.45598 .41612 L
s
.40027 .52593 m
.41079 .51212 L
s
1 0 0 r
.58921 .51212 m
.59973 .52593 L
s
.5064 .399 m
.51906 .41125 L
s
0 0 1 r
.48094 .41125 m
.4936 .399 L
s
1 0 0 r
.4808 .39623 m
.49363 .40787 L
s
0 0 1 r
.50637 .40787 m
.5192 .39623 L
s
.4004 .48651 m
.41064 .47186 L
s
1 0 0 r
.58936 .47186 m
.5996 .48651 L
s
.53178 .40312 m
.54402 .41612 L
s
0 0 1 r
.45598 .41612 m
.46822 .40312 L
s
1 0 0 r
.43175 .41211 m
.44394 .42363 L
s
0 0 1 r
.55606 .42363 m
.56825 .41211 L
s
.39991 .54549 m
.41059 .5322 L
s
1 0 0 r
.58941 .5322 m
.60009 .54549 L
s
.42046 .42046 m
.43228 .43228 L
s
0 0 1 r
.42046 .57954 m
.43228 .56772 L
s
1 0 0 r
.56772 .56772 m
.57954 .57954 L
s
0 0 1 r
.56772 .43228 m
.57954 .42046 L
s
1 0 0 r
.44345 .40331 m
.45595 .41462 L
s
0 0 1 r
.54405 .41462 m
.55655 .40331 L
s
.40965 .5718 m
.42102 .55959 L
s
1 0 0 r
.57898 .55959 m
.59035 .5718 L
s
0 0 1 r
.39055 .52061 m
.40044 .50623 L
s
1 0 0 r
.59956 .50623 m
.60945 .52061 L
s
.45552 .39423 m
.46825 .40542 L
s
0 0 1 r
.53175 .40542 m
.54448 .39423 L
s
.39067 .50135 m
.4004 .48651 L
s
1 0 0 r
.5996 .48651 m
.60933 .50135 L
s
.57906 .43725 m
.5897 .45189 L
s
.56795 .42297 m
.57906 .43725 L
s
0 0 1 r
.42094 .43725 m
.43205 .42297 L
s
.4103 .45189 m
.42094 .43725 L
s
1 0 0 r
.49356 .38722 m
.5064 .399 L
s
0 0 1 r
.4936 .399 m
.50644 .38722 L
s
.40016 .46685 m
.4103 .45189 L
s
1 0 0 r
.5897 .45189 m
.59984 .46685 L
s
.51925 .39059 m
.53178 .40312 L
s
0 0 1 r
.46822 .40312 m
.48075 .39059 L
s
1 0 0 r
.55639 .4091 m
.56795 .42297 L
s
0 0 1 r
.43205 .42297 m
.44361 .4091 L
s
.39021 .53977 m
.40027 .52593 L
s
1 0 0 r
.59973 .52593 m
.60979 .53977 L
s
0 0 1 r
.39936 .56482 m
.41021 .55213 L
s
1 0 0 r
.58979 .55213 m
.60064 .56482 L
s
0 0 1 r
.39058 .48208 m
.40016 .46685 L
s
1 0 0 r
.59984 .46685 m
.60942 .48208 L
s
.46791 .38505 m
.4808 .39623 L
s
0 0 1 r
.5192 .39623 m
.53209 .38505 L
s
1 0 0 r
.54444 .3957 m
.55639 .4091 L
s
0 0 1 r
.44361 .4091 m
.45556 .3957 L
s
.38148 .51633 m
.39067 .50135 L
s
1 0 0 r
.60933 .50135 m
.61852 .51633 L
s
0 0 1 r
.38967 .55872 m
.39991 .54549 L
s
1 0 0 r
.60009 .54549 m
.61033 .55872 L
s
0 0 1 r
.38157 .49752 m
.39058 .48208 L
s
1 0 0 r
.60942 .48208 m
.61843 .49752 L
s
.50647 .37858 m
.51925 .39059 L
s
0 0 1 r
.48075 .39059 m
.49353 .37858 L
s
1 0 0 r
.41974 .40092 m
.43175 .41211 L
s
0 0 1 r
.56825 .41211 m
.58026 .40092 L
s
.38118 .53506 m
.39055 .52061 L
s
1 0 0 r
.60945 .52061 m
.61882 .53506 L
s
.43107 .39238 m
.44345 .40331 L
s
0 0 1 r
.55655 .40331 m
.56893 .39238 L
s
1 0 0 r
.4089 .4089 m
.42046 .42046 L
s
0 0 1 r
.4089 .5911 m
.42046 .57954 L
s
1 0 0 r
.57954 .57954 m
.5911 .5911 L
s
0 0 1 r
.57954 .42046 m
.5911 .4089 L
s
1 0 0 r
.59023 .43216 m
.60027 .44736 L
s
.57964 .41735 m
.59023 .43216 L
s
0 0 1 r
.40977 .43216 m
.42036 .41735 L
s
.39973 .44736 m
.40977 .43216 L
s
1 0 0 r
.48058 .37596 m
.49356 .38722 L
s
0 0 1 r
.50644 .38722 m
.51942 .37596 L
s
.39027 .4629 m
.39973 .44736 L
s
1 0 0 r
.60027 .44736 m
.60973 .4629 L
s
.53213 .38281 m
.54444 .3957 L
s
0 0 1 r
.45556 .3957 m
.46787 .38281 L
s
1 0 0 r
.44284 .38348 m
.45552 .39423 L
s
0 0 1 r
.54448 .39423 m
.55716 .38348 L
s
1 0 0 r
.56854 .40299 m
.57964 .41735 L
s
0 0 1 r
.42036 .41735 m
.43146 .40299 L
s
.3986 .58381 m
.40965 .5718 L
s
1 0 0 r
.59035 .5718 m
.6014 .58381 L
s
0 0 1 r
.38143 .47872 m
.39027 .4629 L
s
1 0 0 r
.60973 .4629 m
.61857 .47872 L
s
0 0 1 r
.38065 .5536 m
.39021 .53977 L
s
1 0 0 r
.60979 .53977 m
.61935 .5536 L
s
0 0 1 r
.37318 .51313 m
.38157 .49752 L
s
1 0 0 r
.61843 .49752 m
.62682 .51313 L
s
.55697 .38912 m
.56854 .40299 L
s
0 0 1 r
.43146 .40299 m
.44303 .38912 L
s
1 0 0 r
.455 .37437 m
.46791 .38505 L
s
0 0 1 r
.53209 .38505 m
.545 .37437 L
s
.3729 .53142 m
.38148 .51633 L
s
1 0 0 r
.61852 .51633 m
.6271 .53142 L
s
0 0 1 r
.38891 .57736 m
.39936 .56482 L
s
1 0 0 r
.60064 .56482 m
.61109 .57736 L
s
0 0 1 r
.37323 .49478 m
.38143 .47872 L
s
1 0 0 r
.61857 .47872 m
.62677 .49478 L
s
.51949 .37048 m
.53213 .38281 L
s
0 0 1 r
.46787 .38281 m
.48051 .37048 L
s
1 0 0 r
.49348 .36714 m
.50647 .37858 L
s
0 0 1 r
.49353 .37858 m
.50652 .36714 L
s
.38976 .44391 m
.3991 .42814 L
s
.38106 .46003 m
.38976 .44391 L
s
1 0 0 r
.61024 .44391 m
.61894 .46003 L
s
.6009 .42814 m
.61024 .44391 L
s
.59093 .41278 m
.6009 .42814 L
s
0 0 1 r
.3991 .42814 m
.40907 .41278 L
s
.37238 .54953 m
.38118 .53506 L
s
1 0 0 r
.61882 .53506 m
.62762 .54953 L
s
.54496 .3758 m
.55697 .38912 L
s
0 0 1 r
.44303 .38912 m
.45504 .3758 L
s
.37989 .57185 m
.38967 .55872 L
s
1 0 0 r
.61033 .55872 m
.62011 .57185 L
s
0 0 1 r
.37305 .47645 m
.38106 .46003 L
s
1 0 0 r
.61894 .46003 m
.62695 .47645 L
s
.46751 .36525 m
.48058 .37596 L
s
0 0 1 r
.51942 .37596 m
.53249 .36525 L
s
1 0 0 r
.58038 .39788 m
.59093 .41278 L
s
0 0 1 r
.40907 .41278 m
.41962 .39788 L
s
.36572 .51101 m
.37323 .49478 L
s
1 0 0 r
.62677 .49478 m
.63428 .51101 L
s
0 0 1 r
.36545 .52886 m
.37318 .51313 L
s
1 0 0 r
.62682 .51313 m
.63455 .52886 L
s
.40797 .39009 m
.41974 .40092 L
s
0 0 1 r
.58026 .40092 m
.59203 .39009 L
s
1 0 0 r
.41886 .38189 m
.43107 .39238 L
s
0 0 1 r
.56893 .39238 m
.58114 .38189 L
s
1 0 0 r
.39765 .39765 m
.4089 .4089 L
s
0 0 1 r
.39765 .60235 m
.4089 .5911 L
s
1 0 0 r
.5911 .5911 m
.60235 .60235 L
s
0 0 1 r
.5911 .4089 m
.60235 .39765 L
s
.36575 .49311 m
.37305 .47645 L
s
1 0 0 r
.62695 .47645 m
.63425 .49311 L
s
.43026 .37322 m
.44284 .38348 L
s
0 0 1 r
.55716 .38348 m
.56974 .37322 L
s
1 0 0 r
.56928 .3835 m
.58038 .39788 L
s
0 0 1 r
.41962 .39788 m
.43072 .3835 L
s
.37162 .56737 m
.38065 .5536 L
s
1 0 0 r
.61935 .5536 m
.62838 .56737 L
s
0 0 1 r
.36494 .54655 m
.3729 .53142 L
s
1 0 0 r
.6271 .53142 m
.63506 .54655 L
s
.50656 .35877 m
.51949 .37048 L
s
0 0 1 r
.48051 .37048 m
.49344 .35877 L
s
.38794 .59557 m
.3986 .58381 L
s
1 0 0 r
.6014 .58381 m
.61206 .59557 L
s
.53254 .36308 m
.54496 .3758 L
s
0 0 1 r
.45504 .3758 m
.46746 .36308 L
s
1 0 0 r
.48032 .35631 m
.49348 .36714 L
s
0 0 1 r
.50652 .36714 m
.51968 .35631 L
s
1 0 0 r
.61953 .44156 m
.62737 .45825 L
s
.61097 .42522 m
.61953 .44156 L
s
0 0 1 r
.38047 .44156 m
.38903 .42522 L
s
.37263 .45825 m
.38047 .44156 L
s
1 0 0 r
.44211 .36425 m
.455 .37437 L
s
0 0 1 r
.545 .37437 m
.55789 .36425 L
s
1 0 0 r
.60173 .4093 m
.61097 .42522 L
s
0 0 1 r
.38903 .42522 m
.39827 .4093 L
s
.36554 .47523 m
.37263 .45825 L
s
1 0 0 r
.62737 .45825 m
.63446 .47523 L
s
0 0 1 r
.35921 .50994 m
.36575 .49311 L
s
1 0 0 r
.63425 .49311 m
.64079 .50994 L
s
0 0 1 r
.35894 .52737 m
.36572 .51101 L
s
1 0 0 r
.63428 .51101 m
.64106 .52737 L
s
0 0 1 r
.37891 .5897 m
.38891 .57736 L
s
1 0 0 r
.61109 .57736 m
.62109 .5897 L
s
.55767 .36971 m
.56928 .3835 L
s
0 0 1 r
.43072 .3835 m
.44233 .36971 L
s
1 0 0 r
.59182 .39386 m
.60173 .4093 L
s
0 0 1 r
.39827 .4093 m
.40818 .39386 L
s
.35923 .49245 m
.36554 .47523 L
s
1 0 0 r
.63446 .47523 m
.64077 .49245 L
s
0 0 1 r
.36419 .56397 m
.37238 .54953 L
s
1 0 0 r
.62762 .54953 m
.63581 .56397 L
s
0 0 1 r
.35843 .54465 m
.36545 .52886 L
s
1 0 0 r
.63455 .52886 m
.64157 .54465 L
s
.45438 .35517 m
.46751 .36525 L
s
0 0 1 r
.53249 .36525 m
.54562 .35517 L
s
.37064 .58482 m
.37989 .57185 L
s
1 0 0 r
.62011 .57185 m
.62936 .58482 L
s
.58129 .37895 m
.59182 .39386 L
s
0 0 1 r
.40818 .39386 m
.41871 .37895 L
s
1 0 0 r
.51976 .35103 m
.53254 .36308 L
s
0 0 1 r
.46746 .36308 m
.48024 .35103 L
s
.35372 .50984 m
.35923 .49245 L
s
1 0 0 r
.64077 .49245 m
.64628 .50984 L
s
0 0 1 r
.35345 .5269 m
.35921 .50994 L
s
1 0 0 r
.64079 .50994 m
.64655 .5269 L
s
.62802 .44028 m
.63492 .4575 L
s
.62035 .42341 m
.62802 .44028 L
s
0 0 1 r
.37198 .44028 m
.37965 .42341 L
s
.36508 .4575 m
.37198 .44028 L
s
1 0 0 r
.49339 .34774 m
.50656 .35877 L
s
0 0 1 r
.49344 .35877 m
.50661 .34774 L
s
.35899 .47501 m
.36508 .4575 L
s
1 0 0 r
.63492 .4575 m
.64101 .47501 L
s
.54557 .35655 m
.55767 .36971 L
s
0 0 1 r
.44233 .36971 m
.45443 .35655 L
s
1 0 0 r
.61191 .40694 m
.62035 .42341 L
s
0 0 1 r
.37965 .42341 m
.38809 .40694 L
s
.35767 .56167 m
.36494 .54655 L
s
1 0 0 r
.63506 .54655 m
.64233 .56167 L
s
0 0 1 r
.35374 .49273 m
.35899 .47501 L
s
1 0 0 r
.64101 .47501 m
.64626 .49273 L
s
.40687 .37187 m
.41886 .38189 L
s
0 0 1 r
.58114 .38189 m
.59313 .37187 L
s
1 0 0 r
.39649 .37968 m
.40797 .39009 L
s
0 0 1 r
.59203 .39009 m
.60351 .37968 L
s
.35293 .5438 m
.35894 .52737 L
s
1 0 0 r
.64106 .52737 m
.64707 .5438 L
s
.41782 .36351 m
.43026 .37322 L
s
0 0 1 r
.56974 .37322 m
.58218 .36351 L
s
1 0 0 r
.38675 .38675 m
.39765 .39765 L
s
0 0 1 r
.38675 .61325 m
.39765 .60235 L
s
1 0 0 r
.60235 .60235 m
.61325 .61325 L
s
0 0 1 r
.60235 .39765 m
.61325 .38675 L
s
.36319 .58102 m
.37162 .56737 L
s
1 0 0 r
.62838 .56737 m
.63681 .58102 L
s
.46703 .34617 m
.48032 .35631 L
s
0 0 1 r
.51968 .35631 m
.53297 .34617 L
s
1 0 0 r
.60275 .39096 m
.61191 .40694 L
s
0 0 1 r
.38809 .40694 m
.39725 .39096 L
s
1 0 0 r
.57017 .36464 m
.58129 .37895 L
s
0 0 1 r
.41871 .37895 m
.42983 .36464 L
s
.34935 .5106 m
.35374 .49273 L
s
1 0 0 r
.64626 .49273 m
.65065 .5106 L
s
0 0 1 r
.34906 .52734 m
.35372 .50984 L
s
1 0 0 r
.64628 .50984 m
.65094 .52734 L
s
0 0 1 r
.37771 .60703 m
.38794 .59557 L
s
1 0 0 r
.61206 .59557 m
.62229 .60703 L
s
.4293 .35474 m
.44211 .36425 L
s
0 0 1 r
.55789 .36425 m
.5707 .35474 L
s
.35852 .4577 m
.36438 .44001 L
s
.35351 .47565 m
.35852 .4577 L
s
1 0 0 r
.64148 .4577 m
.64649 .47565 L
s
.63562 .44001 m
.64148 .4577 L
s
.62891 .42265 m
.63562 .44001 L
s
0 0 1 r
.36438 .44001 m
.37109 .42265 L
s
.35215 .56044 m
.35843 .54465 L
s
1 0 0 r
.64157 .54465 m
.64785 .56044 L
s
0 0 1 r
.34938 .4938 m
.35351 .47565 L
s
1 0 0 r
.64649 .47565 m
.65062 .4938 L
s
0 0 1 r
.34852 .54391 m
.35345 .5269 L
s
1 0 0 r
.64655 .5269 m
.65148 .54391 L
s
.59289 .37551 m
.60275 .39096 L
s
0 0 1 r
.39725 .39096 m
.40711 .37551 L
s
.35667 .57832 m
.36419 .56397 L
s
1 0 0 r
.63581 .56397 m
.64333 .57832 L
s
.50666 .33971 m
.51976 .35103 L
s
0 0 1 r
.48024 .35103 m
.49334 .33971 L
s
1 0 0 r
.62139 .40568 m
.62891 .42265 L
s
0 0 1 r
.37109 .42265 m
.37861 .40568 L
s
1 0 0 r
.53302 .34409 m
.54557 .35655 L
s
0 0 1 r
.45443 .35655 m
.46698 .34409 L
s
.36942 .60178 m
.37891 .5897 L
s
1 0 0 r
.62109 .5897 m
.63058 .60178 L
s
0 0 1 r
.34615 .51206 m
.34938 .4938 L
s
1 0 0 r
.65062 .4938 m
.65385 .51206 L
s
0 0 1 r
.34584 .52855 m
.34935 .5106 L
s
1 0 0 r
.65065 .5106 m
.65416 .52855 L
s
.44126 .34577 m
.45438 .35517 L
s
0 0 1 r
.54562 .35517 m
.55874 .34577 L
s
1 0 0 r
.48001 .33744 m
.49339 .34774 L
s
0 0 1 r
.50661 .34774 m
.51999 .33744 L
s
1 0 0 r
.55848 .35099 m
.57017 .36464 L
s
0 0 1 r
.42983 .36464 m
.44152 .35099 L
s
.34916 .47703 m
.35302 .45872 L
s
.34621 .4955 m
.34916 .47703 L
s
1 0 0 r
.65084 .47703 m
.65379 .4955 L
s
.64698 .45872 m
.65084 .47703 L
s
.64221 .44064 m
.64698 .45872 L
s
0 0 1 r
.35302 .45872 m
.35779 .44064 L
s
.34527 .54487 m
.34906 .52734 L
s
1 0 0 r
.65094 .52734 m
.65473 .54487 L
s
0 0 1 r
.34772 .56022 m
.35293 .5438 L
s
1 0 0 r
.64707 .5438 m
.65228 .56022 L
s
.61307 .38919 m
.62139 .40568 L
s
0 0 1 r
.37861 .40568 m
.38693 .38919 L
s
.3442 .51405 m
.34621 .4955 L
s
1 0 0 r
.65379 .4955 m
.6558 .51405 L
s
.63655 .42287 m
.64221 .44064 L
s
0 0 1 r
.35779 .44064 m
.36345 .42287 L
s
.34385 .53038 m
.34615 .51206 L
s
1 0 0 r
.65385 .51206 m
.65615 .53038 L
s
0 0 1 r
.36196 .59758 m
.37064 .58482 L
s
1 0 0 r
.62936 .58482 m
.63804 .59758 L
s
0 0 1 r
.35113 .57671 m
.35767 .56167 L
s
1 0 0 r
.64233 .56167 m
.64887 .57671 L
s
.58236 .36068 m
.59289 .37551 L
s
0 0 1 r
.40711 .37551 m
.41764 .36068 L
s
1 0 0 r
.65399 .47896 m
.65571 .49764 L
s
.65132 .4604 m
.65399 .47896 L
s
0 0 1 r
.34601 .47896 m
.34868 .4604 L
s
.34429 .49764 m
.34601 .47896 L
s
.34352 .51636 m
.34429 .49764 L
s
1 0 0 r
.65571 .49764 m
.65648 .51636 L
s
.64771 .44204 m
.65132 .4604 L
s
0 0 1 r
.34868 .4604 m
.35229 .44204 L
s
.34313 .53262 m
.3442 .51405 L
s
1 0 0 r
.6558 .51405 m
.65687 .53262 L
s
0 0 1 r
.34324 .54652 m
.34584 .52855 L
s
1 0 0 r
.65416 .52855 m
.65676 .54652 L
s
.63003 .40546 m
.63655 .42287 L
s
0 0 1 r
.36345 .42287 m
.36997 .40546 L
s
1 0 0 r
.45367 .33677 m
.46703 .34617 L
s
0 0 1 r
.53297 .34617 m
.54633 .33677 L
s
.3437 .53505 m
.34352 .51636 L
s
1 0 0 r
.65648 .51636 m
.6563 .53505 L
s
0 0 1 r
.34444 .56092 m
.34852 .54391 L
s
1 0 0 r
.65148 .54391 m
.65556 .56092 L
s
.60398 .37323 m
.61307 .38919 L
s
0 0 1 r
.38693 .38919 m
.39602 .37323 L
s
1 0 0 r
.39514 .3624 m
.40687 .37187 L
s
0 0 1 r
.59313 .37187 m
.60486 .3624 L
s
1 0 0 r
.64318 .42394 m
.64771 .44204 L
s
0 0 1 r
.35229 .44204 m
.35682 .42394 L
s
1 0 0 r
.38536 .36974 m
.39649 .37968 L
s
0 0 1 r
.60351 .37968 m
.61464 .36974 L
s
.35541 .59449 m
.36319 .58102 L
s
1 0 0 r
.63681 .58102 m
.64459 .59449 L
s
0 0 1 r
.34249 .54867 m
.34385 .53038 L
s
1 0 0 r
.65615 .53038 m
.65751 .54867 L
s
.40557 .3544 m
.41782 .36351 L
s
0 0 1 r
.58218 .36351 m
.59443 .3544 L
s
1 0 0 r
.52008 .3324 m
.53302 .34409 L
s
0 0 1 r
.46698 .34409 m
.47992 .3324 L
s
.34667 .57617 m
.35215 .56044 L
s
1 0 0 r
.64785 .56044 m
.65333 .57617 L
s
.54627 .33808 m
.55848 .35099 L
s
0 0 1 r
.44152 .35099 m
.45373 .33808 L
s
1 0 0 r
.37628 .37628 m
.38675 .38675 L
s
0 0 1 r
.37628 .62372 m
.38675 .61325 L
s
1 0 0 r
.61325 .61325 m
.62372 .62372 L
s
0 0 1 r
.61325 .38675 m
.62372 .37628 L
s
.34485 .55363 m
.3437 .53505 L
s
1 0 0 r
.6563 .53505 m
.65515 .55363 L
s
0 0 1 r
.34302 .55112 m
.34313 .53262 L
s
1 0 0 r
.65687 .53262 m
.65698 .55112 L
s
.49328 .32917 m
.50666 .33971 L
s
0 0 1 r
.49334 .33971 m
.50672 .32917 L
s
1 0 0 r
.62265 .38851 m
.63003 .40546 L
s
0 0 1 r
.36997 .40546 m
.37735 .38851 L
s
.34238 .56238 m
.34527 .54487 L
s
1 0 0 r
.65473 .54487 m
.65762 .56238 L
s
.4166 .34591 m
.4293 .35474 L
s
0 0 1 r
.5707 .35474 m
.5834 .34591 L
s
1 0 0 r
.57119 .34653 m
.58236 .36068 L
s
0 0 1 r
.41764 .36068 m
.42881 .34653 L
s
1 0 0 r
.63773 .40618 m
.64318 .42394 L
s
0 0 1 r
.35682 .42394 m
.36227 .40618 L
s
.36796 .61812 m
.37771 .60703 L
s
1 0 0 r
.62229 .60703 m
.63204 .61812 L
s
0 0 1 r
.34986 .59252 m
.35667 .57832 L
s
1 0 0 r
.64333 .57832 m
.65014 .59252 L
s
0 0 1 r
.34159 .56443 m
.34324 .54652 L
s
1 0 0 r
.65676 .54652 m
.65841 .56443 L
s
0 0 1 r
.34336 .57658 m
.34772 .56022 L
s
1 0 0 r
.65228 .56022 m
.65664 .57658 L
s
.46649 .32795 m
.48001 .33744 L
s
0 0 1 r
.51999 .33744 m
.53351 .32795 L
s
1 0 0 r
.59415 .35788 m
.60398 .37323 L
s
0 0 1 r
.39602 .37323 m
.40585 .35788 L
s
.34697 .57204 m
.34485 .55363 L
s
1 0 0 r
.65515 .55363 m
.65303 .57204 L
s
0 0 1 r
.34209 .56688 m
.34249 .54867 L
s
1 0 0 r
.65751 .54867 m
.65791 .56688 L
s
.42819 .3371 m
.44126 .34577 L
s
0 0 1 r
.55874 .34577 m
.57181 .3371 L
s
.34389 .56949 m
.34302 .55112 L
s
1 0 0 r
.65698 .55112 m
.65611 .56949 L
s
0 0 1 r
.36048 .61355 m
.36942 .60178 L
s
1 0 0 r
.63058 .60178 m
.63952 .61355 L
s
.61443 .37208 m
.62265 .38851 L
s
0 0 1 r
.37735 .38851 m
.38557 .37208 L
s
1 0 0 r
.63138 .38884 m
.63773 .40618 L
s
0 0 1 r
.36227 .40618 m
.36862 .38884 L
s
.34127 .57784 m
.34444 .56092 L
s
1 0 0 r
.65556 .56092 m
.65873 .57784 L
s
0 0 1 r
.34537 .59163 m
.35113 .57671 L
s
1 0 0 r
.64887 .57671 m
.65463 .59163 L
s
.53358 .32597 m
.54627 .33808 L
s
0 0 1 r
.45373 .33808 m
.46642 .32597 L
s
1 0 0 r
.50677 .32155 m
.52008 .3324 L
s
0 0 1 r
.47992 .3324 m
.49323 .32155 L
s
.35392 .61008 m
.36196 .59758 L
s
1 0 0 r
.63804 .59758 m
.64608 .61008 L
s
0 0 1 r
.35006 .59018 m
.34697 .57204 L
s
1 0 0 r
.65303 .57204 m
.64994 .59018 L
s
.55942 .33313 m
.57119 .34653 L
s
0 0 1 r
.42881 .34653 m
.44058 .33313 L
s
.34043 .57978 m
.34238 .56238 L
s
1 0 0 r
.65762 .56238 m
.65957 .57978 L
s
.44029 .32817 m
.45367 .33677 L
s
0 0 1 r
.54633 .33677 m
.55971 .32817 L
s
1 0 0 r
.5836 .34322 m
.59415 .35788 L
s
0 0 1 r
.40585 .35788 m
.4164 .34322 L
s
.34574 .58764 m
.34389 .56949 L
s
1 0 0 r
.65611 .56949 m
.65426 .58764 L
s
.47966 .31949 m
.49328 .32917 L
s
0 0 1 r
.50672 .32917 m
.52034 .31949 L
s
.3409 .58221 m
.34159 .56443 L
s
1 0 0 r
.65841 .56443 m
.6591 .58221 L
s
0 0 1 r
.34203 .59176 m
.34667 .57617 L
s
1 0 0 r
.65333 .57617 m
.65797 .59176 L
s
0 0 1 r
.34267 .5849 m
.34209 .56688 L
s
1 0 0 r
.65791 .56688 m
.65733 .5849 L
s
.60541 .35624 m
.61443 .37208 L
s
0 0 1 r
.38557 .37208 m
.39459 .35624 L
s
1 0 0 r
.62414 .372 m
.63138 .38884 L
s
0 0 1 r
.36862 .38884 m
.37586 .372 L
s
.34834 .60773 m
.35541 .59449 L
s
1 0 0 r
.64459 .59449 m
.65166 .60773 L
s
.38375 .35353 m
.39514 .3624 L
s
0 0 1 r
.60486 .3624 m
.61625 .35353 L
s
1 0 0 r
.37463 .36035 m
.38536 .36974 L
s
0 0 1 r
.61464 .36974 m
.62537 .36035 L
s
1 0 0 r
.39359 .34596 m
.40557 .3544 L
s
0 0 1 r
.59443 .3544 m
.60641 .34596 L
s
.3399 .59281 m
.34336 .57658 L
s
1 0 0 r
.65664 .57658 m
.6601 .59281 L
s
0 0 1 r
.35414 .60798 m
.35006 .59018 L
s
1 0 0 r
.64994 .59018 m
.64586 .60798 L
s
.36628 .36628 m
.37628 .37628 L
s
0 0 1 r
.36628 .63372 m
.37628 .62372 L
s
1 0 0 r
.62372 .62372 m
.63372 .63372 L
s
0 0 1 r
.62372 .37628 m
.63372 .36628 L
s
1 0 0 r
.4041 .33781 m
.4166 .34591 L
s
0 0 1 r
.5834 .34591 m
.5959 .33781 L
s
1 0 0 r
.45286 .31932 m
.46649 .32795 L
s
0 0 1 r
.53351 .32795 m
.54714 .31932 L
s
.34382 .6065 m
.34986 .59252 L
s
1 0 0 r
.65014 .59252 m
.65618 .6065 L
s
0 0 1 r
.33903 .59462 m
.34127 .57784 L
s
1 0 0 r
.65873 .57784 m
.66097 .59462 L
s
.54707 .32055 m
.55942 .33313 L
s
0 0 1 r
.44058 .33313 m
.45293 .32055 L
s
.35877 .62879 m
.36796 .61812 L
s
1 0 0 r
.63204 .61812 m
.64123 .62879 L
s
.52044 .31474 m
.53358 .32597 L
s
0 0 1 r
.46642 .32597 m
.47956 .31474 L
s
.34858 .60549 m
.34574 .58764 L
s
1 0 0 r
.65426 .58764 m
.65142 .60549 L
s
.57237 .32932 m
.5836 .34322 L
s
0 0 1 r
.4164 .34322 m
.42763 .32932 L
s
1 0 0 r
.41523 .32924 m
.42819 .3371 L
s
0 0 1 r
.57181 .3371 m
.58477 .32924 L
s
1 0 0 r
.59559 .34109 m
.60541 .35624 L
s
0 0 1 r
.39459 .35624 m
.40441 .34109 L
s
1 0 0 r
.61601 .35574 m
.62414 .372 L
s
0 0 1 r
.37586 .372 m
.38399 .35574 L
s
.33946 .59701 m
.34043 .57978 L
s
1 0 0 r
.65957 .57978 m
.66054 .59701 L
s
.49315 .3116 m
.50677 .32155 L
s
0 0 1 r
.49323 .32155 m
.50685 .3116 L
s
.34425 .60267 m
.34267 .5849 L
s
1 0 0 r
.65733 .5849 m
.65575 .60267 L
s
0 0 1 r
.3412 .59977 m
.3409 .58221 L
s
1 0 0 r
.6591 .58221 m
.6588 .59977 L
s
0 0 1 r
.34045 .60634 m
.34537 .59163 L
s
1 0 0 r
.65463 .59163 m
.65955 .60634 L
s
0 0 1 r
.35218 .62494 m
.36048 .61355 L
s
1 0 0 r
.63952 .61355 m
.64782 .62494 L
s
0 0 1 r
.35919 .62536 m
.35414 .60798 L
s
1 0 0 r
.64586 .60798 m
.64081 .62536 L
s
.46587 .31074 m
.47966 .31949 L
s
0 0 1 r
.52034 .31949 m
.53413 .31074 L
s
1 0 0 r
.42694 .32044 m
.44029 .32817 L
s
0 0 1 r
.55971 .32817 m
.57306 .32044 L
s
.33828 .60716 m
.34203 .59176 L
s
1 0 0 r
.65797 .59176 m
.66172 .60716 L
s
0 0 1 r
.34657 .62223 m
.35392 .61008 L
s
1 0 0 r
.64608 .61008 m
.65343 .62223 L
s
0 0 1 r
.35243 .62296 m
.34858 .60549 L
s
1 0 0 r
.65142 .60549 m
.64757 .62296 L
s
0 0 1 r
.33737 .60882 m
.3399 .59281 L
s
1 0 0 r
.6601 .59281 m
.66263 .60882 L
s
.60703 .34015 m
.61601 .35574 L
s
0 0 1 r
.38399 .35574 m
.39297 .34015 L
s
1 0 0 r
.56048 .31626 m
.57237 .32932 L
s
0 0 1 r
.42763 .32932 m
.43952 .31626 L
s
1 0 0 r
.585 .32671 m
.59559 .34109 L
s
0 0 1 r
.40441 .34109 m
.415 .32671 L
s
1 0 0 r
.5342 .30889 m
.54707 .32055 L
s
0 0 1 r
.45293 .32055 m
.4658 .30889 L
s
.34203 .62066 m
.34834 .60773 L
s
1 0 0 r
.65166 .60773 m
.65797 .62066 L
s
.5069 .30445 m
.52044 .31474 L
s
0 0 1 r
.47956 .31474 m
.4931 .30445 L
s
.34685 .6201 m
.34425 .60267 L
s
1 0 0 r
.65575 .60267 m
.65315 .6201 L
s
0 0 1 r
.33776 .61116 m
.33903 .59462 L
s
1 0 0 r
.66097 .59462 m
.66224 .61116 L
s
.4392 .31163 m
.45286 .31932 L
s
0 0 1 r
.54714 .31932 m
.5608 .31163 L
s
1 0 0 r
.37275 .34533 m
.38375 .35353 L
s
0 0 1 r
.61625 .35353 m
.62725 .34533 L
s
1 0 0 r
.38193 .33826 m
.39359 .34596 L
s
0 0 1 r
.60641 .34596 m
.61807 .33826 L
s
.34252 .61703 m
.3412 .59977 L
s
1 0 0 r
.6588 .59977 m
.65748 .61703 L
s
0 0 1 r
.33948 .61397 m
.33946 .59701 L
s
1 0 0 r
.66054 .59701 m
.66052 .61397 L
s
.36437 .35156 m
.37463 .36035 L
s
0 0 1 r
.62537 .36035 m
.63563 .35156 L
s
1 0 0 r
.39184 .33051 m
.4041 .33781 L
s
0 0 1 r
.5959 .33781 m
.60816 .33051 L
s
1 0 0 r
.47927 .30264 m
.49315 .3116 L
s
0 0 1 r
.50685 .3116 m
.52073 .30264 L
s
.36522 .64221 m
.35919 .62536 L
s
1 0 0 r
.64081 .62536 m
.63478 .64221 L
s
0 0 1 r
.33862 .6202 m
.34382 .6065 L
s
1 0 0 r
.65618 .6065 m
.66138 .6202 L
s
.35683 .35683 m
.36628 .36628 L
s
0 0 1 r
.35683 .64317 m
.36628 .63372 L
s
1 0 0 r
.63372 .63372 m
.64317 .64317 L
s
0 0 1 r
.63372 .36628 m
.64317 .35683 L
s
1 0 0 r
.40244 .32224 m
.41523 .32924 L
s
0 0 1 r
.58477 .32924 m
.59756 .32224 L
s
.3502 .63897 m
.35877 .62879 L
s
1 0 0 r
.64123 .62879 m
.6498 .63897 L
s
0 0 1 r
.33641 .62077 m
.34045 .60634 L
s
1 0 0 r
.65955 .60634 m
.66359 .62077 L
s
0 0 1 r
.35729 .63995 m
.35243 .62296 L
s
1 0 0 r
.64757 .62296 m
.64271 .63995 L
s
.45196 .30299 m
.46587 .31074 L
s
0 0 1 r
.53413 .31074 m
.54804 .30299 L
s
1 0 0 r
.59721 .32531 m
.60703 .34015 L
s
0 0 1 r
.39297 .34015 m
.40279 .32531 L
s
1 0 0 r
.57368 .31317 m
.585 .32671 L
s
0 0 1 r
.415 .32671 m
.42632 .31317 L
s
1 0 0 r
.54797 .30413 m
.56048 .31626 L
s
0 0 1 r
.43952 .31626 m
.45203 .30413 L
s
.34456 .63589 m
.35218 .62494 L
s
1 0 0 r
.64782 .62494 m
.65544 .63589 L
s
.41369 .31366 m
.42694 .32044 L
s
0 0 1 r
.57306 .32044 m
.58631 .31366 L
s
.33547 .62227 m
.33828 .60716 L
s
1 0 0 r
.66172 .60716 m
.66453 .62227 L
s
.52084 .29821 m
.5342 .30889 L
s
0 0 1 r
.4658 .30889 m
.47916 .29821 L
s
.35049 .6371 m
.34685 .6201 L
s
1 0 0 r
.65315 .6201 m
.64951 .6371 L
s
.49302 .2952 m
.5069 .30445 L
s
0 0 1 r
.4931 .30445 m
.50698 .2952 L
s
.33583 .62454 m
.33737 .60882 L
s
1 0 0 r
.66263 .60882 m
.66417 .62454 L
s
0 0 1 r
.37223 .65846 m
.36522 .64221 L
s
1 0 0 r
.63478 .64221 m
.62777 .65846 L
s
0 0 1 r
.33999 .63397 m
.34657 .62223 L
s
1 0 0 r
.65343 .62223 m
.66001 .63397 L
s
0 0 1 r
.34488 .6339 m
.34252 .61703 L
s
1 0 0 r
.65748 .61703 m
.65512 .6339 L
s
0 0 1 r
.33752 .62738 m
.33776 .61116 L
s
1 0 0 r
.66224 .61116 m
.66248 .62738 L
s
0 0 1 r
.34054 .63058 m
.33948 .61397 L
s
1 0 0 r
.66052 .61397 m
.65946 .63058 L
s
.42555 .30494 m
.4392 .31163 L
s
0 0 1 r
.5608 .31163 m
.57445 .30494 L
s
1 0 0 r
.46519 .29473 m
.47927 .30264 L
s
0 0 1 r
.52073 .30264 m
.53481 .29473 L
s
.33654 .6332 m
.34203 .62066 L
s
1 0 0 r
.65797 .62066 m
.66346 .6332 L
s
0 0 1 r
.36318 .65637 m
.35729 .63995 L
s
1 0 0 r
.64271 .63995 m
.63682 .65637 L
s
.58656 .31131 m
.59721 .32531 L
s
0 0 1 r
.40279 .32531 m
.41344 .31131 L
s
1 0 0 r
.37067 .33136 m
.38193 .33826 L
s
0 0 1 r
.61807 .33826 m
.62933 .33136 L
s
1 0 0 r
.36223 .33786 m
.37275 .34533 L
s
0 0 1 r
.62725 .34533 m
.63777 .33786 L
s
1 0 0 r
.56166 .30057 m
.57368 .31317 L
s
0 0 1 r
.42632 .31317 m
.43834 .30057 L
s
1 0 0 r
.37991 .32408 m
.39184 .33051 L
s
0 0 1 r
.60816 .33051 m
.62009 .32408 L
s
1 0 0 r
.35465 .34344 m
.36437 .35156 L
s
0 0 1 r
.63563 .35156 m
.64535 .34344 L
s
.3343 .63353 m
.33862 .6202 L
s
1 0 0 r
.66138 .6202 m
.6657 .63353 L
s
.53489 .29302 m
.54797 .30413 L
s
0 0 1 r
.45203 .30413 m
.46511 .29302 L
s
1 0 0 r
.34799 .34799 m
.35683 .35683 L
s
0 0 1 r
.34799 .65201 m
.35683 .64317 L
s
1 0 0 r
.64317 .64317 m
.65201 .65201 L
s
0 0 1 r
.64317 .35683 m
.65201 .34799 L
s
1 0 0 r
.3899 .3162 m
.40244 .32224 L
s
0 0 1 r
.59756 .32224 m
.6101 .3162 L
s
1 0 0 r
.43798 .29631 m
.45196 .30299 L
s
0 0 1 r
.54804 .30299 m
.56202 .29631 L
s
.35517 .65357 m
.35049 .6371 L
s
1 0 0 r
.64951 .6371 m
.64483 .65357 L
s
.50704 .2886 m
.52084 .29821 L
s
0 0 1 r
.47916 .29821 m
.49296 .2886 L
s
.33332 .63484 m
.33641 .62077 L
s
1 0 0 r
.66359 .62077 m
.66668 .63484 L
s
0 0 1 r
.3802 .67401 m
.37223 .65846 L
s
1 0 0 r
.62777 .65846 m
.6198 .67401 L
s
0 0 1 r
.34232 .64858 m
.3502 .63897 L
s
1 0 0 r
.6498 .63897 m
.65768 .64858 L
s
0 0 1 r
.34831 .65029 m
.34488 .6339 L
s
1 0 0 r
.65512 .6339 m
.65169 .65029 L
s
.47884 .28705 m
.49302 .2952 L
s
0 0 1 r
.50698 .2952 m
.52116 .28705 L
s
.33365 .63702 m
.33547 .62227 L
s
1 0 0 r
.66453 .62227 m
.66635 .63702 L
s
.40061 .30789 m
.41369 .31366 L
s
0 0 1 r
.58631 .31366 m
.59939 .30789 L
s
.33532 .63987 m
.33583 .62454 L
s
1 0 0 r
.66417 .62454 m
.66468 .63987 L
s
0 0 1 r
.34267 .64674 m
.34054 .63058 L
s
1 0 0 r
.65946 .63058 m
.65733 .64674 L
s
0 0 1 r
.33833 .64319 m
.33752 .62738 L
s
1 0 0 r
.66248 .62738 m
.66167 .64319 L
s
0 0 1 r
.33771 .64632 m
.34456 .63589 L
s
1 0 0 r
.65544 .63589 m
.66229 .64632 L
s
.57514 .29826 m
.58656 .31131 L
s
0 0 1 r
.41344 .31131 m
.42486 .29826 L
s
.37008 .67212 m
.36318 .65637 L
s
1 0 0 r
.63682 .65637 m
.62992 .67212 L
s
.45096 .28796 m
.46519 .29473 L
s
0 0 1 r
.53481 .29473 m
.54904 .28796 L
s
.33424 .64523 m
.33999 .63397 L
s
1 0 0 r
.66001 .63397 m
.66576 .64523 L
s
.54897 .28901 m
.56166 .30057 L
s
0 0 1 r
.43834 .30057 m
.45103 .28901 L
s
1 0 0 r
.41199 .29935 m
.42555 .30494 L
s
0 0 1 r
.57445 .30494 m
.58801 .29935 L
s
1 0 0 r
.52129 .28301 m
.53489 .29302 L
s
0 0 1 r
.46511 .29302 m
.47871 .28301 L
s
.33196 .64528 m
.33654 .6332 L
s
1 0 0 r
.66346 .6332 m
.66804 .64528 L
s
0 0 1 r
.36092 .66942 m
.35517 .65357 L
s
1 0 0 r
.64483 .65357 m
.63908 .66942 L
s
0 0 1 r
.38914 .68875 m
.3802 .67401 L
s
1 0 0 r
.6198 .67401 m
.61086 .68875 L
s
.49287 .28015 m
.50704 .2886 L
s
0 0 1 r
.49296 .2886 m
.50713 .28015 L
s
1 0 0 r
.35987 .32534 m
.37067 .33136 L
s
0 0 1 r
.62933 .33136 m
.64013 .32534 L
s
1 0 0 r
.35225 .33121 m
.36223 .33786 L
s
0 0 1 r
.63777 .33786 m
.64775 .33121 L
s
.33095 .6464 m
.3343 .63353 L
s
1 0 0 r
.6657 .63353 m
.66905 .6464 L
s
.42402 .29078 m
.43798 .29631 L
s
0 0 1 r
.56202 .29631 m
.57598 .29078 L
s
1 0 0 r
.36837 .31861 m
.37991 .32408 L
s
0 0 1 r
.62009 .32408 m
.63163 .31861 L
s
.35282 .66609 m
.34831 .65029 L
s
1 0 0 r
.65169 .65029 m
.64718 .66609 L
s
.34555 .33608 m
.35465 .34344 L
s
0 0 1 r
.64535 .34344 m
.65445 .33608 L
s
1 0 0 r
.46443 .28011 m
.47884 .28705 L
s
0 0 1 r
.52116 .28705 m
.53557 .28011 L
s
1 0 0 r
.37768 .31117 m
.3899 .3162 L
s
0 0 1 r
.6101 .3162 m
.62232 .31117 L
s
.33124 .64847 m
.33332 .63484 L
s
1 0 0 r
.66668 .63484 m
.66876 .64847 L
s
.33985 .33985 m
.34799 .34799 L
s
0 0 1 r
.33985 .66015 m
.34799 .65201 L
s
1 0 0 r
.65201 .65201 m
.66015 .66015 L
s
0 0 1 r
.65201 .34799 m
.66015 .33985 L
s
.3459 .66236 m
.34267 .64674 L
s
1 0 0 r
.65733 .64674 m
.6541 .66236 L
s
.56295 .28624 m
.57514 .29826 L
s
0 0 1 r
.42486 .29826 m
.43705 .28624 L
s
.33289 .6513 m
.33365 .63702 L
s
1 0 0 r
.66635 .63702 m
.66711 .6513 L
s
0 0 1 r
.37801 .6871 m
.37008 .67212 L
s
1 0 0 r
.62992 .67212 m
.62199 .6871 L
s
0 0 1 r
.34024 .65849 m
.33833 .64319 L
s
1 0 0 r
.66167 .64319 m
.65976 .65849 L
s
0 0 1 r
.33589 .65472 m
.33532 .63987 L
s
1 0 0 r
.66468 .63987 m
.66411 .65472 L
s
.38777 .30321 m
.40061 .30789 L
s
0 0 1 r
.59939 .30789 m
.61223 .30321 L
s
1 0 0 r
.53565 .27857 m
.54897 .28901 L
s
0 0 1 r
.45103 .28901 m
.46435 .27857 L
s
.33521 .65754 m
.34232 .64858 L
s
1 0 0 r
.65768 .64858 m
.66479 .65754 L
s
.43666 .28241 m
.45096 .28796 L
s
0 0 1 r
.54904 .28796 m
.56334 .28241 L
s
1 0 0 r
.5072 .2742 m
.52129 .28301 L
s
0 0 1 r
.47871 .28301 m
.4928 .2742 L
s
.3317 .65613 m
.33771 .64632 L
s
1 0 0 r
.66229 .64632 m
.6683 .65613 L
s
.61086 .68875 m
.60097 .70258 L
s
0 0 1 r
.39903 .70258 m
.38914 .68875 L
s
1 0 0 r
.3986 .29492 m
.41199 .29935 L
s
0 0 1 r
.58801 .29935 m
.6014 .29492 L
s
.36773 .68452 m
.36092 .66942 L
s
1 0 0 r
.63908 .66942 m
.63227 .68452 L
s
.47837 .27295 m
.49287 .28015 L
s
0 0 1 r
.50713 .28015 m
.52163 .27295 L
s
.32939 .65591 m
.33424 .64523 L
s
1 0 0 r
.66576 .64523 m
.67061 .65591 L
s
0 0 1 r
.35844 .68119 m
.35282 .66609 L
s
1 0 0 r
.64718 .66609 m
.64156 .68119 L
s
0 0 1 r
.32835 .65681 m
.33196 .64528 L
s
1 0 0 r
.66804 .64528 m
.67165 .65681 L
s
.41014 .28649 m
.42402 .29078 L
s
0 0 1 r
.57598 .29078 m
.58986 .28649 L
s
1 0 0 r
.44987 .27444 m
.46443 .28011 L
s
0 0 1 r
.53557 .28011 m
.55013 .27444 L
s
1 0 0 r
.55005 .27537 m
.56295 .28624 L
s
0 0 1 r
.43705 .28624 m
.44995 .27537 L
s
.38694 .7012 m
.37801 .6871 L
s
1 0 0 r
.62199 .6871 m
.61306 .7012 L
s
0 0 1 r
.32861 .65874 m
.33095 .6464 L
s
1 0 0 r
.66905 .6464 m
.67139 .65874 L
s
0 0 1 r
.35025 .67733 m
.3459 .66236 L
s
1 0 0 r
.6541 .66236 m
.64975 .67733 L
s
.34963 .32029 m
.35987 .32534 L
s
0 0 1 r
.64013 .32534 m
.65037 .32029 L
s
1 0 0 r
.35731 .31417 m
.36837 .31861 L
s
0 0 1 r
.63163 .31861 m
.64269 .31417 L
s
1 0 0 r
.52177 .26936 m
.53565 .27857 L
s
0 0 1 r
.46435 .27857 m
.47823 .26936 L
s
1 0 0 r
.3429 .32545 m
.35225 .33121 L
s
0 0 1 r
.64775 .33121 m
.6571 .32545 L
s
.33023 .66154 m
.33124 .64847 L
s
1 0 0 r
.66876 .64847 m
.66977 .66154 L
s
.36587 .30725 m
.37768 .31117 L
s
0 0 1 r
.62232 .31117 m
.63413 .30725 L
s
.34328 .67317 m
.34024 .65849 L
s
1 0 0 r
.65976 .65849 m
.65672 .67317 L
s
.33717 .32955 m
.34555 .33608 L
s
0 0 1 r
.65445 .33608 m
.66283 .32955 L
s
.33323 .66503 m
.33289 .6513 L
s
1 0 0 r
.66711 .6513 m
.66677 .66503 L
s
0 0 1 r
.33758 .66899 m
.33589 .65472 L
s
1 0 0 r
.66411 .65472 m
.66242 .66899 L
s
.4927 .26668 m
.5072 .2742 L
s
0 0 1 r
.4928 .2742 m
.5073 .26668 L
s
1 0 0 r
.60097 .70258 m
.59017 .71538 L
s
0 0 1 r
.40983 .71538 m
.39903 .70258 L
s
1 0 0 r
.33249 .33249 m
.33985 .33985 L
s
0 0 1 r
.33249 .66751 m
.33985 .66015 L
s
1 0 0 r
.66015 .66015 m
.66751 .66751 L
s
0 0 1 r
.66015 .33985 m
.66751 .33249 L
s
1 0 0 r
.37526 .29971 m
.38777 .30321 L
s
0 0 1 r
.61223 .30321 m
.62474 .29971 L
s
1 0 0 r
.42235 .27816 m
.43666 .28241 L
s
0 0 1 r
.56334 .28241 m
.57765 .27816 L
s
.37561 .69878 m
.36773 .68452 L
s
1 0 0 r
.63227 .68452 m
.62439 .69878 L
s
0 0 1 r
.32895 .66577 m
.33521 .65754 L
s
1 0 0 r
.66479 .65754 m
.67105 .66577 L
s
.46361 .26708 m
.47837 .27295 L
s
0 0 1 r
.52163 .27295 m
.53639 .26708 L
s
1 0 0 r
.38546 .29173 m
.3986 .29492 L
s
0 0 1 r
.6014 .29492 m
.61454 .29173 L
s
.32661 .66526 m
.3317 .65613 L
s
1 0 0 r
.6683 .65613 m
.67339 .66526 L
s
0 0 1 r
.36517 .69549 m
.35844 .68119 L
s
1 0 0 r
.64156 .68119 m
.63483 .69549 L
s
.53648 .26574 m
.55005 .27537 L
s
0 0 1 r
.44995 .27537 m
.46352 .26574 L
s
1 0 0 r
.61306 .7012 m
.60312 .7143 L
s
0 0 1 r
.39688 .7143 m
.38694 .7012 L
s
1 0 0 r
.43521 .27014 m
.44987 .27444 L
s
0 0 1 r
.55013 .27444 m
.56479 .27014 L
s
.32554 .66593 m
.32939 .65591 L
s
1 0 0 r
.67061 .65591 m
.67446 .66593 L
s
.39643 .28352 m
.41014 .28649 L
s
0 0 1 r
.58986 .28649 m
.60357 .28352 L
s
1 0 0 r
.50737 .26147 m
.52177 .26936 L
s
0 0 1 r
.47823 .26936 m
.49263 .26147 L
s
.35576 .69152 m
.35025 .67733 L
s
1 0 0 r
.64975 .67733 m
.64424 .69152 L
s
0 0 1 r
.32578 .66769 m
.32835 .65681 L
s
1 0 0 r
.67165 .65681 m
.67422 .66769 L
s
.47785 .26055 m
.4927 .26668 L
s
0 0 1 r
.5073 .26668 m
.52215 .26055 L
s
1 0 0 r
.59017 .71538 m
.57846 .72706 L
s
0 0 1 r
.42154 .72706 m
.40983 .71538 L
s
.34748 .68713 m
.34328 .67317 L
s
1 0 0 r
.65672 .67317 m
.65252 .68713 L
s
0 0 1 r
.32737 .67043 m
.32861 .65874 L
s
1 0 0 r
.67139 .65874 m
.67263 .67043 L
s
.34682 .31084 m
.35731 .31417 L
s
0 0 1 r
.64269 .31417 m
.65318 .31084 L
s
1 0 0 r
.34004 .31627 m
.34963 .32029 L
s
0 0 1 r
.65037 .32029 m
.65996 .31627 L
s
.33035 .67396 m
.33023 .66154 L
s
1 0 0 r
.66977 .66154 m
.66965 .67396 L
s
0 0 1 r
.34044 .68256 m
.33758 .66899 L
s
1 0 0 r
.66242 .66899 m
.65956 .68256 L
s
0 0 1 r
.38457 .71208 m
.37561 .69878 L
s
1 0 0 r
.62439 .69878 m
.61543 .71208 L
s
0 0 1 r
.33472 .67809 m
.33323 .66503 L
s
1 0 0 r
.66677 .66503 m
.66528 .67809 L
s
.35454 .30451 m
.36587 .30725 L
s
0 0 1 r
.63413 .30725 m
.64546 .30451 L
s
1 0 0 r
.33427 .32068 m
.3429 .32545 L
s
0 0 1 r
.6571 .32545 m
.66573 .32068 L
s
1 0 0 r
.40814 .27531 m
.42235 .27816 L
s
0 0 1 r
.57765 .27816 m
.59186 .27531 L
s
1 0 0 r
.32957 .32395 m
.33717 .32955 L
s
0 0 1 r
.66283 .32955 m
.67043 .32395 L
s
1 0 0 r
.44868 .26265 m
.46361 .26708 L
s
0 0 1 r
.53639 .26708 m
.55132 .26265 L
s
1 0 0 r
.36317 .29746 m
.37526 .29971 L
s
0 0 1 r
.62474 .29971 m
.63683 .29746 L
s
1 0 0 r
.326 .326 m
.33249 .33249 L
s
0 0 1 r
.326 .674 m
.33249 .66751 L
s
1 0 0 r
.66751 .66751 m
.674 .674 L
s
0 0 1 r
.66751 .33249 m
.674 .326 L
s
1 0 0 r
.52229 .25746 m
.53648 .26574 L
s
0 0 1 r
.46352 .26574 m
.47771 .25746 L
s
.37303 .70886 m
.36517 .69549 L
s
1 0 0 r
.63483 .69549 m
.62697 .70886 L
s
.37266 .28988 m
.38546 .29173 L
s
0 0 1 r
.61454 .29173 m
.62734 .28988 L
s
1 0 0 r
.60312 .7143 m
.59219 .72629 L
s
0 0 1 r
.40781 .72629 m
.39688 .7143 L
s
.32363 .67318 m
.32895 .66577 L
s
1 0 0 r
.67105 .66577 m
.67637 .67318 L
s
.49252 .25501 m
.50737 .26147 L
s
0 0 1 r
.49263 .26147 m
.50748 .25501 L
s
1 0 0 r
.42056 .2673 m
.43521 .27014 L
s
0 0 1 r
.56479 .27014 m
.57944 .2673 L
s
.32253 .67359 m
.32661 .66526 L
s
1 0 0 r
.67339 .66526 m
.67747 .67359 L
s
0 0 1 r
.36243 .70483 m
.35576 .69152 L
s
1 0 0 r
.64424 .69152 m
.63757 .70483 L
s
.38298 .28196 m
.39643 .28352 L
s
0 0 1 r
.60357 .28352 m
.61702 .28196 L
s
1 0 0 r
.57846 .72706 m
.56588 .73748 L
s
0 0 1 r
.43412 .73748 m
.42154 .72706 L
s
1 0 0 r
.46273 .25589 m
.47785 .26055 L
s
0 0 1 r
.52215 .26055 m
.53727 .25589 L
s
.32274 .67518 m
.32554 .66593 L
s
1 0 0 r
.67446 .66593 m
.67726 .67518 L
s
0 0 1 r
.35288 .70024 m
.34748 .68713 L
s
1 0 0 r
.65252 .68713 m
.64712 .70024 L
s
.61543 .71208 m
.60542 .72429 L
s
0 0 1 r
.39458 .72429 m
.38457 .71208 L
s
.32432 .67782 m
.32578 .66769 L
s
1 0 0 r
.67422 .66769 m
.67568 .67782 L
s
0 0 1 r
.34452 .69532 m
.34044 .68256 L
s
1 0 0 r
.65956 .68256 m
.65548 .69532 L
s
0 0 1 r
.32729 .68137 m
.32737 .67043 L
s
1 0 0 r
.67263 .67043 m
.67271 .68137 L
s
.3941 .27392 m
.40814 .27531 L
s
0 0 1 r
.59186 .27531 m
.6059 .27392 L
s
1 0 0 r
.43366 .25973 m
.44868 .26265 L
s
0 0 1 r
.55132 .26265 m
.56634 .25973 L
s
.33742 .69036 m
.33472 .67809 L
s
1 0 0 r
.66528 .67809 m
.66258 .69036 L
s
0 0 1 r
.33167 .68563 m
.33035 .67396 L
s
1 0 0 r
.66965 .67396 m
.66833 .68563 L
s
.33699 .3087 m
.34682 .31084 L
s
0 0 1 r
.65318 .31084 m
.66301 .3087 L
s
1 0 0 r
.50756 .25064 m
.52229 .25746 L
s
0 0 1 r
.47771 .25746 m
.49244 .25064 L
s
1 0 0 r
.33119 .31339 m
.34004 .31627 L
s
0 0 1 r
.65996 .31627 m
.66881 .31339 L
s
1 0 0 r
.34381 .30304 m
.35454 .30451 L
s
0 0 1 r
.64546 .30451 m
.65619 .30304 L
s
1 0 0 r
.32646 .31697 m
.33427 .32068 L
s
0 0 1 r
.66573 .32068 m
.67354 .31697 L
s
1 0 0 r
.59219 .72629 m
.58031 .73704 L
s
0 0 1 r
.41969 .73704 m
.40781 .72629 L
s
.38202 .72117 m
.37303 .70886 L
s
1 0 0 r
.62697 .70886 m
.61798 .72117 L
s
.35159 .29655 m
.36317 .29746 L
s
0 0 1 r
.63683 .29746 m
.64841 .29655 L
s
1 0 0 r
.32287 .31935 m
.32957 .32395 L
s
0 0 1 r
.67043 .32395 m
.67713 .31935 L
s
1 0 0 r
.4773 .25008 m
.49252 .25501 L
s
0 0 1 r
.50748 .25501 m
.5227 .25008 L
s
1 0 0 r
.36029 .28943 m
.37266 .28988 L
s
0 0 1 r
.62734 .28988 m
.63971 .28943 L
s
1 0 0 r
.40599 .266 m
.42056 .2673 L
s
0 0 1 r
.57944 .2673 m
.59401 .266 L
s
1 0 0 r
.32047 .32047 m
.326 .326 L
s
0 0 1 r
.32047 .67953 m
.326 .674 L
s
1 0 0 r
.674 .674 m
.67953 .67953 L
s
0 0 1 r
.674 .326 m
.67953 .32047 L
s
1 0 0 r
.56588 .73748 m
.55249 .74654 L
s
0 0 1 r
.44751 .74654 m
.43412 .73748 L
s
.37028 .71713 m
.36243 .70483 L
s
1 0 0 r
.63757 .70483 m
.62972 .71713 L
s
.44742 .25282 m
.46273 .25589 L
s
0 0 1 r
.53727 .25589 m
.55258 .25282 L
s
.31934 .67967 m
.32363 .67318 L
s
1 0 0 r
.67637 .67318 m
.68066 .67967 L
s
.36988 .28187 m
.38298 .28196 L
s
0 0 1 r
.61702 .28196 m
.63012 .28187 L
s
1 0 0 r
.60542 .72429 m
.59436 .73528 L
s
0 0 1 r
.40564 .73528 m
.39458 .72429 L
s
.31953 .68104 m
.32253 .67359 L
s
1 0 0 r
.67747 .67359 m
.68047 .68104 L
s
0 0 1 r
.35951 .71237 m
.35288 .70024 L
s
1 0 0 r
.64712 .70024 m
.64049 .71237 L
s
0 0 1 r
.3211 .68355 m
.32274 .67518 L
s
1 0 0 r
.67726 .67518 m
.6789 .68355 L
s
.41864 .25842 m
.43366 .25973 L
s
0 0 1 r
.56634 .25973 m
.58136 .25842 L
s
1 0 0 r
.49233 .24538 m
.50756 .25064 L
s
0 0 1 r
.49244 .25064 m
.50767 .24538 L
s
.34984 .70715 m
.34452 .69532 L
s
1 0 0 r
.65548 .69532 m
.65016 .70715 L
s
.38033 .2741 m
.3941 .27392 L
s
0 0 1 r
.6059 .27392 m
.61967 .2741 L
s
.32406 .68708 m
.32432 .67782 L
s
1 0 0 r
.67568 .67782 m
.67594 .68708 L
s
.58031 .73704 m
.56751 .74643 L
s
0 0 1 r
.43249 .74643 m
.41969 .73704 L
s
.34138 .70173 m
.33742 .69036 L
s
1 0 0 r
.66258 .69036 m
.65862 .70173 L
s
0 0 1 r
.32844 .69144 m
.32729 .68137 L
s
1 0 0 r
.67271 .68137 m
.67156 .69144 L
s
0 0 1 r
.33422 .69641 m
.33167 .68563 L
s
1 0 0 r
.66833 .68563 m
.66578 .69641 L
s
.61798 .72117 m
.60787 .7323 L
s
0 0 1 r
.39213 .7323 m
.38202 .72117 L
s
1 0 0 r
.46179 .24677 m
.4773 .25008 L
s
0 0 1 r
.5227 .25008 m
.53821 .24677 L
s
1 0 0 r
.32794 .30785 m
.33699 .3087 L
s
0 0 1 r
.66301 .3087 m
.67206 .30785 L
s
1 0 0 r
.33377 .30291 m
.34381 .30304 L
s
0 0 1 r
.65619 .30304 m
.66623 .30291 L
s
1 0 0 r
.32319 .31172 m
.33119 .31339 L
s
0 0 1 r
.66881 .31339 m
.67681 .31172 L
s
1 0 0 r
.34063 .29706 m
.35159 .29655 L
s
0 0 1 r
.64841 .29655 m
.65937 .29706 L
s
1 0 0 r
.55249 .74654 m
.53832 .75411 L
s
0 0 1 r
.46168 .75411 m
.44751 .74654 L
s
1 0 0 r
.39162 .26633 m
.40599 .266 L
s
0 0 1 r
.59401 .266 m
.60838 .26633 L
s
1 0 0 r
.31957 .31442 m
.32646 .31697 L
s
0 0 1 r
.67354 .31697 m
.68043 .31442 L
s
1 0 0 r
.34847 .29048 m
.36029 .28943 L
s
0 0 1 r
.63971 .28943 m
.65153 .29048 L
s
1 0 0 r
.43201 .25141 m
.44742 .25282 L
s
0 0 1 r
.55258 .25282 m
.56799 .25141 L
s
.37932 .72827 m
.37028 .71713 L
s
1 0 0 r
.62972 .71713 m
.62068 .72827 L
s
.31716 .31586 m
.32287 .31935 L
s
0 0 1 r
.67713 .31935 m
.68284 .31586 L
s
1 0 0 r
.59436 .73528 m
.58228 .74493 L
s
0 0 1 r
.41772 .74493 m
.40564 .73528 L
s
1 0 0 r
.316 .316 m
.32047 .32047 L
s
0 0 1 r
.316 .684 m
.32047 .67953 L
s
1 0 0 r
.67953 .67953 m
.684 .684 L
s
0 0 1 r
.67953 .32047 m
.684 .316 L
s
1 0 0 r
.35726 .28335 m
.36988 .28187 L
s
0 0 1 r
.63012 .28187 m
.64274 .28335 L
s
.36737 .72339 m
.35951 .71237 L
s
1 0 0 r
.64049 .71237 m
.63263 .72339 L
s
.47671 .2418 m
.49233 .24538 L
s
0 0 1 r
.50767 .24538 m
.52329 .2418 L
s
.31618 .68513 m
.31934 .67967 L
s
1 0 0 r
.68066 .67967 m
.68382 .68513 L
s
.40371 .25881 m
.41864 .25842 L
s
0 0 1 r
.58136 .25842 m
.59629 .25881 L
s
1 0 0 r
.56751 .74643 m
.55383 .75433 L
s
0 0 1 r
.44617 .75433 m
.43249 .74643 L
s
.31772 .68749 m
.31953 .68104 L
s
1 0 0 r
.68047 .68104 m
.68228 .68749 L
s
.36695 .27591 m
.38033 .2741 L
s
0 0 1 r
.61967 .2741 m
.63305 .27591 L
s
.35643 .7179 m
.34984 .70715 L
s
1 0 0 r
.65016 .70715 m
.64357 .7179 L
s
.44607 .24519 m
.46179 .24677 L
s
0 0 1 r
.53821 .24677 m
.55393 .24519 L
s
1 0 0 r
.60787 .7323 m
.59666 .74212 L
s
0 0 1 r
.40334 .74212 m
.39213 .7323 L
s
.32068 .69095 m
.3211 .68355 L
s
1 0 0 r
.6789 .68355 m
.67932 .69095 L
s
0 0 1 r
.34663 .71206 m
.34138 .70173 L
s
1 0 0 r
.65862 .70173 m
.65337 .71206 L
s
0 0 1 r
.32506 .69536 m
.32406 .68708 L
s
1 0 0 r
.67594 .68708 m
.67494 .69536 L
s
.53832 .75411 m
.52345 .76006 L
s
0 0 1 r
.47655 .76006 m
.46168 .75411 L
s
.33809 .70618 m
.33422 .69641 L
s
1 0 0 r
.66578 .69641 m
.66191 .70618 L
s
0 0 1 r
.33088 .70052 m
.32844 .69144 L
s
1 0 0 r
.67156 .69144 m
.66912 .70052 L
s
.37754 .26836 m
.39162 .26633 L
s
0 0 1 r
.60838 .26633 m
.62246 .26836 L
s
1 0 0 r
.41661 .25176 m
.43201 .25141 L
s
0 0 1 r
.56799 .25141 m
.58339 .25176 L
s
1 0 0 r
.32455 .30422 m
.33377 .30291 L
s
0 0 1 r
.66623 .30291 m
.67545 .30422 L
s
1 0 0 r
.31977 .30836 m
.32794 .30785 L
s
0 0 1 r
.67206 .30785 m
.68023 .30836 L
s
1 0 0 r
.33041 .29907 m
.34063 .29706 L
s
0 0 1 r
.65937 .29706 m
.66959 .29907 L
s
1 0 0 r
.62068 .72827 m
.61046 .73814 L
s
0 0 1 r
.38954 .73814 m
.37932 .72827 L
s
1 0 0 r
.31614 .31136 m
.32319 .31172 L
s
0 0 1 r
.67681 .31172 m
.68386 .31136 L
s
1 0 0 r
.58228 .74493 m
.56923 .7531 L
s
0 0 1 r
.43077 .7531 m
.41772 .74493 L
s
1 0 0 r
.33731 .2931 m
.34847 .29048 L
s
0 0 1 r
.65153 .29048 m
.66269 .2931 L
s
1 0 0 r
.31371 .31312 m
.31957 .31442 L
s
0 0 1 r
.68043 .31442 m
.68629 .31312 L
s
1 0 0 r
.46079 .23999 m
.47671 .2418 L
s
0 0 1 r
.52329 .2418 m
.53921 .23999 L
s
1 0 0 r
.34521 .28647 m
.35726 .28335 L
s
0 0 1 r
.64274 .28335 m
.65479 .28647 L
s
1 0 0 r
.31254 .31357 m
.31716 .31586 L
s
0 0 1 r
.68284 .31586 m
.68746 .31357 L
s
1 0 0 r
.38901 .26097 m
.40371 .25881 L
s
0 0 1 r
.59629 .25881 m
.61099 .26097 L
s
.37648 .73317 m
.36737 .72339 L
s
1 0 0 r
.63263 .72339 m
.62352 .73317 L
s
.55383 .75433 m
.53933 .76062 L
s
0 0 1 r
.46067 .76062 m
.44617 .75433 L
s
1 0 0 r
.3127 .3127 m
.316 .316 L
s
0 0 1 r
.3127 .6873 m
.316 .684 L
s
1 0 0 r
.684 .684 m
.6873 .6873 L
s
0 0 1 r
.684 .316 m
.6873 .3127 L
s
1 0 0 r
.43026 .24543 m
.44607 .24519 L
s
0 0 1 r
.55393 .24519 m
.56974 .24543 L
s
1 0 0 r
.35408 .27943 m
.36695 .27591 L
s
0 0 1 r
.63305 .27591 m
.64592 .27943 L
s
1 0 0 r
.59666 .74212 m
.58436 .75048 L
s
0 0 1 r
.41564 .75048 m
.40334 .74212 L
s
.31423 .68946 m
.31618 .68513 L
s
1 0 0 r
.68382 .68513 m
.68577 .68946 L
s
0 0 1 r
.36433 .72744 m
.35643 .7179 L
s
1 0 0 r
.64357 .7179 m
.63567 .72744 L
s
.52345 .76006 m
.50796 .76429 L
s
0 0 1 r
.49204 .76429 m
.47655 .76006 L
s
.31718 .69282 m
.31772 .68749 L
s
1 0 0 r
.68228 .68749 m
.68282 .69282 L
s
0 0 1 r
.35322 .72123 m
.34663 .71206 L
s
1 0 0 r
.65337 .71206 m
.64678 .72123 L
s
.40132 .25396 m
.41661 .25176 L
s
0 0 1 r
.58339 .25176 m
.59868 .25396 L
s
.32157 .69725 m
.32068 .69095 L
s
1 0 0 r
.67932 .69095 m
.67843 .69725 L
s
.36389 .27218 m
.37754 .26836 L
s
0 0 1 r
.62246 .26836 m
.63611 .27218 L
s
.3433 .71481 m
.33809 .70618 L
s
1 0 0 r
.66191 .70618 m
.6567 .71481 L
s
0 0 1 r
.32741 .70254 m
.32506 .69536 L
s
1 0 0 r
.67494 .69536 m
.67259 .70254 L
s
0 0 1 r
.33467 .70849 m
.33088 .70052 L
s
1 0 0 r
.66912 .70052 m
.66533 .70849 L
s
.56923 .7531 m
.55524 .75967 L
s
0 0 1 r
.44476 .75967 m
.43077 .7531 L
s
1 0 0 r
.61046 .73814 m
.59906 .74658 L
s
0 0 1 r
.40094 .74658 m
.38954 .73814 L
s
1 0 0 r
.31625 .30704 m
.32455 .30422 L
s
0 0 1 r
.67545 .30422 m
.68375 .30704 L
s
1 0 0 r
.32104 .30266 m
.33041 .29907 L
s
0 0 1 r
.66959 .29907 m
.67896 .30266 L
s
1 0 0 r
.44466 .24004 m
.46079 .23999 L
s
0 0 1 r
.53921 .23999 m
.55534 .24004 L
s
1 0 0 r
.3126 .31032 m
.31977 .30836 L
s
0 0 1 r
.68023 .30836 m
.6874 .31032 L
s
1 0 0 r
.32693 .29735 m
.33731 .2931 L
s
0 0 1 r
.66269 .2931 m
.67307 .29735 L
s
1 0 0 r
.31016 .31239 m
.31614 .31136 L
s
0 0 1 r
.68386 .31136 m
.68984 .31239 L
s
1 0 0 r
.37463 .26498 m
.38901 .26097 L
s
0 0 1 r
.61099 .26097 m
.62537 .26498 L
s
1 0 0 r
.53933 .76062 m
.52408 .76517 L
s
0 0 1 r
.47592 .76517 m
.46067 .76062 L
s
1 0 0 r
.33387 .2913 m
.34521 .28647 L
s
0 0 1 r
.65479 .28647 m
.66613 .2913 L
s
1 0 0 r
.62352 .73317 m
.61316 .74156 L
s
0 0 1 r
.38684 .74156 m
.37648 .73317 L
s
1 0 0 r
.30898 .31316 m
.31371 .31312 L
s
0 0 1 r
.68629 .31312 m
.69102 .31316 L
s
1 0 0 r
.41448 .24757 m
.43026 .24543 L
s
0 0 1 r
.56974 .24543 m
.58552 .24757 L
s
1 0 0 r
.58436 .75048 m
.57103 .75726 L
s
0 0 1 r
.42897 .75726 m
.41564 .75048 L
s
1 0 0 r
.30913 .31258 m
.31254 .31357 L
s
0 0 1 r
.68746 .31357 m
.69087 .31258 L
s
1 0 0 r
.50796 .76429 m
.49192 .76669 L
s
0 0 1 r
.50808 .76669 m
.49204 .76429 L
s
1 0 0 r
.34183 .28472 m
.35408 .27943 L
s
0 0 1 r
.64592 .27943 m
.65817 .28472 L
s
.37353 .73564 m
.36433 .72744 L
s
1 0 0 r
.63567 .72744 m
.62647 .73564 L
s
.31065 .31065 m
.3127 .3127 L
s
0 0 1 r
.31065 .68935 m
.3127 .6873 L
s
1 0 0 r
.6873 .6873 m
.68935 .68935 L
s
0 0 1 r
.6873 .3127 m
.68935 .31065 L
s
1 0 0 r
.38629 .25806 m
.40132 .25396 L
s
0 0 1 r
.59868 .25396 m
.61371 .25806 L
s
.3136 .69256 m
.31423 .68946 L
s
1 0 0 r
.68577 .68946 m
.6864 .69256 L
s
.35079 .27784 m
.36389 .27218 L
s
0 0 1 r
.63611 .27218 m
.64921 .27784 L
s
1 0 0 r
.55524 .75967 m
.54038 .7645 L
s
0 0 1 r
.45962 .7645 m
.44476 .75967 L
s
.36117 .72908 m
.35322 .72123 L
s
1 0 0 r
.64678 .72123 m
.63883 .72908 L
s
0 0 1 r
.318 .69694 m
.31718 .69282 L
s
1 0 0 r
.68282 .69282 m
.682 .69694 L
s
.59906 .74658 m
.58653 .75346 L
s
0 0 1 r
.41347 .75346 m
.40094 .74658 L
s
1 0 0 r
.42844 .24205 m
.44466 .24004 L
s
0 0 1 r
.55534 .24004 m
.57156 .24205 L
s
.34991 .72217 m
.3433 .71481 L
s
1 0 0 r
.6567 .71481 m
.65009 .72217 L
s
0 0 1 r
.32386 .70232 m
.32157 .69725 L
s
1 0 0 r
.67843 .69725 m
.67614 .70232 L
s
0 0 1 r
.33987 .7152 m
.33467 .70849 L
s
1 0 0 r
.66533 .70849 m
.66013 .7152 L
s
0 0 1 r
.33116 .70849 m
.32741 .70254 L
s
1 0 0 r
.67259 .70254 m
.66884 .70849 L
s
.52408 .76517 m
.50817 .76786 L
s
0 0 1 r
.49183 .76786 m
.47592 .76517 L
s
1 0 0 r
.36072 .2709 m
.37463 .26498 L
s
0 0 1 r
.62537 .26498 m
.63928 .2709 L
s
1 0 0 r
.31265 .30788 m
.32104 .30266 L
s
0 0 1 r
.67896 .30266 m
.68735 .30788 L
s
1 0 0 r
.309 .31143 m
.31625 .30704 L
s
0 0 1 r
.68375 .30704 m
.691 .31143 L
s
1 0 0 r
.31745 .30331 m
.32693 .29735 L
s
0 0 1 r
.67307 .29735 m
.68255 .30331 L
s
1 0 0 r
.39884 .25169 m
.41448 .24757 L
s
0 0 1 r
.58552 .24757 m
.60116 .25169 L
s
1 0 0 r
.30656 .31381 m
.3126 .31032 L
s
0 0 1 r
.6874 .31032 m
.69344 .31381 L
s
1 0 0 r
.61316 .74156 m
.60156 .74842 L
s
0 0 1 r
.39844 .74842 m
.38684 .74156 L
s
1 0 0 r
.32336 .29789 m
.33387 .2913 L
s
0 0 1 r
.66613 .2913 m
.67664 .29789 L
s
1 0 0 r
.49192 .76669 m
.47544 .76713 L
s
0 0 1 r
.52456 .76713 m
.50808 .76669 L
s
1 0 0 r
.57103 .75726 m
.55671 .76231 L
s
0 0 1 r
.44329 .76231 m
.42897 .75726 L
s
1 0 0 r
.30537 .3149 m
.31016 .31239 L
s
0 0 1 r
.68984 .31239 m
.69463 .3149 L
s
1 0 0 r
.33035 .29185 m
.34183 .28472 L
s
0 0 1 r
.65817 .28472 m
.66965 .29185 L
s
1 0 0 r
.30551 .31463 m
.30898 .31316 L
s
0 0 1 r
.69102 .31316 m
.69449 .31463 L
s
1 0 0 r
.37162 .26414 m
.38629 .25806 L
s
0 0 1 r
.61371 .25806 m
.62838 .26414 L
s
1 0 0 r
.62647 .73564 m
.61595 .74234 L
s
0 0 1 r
.38405 .74234 m
.37353 .73564 L
s
1 0 0 r
.30703 .31298 m
.30913 .31258 L
s
0 0 1 r
.69087 .31258 m
.69297 .31298 L
s
1 0 0 r
.54038 .7645 m
.52474 .76747 L
s
0 0 1 r
.47526 .76747 m
.45962 .7645 L
s
1 0 0 r
.33837 .28539 m
.35079 .27784 L
s
0 0 1 r
.64921 .27784 m
.66163 .28539 L
s
1 0 0 r
.41227 .2461 m
.42844 .24205 L
s
0 0 1 r
.57156 .24205 m
.58773 .2461 L
s
1 0 0 r
.30997 .30997 m
.31065 .31065 L
s
0 0 1 r
.30997 .69003 m
.31065 .68935 L
s
1 0 0 r
.68935 .68935 m
.69003 .69003 L
s
0 0 1 r
.68935 .31065 m
.69003 .30997 L
s
1 0 0 r
.58653 .75346 m
.5729 .75863 L
s
0 0 1 r
.4271 .75863 m
.41347 .75346 L
s
.3705 .73548 m
.36117 .72908 L
s
1 0 0 r
.63883 .72908 m
.6295 .73548 L
s
.50817 .76786 m
.4917 .76859 L
s
0 0 1 r
.5083 .76859 m
.49183 .76786 L
s
.31437 .6943 m
.3136 .69256 L
s
1 0 0 r
.6864 .69256 m
.68563 .6943 L
s
0 0 1 r
.35794 .72811 m
.34991 .72217 L
s
1 0 0 r
.65009 .72217 m
.64206 .72811 L
s
.34742 .27877 m
.36072 .2709 L
s
0 0 1 r
.63928 .2709 m
.65258 .27877 L
s
1 0 0 r
.38348 .25784 m
.39884 .25169 L
s
0 0 1 r
.60116 .25169 m
.61652 .25784 L
s
.32025 .69971 m
.318 .69694 L
s
1 0 0 r
.682 .69694 m
.67975 .69971 L
s
0 0 1 r
.34652 .72054 m
.33987 .7152 L
s
1 0 0 r
.66013 .7152 m
.65348 .72054 L
s
0 0 1 r
.3276 .70605 m
.32386 .70232 L
s
1 0 0 r
.67614 .70232 m
.6724 .70605 L
s
.47544 .76713 m
.45865 .76554 L
s
0 0 1 r
.54135 .76554 m
.52456 .76713 L
s
.33638 .71309 m
.33116 .70849 L
s
1 0 0 r
.66884 .70849 m
.66362 .71309 L
s
.30537 .3148 m
.31265 .30788 L
s
0 0 1 r
.68735 .30788 m
.69463 .3148 L
s
1 0 0 r
.30902 .31102 m
.31745 .30331 L
s
0 0 1 r
.68255 .30331 m
.69098 .31102 L
s
1 0 0 r
.55671 .76231 m
.54148 .7655 L
s
0 0 1 r
.45852 .7655 m
.44329 .76231 L
s
1 0 0 r
.60156 .74842 m
.58877 .75361 L
s
0 0 1 r
.41123 .75361 m
.39844 .74842 L
s
1 0 0 r
.30293 .31747 m
.309 .31143 L
s
0 0 1 r
.691 .31143 m
.69707 .31747 L
s
1 0 0 r
.31383 .3063 m
.32336 .29789 L
s
0 0 1 r
.67664 .29789 m
.68617 .3063 L
s
1 0 0 r
.30175 .31889 m
.30656 .31381 L
s
0 0 1 r
.69344 .31381 m
.69825 .31889 L
s
1 0 0 r
.35748 .27225 m
.37162 .26414 L
s
0 0 1 r
.62838 .26414 m
.64252 .27225 L
s
1 0 0 r
.31976 .30084 m
.33035 .29185 L
s
0 0 1 r
.66965 .29185 m
.68024 .30084 L
s
1 0 0 r
.30189 .31896 m
.30537 .3149 L
s
0 0 1 r
.69463 .3149 m
.69811 .31896 L
s
1 0 0 r
.52474 .76747 m
.5084 .76847 L
s
0 0 1 r
.4916 .76847 m
.47526 .76747 L
s
1 0 0 r
.39628 .25223 m
.41227 .2461 L
s
0 0 1 r
.58773 .2461 m
.60372 .25223 L
s
1 0 0 r
.61595 .74234 m
.60413 .74741 L
s
0 0 1 r
.39587 .74741 m
.38405 .74234 L
s
1 0 0 r
.32678 .29487 m
.33837 .28539 L
s
0 0 1 r
.66163 .28539 m
.67322 .29487 L
s
1 0 0 r
.30341 .31761 m
.30551 .31463 L
s
0 0 1 r
.69449 .31463 m
.69659 .31761 L
s
1 0 0 r
.5729 .75863 m
.55823 .76198 L
s
0 0 1 r
.44177 .76198 m
.4271 .75863 L
s
1 0 0 r
.4917 .76859 m
.47477 .76725 L
s
0 0 1 r
.52523 .76725 m
.5083 .76859 L
s
1 0 0 r
.30635 .31486 m
.30703 .31298 L
s
0 0 1 r
.69297 .31298 m
.69365 .31486 L
s
1 0 0 r
.36855 .26607 m
.38348 .25784 L
s
0 0 1 r
.61652 .25784 m
.63145 .26607 L
s
1 0 0 r
.6295 .73548 m
.6188 .74028 L
s
0 0 1 r
.3812 .74028 m
.3705 .73548 L
s
1 0 0 r
.33487 .28864 m
.34742 .27877 L
s
0 0 1 r
.65258 .27877 m
.66513 .28864 L
s
1 0 0 r
.45865 .76554 m
.44166 .76183 L
s
0 0 1 r
.55834 .76183 m
.54135 .76554 L
s
1 0 0 r
.31075 .31075 m
.30997 .30997 L
s
0 0 1 r
.31075 .68925 m
.30997 .69003 L
s
1 0 0 r
.69003 .69003 m
.68925 .68925 L
s
0 0 1 r
.69003 .30997 m
.68925 .31075 L
s
.36741 .7325 m
.35794 .72811 L
s
1 0 0 r
.64206 .72811 m
.63259 .7325 L
s
.54148 .7655 m
.52541 .76672 L
s
0 0 1 r
.47459 .76672 m
.45852 .7655 L
s
.31665 .6946 m
.31437 .6943 L
s
1 0 0 r
.68563 .6943 m
.68335 .6946 L
s
.58877 .75361 m
.57482 .75699 L
s
0 0 1 r
.42518 .75699 m
.41123 .75361 L
s
.32403 .70103 m
.32025 .69971 L
s
1 0 0 r
.67975 .69971 m
.67597 .70103 L
s
0 0 1 r
.35467 .72436 m
.34652 .72054 L
s
1 0 0 r
.65348 .72054 m
.64533 .72436 L
s
.30176 .32052 m
.30902 .31102 L
s
0 0 1 r
.69098 .31102 m
.69824 .32052 L
s
1 0 0 r
.34401 .28239 m
.35748 .27225 L
s
0 0 1 r
.64252 .27225 m
.65599 .28239 L
s
1 0 0 r
.30541 .31654 m
.31383 .3063 L
s
0 0 1 r
.68617 .3063 m
.69459 .31654 L
s
1 0 0 r
.29933 .32346 m
.30537 .3148 L
s
0 0 1 r
.69463 .3148 m
.70067 .32346 L
s
.33287 .70831 m
.3276 .70605 L
s
1 0 0 r
.6724 .70605 m
.66713 .70831 L
s
0 0 1 r
.34311 .71619 m
.33638 .71309 L
s
1 0 0 r
.66362 .71309 m
.65689 .71619 L
s
.29817 .32521 m
.30293 .31747 L
s
0 0 1 r
.69707 .31747 m
.70183 .32521 L
s
1 0 0 r
.31021 .31173 m
.31976 .30084 L
s
0 0 1 r
.68024 .30084 m
.68979 .31173 L
s
1 0 0 r
.38062 .2605 m
.39628 .25223 L
s
0 0 1 r
.60372 .25223 m
.61938 .2605 L
s
1 0 0 r
.5084 .76847 m
.49147 .76738 L
s
0 0 1 r
.50853 .76738 m
.4916 .76847 L
s
1 0 0 r
.29831 .32562 m
.30175 .31889 L
s
0 0 1 r
.69825 .31889 m
.70169 .32562 L
s
1 0 0 r
.31616 .3063 m
.32678 .29487 L
s
0 0 1 r
.67322 .29487 m
.68384 .3063 L
s
1 0 0 r
.47477 .76725 m
.45753 .76376 L
s
0 0 1 r
.54247 .76376 m
.52523 .76725 L
s
1 0 0 r
.60413 .74741 m
.59105 .75072 L
s
0 0 1 r
.40895 .75072 m
.39587 .74741 L
s
1 0 0 r
.29983 .32463 m
.30189 .31896 L
s
0 0 1 r
.69811 .31896 m
.70017 .32463 L
s
1 0 0 r
.55823 .76198 m
.54259 .76336 L
s
0 0 1 r
.45741 .76336 m
.44177 .76198 L
s
1 0 0 r
.35421 .2764 m
.36855 .26607 L
s
0 0 1 r
.63145 .26607 m
.64579 .2764 L
s
1 0 0 r
.44166 .76183 m
.42463 .75593 L
s
0 0 1 r
.57537 .75593 m
.55834 .76183 L
s
1 0 0 r
.32321 .3005 m
.33487 .28864 L
s
0 0 1 r
.66513 .28864 m
.67679 .3005 L
s
1 0 0 r
.30277 .32218 m
.30341 .31761 L
s
0 0 1 r
.69659 .31761 m
.69723 .32218 L
s
1 0 0 r
.6188 .74028 m
.60674 .74336 L
s
0 0 1 r
.39326 .74336 m
.3812 .74028 L
s
1 0 0 r
.52541 .76672 m
.50863 .76586 L
s
0 0 1 r
.49137 .76586 m
.47459 .76672 L
s
1 0 0 r
.30719 .31831 m
.30635 .31486 L
s
0 0 1 r
.69365 .31486 m
.69281 .31831 L
s
1 0 0 r
.33136 .29459 m
.34401 .28239 L
s
0 0 1 r
.65599 .28239 m
.66864 .29459 L
s
1 0 0 r
.57482 .75699 m
.55977 .75844 L
s
0 0 1 r
.44023 .75844 m
.42518 .75699 L
s
1 0 0 r
.63259 .7325 m
.62168 .7352 L
s
0 0 1 r
.37832 .7352 m
.36741 .7325 L
s
1 0 0 r
.31309 .31309 m
.31075 .31075 L
s
0 0 1 r
.31309 .68691 m
.31075 .68925 L
s
1 0 0 r
.68925 .68925 m
.68691 .68691 L
s
0 0 1 r
.68925 .31075 m
.68691 .31309 L
s
1 0 0 r
.36545 .27092 m
.38062 .2605 L
s
0 0 1 r
.61938 .2605 m
.63455 .27092 L
s
1 0 0 r
.49147 .76738 m
.47409 .76413 L
s
0 0 1 r
.52591 .76413 m
.50853 .76738 L
s
1 0 0 r
.29823 .32863 m
.30541 .31654 L
s
0 0 1 r
.69459 .31654 m
.70177 .32863 L
s
1 0 0 r
.29582 .33182 m
.30176 .32052 L
s
0 0 1 r
.69824 .32052 m
.70418 .33182 L
s
.3205 .69334 m
.31665 .6946 L
s
1 0 0 r
.68335 .6946 m
.6795 .69334 L
s
.30186 .3245 m
.31021 .31173 L
s
0 0 1 r
.68979 .31173 m
.69814 .3245 L
s
.36431 .72653 m
.35467 .72436 L
s
1 0 0 r
.64533 .72436 m
.63569 .72653 L
s
.29467 .33388 m
.29933 .32346 L
s
0 0 1 r
.70067 .32346 m
.70533 .33388 L
s
.32939 .70079 m
.32403 .70103 L
s
1 0 0 r
.67597 .70103 m
.67061 .70079 L
s
.45753 .76376 m
.44011 .75806 L
s
0 0 1 r
.55989 .75806 m
.54247 .76376 L
s
.35139 .71768 m
.34311 .71619 L
s
1 0 0 r
.65689 .71619 m
.64861 .71768 L
s
0 0 1 r
.33972 .709 m
.33287 .70831 L
s
1 0 0 r
.66713 .70831 m
.66028 .709 L
s
.30666 .31966 m
.31616 .3063 L
s
0 0 1 r
.68384 .3063 m
.69334 .31966 L
s
1 0 0 r
.29483 .33467 m
.29817 .32521 L
s
0 0 1 r
.70183 .32521 m
.70517 .33467 L
s
1 0 0 r
.34061 .28883 m
.35421 .2764 L
s
0 0 1 r
.64579 .2764 m
.65939 .28883 L
s
1 0 0 r
.42463 .75593 m
.40771 .74781 L
s
0 0 1 r
.59229 .74781 m
.57537 .75593 L
s
1 0 0 r
.54259 .76336 m
.5261 .76267 L
s
0 0 1 r
.4739 .76267 m
.45741 .76336 L
s
1 0 0 r
.59105 .75072 m
.57676 .75212 L
s
0 0 1 r
.42324 .75212 m
.40895 .75072 L
s
1 0 0 r
.29636 .33405 m
.29831 .32562 L
s
0 0 1 r
.70169 .32562 m
.70364 .33405 L
s
1 0 0 r
.31261 .31435 m
.32321 .3005 L
s
0 0 1 r
.67679 .3005 m
.68739 .31435 L
s
1 0 0 r
.29931 .33197 m
.29983 .32463 L
s
0 0 1 r
.70017 .32463 m
.70069 .33197 L
s
1 0 0 r
.50863 .76586 m
.49124 .76282 L
s
0 0 1 r
.50876 .76282 m
.49137 .76586 L
s
1 0 0 r
.3197 .30881 m
.33136 .29459 L
s
0 0 1 r
.66864 .29459 m
.6803 .30881 L
s
1 0 0 r
.60674 .74336 m
.59335 .74458 L
s
0 0 1 r
.40665 .74458 m
.39326 .74336 L
s
1 0 0 r
.35094 .28349 m
.36545 .27092 L
s
0 0 1 r
.63455 .27092 m
.64906 .28349 L
s
1 0 0 r
.30372 .3284 m
.30277 .32218 L
s
0 0 1 r
.69723 .32218 m
.69628 .3284 L
s
1 0 0 r
.47409 .76413 m
.4564 .75863 L
s
0 0 1 r
.5436 .75863 m
.52591 .76413 L
s
1 0 0 r
.55977 .75844 m
.54373 .75784 L
s
0 0 1 r
.45627 .75784 m
.44023 .75844 L
s
1 0 0 r
.30964 .3234 m
.30719 .31831 L
s
0 0 1 r
.69281 .31831 m
.69036 .3234 L
s
1 0 0 r
.44011 .75806 m
.42268 .75009 L
s
0 0 1 r
.57732 .75009 m
.55989 .75806 L
s
1 0 0 r
.62168 .7352 m
.60934 .73608 L
s
0 0 1 r
.39066 .73608 m
.37832 .7352 L
s
1 0 0 r
.29244 .34255 m
.29823 .32863 L
s
0 0 1 r
.70177 .32863 m
.70756 .34255 L
s
1 0 0 r
.29483 .33915 m
.30186 .3245 L
s
0 0 1 r
.69814 .3245 m
.70517 .33915 L
s
1 0 0 r
.32791 .30333 m
.34061 .28883 L
s
0 0 1 r
.65939 .28883 m
.67209 .30333 L
s
1 0 0 r
.29132 .34492 m
.29582 .33182 L
s
0 0 1 r
.70418 .33182 m
.70868 .34492 L
s
1 0 0 r
.40771 .74781 m
.39106 .73745 L
s
0 0 1 r
.60894 .73745 m
.59229 .74781 L
s
1 0 0 r
.29843 .33493 m
.30666 .31966 L
s
0 0 1 r
.69334 .31966 m
.70157 .33493 L
s
1 0 0 r
.31707 .31707 m
.31309 .31309 L
s
0 0 1 r
.31707 .68293 m
.31309 .68691 L
s
1 0 0 r
.68691 .68691 m
.68293 .68293 L
s
0 0 1 r
.68691 .31309 m
.68293 .31707 L
s
1 0 0 r
.29151 .34608 m
.29467 .33388 L
s
0 0 1 r
.70533 .33388 m
.70849 .34608 L
s
1 0 0 r
.63569 .72653 m
.62454 .72693 L
s
0 0 1 r
.37546 .72693 m
.36431 .72653 L
s
1 0 0 r
.5261 .76267 m
.50886 .75981 L
s
0 0 1 r
.49114 .75981 m
.4739 .76267 L
s
.326 .69044 m
.3205 .69334 L
s
1 0 0 r
.6795 .69334 m
.674 .69044 L
s
.30322 .33014 m
.31261 .31435 L
s
0 0 1 r
.68739 .31435 m
.69678 .33014 L
s
.36124 .71745 m
.35139 .71768 L
s
1 0 0 r
.64861 .71768 m
.63876 .71745 L
s
.57676 .75212 m
.56133 .7515 L
s
0 0 1 r
.43867 .7515 m
.42324 .75212 L
s
1 0 0 r
.29305 .34587 m
.29483 .33467 L
s
0 0 1 r
.70517 .33467 m
.70695 .34587 L
s
.33639 .69888 m
.32939 .70079 L
s
1 0 0 r
.67061 .70079 m
.66361 .69888 L
s
0 0 1 r
.34817 .70799 m
.33972 .709 L
s
1 0 0 r
.66028 .709 m
.65183 .70799 L
s
.49124 .76282 m
.4734 .75754 L
s
0 0 1 r
.5266 .75754 m
.50876 .76282 L
s
1 0 0 r
.33726 .29817 m
.35094 .28349 L
s
0 0 1 r
.64906 .28349 m
.66274 .29817 L
s
1 0 0 r
.30918 .32502 m
.3197 .30881 L
s
0 0 1 r
.6803 .30881 m
.69082 .32502 L
s
1 0 0 r
.29601 .3442 m
.29636 .33405 L
s
0 0 1 r
.70364 .33405 m
.70399 .3442 L
s
1 0 0 r
.4564 .75863 m
.43856 .75086 L
s
0 0 1 r
.56144 .75086 m
.5436 .75863 L
s
1 0 0 r
.59335 .74458 m
.5787 .74382 L
s
0 0 1 r
.4213 .74382 m
.40665 .74458 L
s
1 0 0 r
.42268 .75009 m
.40541 .73985 L
s
0 0 1 r
.59459 .73985 m
.57732 .75009 L
s
1 0 0 r
.30043 .34101 m
.29931 .33197 L
s
0 0 1 r
.70069 .33197 m
.69957 .34101 L
s
1 0 0 r
.54373 .75784 m
.52679 .75509 L
s
0 0 1 r
.47321 .75509 m
.45627 .75784 L
s
1 0 0 r
.3163 .31985 m
.32791 .30333 L
s
0 0 1 r
.67209 .30333 m
.6837 .31985 L
s
1 0 0 r
.39106 .73745 m
.37488 .72486 L
s
0 0 1 r
.62512 .72486 m
.60894 .73745 L
s
1 0 0 r
.30635 .33632 m
.30372 .3284 L
s
0 0 1 r
.69628 .3284 m
.69365 .33632 L
s
1 0 0 r
.28926 .35561 m
.29483 .33915 L
s
0 0 1 r
.70517 .33915 m
.71074 .35561 L
s
1 0 0 r
.29161 .35204 m
.29843 .33493 L
s
0 0 1 r
.70157 .33493 m
.70839 .35204 L
s
1 0 0 r
.28818 .35826 m
.29244 .34255 L
s
0 0 1 r
.70756 .34255 m
.71182 .35826 L
s
1 0 0 r
.60934 .73608 m
.59563 .73504 L
s
0 0 1 r
.40437 .73504 m
.39066 .73608 L
s
1 0 0 r
.28839 .35979 m
.29132 .34492 L
s
0 0 1 r
.70868 .34492 m
.71161 .35979 L
s
1 0 0 r
.50886 .75981 m
.49101 .7547 L
s
0 0 1 r
.50899 .7547 m
.49114 .75981 L
s
1 0 0 r
.29518 .34779 m
.30322 .33014 L
s
0 0 1 r
.69678 .33014 m
.70482 .34779 L
s
1 0 0 r
.31379 .33018 m
.30964 .3234 L
s
0 0 1 r
.69036 .3234 m
.68621 .33018 L
s
1 0 0 r
.32457 .3149 m
.33726 .29817 L
s
0 0 1 r
.66274 .29817 m
.67543 .3149 L
s
1 0 0 r
.28996 .36001 m
.29151 .34608 L
s
0 0 1 r
.70849 .34608 m
.71004 .36001 L
s
1 0 0 r
.4734 .75754 m
.45527 .74996 L
s
0 0 1 r
.54473 .74996 m
.5266 .75754 L
s
1 0 0 r
.29995 .34312 m
.30918 .32502 L
s
0 0 1 r
.69082 .32502 m
.70005 .34312 L
s
1 0 0 r
.56133 .7515 m
.54486 .74877 L
s
0 0 1 r
.45514 .74877 m
.43867 .7515 L
s
1 0 0 r
.62454 .72693 m
.61192 .72545 L
s
0 0 1 r
.38808 .72545 m
.37546 .72693 L
s
1 0 0 r
.32274 .32274 m
.31707 .31707 L
s
0 0 1 r
.32274 .67726 m
.31707 .68293 L
s
1 0 0 r
.68293 .68293 m
.67726 .67726 L
s
0 0 1 r
.68293 .31707 m
.67726 .32274 L
s
1 0 0 r
.43856 .75086 m
.42075 .74078 L
s
0 0 1 r
.57925 .74078 m
.56144 .75086 L
s
1 0 0 r
.29293 .3588 m
.29305 .34587 L
s
0 0 1 r
.70695 .34587 m
.70707 .3588 L
s
.33319 .68581 m
.326 .69044 L
s
1 0 0 r
.674 .69044 m
.66681 .68581 L
s
.63876 .71745 m
.62735 .71538 L
s
0 0 1 r
.37265 .71538 m
.36124 .71745 L
s
1 0 0 r
.40541 .73985 m
.38848 .72735 L
s
0 0 1 r
.61152 .72735 m
.59459 .73985 L
s
.34506 .69522 m
.33639 .69888 L
s
1 0 0 r
.66361 .69888 m
.65494 .69522 L
s
0 0 1 r
.35826 .70519 m
.34817 .70799 L
s
1 0 0 r
.65183 .70799 m
.64174 .70519 L
s
.37488 .72486 m
.35934 .71008 L
s
0 0 1 r
.64066 .71008 m
.62512 .72486 L
s
1 0 0 r
.30591 .33829 m
.3163 .31985 L
s
0 0 1 r
.6837 .31985 m
.69409 .33829 L
s
1 0 0 r
.29736 .35606 m
.29601 .3442 L
s
0 0 1 r
.70399 .3442 m
.70264 .35606 L
s
1 0 0 r
.52679 .75509 m
.50909 .75012 L
s
0 0 1 r
.49091 .75012 m
.47321 .75509 L
s
1 0 0 r
.5787 .74382 m
.56287 .74098 L
s
0 0 1 r
.43713 .74098 m
.4213 .74382 L
s
1 0 0 r
.28634 .3709 m
.29161 .35204 L
s
0 0 1 r
.70839 .35204 m
.71366 .3709 L
s
1 0 0 r
.2853 .3738 m
.28926 .35561 L
s
0 0 1 r
.71074 .35561 m
.7147 .3738 L
s
1 0 0 r
.28864 .36721 m
.29518 .34779 L
s
0 0 1 r
.70482 .34779 m
.71136 .36721 L
s
1 0 0 r
.30328 .35177 m
.30043 .34101 L
s
0 0 1 r
.69957 .34101 m
.69672 .35177 L
s
1 0 0 r
.31306 .33358 m
.32457 .3149 L
s
0 0 1 r
.67543 .3149 m
.68694 .33358 L
s
1 0 0 r
.28556 .37569 m
.28818 .35826 L
s
0 0 1 r
.71182 .35826 m
.71444 .37569 L
s
1 0 0 r
.49101 .7547 m
.47272 .74731 L
s
0 0 1 r
.52728 .74731 m
.50899 .7547 L
s
1 0 0 r
.29217 .363 m
.29995 .34312 L
s
0 0 1 r
.70005 .34312 m
.70783 .363 L
s
1 0 0 r
.45527 .74996 m
.43702 .74007 L
s
0 0 1 r
.56298 .74007 m
.54473 .74996 L
s
1 0 0 r
.28715 .37636 m
.28839 .35979 L
s
0 0 1 r
.71161 .35979 m
.71285 .37636 L
s
1 0 0 r
.59563 .73504 m
.58061 .73196 L
s
0 0 1 r
.41939 .73196 m
.40437 .73504 L
s
1 0 0 r
.31072 .34595 m
.30635 .33632 L
s
0 0 1 r
.69365 .33632 m
.68928 .34595 L
s
1 0 0 r
.42075 .74078 m
.40315 .72842 L
s
0 0 1 r
.59685 .72842 m
.57925 .74078 L
s
1 0 0 r
.38848 .72735 m
.37209 .71264 L
s
0 0 1 r
.62791 .71264 m
.61152 .72735 L
s
1 0 0 r
.35934 .71008 m
.34463 .69319 L
s
0 0 1 r
.65537 .69319 m
.64066 .71008 L
s
1 0 0 r
.54486 .74877 m
.52747 .74383 L
s
0 0 1 r
.47253 .74383 m
.45514 .74877 L
s
1 0 0 r
.29692 .35852 m
.30591 .33829 L
s
0 0 1 r
.69409 .33829 m
.70308 .35852 L
s
1 0 0 r
.29015 .37565 m
.28996 .36001 L
s
0 0 1 r
.71004 .36001 m
.70985 .37565 L
s
1 0 0 r
.31969 .3387 m
.31379 .33018 L
s
0 0 1 r
.68621 .33018 m
.68031 .3387 L
s
1 0 0 r
.61192 .72545 m
.59786 .72199 L
s
0 0 1 r
.40214 .72199 m
.38808 .72545 L
s
1 0 0 r
.33017 .33017 m
.32274 .32274 L
s
0 0 1 r
.33017 .66983 m
.32274 .67726 L
s
1 0 0 r
.67726 .67726 m
.66983 .66983 L
s
0 0 1 r
.67726 .32274 m
.66983 .33017 L
s
1 0 0 r
.29458 .37342 m
.29293 .3588 L
s
0 0 1 r
.70707 .3588 m
.70542 .37342 L
s
1 0 0 r
.30288 .35407 m
.31306 .33358 L
s
0 0 1 r
.68694 .33358 m
.69712 .35407 L
s
1 0 0 r
.50909 .75012 m
.49078 .74286 L
s
0 0 1 r
.50922 .74286 m
.49091 .75012 L
s
1 0 0 r
.62735 .71538 m
.61441 .71139 L
s
0 0 1 r
.38559 .71139 m
.37265 .71538 L
s
.34211 .6794 m
.33319 .68581 L
s
1 0 0 r
.66681 .68581 m
.65789 .6794 L
s
.28274 .39137 m
.28634 .3709 L
s
0 0 1 r
.71366 .3709 m
.71726 .39137 L
s
1 0 0 r
.28373 .38826 m
.28864 .36721 L
s
0 0 1 r
.71136 .36721 m
.71627 .38826 L
s
1 0 0 r
.64174 .70519 m
.63004 .70052 L
s
0 0 1 r
.36996 .70052 m
.35826 .70519 L
s
.35541 .68974 m
.34506 .69522 L
s
1 0 0 r
.65494 .69522 m
.64459 .68974 L
s
.56287 .74098 m
.54597 .73599 L
s
0 0 1 r
.45403 .73599 m
.43713 .74098 L
s
1 0 0 r
.28305 .39361 m
.2853 .3738 L
s
0 0 1 r
.7147 .3738 m
.71695 .39361 L
s
1 0 0 r
.28598 .38451 m
.29217 .363 L
s
0 0 1 r
.70783 .363 m
.71402 .38451 L
s
1 0 0 r
.47272 .74731 m
.45416 .7376 L
s
0 0 1 r
.54584 .7376 m
.52728 .74731 L
s
1 0 0 r
.3005 .36962 m
.29736 .35606 L
s
0 0 1 r
.70264 .35606 m
.6995 .36962 L
s
1 0 0 r
.43702 .74007 m
.41885 .72789 L
s
0 0 1 r
.58115 .72789 m
.56298 .74007 L
s
1 0 0 r
.37209 .71264 m
.35644 .6958 L
s
0 0 1 r
.64356 .6958 m
.62791 .71264 L
s
1 0 0 r
.40315 .72842 m
.38598 .71384 L
s
0 0 1 r
.61402 .71384 m
.59685 .72842 L
s
.66905 .67431 m
.65537 .69319 L
s
1 0 0 r
.34463 .69319 m
.33095 .67431 L
s
.28469 .39473 m
.28556 .37569 L
s
0 0 1 r
.71444 .37569 m
.71531 .39473 L
s
1 0 0 r
.28947 .3804 m
.29692 .35852 L
s
0 0 1 r
.70308 .35852 m
.71053 .3804 L
s
1 0 0 r
.30794 .36423 m
.30328 .35177 L
s
0 0 1 r
.69672 .35177 m
.69206 .36423 L
s
1 0 0 r
.2877 .39454 m
.28715 .37636 L
s
0 0 1 r
.71285 .37636 m
.7123 .39454 L
s
1 0 0 r
.58061 .73196 m
.56437 .72679 L
s
0 0 1 r
.43563 .72679 m
.41939 .73196 L
s
1 0 0 r
.52747 .74383 m
.50931 .73666 L
s
0 0 1 r
.49069 .73666 m
.47253 .74383 L
s
1 0 0 r
.29419 .37621 m
.30288 .35407 L
s
0 0 1 r
.69712 .35407 m
.70581 .37621 L
s
1 0 0 r
.31691 .3573 m
.31072 .34595 L
s
0 0 1 r
.68928 .34595 m
.68309 .3573 L
s
1 0 0 r
.29215 .39289 m
.29015 .37565 L
s
0 0 1 r
.70985 .37565 m
.70785 .39289 L
s
1 0 0 r
.28057 .41075 m
.28373 .38826 L
s
0 0 1 r
.71627 .38826 m
.71943 .41075 L
s
1 0 0 r
.2815 .40746 m
.28598 .38451 L
s
0 0 1 r
.71402 .38451 m
.7185 .40746 L
s
1 0 0 r
.49078 .74286 m
.47205 .73332 L
s
0 0 1 r
.52795 .73332 m
.50922 .74286 L
s
1 0 0 r
.28093 .4133 m
.28274 .39137 L
s
0 0 1 r
.71726 .39137 m
.71907 .4133 L
s
1 0 0 r
.33095 .67431 m
.31846 .6536 L
s
0 0 1 r
.68154 .6536 m
.66905 .67431 L
s
1 0 0 r
.35644 .6958 m
.34171 .67695 L
s
0 0 1 r
.65829 .67695 m
.64356 .6958 L
s
1 0 0 r
.59786 .72199 m
.58245 .71649 L
s
0 0 1 r
.41755 .71649 m
.40214 .72199 L
s
1 0 0 r
.38598 .71384 m
.36943 .69711 L
s
0 0 1 r
.63057 .69711 m
.61402 .71384 L
s
1 0 0 r
.28369 .40372 m
.28947 .3804 L
s
0 0 1 r
.71053 .3804 m
.71631 .40372 L
s
1 0 0 r
.45416 .7376 m
.43553 .72561 L
s
0 0 1 r
.56447 .72561 m
.54584 .7376 L
s
1 0 0 r
.32741 .34895 m
.31969 .3387 L
s
0 0 1 r
.68031 .3387 m
.67259 .34895 L
s
1 0 0 r
.41885 .72789 m
.40097 .71347 L
s
0 0 1 r
.59903 .71347 m
.58115 .72789 L
s
1 0 0 r
.28261 .41487 m
.28305 .39361 L
s
0 0 1 r
.71695 .39361 m
.71739 .41487 L
s
1 0 0 r
.29807 .38966 m
.29458 .37342 L
s
0 0 1 r
.70542 .37342 m
.70193 .38966 L
s
1 0 0 r
.54597 .73599 m
.52813 .7288 L
s
0 0 1 r
.47187 .7288 m
.45403 .73599 L
s
1 0 0 r
.61441 .71139 m
.59999 .70542 L
s
0 0 1 r
.40001 .70542 m
.38559 .71139 L
s
1 0 0 r
.33938 .33938 m
.33017 .33017 L
s
0 0 1 r
.33938 .66062 m
.33017 .66983 L
s
1 0 0 r
.66983 .66983 m
.66062 .66062 L
s
0 0 1 r
.66983 .33017 m
.66062 .33938 L
s
1 0 0 r
.28713 .39979 m
.29419 .37621 L
s
0 0 1 r
.70581 .37621 m
.71287 .39979 L
s
1 0 0 r
.28566 .41523 m
.28469 .39473 L
s
0 0 1 r
.71531 .39473 m
.71434 .41523 L
s
1 0 0 r
.63004 .70052 m
.61677 .69393 L
s
0 0 1 r
.38323 .69393 m
.36996 .70052 L
s
.35275 .67117 m
.34211 .6794 L
s
1 0 0 r
.65789 .6794 m
.64725 .67117 L
s
.64459 .68974 m
.63258 .68239 L
s
0 0 1 r
.36742 .68239 m
.35541 .68974 L
s
1 0 0 r
.3055 .38481 m
.3005 .36962 L
s
0 0 1 r
.6995 .36962 m
.6945 .38481 L
s
.69265 .63123 m
.68154 .6536 L
s
1 0 0 r
.31846 .6536 m
.30735 .63123 L
s
.34171 .67695 m
.32811 .65626 L
s
0 0 1 r
.67189 .65626 m
.65829 .67695 L
s
1 0 0 r
.27882 .43165 m
.2815 .40746 L
s
0 0 1 r
.7185 .40746 m
.72118 .43165 L
s
1 0 0 r
.29012 .4142 m
.2877 .39454 L
s
0 0 1 r
.7123 .39454 m
.70988 .4142 L
s
1 0 0 r
.27924 .43448 m
.28057 .41075 L
s
0 0 1 r
.71943 .41075 m
.72076 .43448 L
s
1 0 0 r
.50931 .73666 m
.49056 .72721 L
s
0 0 1 r
.50944 .72721 m
.49069 .73666 L
s
1 0 0 r
.27968 .42825 m
.28369 .40372 L
s
0 0 1 r
.71631 .40372 m
.72032 .42825 L
s
1 0 0 r
.36943 .69711 m
.35371 .67836 L
s
0 0 1 r
.64629 .67836 m
.63057 .69711 L
s
1 0 0 r
.56437 .72679 m
.54703 .71946 L
s
0 0 1 r
.45297 .71946 m
.43563 .72679 L
s
1 0 0 r
.28098 .43648 m
.28093 .4133 L
s
0 0 1 r
.71907 .4133 m
.71902 .43648 L
s
1 0 0 r
.40097 .71347 m
.38359 .6969 L
s
0 0 1 r
.61641 .6969 m
.59903 .71347 L
s
1 0 0 r
.28181 .42457 m
.28713 .39979 L
s
0 0 1 r
.71287 .39979 m
.71819 .42457 L
s
1 0 0 r
.31446 .37834 m
.30794 .36423 L
s
0 0 1 r
.69206 .36423 m
.68554 .37834 L
s
1 0 0 r
.47205 .73332 m
.45308 .72149 L
s
0 0 1 r
.54692 .72149 m
.52795 .73332 L
s
1 0 0 r
.43553 .72561 m
.41704 .71138 L
s
0 0 1 r
.58296 .71138 m
.56447 .72561 L
s
1 0 0 r
.29603 .41163 m
.29215 .39289 L
s
0 0 1 r
.70785 .39289 m
.70397 .41163 L
s
1 0 0 r
.28406 .4374 m
.28261 .41487 L
s
0 0 1 r
.71739 .41487 m
.71594 .4374 L
s
.70224 .60744 m
.69265 .63123 L
s
1 0 0 r
.30735 .63123 m
.29776 .60744 L
s
0 0 1 r
.68419 .63391 m
.67189 .65626 L
s
1 0 0 r
.32811 .65626 m
.31581 .63391 L
s
.32495 .37033 m
.31691 .3573 L
s
0 0 1 r
.68309 .3573 m
.67505 .37033 L
s
1 0 0 r
.27754 .45375 m
.27968 .42825 L
s
0 0 1 r
.72032 .42825 m
.72246 .45375 L
s
1 0 0 r
.58245 .71649 m
.5658 .7089 L
s
0 0 1 r
.4342 .7089 m
.41755 .71649 L
s
1 0 0 r
.27803 .45682 m
.27882 .43165 L
s
0 0 1 r
.72118 .43165 m
.72197 .45682 L
s
1 0 0 r
.27833 .45029 m
.28181 .42457 L
s
0 0 1 r
.71819 .42457 m
.72167 .45029 L
s
1 0 0 r
.35371 .67836 m
.33902 .65777 L
s
0 0 1 r
.66098 .65777 m
.64629 .67836 L
s
1 0 0 r
.52813 .7288 m
.50953 .71938 L
s
0 0 1 r
.49047 .71938 m
.47187 .7288 L
s
1 0 0 r
.28854 .43703 m
.28566 .41523 L
s
0 0 1 r
.71434 .41523 m
.71146 .43703 L
s
1 0 0 r
.27982 .45922 m
.27924 .43448 L
s
0 0 1 r
.72076 .43448 m
.72018 .45922 L
s
1 0 0 r
.30345 .40742 m
.29807 .38966 L
s
0 0 1 r
.70193 .38966 m
.69655 .40742 L
s
1 0 0 r
.33694 .36093 m
.32741 .34895 L
s
0 0 1 r
.67259 .34895 m
.66306 .36093 L
s
.71015 .58246 m
.70224 .60744 L
s
1 0 0 r
.29776 .60744 m
.28985 .58246 L
s
.38359 .6969 m
.36693 .67832 L
s
0 0 1 r
.63307 .67832 m
.61641 .6969 L
s
1 0 0 r
.59999 .70542 m
.58419 .69742 L
s
0 0 1 r
.41581 .69742 m
.40001 .70542 L
s
1 0 0 r
.28295 .46069 m
.28098 .43648 L
s
0 0 1 r
.71902 .43648 m
.71705 .46069 L
s
.69501 .61015 m
.68419 .63391 L
s
1 0 0 r
.31581 .63391 m
.30499 .61015 L
s
.49056 .72721 m
.47141 .71553 L
s
0 0 1 r
.52859 .71553 m
.50944 .72721 L
s
1 0 0 r
.27732 .47992 m
.27754 .45375 L
s
0 0 1 r
.72246 .45375 m
.72268 .47992 L
s
1 0 0 r
.27676 .47666 m
.27833 .45029 L
s
0 0 1 r
.72167 .45029 m
.72324 .47666 L
s
1 0 0 r
.35036 .35036 m
.33938 .33938 L
s
0 0 1 r
.35036 .64964 m
.33938 .66062 L
s
1 0 0 r
.66062 .66062 m
.64964 .64964 L
s
0 0 1 r
.66062 .33938 m
.64964 .35036 L
s
1 0 0 r
.41704 .71138 m
.39891 .69501 L
s
0 0 1 r
.60109 .69501 m
.58296 .71138 L
s
1 0 0 r
.29445 .43517 m
.29012 .4142 L
s
0 0 1 r
.70988 .4142 m
.70555 .43517 L
s
1 0 0 r
.45308 .72149 m
.4341 .70745 L
s
0 0 1 r
.5659 .70745 m
.54692 .72149 L
s
1 0 0 r
.61677 .69393 m
.60198 .68538 L
s
0 0 1 r
.39802 .68538 m
.38323 .69393 L
s
1 0 0 r
.27918 .48269 m
.27803 .45682 L
s
0 0 1 r
.72197 .45682 m
.72082 .48269 L
s
1 0 0 r
.31239 .40155 m
.3055 .38481 L
s
0 0 1 r
.6945 .38481 m
.68761 .40155 L
s
1 0 0 r
.64725 .67117 m
.63489 .66111 L
s
0 0 1 r
.36511 .66111 m
.35275 .67117 L
s
1 0 0 r
.28985 .58246 m
.28372 .5566 L
s
0 0 1 r
.71628 .5566 m
.71015 .58246 L
s
1 0 0 r
.63258 .68239 m
.61895 .67315 L
s
0 0 1 r
.38105 .67315 m
.36742 .68239 L
s
1 0 0 r
.33902 .65777 m
.32556 .63554 L
s
0 0 1 r
.67444 .63554 m
.66098 .65777 L
s
1 0 0 r
.28745 .46099 m
.28406 .4374 L
s
0 0 1 r
.71594 .4374 m
.71255 .46099 L
s
1 0 0 r
.27713 .50338 m
.27676 .47666 L
s
0 0 1 r
.72324 .47666 m
.72287 .50338 L
s
1 0 0 r
.54703 .71946 m
.52876 .70997 L
s
0 0 1 r
.47124 .70997 m
.45297 .71946 L
s
.70421 .58523 m
.69501 .61015 L
s
1 0 0 r
.30499 .61015 m
.29579 .58523 L
s
.28235 .48469 m
.27982 .45922 L
s
0 0 1 r
.72018 .45922 m
.71765 .48469 L
s
1 0 0 r
.27906 .50647 m
.27732 .47992 L
s
0 0 1 r
.72268 .47992 m
.72094 .50647 L
s
1 0 0 r
.28372 .5566 m
.27946 .53013 L
s
0 0 1 r
.72054 .53013 m
.71628 .5566 L
s
1 0 0 r
.27946 .53013 m
.27713 .50338 L
s
0 0 1 r
.72287 .50338 m
.72054 .53013 L
s
1 0 0 r
.36693 .67832 m
.35121 .6579 L
s
0 0 1 r
.64879 .6579 m
.63307 .67832 L
s
1 0 0 r
.30185 .43171 m
.29603 .41163 L
s
0 0 1 r
.70397 .41163 m
.69815 .43171 L
s
1 0 0 r
.32286 .39403 m
.31446 .37834 L
s
0 0 1 r
.68554 .37834 m
.67714 .39403 L
s
1 0 0 r
.28228 .50897 m
.27918 .48269 L
s
0 0 1 r
.72082 .48269 m
.71772 .50897 L
s
.71166 .55944 m
.70421 .58523 L
s
1 0 0 r
.29579 .58523 m
.28834 .55944 L
s
.28274 .53308 m
.27906 .50647 L
s
0 0 1 r
.72094 .50647 m
.71726 .53308 L
s
1 0 0 r
.32556 .63554 m
.31351 .6119 L
s
0 0 1 r
.68649 .6119 m
.67444 .63554 L
s
1 0 0 r
.29336 .4599 m
.28854 .43703 L
s
0 0 1 r
.71146 .43703 m
.70664 .4599 L
s
1 0 0 r
.28688 .48566 m
.28295 .46069 L
s
0 0 1 r
.71705 .46069 m
.71312 .48566 L
s
1 0 0 r
.28834 .55944 m
.28274 .53308 L
s
0 0 1 r
.71726 .53308 m
.71166 .55944 L
s
1 0 0 r
.39891 .69501 m
.38138 .67663 L
s
0 0 1 r
.61862 .67663 m
.60109 .69501 L
s
1 0 0 r
.50953 .71938 m
.49035 .70776 L
s
0 0 1 r
.50965 .70776 m
.49047 .71938 L
s
1 0 0 r
.5658 .7089 m
.54804 .69921 L
s
0 0 1 r
.45196 .69921 m
.4342 .7089 L
s
1 0 0 r
.28684 .5106 m
.28235 .48469 L
s
0 0 1 r
.71765 .48469 m
.71316 .5106 L
s
1 0 0 r
.28733 .53535 m
.28228 .50897 L
s
0 0 1 r
.71772 .50897 m
.71267 .53535 L
s
1 0 0 r
.33483 .38499 m
.32495 .37033 L
s
0 0 1 r
.67505 .37033 m
.66517 .38499 L
s
1 0 0 r
.4341 .70745 m
.41534 .69129 L
s
0 0 1 r
.58466 .69129 m
.5659 .70745 L
s
.69696 .58712 m
.68649 .6119 L
s
1 0 0 r
.31351 .6119 m
.30304 .58712 L
s
.47141 .71553 m
.45207 .70165 L
s
0 0 1 r
.54793 .70165 m
.52859 .71553 L
s
1 0 0 r
.31076 .42655 m
.30345 .40742 L
s
0 0 1 r
.69655 .40742 m
.68924 .42655 L
s
1 0 0 r
.35121 .6579 m
.33662 .63585 L
s
0 0 1 r
.66338 .63585 m
.64879 .6579 L
s
1 0 0 r
.29279 .48537 m
.28745 .46099 L
s
0 0 1 r
.71255 .46099 m
.70721 .48537 L
s
1 0 0 r
.29428 .5615 m
.28733 .53535 L
s
0 0 1 r
.71267 .53535 m
.70572 .5615 L
s
1 0 0 r
.30074 .45726 m
.29445 .43517 L
s
0 0 1 r
.70555 .43517 m
.69926 .45726 L
s
1 0 0 r
.30304 .58712 m
.29428 .5615 L
s
0 0 1 r
.70572 .5615 m
.69696 .58712 L
s
1 0 0 r
.58419 .69742 m
.56712 .68739 L
s
0 0 1 r
.43288 .68739 m
.41581 .69742 L
s
1 0 0 r
.34827 .37458 m
.33694 .36093 L
s
0 0 1 r
.66306 .36093 m
.65173 .37458 L
s
1 0 0 r
.29276 .51111 m
.28688 .48566 L
s
0 0 1 r
.71312 .48566 m
.70724 .51111 L
s
1 0 0 r
.29326 .53665 m
.28684 .5106 L
s
0 0 1 r
.71316 .5106 m
.70674 .53665 L
s
1 0 0 r
.38138 .67663 m
.36467 .65644 L
s
0 0 1 r
.63533 .65644 m
.61862 .67663 L
s
1 0 0 r
.33662 .63585 m
.32337 .61241 L
s
0 0 1 r
.67663 .61241 m
.66338 .63585 L
s
1 0 0 r
.52876 .70997 m
.50973 .69833 L
s
0 0 1 r
.49027 .69833 m
.47124 .70997 L
s
1 0 0 r
.32119 .4197 m
.31239 .40155 L
s
0 0 1 r
.68761 .40155 m
.67881 .4197 L
s
1 0 0 r
.36307 .36307 m
.35036 .35036 L
s
.64964 .64964 m
.63693 .63693 L
s
0 0 1 r
.36307 .63693 m
.35036 .64964 L
s
.64964 .35036 m
.63693 .36307 L
s
1 0 0 r
.60198 .68538 m
.58578 .67488 L
s
0 0 1 r
.41422 .67488 m
.39802 .68538 L
s
1 0 0 r
.30014 .48361 m
.29336 .4599 L
s
0 0 1 r
.70664 .4599 m
.69986 .48361 L
s
1 0 0 r
.63489 .66111 m
.62089 .64926 L
s
0 0 1 r
.37911 .64926 m
.36511 .66111 L
s
1 0 0 r
.61895 .67315 m
.60378 .66203 L
s
0 0 1 r
.39622 .66203 m
.38105 .67315 L
s
1 0 0 r
.30155 .56251 m
.29326 .53665 L
s
0 0 1 r
.70674 .53665 m
.69845 .56251 L
s
1 0 0 r
.3096 .45294 m
.30185 .43171 L
s
0 0 1 r
.69815 .43171 m
.6904 .45294 L
s
1 0 0 r
.32337 .61241 m
.31163 .58787 L
s
0 0 1 r
.68837 .58787 m
.67663 .61241 L
s
1 0 0 r
.41534 .69129 m
.39702 .67315 L
s
0 0 1 r
.60298 .67315 m
.58466 .69129 L
s
1 0 0 r
.31163 .58787 m
.30155 .56251 L
s
0 0 1 r
.69845 .56251 m
.68837 .58787 L
s
1 0 0 r
.49035 .70776 m
.47081 .694 L
s
0 0 1 r
.52919 .694 m
.50965 .70776 L
s
1 0 0 r
.30008 .51027 m
.29279 .48537 L
s
0 0 1 r
.70721 .48537 m
.69992 .51027 L
s
1 0 0 r
.30055 .53673 m
.29276 .51111 L
s
0 0 1 r
.70724 .51111 m
.69945 .53673 L
s
1 0 0 r
.45207 .70165 m
.43279 .68569 L
s
0 0 1 r
.56721 .68569 m
.54793 .70165 L
s
1 0 0 r
.36467 .65644 m
.349 .63463 L
s
0 0 1 r
.651 .63463 m
.63533 .65644 L
s
1 0 0 r
.33313 .41119 m
.32286 .39403 L
s
0 0 1 r
.67714 .39403 m
.66687 .41119 L
s
1 0 0 r
.54804 .69921 m
.52934 .68744 L
s
0 0 1 r
.47066 .68744 m
.45196 .69921 L
s
1 0 0 r
.30896 .48022 m
.30074 .45726 L
s
0 0 1 r
.69926 .45726 m
.69104 .48022 L
s
1 0 0 r
.31998 .44688 m
.31076 .42655 L
s
0 0 1 r
.68924 .42655 m
.68002 .44688 L
s
1 0 0 r
.3102 .56221 m
.30055 .53673 L
s
0 0 1 r
.69945 .53673 m
.6898 .56221 L
s
1 0 0 r
.349 .63463 m
.33457 .61147 L
s
0 0 1 r
.66543 .61147 m
.651 .63463 L
s
1 0 0 r
.39702 .67315 m
.3794 .65321 L
s
0 0 1 r
.6206 .65321 m
.60298 .67315 L
s
1 0 0 r
.34654 .40116 m
.33483 .38499 L
s
0 0 1 r
.66517 .38499 m
.65346 .40116 L
s
1 0 0 r
.30885 .50788 m
.30014 .48361 L
s
0 0 1 r
.69986 .48361 m
.69115 .50788 L
s
1 0 0 r
.30926 .53538 m
.30008 .51027 L
s
0 0 1 r
.69992 .51027 m
.69074 .53538 L
s
1 0 0 r
.32158 .58723 m
.3102 .56221 L
s
0 0 1 r
.6898 .56221 m
.67842 .58723 L
s
1 0 0 r
.33457 .61147 m
.32158 .58723 L
s
0 0 1 r
.67842 .58723 m
.66543 .61147 L
s
1 0 0 r
.56712 .68739 m
.54895 .67537 L
s
0 0 1 r
.45105 .67537 m
.43288 .68739 L
s
1 0 0 r
.50973 .69833 m
.49016 .68461 L
s
0 0 1 r
.50984 .68461 m
.49027 .69833 L
s
1 0 0 r
.43279 .68569 m
.41379 .66779 L
s
0 0 1 r
.58621 .66779 m
.56721 .68569 L
s
1 0 0 r
.36135 .38982 m
.34827 .37458 L
s
0 0 1 r
.65173 .37458 m
.63865 .38982 L
s
1 0 0 r
.47081 .694 m
.45115 .6782 L
s
0 0 1 r
.54885 .6782 m
.52919 .694 L
s
1 0 0 r
.31927 .47509 m
.3096 .45294 L
s
0 0 1 r
.6904 .45294 m
.68073 .47509 L
s
1 0 0 r
.33187 .43909 m
.32119 .4197 L
s
0 0 1 r
.67881 .4197 m
.66813 .43909 L
s
1 0 0 r
.3794 .65321 m
.36269 .6317 L
s
0 0 1 r
.63731 .6317 m
.6206 .65321 L
s
1 0 0 r
.58578 .67488 m
.56832 .66246 L
s
0 0 1 r
.43168 .66246 m
.41422 .67488 L
s
1 0 0 r
.32025 .5604 m
.30926 .53538 L
s
0 0 1 r
.69074 .53538 m
.67975 .5604 L
s
1 0 0 r
.63693 .63693 m
.62256 .62256 L
s
0 0 1 r
.63693 .36307 m
.62256 .37744 L
s
1 0 0 r
.37744 .37744 m
.36307 .36307 L
s
0 0 1 r
.37744 .62256 m
.36307 .63693 L
s
1 0 0 r
.60378 .66203 m
.58719 .64909 L
s
0 0 1 r
.41281 .64909 m
.39622 .66203 L
s
1 0 0 r
.62089 .64926 m
.60535 .63566 L
s
0 0 1 r
.39465 .63566 m
.37911 .64926 L
s
1 0 0 r
.31908 .50379 m
.30896 .48022 L
s
0 0 1 r
.69104 .48022 m
.68092 .50379 L
s
1 0 0 r
.31941 .53241 m
.30885 .50788 L
s
0 0 1 r
.69115 .50788 m
.68059 .53241 L
s
1 0 0 r
.36269 .6317 m
.34713 .60887 L
s
0 0 1 r
.65287 .60887 m
.63731 .6317 L
s
1 0 0 r
.52934 .68744 m
.50992 .67366 L
s
0 0 1 r
.49008 .67366 m
.47066 .68744 L
s
1 0 0 r
.33293 .585 m
.32025 .5604 L
s
0 0 1 r
.67975 .5604 m
.66707 .585 L
s
1 0 0 r
.34523 .42966 m
.33313 .41119 L
s
0 0 1 r
.66687 .41119 m
.65477 .42966 L
s
1 0 0 r
.41379 .66779 m
.39534 .64813 L
s
0 0 1 r
.60466 .64813 m
.58621 .66779 L
s
1 0 0 r
.33108 .46819 m
.31998 .44688 L
s
0 0 1 r
.68002 .44688 m
.66892 .46819 L
s
1 0 0 r
.34713 .60887 m
.33293 .585 L
s
0 0 1 r
.66707 .585 m
.65287 .60887 L
s
1 0 0 r
.49016 .68461 m
.47027 .66892 L
s
0 0 1 r
.52973 .66892 m
.50984 .68461 L
s
1 0 0 r
.45115 .6782 m
.4316 .66052 L
s
0 0 1 r
.5684 .66052 m
.54885 .6782 L
s
1 0 0 r
.33173 .5569 m
.31941 .53241 L
s
0 0 1 r
.68059 .53241 m
.66827 .5569 L
s
1 0 0 r
.36001 .41872 m
.34654 .40116 L
s
0 0 1 r
.65346 .40116 m
.63999 .41872 L
s
1 0 0 r
.33079 .49791 m
.31927 .47509 L
s
0 0 1 r
.68073 .47509 m
.66921 .49791 L
s
1 0 0 r
.54895 .67537 m
.52986 .66142 L
s
0 0 1 r
.47014 .66142 m
.45105 .67537 L
s
1 0 0 r
.39534 .64813 m
.37768 .62694 L
s
0 0 1 r
.62232 .62694 m
.60466 .64813 L
s
1 0 0 r
.33101 .52768 m
.31908 .50379 L
s
0 0 1 r
.68092 .50379 m
.66899 .52768 L
s
1 0 0 r
.34436 .45954 m
.33187 .43909 L
s
0 0 1 r
.66813 .43909 m
.65564 .45954 L
s
1 0 0 r
.34566 .58103 m
.33173 .5569 L
s
0 0 1 r
.66827 .5569 m
.65434 .58103 L
s
1 0 0 r
.3761 .40652 m
.36135 .38982 L
s
0 0 1 r
.63865 .38982 m
.6239 .40652 L
s
1 0 0 r
.37768 .62694 m
.36105 .60447 L
s
0 0 1 r
.63895 .60447 m
.62232 .62694 L
s
1 0 0 r
.56832 .66246 m
.54976 .64821 L
s
0 0 1 r
.45024 .64821 m
.43168 .66246 L
s
1 0 0 r
.4316 .66052 m
.41244 .64113 L
s
0 0 1 r
.58756 .64113 m
.5684 .66052 L
s
1 0 0 r
.36105 .60447 m
.34566 .58103 L
s
0 0 1 r
.65434 .58103 m
.63895 .60447 L
s
1 0 0 r
.50992 .67366 m
.48999 .65799 L
s
0 0 1 r
.51001 .65799 m
.49008 .67366 L
s
1 0 0 r
.62256 .62256 m
.60664 .60664 L
s
0 0 1 r
.62256 .37744 m
.60664 .39336 L
s
1 0 0 r
.39336 .39336 m
.37744 .37744 L
s
0 0 1 r
.39336 .60664 m
.37744 .62256 L
s
1 0 0 r
.58719 .64909 m
.56935 .63441 L
s
0 0 1 r
.43065 .63441 m
.41281 .64909 L
s
1 0 0 r
.34397 .49023 m
.33108 .46819 L
s
0 0 1 r
.66892 .46819 m
.65603 .49023 L
s
1 0 0 r
.60535 .63566 m
.58839 .62042 L
s
0 0 1 r
.41161 .62042 m
.39465 .63566 L
s
1 0 0 r
.47027 .66892 m
.45033 .6514 L
s
0 0 1 r
.54967 .6514 m
.52973 .66892 L
s
1 0 0 r
.34463 .55159 m
.33101 .52768 L
s
0 0 1 r
.66899 .52768 m
.65537 .55159 L
s
1 0 0 r
.35907 .44924 m
.34523 .42966 L
s
0 0 1 r
.65477 .42966 m
.64093 .44924 L
s
1 0 0 r
.34406 .52113 m
.33079 .49791 L
s
0 0 1 r
.66921 .49791 m
.65594 .52113 L
s
1 0 0 r
.41244 .64113 m
.39392 .62027 L
s
0 0 1 r
.60608 .62027 m
.58756 .64113 L
s
1 0 0 r
.52986 .66142 m
.51008 .64567 L
s
0 0 1 r
.48992 .64567 m
.47014 .66142 L
s
1 0 0 r
.35978 .5752 m
.34463 .55159 L
s
0 0 1 r
.65537 .55159 m
.64022 .5752 L
s
.63999 .41872 m
.62488 .43748 L
s
1 0 0 r
.37512 .43748 m
.36001 .41872 L
s
.35858 .48079 m
.34436 .45954 L
s
0 0 1 r
.65564 .45954 m
.64142 .48079 L
s
1 0 0 r
.39392 .62027 m
.37629 .5982 L
s
0 0 1 r
.62371 .5982 m
.60608 .62027 L
s
1 0 0 r
.45033 .6514 m
.43059 .63225 L
s
0 0 1 r
.56941 .63225 m
.54967 .6514 L
s
1 0 0 r
.37629 .5982 m
.35978 .5752 L
s
0 0 1 r
.64022 .5752 m
.62371 .5982 L
s
1 0 0 r
.48999 .65799 m
.46981 .64058 L
s
0 0 1 r
.53019 .64058 m
.51001 .65799 L
s
1 0 0 r
.35894 .54442 m
.34406 .52113 L
s
0 0 1 r
.65594 .52113 m
.64106 .54442 L
s
1 0 0 r
.54976 .64821 m
.53031 .63226 L
s
0 0 1 r
.46969 .63226 m
.45024 .64821 L
s
1 0 0 r
.35853 .51274 m
.34397 .49023 L
s
0 0 1 r
.65603 .49023 m
.64147 .51274 L
s
.6239 .40652 m
.60762 .42452 L
s
1 0 0 r
.39238 .42452 m
.3761 .40652 L
s
.56935 .63441 m
.55043 .61813 L
s
0 0 1 r
.44957 .61813 m
.43065 .63441 L
s
1 0 0 r
.60664 .60664 m
.58932 .58932 L
s
0 0 1 r
.60664 .39336 m
.58932 .41068 L
s
1 0 0 r
.41068 .41068 m
.39336 .39336 L
s
0 0 1 r
.41068 .58932 m
.39336 .60664 L
s
.64093 .44924 m
.62547 .46973 L
s
1 0 0 r
.37453 .46973 m
.35907 .44924 L
s
.58839 .62042 m
.57018 .60368 L
s
0 0 1 r
.42982 .60368 m
.41161 .62042 L
s
1 0 0 r
.43059 .63225 m
.41132 .61171 L
s
0 0 1 r
.58868 .61171 m
.56941 .63225 L
s
1 0 0 r
.37525 .56749 m
.35894 .54442 L
s
0 0 1 r
.64106 .54442 m
.62475 .56749 L
s
1 0 0 r
.51008 .64567 m
.48984 .62827 L
s
0 0 1 r
.51016 .62827 m
.48992 .64567 L
s
1 0 0 r
.46981 .64058 m
.44964 .62162 L
s
0 0 1 r
.55036 .62162 m
.53019 .64058 L
s
.64142 .48079 m
.62564 .5026 L
s
1 0 0 r
.37436 .5026 m
.35858 .48079 L
s
.41132 .61171 m
.39279 .59002 L
s
0 0 1 r
.60721 .59002 m
.58868 .61171 L
s
1 0 0 r
.3746 .53541 m
.35853 .51274 L
s
0 0 1 r
.64147 .51274 m
.6254 .53541 L
s
1 0 0 r
.39279 .59002 m
.37525 .56749 L
s
0 0 1 r
.62475 .56749 m
.60721 .59002 L
s
.62488 .43748 m
.60827 .45724 L
s
1 0 0 r
.39173 .45724 m
.37512 .43748 L
s
.53031 .63226 m
.51021 .61476 L
s
0 0 1 r
.48979 .61476 m
.46969 .63226 L
s
1 0 0 r
.44964 .62162 m
.42976 .60134 L
s
0 0 1 r
.57024 .60134 m
.55036 .62162 L
s
.60762 .42452 m
.58998 .44361 L
s
1 0 0 r
.41002 .44361 m
.39238 .42452 L
s
0 0 1 r
.6254 .53541 m
.60802 .55794 L
s
1 0 0 r
.39198 .55794 m
.3746 .53541 L
s
0 0 1 r
.62547 .46973 m
.60855 .49085 L
s
1 0 0 r
.39145 .49085 m
.37453 .46973 L
s
.48984 .62827 m
.46942 .60941 L
s
0 0 1 r
.53058 .60941 m
.51016 .62827 L
s
1 0 0 r
.55043 .61813 m
.53067 .60041 L
s
0 0 1 r
.46933 .60041 m
.44957 .61813 L
s
1 0 0 r
.58932 .58932 m
.5708 .5708 L
s
0 0 1 r
.58932 .41068 m
.5708 .4292 L
s
1 0 0 r
.4292 .4292 m
.41068 .41068 L
s
0 0 1 r
.4292 .5708 m
.41068 .58932 L
s
.62564 .5026 m
.60847 .52466 L
s
1 0 0 r
.39153 .52466 m
.37436 .5026 L
s
.57018 .60368 m
.55095 .58562 L
s
0 0 1 r
.44905 .58562 m
.42982 .60368 L
s
1 0 0 r
.42976 .60134 m
.41046 .58002 L
s
0 0 1 r
.58954 .58002 m
.57024 .60134 L
s
1 0 0 r
.41046 .58002 m
.39198 .55794 L
s
0 0 1 r
.60802 .55794 m
.58954 .58002 L
s
.60827 .45724 m
.59034 .47774 L
s
1 0 0 r
.40966 .47774 m
.39173 .45724 L
s
.51021 .61476 m
.48973 .59592 L
s
0 0 1 r
.51027 .59592 m
.48979 .61476 L
s
1 0 0 r
.46942 .60941 m
.4491 .58935 L
s
0 0 1 r
.5509 .58935 m
.53058 .60941 L
s
1 0 0 r
.40988 .54667 m
.39153 .52466 L
s
0 0 1 r
.60847 .52466 m
.59012 .54667 L
s
.60855 .49085 m
.59039 .51234 L
s
1 0 0 r
.40961 .51234 m
.39145 .49085 L
s
0 0 1 r
.58998 .44361 m
.57119 .46357 L
s
1 0 0 r
.42881 .46357 m
.41002 .44361 L
s
.53067 .60041 m
.51031 .58147 L
s
0 0 1 r
.48969 .58147 m
.46933 .60041 L
s
1 0 0 r
.4491 .58935 m
.42916 .56834 L
s
0 0 1 r
.57084 .56834 m
.5509 .58935 L
s
1 0 0 r
.42916 .56834 m
.40988 .54667 L
s
0 0 1 r
.59012 .54667 m
.57084 .56834 L
s
1 0 0 r
.5708 .5708 m
.5513 .5513 L
s
0 0 1 r
.5708 .4292 m
.5513 .4487 L
s
1 0 0 r
.4487 .4487 m
.4292 .4292 L
s
0 0 1 r
.4487 .5513 m
.4292 .5708 L
s
1 0 0 r
.55095 .58562 m
.53092 .56645 L
s
0 0 1 r
.46908 .56645 m
.44905 .58562 L
s
1 0 0 r
.48973 .59592 m
.46914 .57598 L
s
0 0 1 r
.53086 .57598 m
.51027 .59592 L
s
.59034 .47774 m
.57132 .49871 L
s
1 0 0 r
.42868 .49871 m
.40966 .47774 L
s
0 0 1 r
.59039 .51234 m
.5712 .53389 L
s
1 0 0 r
.4288 .53389 m
.40961 .51234 L
s
.51031 .58147 m
.48964 .56155 L
s
0 0 1 r
.51036 .56155 m
.48969 .58147 L
s
1 0 0 r
.46914 .57598 m
.44873 .5552 L
s
0 0 1 r
.55127 .5552 m
.53086 .57598 L
s
.57119 .46357 m
.55148 .48411 L
s
1 0 0 r
.44852 .48411 m
.42881 .46357 L
s
.44873 .5552 m
.4288 .53389 L
s
0 0 1 r
.5712 .53389 m
.55127 .5552 L
s
1 0 0 r
.53092 .56645 m
.51038 .54644 L
s
0 0 1 r
.48962 .54644 m
.46908 .56645 L
s
1 0 0 r
.46892 .46892 m
.4487 .4487 L
s
.5513 .5513 m
.53108 .53108 L
s
0 0 1 r
.46892 .53108 m
.4487 .5513 L
s
.5513 .4487 m
.53108 .46892 L
s
1 0 0 r
.44853 .51987 m
.42868 .49871 L
s
0 0 1 r
.57132 .49871 m
.55147 .51987 L
s
1 0 0 r
.48964 .56155 m
.46895 .54092 L
s
0 0 1 r
.53105 .54092 m
.51036 .56155 L
s
1 0 0 r
.46895 .54092 m
.44853 .51987 L
s
0 0 1 r
.55147 .51987 m
.53105 .54092 L
s
1 0 0 r
.46888 .50497 m
.44852 .48411 L
s
0 0 1 r
.55148 .48411 m
.53112 .50497 L
s
1 0 0 r
.51038 .54644 m
.4896 .52585 L
s
0 0 1 r
.5104 .52585 m
.48962 .54644 L
s
1 0 0 r
.53108 .53108 m
.51041 .51041 L
s
0 0 1 r
.53108 .46892 m
.51041 .48959 L
s
1 0 0 r
.48959 .48959 m
.46892 .46892 L
s
0 0 1 r
.48959 .51041 m
.46892 .53108 L
s
.53112 .50497 m
.5104 .52585 L
s
1 0 0 r
.4896 .52585 m
.46888 .50497 L
s
.51041 .51041 m
.48959 .48959 L
s
0 0 1 r
.51041 .48959 m
.48959 .51041 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
OGoo2G`04goo2@0OOWoo001iOol4O009Ool5O009Ool501l9Ool401mjOol007Eooa5l00Eoo`Al0003
Ool07`0O00807`Eooa407gIoo`00Lgoo1W`03Goo17`00goo0`0O0W`00goo100O3Goo1P0OM7oo001a
OolAO008Ool2O0000`0OOomoo`03Ool00g`001l07`08OolA01mbOol006ioo`Al011oo`El009oo`80
7`03Ooml07`000=oo`807`03Ooml07`0009oo`D07a1oo`@07fmoo`00K7oo4W`02Goo0g`017oo00=l
000O01l017oo0`0O2Goo4P0OKGoo001ZOol5O00?Ool5O003Ool201l2Ool2O00017oo01l07goo0W`0
00=oo`0O01l00Woo0W`00goo1@0O3goo1@0OJgoo001YOol4O002Ool;O009Ool2O0000`0OOomoo`03
Ool00`0OO01l0003Ool201l00g`0Oomoo`03Ool00g`001l07`09Ool;01l2Ool401mZOol006Moo`=l
0003Ooml07`0009l00]oo`El00Eoo`0501moog`0O01oo`0201l3Ool00g`001l07`03Ool2O0001Goo
01l07gooO0001Goo1@0O2goo100O00Aoo`0O01l07fQoo`00IWoo1G`000=oog`0O0001G`037oo0g`0
0P0O0goo00<07g`0O0000goo0P0O00=oog`0O0000goo0P0O00Al07ooOomoo`9l00<07`aoo`L07`03
Ool07`0O00<07fMoo`00I7oo0g`000=oog`0O0000W`01goo1g`01goo00@07g`0O01oo`807`=oo`9l
000301moogoo00=oo`03O0007`0O00=oo`9l0004Ool07`0OO007Ool701l7Ool401l017oo01l07`0O
IGoo001ROol6O0000gooO01l0004O00;Ool2O004Ool0100OOomoogoo0W`017oo0P0O0W`00goo0P0O
0W`017oo0P0O0goo00=l07ooOol00Woo0P0O2goo1P0O00=oo`0O01l0100OHgoo001QOol8O006Ool4
O009Ool2O00201l2Ool201l2Ool2O0000goo01moo`03Ool00g`001l07`04Ool017`0Ool07`0O0Woo
0W`00Woo0W`00P0O2Goo100O1Woo200OHWoo001POol5O00>Ool4O006Ool00`0OOoml0002O006Ool2
O003Ool201l00gooO01l0003Ool201l6Ool301l00gooO01oo`05Ool401l>Ool501mQOol005iooa9l
00Moo`=l009oo`0601moogooOol07goo0W`00Woo0P0O0Woo0W`000<07gooOol00goo00=l000O01l0
0Woo0W`00Woo0P0O00=oog`0Ool00Woo00=l07ooOol00`0O1goo4P0OGgoo001MOol6O00=Ool4O006
Ool201l3Ool00`0OOomoo`02Ool00g`001moo`03Ool201l2O003Ool201l2O004Ool00g`001moo`03
Ool017`0Oomoogoo0W`01Woo100O3Goo1P0OGWoo001LOol>O00:Ool3O002Ool00`0OOomoo`02O000
0`0OOomoo`03Ool01P0OOoml07`0Ool07`Aoo`03O01oo`0O00Aoo`06O01oo`0O01moog`01Goo00=l
000O01l00Woo00=l07ooOol00`0O2Woo3P0OGGoo001KOol3O0000gooO01l0003O006Ool3O00:Ool2
O004Ool00`0OOoml0002O00201l4Ool2O004Ool201l00g`0Oomoo`02Ool201l4Ool2O00301l00goo
O01oo`03Ool201l:Ool301l6Ool501l017oo01l07`0OG7oo001JOol6O004Ool3O006Ool4O006Ool0
1P0OOoml07`0Ool07`Aoo`0301ml07oo009oo`807`9oo`04O01oogoo01l3Ool017`0Oomoo`0O0Woo
0W`00goo00<07g`0Ool00goo00El07oo01l07g`000Moo`@07`Ioo`<07`Aoo`H07e]oo`00F7oo2W`0
1Goo17`01Woo0W`017oo00H07gooOomoo`0OO003Ool00`0OOomoo`02O0000`0OOomoo`03Ool2O005
Ool201l5Ool00g`001l07`02Ool01W`0Oomoogoo01ml00=oo`03O01oogoo009oo`807`Ioo`@07`Eo
o`X07eUoo`00F7oo27`00Woo0g`01Woo0g`01Goo0W`000=oo`0OOol00Woo00<07gooOol00W`000<0
7gooOol00Woo00<07g`0Ool00goo0P0O00=oog`0Ool00Woo00@07gooO01l00Aoo`0301ml07oo00=o
o`03O0007`0O009oo`06O01oogooOoml07oo0P0O1Goo0`0O1Woo0`0O0Woo200OFGoo001GOol7O002
Ool3O002Ool3O006Ool2O005Ool3O0000goo01moo`03Ool0100OO01l07oo0P0O0Woo0W`000=oo`0O
Ool00goo00=l07oo01l017oo00Al07oo01l07`9oo`9l0004Ool07`0OO004Ool00g`0Ool07`0201l5
Ool201l6Ool301l2Ool301l2Ool701mHOol005Ioo`Ml0003Ooml07oo00=oo`9l00=oo`9l00Ioo`9l
009oo`0401moogooOol3O002Ool01@0OOomoogooO0001Woo0W`017oo0P0O00=l07ooOol00Woo0P0O
1Woo00D07gooOomoog`0009oo`<07`9oo`04O01oogooOol201l6Ool201l3Ool201l4Ool00`0OOol0
7`0601mGOol005Eoo`El0003Ooml07`000Al00Aoo`9l00=oo`9l00Ioo`9l000501moogooOol07`02
Ool00g`001moo`02Ool00`0OOoml0003Ool201l2Ool017`0Oomoo`0O0goo00Al07ooOol07`9oo`9l
00=oo`0301moog`000=oo`05O0007gooOoml0003Ool00g`001l07`06Ool201l3Ool201l4Ool<01mF
Ool005Eoo`El0007Ooml07ooO01oog`0Ool00W`017oo00=l07ooOol00Woo0g`017oo00D07g`0O01o
o`0O00=oo`0501ml07`0Ool07`03Ool2O0000`0OOomoo`03Ool2O005Ool201l5Ool00g`001l07`02
Ool00g`0Oomoo`0201l01W`0OomoogooO01oo`807`03O01oogoo009oo`<07`Aoo`0301moogoo009o
o`807`07Ool07goo01moo`0OOol01@0OEWoo001DOol5O0000gooO01oo`02Ool00g`0Ooml0002Ool2
O003Ool2O005Ool2O0000goo01moo`02Ool2O002Ool01P0OOomoogooO0007`Aoo`0301ml07oo00=o
o`807`03Ooml07oo009oo`0401moog`0O004Ool00`0OO01oo`03Ool00g`001moo`02Ool00g`0Oomo
o`0201l3Ool017`0Ool07`0O1Goo0P0O0goo0P0O0Woo00<07goo01l00goo1`0OEGoo001DOol7O004
Ool017`0Ooml07`00Woo00=l07ooOol00Woo00=l07ooOol017oo00D07g`0Oomoo`0O009oo`9l00Ao
o`0301ml07`0009oo`0301moogoo009l0003Ool07goo00=oo`03O01oo`0O00Aoo`06O01oo`0O01mo
og`00goo0P0O00=l07ooOol00Woo0P0O00=oog`0Ool00Woo00=l000OOol01Goo00<07gooOol00Woo
00<07gooOol00P0O00=oo`0OOol00goo1`0OEGoo001DOol5O002Ool00g`0Oomoo`02Ool017`0Oomo
og`00Woo0W`00goo0W`017oo00D07gooO01oo`0O009oo`0301moog`0009oo`0401moogooOol2O000
0`0OOomoo`02Ool2O004Ool201l00g`0Oomoo`02Ool201l4Ool00g`001l07`03Ool01G`0Oomoo`0O
O0000goo00El07oo01moog`000Aoo`807`=oo`807`9oo`0401moogoo01l4Ool00`0OOol07`0501mE
Ool005=oo`Il009oo`03O01oogoo00=oo`04O01oogooO003Ool00g`0Oomoo`02Ool017`0Oomoo`0O
0goo00D07gooOomoo`0O009oo`03O0007goo00Aoo`0301ml07oo009oo`0401moogooO002Ool01@0O
OomoogooO0000Woo00@07gooOoml00=oo`0301ml07oo00=oo`03O01oo`0O009oo`05O01oogooOoml
0003Ool017`0Oomoo`0O17oo00D07gooOomoo`0O009oo`0301moogoo00=oo`0301moogoo00H07eAo
o`00Dgoo1W`00goo00=l07ooOol00goo00Al07ooOoml00=oo`03O01oogoo009oo`9l000501moogoo
01moo`02O0000`0OOomoo`02Ool00`0OO01oo`02Ool00`0OOomoo`02O0000`0OOomoo`02Ool2O005
Ool201l4Ool00g`001l07`02Ool01W`0Oomoogoo01ml00Aoo`05O0007`0OOoml0002Ool00g`001l0
7`04Ool01@0OOomoogoo01l00Woo00<07gooOol00goo00@07gooOomoo`H07eAoo`00Dgoo1G`000Eo
og`0Oomoog`000Ioo`03O01oogoo009l009oo`03O01oogoo009oo`0501ml07ooOol07`02Ool00`0O
O01oo`02Ool0100OOomoog`00P0O17oo00<07g`0Ool00Woo0P0O00=oog`0Ool00Woo00@07gooO01l
00=oo`0301ml07oo00=oo`9l000401moogooO003Ool01@0OO01oogooO0000Woo00<07g`0Ool00goo
00<07gooOol00P0O0Woo00<07gooOol017oo00D07gooOol07goo00807`03Ool07`0O05Aoo`00DWoo
1W`000=oog`0Ool00Woo00=l07ooOol017oo00El07ooOomoog`0009oo`9l009oo`0401moog`001l2
Ool00`0OOomoo`02O0001@0OOomoogoo01l00W`00goo00H07gooOoml07oo01l4Ool00g`0Ool07`04
Ool00g`0Ool07`02Ool017`0Oomoogoo0P0O00El07ooOomoog`000807`03Ooml07oo009oo`04O000
7gooO002Ool201l2Ool01@0OOomoogoo01l01Woo00H07gooOomoo`0OOol501mDOol0059oo`Il009o
o`05O01oogooOoml0006Ool01G`0OomoogooO0000goo0W`00goo00@07g`0O0007`=oo`0501ml07`0
Ool07`03Ool2O0000`0OOomoo`02Ool00g`0Oomoo`03Ool201l00g`0Oomoo`03Ool00`0OOomoo`02
Ool00g`001l07`03Ool01G`0Ool07`0OO0000goo00Al000O01ml00=oo`807`=oo`0501moogooOol0
7`06Ool01@0OOomoogoo01l00Woo1P0ODgoo001BOol6O002Ool00g`0Oomoo`02Ool00g`0Oomoo`04
Ool01G`0OomoogooO0000goo00@07g`0Ool07`9oo`0501ml07ooOol07`03Ool00`0OOomoo`03Ool0
0`0OO01oo`02Ool00`0OOoml0003Ool01@0OOomoogooO0000goo00<07g`0Ool00goo00<07g`0Ool0
0goo00=l000OOol00Woo00El07ooOol07g`0009oo`04O01oo`0OO003Ool01@0OOomoogoo01l01Woo
00<07gooOol00Woo00@07goo01moo`D07e=oo`00DWoo17`00Woo00Al07ooOoml00Aoo`03O01oogoo
00Aoo`07O01oogooOoml07oo01l00Woo00Al07ooOol07`9oo`03O0007goo00=oo`0301ml07oo009o
o`0301moogoo009l0007Ool07gooOoml07oo01l01Goo00=l07oo01l00Woo00Al07oo01l07`9oo`06
O01oogooOol07g`017oo00El000OOomoog`0009oo`0601moogooO01oo`0O0goo00<07gooOol017oo
00<07gooOol00Woo00@07gooOol07`9oo`@07e=oo`00DWoo17`00Woo00Al07ooOoml00Eoo`03O01o
ogoo00Aoo`05O01oogooOol07`02Ool01@0OOoml07oo01l00Woo00<07g`0Ool00Woo00H07gooOoml
07oo01l5Ool00`0OOomoo`02Ool2O005Ool201l4Ool00g`0Oomoo`03Ool00g`0Ool07`02Ool01W`0
Oomoogoo01ml009oo`04O01oo`0OO002Ool00g`001moo`02Ool00`0OOomoo`04Ool00`0OOomoo`02
Ool01P0OOomoogoo01moo`D07e=oo`00DGoo1W`000=oog`0Ool00Woo00=l07ooOol00Woo00=l07oo
Ool01Goo00Ml07ooOol07g`0Ool07`02Ool0100OO01oo`0O0Woo00=l07oo01l017oo00<07gooOol0
0goo00<07gooO0000Woo00@07gooOoml00=oo`0401moogooO002Ool00`0OOoml0005Ool00g`0Oomo
o`02Ool01G`0Ool07gooO0000Woo00P07g`0Oomoog`0Ool07g`00Woo00<07gooOol017oo00<07goo
Ool00goo00@07gooOol07`9oo`H07e9oo`00DGoo17`000Eoog`0Oomoog`000=oo`03O01oogoo009o
o`03O01oogoo00Eoo`05O0007gooOoml0003Ool0100OOoml000O0goo00<07g`0Ool00Woo00D07goo
O01l07oo00807`=oo`03O0007goo00=oo`03O01oo`0O00Aoo`03O0007goo009oo`9l0005Ool07`0O
Ooml0003Ool00g`001moo`02Ool017`001moog`00goo00D07gooOoml000O00Moo`0301moogoo009o
o`0501moogooOol07`02Ool00`0OOol07`0301mBOol0055oo`Al0005Ooml07ooOoml0004Ool00g`0
Oomoo`02Ool00g`0Oomoo`05Ool017`0Oomoo`0O0W`000D07gooOol07g`000=oo`0501moog`0Ool0
7`04Ool00g`0Oomoo`03Ool00`0OO01oo`03Ool201l00g`0Oomoo`02Ool00`0OO01oo`04Ool00`0O
Oomoo`02Ool01G`0Ool07gooO0000goo00D07g`0Oomoog`000807`04O01oogoo01l7Ool00`0OOomo
o`02Ool01@0OOomoogoo01l00goo00<07goo01l00`0ODWoo001AOol4O0000gooO01oo`02Ool01G`0
OomoogooO0001Goo00=l07ooOol00goo00@07gooO0007`9oo`0601ml07ooOol07goo0W`000D07goo
Oomoo`0O00Aoo`0301moog`000=oo`0401moogooO002Ool01@0OOomoogooO0000Woo00@07gooOoml
00=oo`0301moog`000=oo`03O0007goo009oo`05O0007`0OOoml0002Ool0200OOomoogooO0007goo
O005Ool00`0OOomoo`02Ool00`0OOomoo`02Ool0100OOomoo`0O0Woo100ODWoo001AOol4O002Ool0
17`0Oomoog`017oo00=l07ooOol00goo00=l07ooOol00Woo00@07gooOoml009oo`0401moog`001l3
Ool00`0OO01oo`02Ool01@0OO01l07oo01l00goo0W`000<07gooOol00Woo00=l000OOol017oo00=l
000OOol00goo00=l000O01l00Woo00=l07ooOol00P0O00Il07ooOomoo`0OO003Ool017`001moog`0
0Woo00@07gooOoml00Aoo`0301moogoo00=oo`0301moogoo009oo`0701moogoo01moo`0OOol00`0O
DWoo001AOol3O00017ooO01oog`00goo00=l07ooOol00Woo00=l07ooOol00goo00Al07ooOol07`9o
o`0401moog`001l3Ool02@0OO01oogoo01moog`0Ool07`03Ool00g`001moo`03Ool00`0OO01oo`03
Ool00`0OO01oo`04Ool00`0OO01oo`03Ool00`0OO01oo`03Ool00g`001moo`02Ool01G`0Ool07goo
O0000Woo00T07g`0Oomoog`0Ool07gooO0000Woo00Al07ooOol07`Eoo`0301moogoo009oo`0801mo
ogooOol07goo01moo`<07e9oo`00DGoo0g`000Aoog`0Ooml00=oo`03O01oogoo00=oo`03O01oogoo
00=oo`03O01oo`0O009oo`0401moogooO002Ool01@0OOomoog`001l00goo00<07gooOol00Woo00<0
7g`0Ool00Woo00@07gooOoml009oo`0401moogooO003Ool0100OOomoog`00Woo00@07gooOoml00=o
o`0301ml07oo00=oo`06O01oogooOoml000O0Woo00Al07ooOol07`9oo`06O01oogooO01oo`0O1Goo
00<07gooOol00goo00P07gooOomoo`0OOol07goo0`0ODWoo001AOol3O0001GooO01oogooO0000goo
00=l07ooOol00Woo00=l07ooOol017oo00]l000OOomoo`0OOol07gooO01oo`0O00=oo`0601moogoo
01moog`00Woo00H07gooOoml07oo01l4Ool00g`001moo`03Ool00g`0Ool07`04Ool00g`001moo`03
Ool00g`0Ool07`02Ool01G`0Oomoo`0OO0000goo00]l07ooOomoog`0Ool07gooO01oog`0009oo`03
O0007goo00Eoo`0301moogoo009oo`0501moogooOol07`02Ool00`0OOol07`0201mBOol0055oo`=l
009oo`03O01oog`000=oo`03O01oogoo00=oo`03O01oogoo00=oo`0401ml07oo01l2Ool0100OOomo
og`00goo00D07g`0Oomoo`0O009oo`03O0007goo00=oo`03O01oogoo00=oo`0301ml07oo00=oo`80
7`03O01oogoo009oo`0301ml07oo00Aoo`0301moogoo009oo`09O0007gooOoml07oo01moog`000=o
o`0401moogooO002Ool017`0Ool07g`01Goo00<07gooOol00goo00L07gooOomoo`0OOol07`02Ool3
01mBOol0051oo`Al009oo`04O01oogooO003Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool01P0OO01o
o`0OOol07`9oo`0501moog`0Ool07`02Ool00g`001moo`02Ool00`0OO01l0002Ool00`0OOoml0003
Ool0100OOomoog`00Woo00D07gooOomoog`0009oo`0401moogooO003Ool00`0OOoml0002Ool201l0
1W`0OomoogooO0007`9oo`04O01oo`0OO003Ool01W`0Ooml07oo01ml00Eoo`0301moogoo009oo`05
01moogooOol07`02Ool00`0OOomoo`0301mBOol0051oo`Al00=oo`03O01oog`000=oo`03O01oogoo
00=oo`05O01oogooOol07`02Ool017`0Oomoo`0O0Woo00@07gooOoml00=oo`0501ml07ooOol07`03
Ool00g`001moo`02Ool2O0000`0OOomoo`02Ool00g`001moo`04Ool00g`001moo`03Ool00g`001l0
7`02Ool00g`0Ool07`03Ool01G`0Oomoo`0OO0000Woo00El000OOomoog`0009oo`04O01oogoo01l2
Ool01G`0Oomoogoo01l01Goo00L07gooOomoo`0OOol07`02Ool00`0OOol07`0201mAOol0051oo`9l
0003Ooml07`0009oo`04O01oogooO003Ool00g`0Oomoo`03Ool017`0Oomoo`0O0Woo00<07g`001l0
0Woo00P07gooOomoo`0OO01oo`0O0Woo00=l000OOol017oo00<07gooOol00Woo00<07g`0Ool00goo
00<07g`0Ool017oo00<07gooOol00goo00<07g`0Ool00goo00=l07ooOol00goo00Al000OOoml009o
o`0301ml07oo009oo`06O01oogooO0007g`00Woo00Al07ooOol07`Eoo`0501moogooOol07`02Ool0
0`0OOomoo`0201l00goo01l07`1AOol0051oo`9l0003Ooml07`0009oo`04O01oogooO003Ool00g`0
Oomoo`04Ool00g`0Ool07`02Ool01@0OOoml07oo01l00goo00D07gooOoml000O009oo`0301ml07oo
00=oo`0301moog`0009oo`0401moogooO003Ool00`0OOoml0003Ool00`0OOoml0003Ool0100OOomo
og`00Woo00<07gooO00017oo00Il07ooOomoog`001l2Ool02G`0OomoogooO01oo`0OOoml0002Ool0
0g`0Ool07`06Ool01@0OOomoogoo01l00Woo00<07gooOol00P0O00=oo`0O01l0DGoo001@Ool2O000
0gooO01l0003Ool017`0Oomoog`00goo00=l07ooOol00goo00Yl07oo01moo`0OOol07gooO0007`9o
o`0601moogooOol07g`00Woo00<07gooO0000Woo00H07gooOomoog`001l4Ool2O0001`0OOomoogoo
O01oo`0O00=oo`03O0007`0O00Aoo`03O0007goo009oo`06O01oogoo01moog`00Woo00<07g`0Ool0
0Woo00el07ooOoml000OOoml07ooO01oog`0Ool07`05Ool01@0OOomoogoo01l00Woo00@07gooOomo
o`807`03Ool07`0O055oo`00D7oo0W`000=oog`0O0000goo00Al07ooOoml00Aoo`03O01oogoo00=o
o`09O01oogoo01moo`0OOol07g`0009oo`0401moogoo01l2Ool00g`001moo`02Ool00g`001moo`03
Ool00`0OO01oo`04Ool00`0OO01oo`02Ool201l01W`0Oomoogoo01ml00Eoo`0301ml07oo00=oo`03
O0007goo009oo`05O0007gooOoml0002Ool02G`0Oomoo`0OO01oog`0Ooml0002Ool00`0OOomoo`03
Ool00`0OOomoo`02Ool0100OOomoo`0O0goo0P0O00=oo`0O01l0DGoo001@Ool2O00017ooO01oog`0
0Woo00El07ooOomoog`000Aoo`03O01oogoo009oo`0501ml000OOol07`02Ool0100OOoml000O0Woo
00H07gooOomoo`0OO004Ool01@0OO01oogoo01l00Woo00=l07ooOol00P0O0Woo00=l07oo01l00goo
00=l07oo01l00Woo0W`00Woo00@07gooOoml009oo`807`06O01oogooOol07g`00Woo00Ql07ooOomo
og`001moog`00Woo00El07ooO0007g`000Aoo`0301moogoo009oo`0501moogooOol07`02Ool0100O
Ool07goo0P0ODGoo001@Ool2O00017ooO01oog`00goo00Al07ooOoml00Aoo`03O01oogoo009oo`07
01moog`0Ool07goo01l00goo00Al07ooOol07`=oo`0301moog`0009oo`0501moogooO0007`04Ool0
0g`001moo`03Ool00g`001moo`04Ool00`0OOomoo`03Ool00g`001moo`02Ool00g`0Ool07`03Ool0
1G`0Ool07gooO0000goo00Al07ooOol07`=oo`07O01oog`0Ool07gooO00017oo00D07gooOomoo`0O
00=oo`0401moogooOol201l2Ool201mAOol0051oo`9l009oo`03O01oog`0009oo`05O01oogooOoml
0004Ool02g`0Oomoogoo01moo`0OO0007goo01l00Woo00@07gooO0007`=oo`0601moogooOoml000O
17oo00<07gooOol00Woo00<07g`0Ool00goo00<07g`0Ool017oo00<07gooOol00goo00<07g`0Ool0
0goo00=l07ooOol00goo00D07gooOomoog`000=oo`04O0007gooO002Ool01g`0Ooml000OO01oog`0
00=oo`0301moogoo009oo`0501moogooOol07`02Ool0100OOol07goo0`0ODGoo001@Ool3O00017oo
O01oog`00Woo00El07ooOomoog`000Eoo`03O01oogoo00807`04Ooml07oo01l2Ool01@0OOomoo`0O
O0000goo00H07gooOomoo`0OO003Ool00`0OOoml0002Ool0100OOomoog`00goo00<07gooO0000goo
00<07gooO0000goo00@07gooOoml009oo`0301moog`000=oo`0301ml07oo009oo`08O01oogooOol0
7g`0Ooml00=oo`04O01oo`0OOol2O002Ool00`0OOomoo`02Ool00`0OOomoo`02Ool01`0OOomoo`0O
Ool07goo00<07e5oo`00D7oo0g`000Aoog`0Ooml00=oo`05O01oogooOoml0005Ool027`001moo`0O
Ool07g`001l2Ool01@0OOomoo`0OO0000Woo00D07gooOomoo`0O009oo`03O01oo`0O00=oo`03O000
7goo00=oo`9l000701moogooOoml07oo01l00goo00=l000O01l017oo00=l000OOol00Woo00=l07oo
01l00Woo00Ul07ooOomoog`0Ool07gooO0000Woo00]l07ooOoml000OO01oog`0Ooml000O00Eoo`05
01moogooOol07`03Ool0100OOol07goo0`0ODGoo001?Ool4O0001GooO01oogooO0000Woo00El07oo
Oomoog`000Ioo`09O0007goo01moo`0OO01oo`0O009oo`0501moogooO0007`03Ool00`0OOomoo`02
Ool00g`0Oomoo`02Ool00`0OO01oo`04Ool00`0OO01oo`02Ool201l01W`0Oomoogoo01ml00Eoo`03
01ml07oo009oo`03O0007goo00=oo`06O01oogooOoml000O0Woo00=l07ooO0000Woo00L07g`0Ooml
07ooO0007`05Ool00`0OOomoo`02Ool0100OOomoo`0O0Woo00<07goo01l00P0ODGoo001?Ool4O002
Ool00g`0Ooml0002Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool02G`001moo`0OOol07gooO0007`02
Ool01@0OOomoo`0OO0000Woo00<07gooOol00goo00D07g`0Oomoo`0O009oo`03O01oogoo00807`9o
o`03O01oo`0O00=oo`03O01oo`0O009oo`9l009oo`0401moogooO002Ool00`0OO01oo`04Ool017`0
Oomoo`0O0goo00al07ooOoml000OOoml07ooO01oog`001l5Ool00`0OOomoo`02Ool01P0OOomoo`0O
Ool07`9oo`@07e1oo`00Cgoo0g`000Ioog`0Ooml07ooO003Ool00g`0Oomoo`02Ool00g`0Oomoo`02
Ool02`0OO01oo`0OOol07goo01ml07oo01l00goo00@07gooO0007`Eoo`0501moogooO0007`04Ool0
0g`001moo`03Ool00g`001moo`04Ool00`0OOomoo`03Ool00g`001moo`02Ool00g`0Ool07`02Ool0
0g`0Oomoo`02Ool01G`0Ool07gooO0000goo00]l07oo01ml07ooO01oog`0Ool07g`000Aoo`0301mo
ogoo009oo`0:01moogooOol07goo01moo`0OOol301m@Ool004moo`=l0004Ooml07ooO002Ool017`0
Oomoog`017oo00=l07ooOol00Woo0P0O00=l07oo01l00Woo00@07g`0Ool07`9oo`0501moogooOoml
0004Ool00`0OOomoo`02Ool00g`0Oomoo`02Ool00`0OO01oo`03Ool00`0OO01oo`04Ool00`0OOomo
o`03Ool00`0OO01oo`03Ool00`0OOomoo`02Ool00g`0Oomoo`02Ool01@0OOomoogooO0000Woo00Al
000OOoml009oo`03O01oo`0O009l00Aoo`0301moogoo009oo`0401moogoo01l2Ool0100OOol07goo
0`0OD7oo001?Ool5O0001GooO01oogooO0000goo00=l07ooOol00Woo00=l07ooOol00P0O00Ioo`0O
O0007goo01l2Ool017`0Oomoo`0O0goo00<07gooO0000Woo00<07gooOol00Woo00<07gooO0000Woo
00@07gooOoml00=oo`0301moog`000=oo`0301moog`000=oo`0301moog`000=oo`0301moog`000Ao
o`06O01oogoo01moog`00Woo00El07ooOomoo`0O009oo`07O01oog`001ml07ooO0000goo00<07goo
Ool00Woo00D07gooOomoo`0O009oo`0301moo`0O00@07e1oo`00Cgoo17`000Ioog`0Ooml07ooO003
Ool00g`0Oomoo`02Ool00g`0Oomoo`0301l01GooO01oogoo01l00Woo00@07g`0Ool07`9oo`0601mo
ogooOoml000O17oo00L07gooOomoog`0Ool07`03Ool2O0001`0OOomoogooO01oo`0O00=oo`03O000
7`0O00=oo`03O01oo`0O00=oo`03O01oogoo009oo`03O0007goo009oo`07O01oogooO01oo`0OO000
0Woo00El07ooOol07goo00=l009oo`0301moogoo009oo`0:01moogooOol07goo01moo`0OOol401m@
Ool004moo`Al0004Ooml07ooO002Ool01G`0OomoogooO00017oo00=l07oo01l00P0O00Aoo`0OO000
7`9oo`0401moogooO002Ool00`0OOomoo`02Ool00`0OO01oo`02Ool00`0OOomoo`03Ool00g`0Oomo
o`03Ool00`0OO01oo`02Ool201l01W`0Oomoogoo01ml00Eoo`0301moogoo009oo`03O01oogoo009o
o`0301ml07oo009oo`05O01oogooO0007`02Ool01g`0Oomoog`001ml07oo00=l0003Ool07goo00=o
o`0501moogooOol07`02Ool0100OOol07goo100OD7oo001?Ool4O00017ooO01oog`00Woo00=l07oo
Ool00Woo00=l07ooOol00Woo00Ql000O01l07goo01moog`00Woo00L07gooOol07g`0Ool07`03Ool0
100OOomoog`00Woo00<07gooOol00Woo00<07gooO0000Woo0P0O0Woo00=l07oo01l00goo00=l07oo
01l00Woo0W`00Woo00<07gooO00017oo00Al07ooOol07`9oo`08O01oogooOoml07oo01ml009oo`07
O01oogoo01moog`0Ool00g`000<07gooOol00Woo00<07gooOol00Woo00L07gooOol07goo01moo`04
01m@Ool004moo`Al009oo`03O01oog`0009oo`05O01oogooOoml0004Ool01G`001l07`0OOol00P0O
00=l07oo01l00Woo00@07gooOoml00=oo`0301moogoo009oo`03O0007goo00=oo`0601moogooOoml
000O17oo00=l000OOol017oo00=l07ooOol00goo00=l000OOol00Woo00=l07ooOol00Woo00=l000O
Ool00Woo00=l07ooOol00Woo00H07gooOoml07ooO002Ool0100OO01l07oo0g`000<07gooOol00Woo
00D07gooOomoo`0O009oo`0301moo`0O009oo`@07e1oo`00Cgoo0g`000Ioog`0Ooml07ooO002Ool0
0g`0Oomoo`02Ool00g`0Oomoo`02Ool02G`001moo`0OOol07gooO0007`02Ool0100OOomoog`00goo
00<07gooOol00Woo00<07g`0Ool00Woo00<07gooOol00Woo00<07g`0Ool00goo00<07g`0Ool017oo
00=l07ooOol00goo00<07g`0Ool00goo00Il07ooOomoo`0OO004Ool01G`0Oomoo`0OO0000Woo00al
07ooOoml000OOoml07ooO01oog`001l4Ool00`0OOomoo`02Ool02@0OOomoo`0OOol07goo01moo`03
01m@Ool004moo`=l0006Ooml07ooO01oog`00goo00El07ooOomoog`000=oo`807`04O01oo`0O01l2
Ool0100OO01oo`0O0Woo00D07gooO01oo`0O00Aoo`0601moogooO01oo`0O17oo00@07gooOoml00=o
o`0301moog`000=oo`0301moog`000=oo`0301moog`000Eoo`05O01oo`0OOoml0005Ool01G`0Ool0
7gooO0000Woo00=l07oo01l00goo0W`000Aoo`0OO01l009oo`0301moogoo009oo`0:01moogooOol0
7goo01moo`0OOol301m@Ool004moo`El0005Ooml07ooOoml0002Ool00g`0Oomoo`02Ool00g`0Oomo
o`0201l017`0Ool07`0O0Woo00@07gooO0007`9oo`0401moogooO005Ool01@0OOomoogooO0001Goo
00L07gooOomoog`0Ool07`03Ool00g`0Ool07`03Ool00g`0Ool07`03Ool00g`0Oomoo`03Ool01@0O
OomoogooO0001Goo00@07gooOoml009oo`04O0007gooO002Ool2O00017oo01ml07`00Woo00<07goo
Ool00Woo00@07gooOol07`9oo`0301moo`0O00@07e1oo`00Cgoo1G`00Woo00=l07ooO0000Woo00=l
07ooOol00Woo00=l07ooOol00`0O00El000O01moo`0O009oo`04O01oogoo01l2Ool00`0OOoml0003
Ool01`0OOomoogoo01moog`000=oo`0301moogoo00=oo`03O01oogoo00=oo`0301moogoo00=oo`03
01moogoo00=oo`06O01oogooOol07g`017oo00Il07ooOomoo`0OO003Ool017`0Ool07g`00Woo00El
07ooO01l000O00=l0003Ool07goo00=oo`0701moogooOol07goo01l00Woo1@0OD7oo001?Ool4O000
1WooO01oog`0Ooml00=oo`03O01oogoo009oo`03O01oo`0O00<07`0:O0007goo01moo`0OOoml07oo
01l2Ool01P0OOomoog`0Ool07`Aoo`0601moogooO01oo`0O1Goo00<07gooO0000goo00<07gooO000
0goo00<07gooO0001Goo00=l07oo01l00Woo00=l07ooOol00Woo00=l07oo01l00Woo00Ml07ooOoml
07oo01ml0002Ool017`0Ooml000O17`000=oo`0OOol00goo00X07gooOomoo`0OOol07goo01moo`@0
7e1oo`00Cgoo17`000Aoog`0Ooml009oo`04O01oogooO004Ool02G`0Ool07`0OOol07g`0Ool07`02
Ool0100OOomoog`00Woo00<07gooOol00Woo00=l07ooOol00Woo00<07gooOol00Woo00=l07ooOol0
0goo00L07gooOomoog`0Ool07`03Ool00g`0Ool07`03Ool00g`0Oomoo`03Ool00`0OOomoo`02Ool0
0g`0Oomoo`02Ool00`0OOomoo`02Ool017`0Oomoo`0O0Woo00Ql07ooOoml07oo01ml07oo0W`000<0
7gooOol00Woo00D07gooOomoo`0O009oo`0401moo`0OOol401m@Ool004moo`Al0007Ooml07ooOoml
07ooO0000goo00=l07ooOol00Woo00Yl000O01l07goo01ml000OOol07`9oo`0401moog`001l4Ool0
0`0OOoml0002Ool00`0OOomoo`02Ool00`0OOoml0003Ool00`0OOomoo`03Ool00g`0Oomoo`03Ool0
0`0OOomoo`03Ool01g`0Oomoogoo01moog`000Aoo`06O01oogoo01moog`00goo00Al07oo01ml009o
o`07O01oogooO0007g`0Ool00g`000<07gooOol00Woo00L07gooOomoo`0OOol07`02Ool00`0OOol0
7`0301m@Ool004moo`=l0006Ooml07ooO01oog`00Woo00Al07ooOoml00Aoo`0501ml000O01moo`02
01l00g`0Ool07`02Ool0100OOomoog`00goo00H07gooOomoog`001l4Ool01`0OOomoogooO01oo`0O
00Eoo`0301moog`000=oo`0301moog`000Eoo`03O01oo`0O00=oo`07O01oogooOoml07oo01l00goo
00El07ooOomoo`0O009oo`06O01oogooO01oo`0O0W`000Eoog`0O0007g`000=oo`0501moogooOol0
7`02Ool01P0OOol07goo01moo`<07e1oo`00Cgoo0g`000Ioog`0Ooml07ooO002Ool01G`0Oomoogoo
O0000goo00D07g`001l07goo00807`05Ooml07ooOol07`02Ool01@0OO01oogoo01l01Goo00El07oo
Oomoo`0O00Eoo`03O01oogoo00=oo`0701moogooOoml07oo01l00goo00=l07ooOol00goo00<07goo
Ool00goo00El07ooOomoo`0O00Eoo`04O01oogoo01l3Ool01G`0Oomoo`0OOol00W`000Eoog`0O000
7g`000=oo`0501moogooOol07`02Ool01P0OOol07goo01moo`<07e1oo`00Cgoo1G`000Aoog`0Ooml
00=oo`05O01oogooOoml0002Ool201l01g`001l07goo01moog`0009oo`0701moogoo01moog`001l0
1Goo00D07gooO01oo`0O00Eoo`0301moog`000=oo`0301moogoo00=oo`0301moogoo00=oo`07O01o
ogooOol07gooO00017oo00Il07ooOol07gooO004Ool01G`0Ool07gooO0000Woo00Ml07ooOol07goo
O01oo`02O0000`0OO01l0002Ool01@0OOomoogoo01l00goo00@07goo01moo`D07e1oo`00Cgoo1G`0
00Eoog`0Oomoog`0009oo`05O01oogooOoml0002Ool201l02G`0Ool07`0OOol07gooO0007`02Ool0
1@0OOomoogooO00017oo00H07gooOomoog`001l4Ool01`0OOomoogooO01oo`0O00Eoo`0301moog`0
00Eoo`03O01oo`0O00=oo`03O01oogoo009oo`03O0007goo009oo`03O01oogoo009oo`0501moogoo
Ooml0002Ool01G`001moog`0Ool00W`000Aoo`0OO01l009oo`0501moogooOol07`02Ool01@0OOomo
o`0OOol01@0OD7oo001?Ool4O0001WooO01oog`0Ooml00=oo`06O01oogooOoml07oo0`0O00El07oo
01moo`0O009oo`04O01oogoo01l2Ool0100OOoml07oo0P0O17oo00<07g`0Ool00Woo00<07gooOol0
0goo00=l07ooOol00goo00D07gooOomoog`000Eoo`0301moogoo00=oo`06O01oogooOol07g`017oo
0W`000Aoo`0OOoml009oo`04O01oogoo01l2Ool01G`0Ooml07oo01l00g`000=oo`0OOol00goo00T0
7gooOol07goo01moo`0OOol0100OD7oo001?Ool4O0001WooO01oog`0Ooml00=oo`06O01oogooOoml
07oo0`0O00Al07oo01l07`9oo`0401moog`001l2Ool01@0OOomoog`001l01Goo00<07gooO0000Woo
00<07gooOol00goo00<07gooO0000goo00<07gooOol00goo00Ml07ooOomoo`0OOoml0005Ool00g`0
Ool07`02Ool00g`0Oomoo`03Ool017`001moog`00goo00Al000OOoml009oo`9l0003Ool07g`0009l
0003Ool07goo009oo`0:01moogooOol07goo01moo`0OOol401m@Ool004moo`Al0004Ooml07ooO002
Ool01G`0OomoogooO0000goo00=l000O01l00P0O00=l000O01l00Woo00@07gooO0007`9oo`0501mo
ogoo01ml0004Ool01P0OOomoogooO0007`Eoo`0701moogooOoml07oo01l01goo00=l07oo01l00goo
00=l07ooOol00goo00=l000OOol00Woo00=l07ooOol00Woo00D07g`0Oomoog`0009oo`0401moogoo
O002Ool2O0000`0OO01l0002O0000`0OOomoo`02Ool0100OOomoo`0O0Woo00@07goo01moo`@07e1o
o`00Cgoo17`000Moog`0Oomoog`0Ooml0003Ool01G`0OomoogooO0001@0O00Al000OOol07`9oo`04
01ml07oo01l2Ool0100OOomoog`00Woo00<07gooOol00Woo00<07g`0Ool00goo00<07gooOol00goo
00=l07ooOol01goo00<07gooOol00goo00=l07ooOol00Woo00<07g`0Ool00goo00Il07ooOol07goo
O002Ool01G`0Oomoo`0OO0000Woo00Al07ooO0007`El000501moogooOol07`03Ool0200OOol07goo
01moo`0OOol201mAOol0051oo`9l0006Ooml07ooO01oog`00Woo00El07ooOomoog`000=oo`04O000
7`0OOol201l01G`001moogoo01l00Woo00El000OOomoo`0O00=oo`03O0007goo00=oo`0401moogoo
O002Ool00`0OOomoo`03Ool00`0OOoml0007Ool00`0OOoml0005Ool01W`0Oomoo`0OOoml00Eoo`03
O0007goo009oo`07O01oogooO0007gooO0000Woo00=l07oo01l00W`000Aoog`0O0007`Aoo`0401mo
ogoo01l2Ool01P0OOol07goo01moo`807e5oo`00D7oo17`000Aoog`0Ooml009oo`05O01oogooOoml
0003Ool0200OO0007`0OOol07g`001l2Ool01`0OOomoo`0OO01oo`0O00Aoo`0301ml07oo00=oo`06
01moogooOoml000O1Goo00D07gooOomoog`000Eoo`0501moogooOoml0005Ool00g`001moo`02Ool0
0g`0Oomoo`02Ool00`0OO01oo`03Ool017`0Ool07g`00Woo00Ml07ooOol07gooO01oo`02O0000`0O
O01oo`02Ool01@0OOomoogoo01l00Woo00@07goo01moo`@07e5oo`00D7oo17`000Aoog`0Ooml00=o
o`05O01oogooOoml0002Ool01@0OO0007`0OOol00P0O00=l07oo01l00Woo00@07gooOoml00Aoo`04
01moogooO002Ool00`0OOomoo`02Ool00`0OO01oo`03Ool00`0OOomoo`03Ool01G`0Oomoogoo01l0
1Goo00=l07ooOol00Woo00<07g`0Ool00goo00Al07ooOol07`9oo`03O01oogoo009oo`0301moog`0
009oo`04O01oogoo01l2O0001GooO01l000OO0000goo00@07gooOol07`=oo`0401moo`0OOol401mA
Ool0051oo`Al0005Ooml07ooOoml0002Ool01G`0OomoogooO0000Woo0P0O00=l000OOol00P0O00=o
og`001l00Woo00D07goo01moog`0009oo`0301moogoo009oo`03O0007goo00=oo`0401moogooO002
Ool00`0OOomoo`05Ool00g`0Ool07`07Ool017`0Oomoo`0O0Woo00=l07ooOol00Woo00=l000OOol0
0goo00El07ooOol07g`0009oo`06O01oogooO0007goo0W`000=oog`001l00W`00Woo00D07gooOomo
o`0O009oo`0601moo`0OOol07goo0`0ODGoo001@Ool3O0001WooO01oog`0Ooml00=oo`06O01oogoo
Ooml07oo0`0O00=l000O01l00Woo00@07g`0Ool07`9oo`0501moog`0Ool07`04Ool201l01G`0Oomo
ogoo01l017oo00=l000OOol027oo00<07gooOol01goo00=l000OOol00goo00El07ooOomoo`0O009l
00Aoo`05O0007gooOoml0002Ool017`0Ool07g`00Woo0W`000@07g`0O01l009oo`0401moogoo01l3
Ool01P0OOol07goo01moo`<07e5oo`00D7oo0g`000Ioog`0Ooml07ooO003Ool01W`0OomoogooO01o
o`<07`05Ooml000OOol07`02Ool017`0Oomoo`0O0goo00=l07ooOol00Woo00L07gooOomoog`0Ool0
7`05Ool00`0OO01oo`07Ool00`0OOoml0008Ool00`0OO01oo`04Ool00g`0Ool07`03Ool01W`0Oomo
ogooO0007`=oo`06O01oogoo01moog`00Woo00=l000OOol00g`000=oo`0OOol00Woo00X07gooOomo
o`0OOol07goo01moo`<07e5oo`00D7oo0g`000Aoog`0Ooml009oo`05O01oogooOoml0003Ool00g`0
01l07`0201l02G`0Oomoo`0OOol07g`0Ool07`04Ool01@0OO01oogoo01l01Goo00=l07ooOol00goo
00@07gooOoml00Ioo`0501moogooOoml0006Ool0100OOomoog`017oo00=l000OOol017oo00El07oo
Ool07g`000=oo`04O01oogoo01l2Ool017`0Oomoo`0O17`000Eoo`0OOomoo`0O00=oo`0501moogoo
01moo`0201l00goo01l07`1AOol0055oo`09O01oog`0Ooml07ooO01oog`000=oo`05O01oogooOoml
000501l027`001moogoo01moog`001l3Ool01@0OOomoog`001l01Woo00=l07ooOol00Woo00<07goo
Ool00Woo00=l07ooOol00Woo00<07gooOol00goo00=l07ooOol00Woo00<07gooOol00Woo00Il07oo
Oomoo`0OO005Ool00g`0Ool07`02Ool027`0OomoogooO0007gooO002Ool00g`001ml0004O0001@0O
Oomoogoo01l00goo00H07goo01moo`0OOol301mBOol0055oo`=l0004Ooml07ooO002Ool01G`0Oomo
ogooO0000goo00Ul000O01moo`0OOoml07oo01l00Woo00D07g`0Oomoo`0O00Aoo`03O01oogoo00=o
o`0301moog`0009oo`0301moogoo00Aoo`04O01oogoo01l7Ool017`0Oomoo`0O1Woo00Il07ooOol0
7gooO005Ool00`0OOomoo`02Ool017`0Oomoo`0O0goo00Al07oo01moo`El000401moogoo01l3Ool0
1`0OOomoo`0OOol07goo00<07e9oo`00DGoo0g`000Moog`0Oomoog`0Ooml0003Ool01G`0Oomoogoo
O0000`0O00Aoo`0OO0007`=oo`0401moog`001l4Ool00`0OOoml0003Ool01P0OOomoogooO0007`Qo
o`03O0007goo00Qoo`03O0007goo00Moo`03O0007goo009oo`07O01oogooOol07gooO0000goo00El
07oo01moog`0009oo`03O01oo`0O009l0004Ooml07`001l3Ool01`0OOomoogoo01moo`0O009oo`03
01moo`0O00807e9oo`00DGoo0g`000Eoog`0Oomoog`0009oo`05O01oogooOoml0002Ool0200OO01o
o`0OOol07gooO002Ool01@0OOomoog`001l00goo00D07gooOomoog`000807`Aoo`0301ml07oo00Mo
o`0301ml07oo00Qoo`0301ml07oo00Moo`0301ml07oo00=oo`9l000501moogooOoml0003Ool01G`0
01moogooO0000Woo00@07gooO01oo`9l000501ml07ooOol07`03Ool0100OOomoo`0O0Woo0P0O00=o
o`0O01l0DWoo001AOol2O00017ooO01oog`00Woo00=l07ooO00017oo00El07oo01ml07oo00807`05
Ool07gooO0007`03Ool01@0OO01oogoo01l017oo00=l07ooOol00goo00@07gooOoml00Ioo`0401mo
ogooO007Ool0100OOomoog`01Woo00@07gooOoml00Eoo`0501moogooOoml0003Ool0200OO01oogoo
O01oo`0OO002Ool2O0001Goo01ml07oo01l017oo00<07goo01l00Woo00@07goo01moo`807e9oo`00
DGoo0W`000Aoog`0Ooml009oo`04O01oogooO003Ool01G`0Ool07`0OO0000P0O00Eoo`0OOoml000O
009oo`0601moogooO01oo`0O0goo00<07gooO0000goo00<07gooOol00Woo00=l07ooOol00Woo00<0
7gooOol00Woo00=l07ooOol00goo00<07gooOol00Woo00=l07ooOol00Woo00<07gooOol00Woo00Ml
07ooOomoo`0OOoml0003Ool01G`0Ool07gooO0000goo00El000OOoml07oo009l000501ml07`0Ool0
7`03Ool0100OOomoo`0O0Woo00D07goo01moo`0O05=oo`00DWoo0g`000Eoog`0Oomoog`0009oo`03
O01oogoo009oo`07O0007`0O01ml07oo01l00Woo00D07g`0Oomoo`0O00=oo`05O01oogooOol07`03
Ool00g`0Ool07`06Ool017`0Oomoo`0O1Woo00El07ooOomoo`0O00Ioo`04O01oogoo01l6Ool00g`0
Ool07`02Ool00g`0Oomoo`02Ool01@0OOomoogooO0000Woo00L07g`0Ooml07ooO0007`03O0000`0O
Oomoo`02Ool0100OOomoo`0O0Woo00<07goo01l00P0ODgoo001BOol2O00017ooO01oog`00Woo00Al
07ooOoml00=oo`03O0007`0O00807`04O0007goo01l2Ool00g`001moo`02Ool00`0OO01oo`02Ool0
0`0OOomoo`02Ool00`0OOomoo`06Ool00g`001moo`07Ool00g`0Ool07`08Ool00g`001moo`07Ool0
0g`0Oomoo`02Ool01W`0Oomoo`0OOoml009oo`05O01oo`0OOoml0002Ool00g`001ml0003O0001@0O
Oomoogoo01l00Woo00L07gooOol07goo01moo`0201mCOol0059oo`9l0004Ooml07ooO002Ool017`0
Oomoog`00goo00H07g`001l07gooO002Ool01@0OOomoog`001l00Woo00H07gooOoml07oo01l4Ool0
0`0OOoml0007Ool00`0OO01oo`07Ool201l00g`0Oomoo`06Ool00`0OO01oo`06Ool00`0OOoml0004
Ool00g`0Ool07`02Ool01G`0Oomoog`001l00Woo00Ul07ooO0007g`0Ooml000OO0000goo00@07goo
Ool07`9oo`0401moo`0OOol201mCOol0059oo`9l0005Ooml07ooOoml0002Ool017`0Oomoog`00Woo
00P07g`001l07goo01ml000O0goo00@07g`0Ool07`Aoo`03O01oogoo009oo`0501moogooOoml0005
Ool0100OOomoog`01Woo00D07gooOomoog`000Ioo`0401moogooO005Ool01@0OOomoogooO00017oo
00<07gooOol00Woo00Al07oo01ml009oo`05O01oo`0OO01oo`02O0001@0OO01oogoo01l00Woo00@0
7gooOol07`9oo`0301moo`0O05Aoo`00Dgoo0g`00Woo00Al07ooOoml009oo`03O01oogoo00807`06
O0007goo01moog`00Woo00@07gooOoml00Aoo`0301moog`0009oo`0301moogoo009oo`03O01oogoo
009oo`0301moogoo009oo`03O01oogoo009oo`0301moogoo00=oo`03O01oogoo009oo`0301moogoo
009oo`05O01oogooOol07`05Ool01W`0Oomoo`0OOoml00Aoo`0401moogooO002Ool01P0OOoml07oo
O0007`9l009oo`0401moogoo01l2Ool00`0OOomoo`0301mDOol005=oo`9l0005Ooml07ooOoml0002
Ool01G`0Oomoog`0Ool00`0O00Ml000OOol07g`0Ool07`02Ool00`0OOoml0002Ool01P0OOomoogoo
O0007`Ioo`04O01oogoo01l6Ool017`0Oomoo`0O1goo00Al07ooOol07`Ioo`04O01oogoo01l6Ool0
0g`001moo`02Ool01G`0Oomoo`0OO0000goo00=l07oo01l00Woo00=l000OO0000W`000Eoo`0OOomo
o`0O009oo`0501moogoo01moo`0201mDOol005=oo`9l0005Ooml07ooOoml0002Ool01G`0Oomoogoo
O0000`0O00Il000OOol07gooO003Ool01@0OOoml07oo01l017oo00<07g`0Ool01Woo00=l000OOol0
1goo00=l000OOol027oo00=l000OOol01goo00=l000OOol01Woo00<07g`0Ool00goo00El07oo01mo
og`000=oo`0601moog`0Ooml000O0g`000D07gooOomoo`0O009oo`0501moogoo01moo`0201mDOol0
05Aoo`=l009oo`05O01oogooOoml0002Ool00g`001l07`0201l027`001moo`0OOoml07oo01l3Ool0
0g`0Oomoo`02Ool0100OOomoog`01Woo00<07g`0Ool01goo00<07g`0Ool027oo00<07g`0Ool01goo
00<07g`0Ool01Goo00@07gooOoml00Aoo`0<01moogooOoml07oo01ml07ooO01oo`0O17`000@07goo
Ool07`=oo`0301moogoo00<07eEoo`00E7oo0W`000Eoog`0Oomoog`0009oo`05O01oogooOoml0003
01l01g`001moo`0OOoml000O00=oo`0301moog`0009oo`0301moogoo009oo`03O01oogoo009oo`04
01moogooO006Ool0100OOomoog`01goo00@07gooOoml00Ioo`0401moogooO004Ool00`0OOomoo`02
Ool01W`0Oomoo`0OOoml00=oo`07O0007gooO01oog`001l00g`000D07gooOomoo`0O009oo`0501mo
ogoo01moo`0201mEOol005Aoo`9l0005Ooml07ooOoml0003Ool017`0Oomoog`0100O00=l000OOol0
0Woo00Al07ooOol07`=oo`03O0007goo00Eoo`04O01oogoo01l4Ool00g`0Oomoo`02Ool00`0OOomo
o`02Ool00g`0Oomoo`03Ool00`0OOomoo`02Ool00g`0Oomoo`02Ool00`0OOomoo`02Ool017`0Oomo
o`0O1Woo00=l000OOol00Woo00Al07ooOol07`=oo`07O0007g`0O01oog`001l00Woo00D07gooOomo
o`0O009oo`807`03Ool07goo05Aoo`00E7oo00El07ooO01oog`0009oo`05O01oogooO01oo`0201l0
1G`001l07`0OO0000goo00@07gooO0007`Aoo`0301ml07oo00Ioo`03O0007goo00Eoo`9l0003Ool0
7goo00Eoo`05O01oogooOol07`06Ool017`0Ool07`0O1Woo00=l000OOol01Woo00<07g`0Ool00Woo
00El07oo01moog`0009oo`03O0007g`0009l000501ml07ooOol07`02Ool0200OOomoo`0OOol07goo
01mEOol005Eoo`9l0005Ooml07ooOoml0003Ool01G`001l07g`0Ool00`0O00=l07oo01l00goo00El
07ooOomoo`0O009oo`03O01oogoo00Aoo`0301ml07oo00Moo`03O01oogoo00Ioo`03O01oo`0O00Qo
o`0301moogoo00Ioo`0301ml07oo00Eoo`0401moogooO003Ool01`0OOomoogooO01oo`0O00Al0004
01ml07`001l3Ool01@0OOomoo`0OOol00P0OEWoo001EOol01G`0Ooml07ooO0000Woo00Al07ooOoml
00<07`03O0007`0O009oo`09O01oogooOol07gooO01oo`0O00Aoo`03O01oogoo009oo`0401moogoo
O006Ool00`0OOoml0007Ool201l00g`0Oomoo`05Ool00`0OOoml0006Ool0100OOomoog`017oo00<0
7gooOol00Woo00El07oo01moog`0009oo`03O0007goo00=l000501ml07`0O0007`02Ool0200OOomo
o`0OOol07goo01mFOol005Eoo`05O01oog`0Ooml0002Ool01G`0OomoogooO0000`0O00Ql000OOomo
o`0OO01oo`0O0Woo00=l000OOol01Goo00Al07ooOol07`Aoo`03O01oogoo009oo`0501moogooOoml
0005Ool01@0OOomoogooO0001Goo00D07gooOomoog`000Aoo`0301moogoo009oo`04O01oogoo01l6
Ool027`001moogooO01oo`0OO002Ool00g`001ml0002O0001@0OOomoogoo01l00Woo00D07goo01mo
o`0O05Ioo`00EWoo0W`00Woo00Al07ooOoml009oo`0501ml000O01ml000301l00gooO0007`03Ool0
0`0OO01oo`06Ool00g`001moo`05Ool017`0Oomoo`0O1Goo00El07ooOomoo`0O00Eoo`05O01oogoo
Ool07`05Ool017`0Oomoo`0O1Woo00=l000OOol01Woo00<07g`0Ool00Woo00<07gooOol00g`000D0
7g`0O0007g`0009oo`0801moogoo01moo`0OOol07eMoo`00EWoo00El07ooO01oog`0009oo`05O01o
ogoo01ml000301l01W`001moogoo01ml009oo`0401moogooO006Ool00`0OO01oo`06Ool00g`001mo
o`06Ool00g`0Ool07`07Ool00g`0Ool07`07Ool00g`001moo`06Ool00`0OO01oo`05Ool0100OOomo
og`00Woo00H07g`0Oomoog`001l3O0001@0OO01oogoo01l00Woo00D07goo01moo`0O05Moo`00Egoo
0W`00Woo00El07ooOoml07oo00807`05O0007goo01ml000201l2Ool00g`001moo`03Ool00g`0Oomo
o`02Ool00`0OOoml0007Ool00`0OO01oo`07Ool00g`0Oomoo`07Ool00`0OOomoo`06Ool00`0OO01o
o`05Ool0100OOomoog`017oo00<07gooOol00Woo00Al000OOomoo`9l000501ml07ooO0007`02O000
2Goo01moogoo01moo`0OOol07`1HOol005Moo`05O01oog`0Ooml0002Ool02W`0Ool07`0OO0007goo
01moog`00goo00<07g`0Ool017oo00Al07ooOol07`=oo`03O01oogoo00=oo`0401moogooO005Ool2
01l00gooO01oo`06Ool0100OOoml07`01Goo00@07gooOoml00Eoo`0501moogooOoml0002Ool00`0O
Oomoo`03Ool00`0OO01oo`02Ool01P0OOoml07ooO0007`9l0009Ool07gooOol07goo01moo`0O05Qo
o`00F7oo0W`00Woo00Al07ooOoml00<07`05O0007`0O01ml0002Ool0100OOomoog`01Goo00=l000O
Ool017oo00=l07ooOol00P0O17oo00El07ooOomoo`0O00Aoo`03O01oogoo00=oo`0301moogoo009o
o`05O01oogooOol07`04Ool2O002Ool00`0OOomoo`03Ool00g`001moo`04Ool0100OOomoog`00Woo
00D07g`0O01l000O00=l000801moogoo01moo`0OOol07eUoo`00F7oo00El07ooO01oog`0009oo`05
O0007`0O01ml000401l00g`001moo`02Ool00g`0Oomoo`02Ool00`0OO01oo`06Ool00g`001moo`06
Ool00g`0Ool07`06Ool01G`0Oomoogoo01l01Woo00=l07oo01l01goo00=l000OOol01Goo00<07goo
O00017oo00H07gooOomoog`001l4O0001@0OO01l07`001l00Woo00D07goo01moo`0O05Uoo`00F7oo
00Ul07ooOoml07ooO01oo`0OO0000P0O00Moog`001l07goo01ml0004Ool017`0Oomoo`0O0Woo00=l
07ooOol017oo00<07g`0Ool01goo00=l07ooOol01Woo00=l07oo01l027oo00<07gooOol01Woo00<0
7g`0Ool01Goo00@07gooOoml009oo`0301moogoo009oo`0301ml07oo009l000<01moog`0O0007g`0
Ool07goo01moo`0OFWoo001IOol00g`0Ooml0002Ool027`001l07g`001moo`0OO00301l00g`0Oomo
o`03Ool00g`001moo`03Ool00g`0Oomoo`02Ool0100OOomoog`01Woo00<07gooO0001goo0P0O00=l
07ooOol01Goo00<07gooO0001Woo00@07gooOoml00Aoo`0301moogoo009oo`03O0007goo00Aoo`09
01ml07`0O0007g`0Ooml000O009l000601moogoo01moo`0OFWoo001IOol01W`0Oomoog`0Ooml0080
7`0:O0007`0O01ml000OOol07gooO003Ool201l00g`0Oomoo`03Ool017`0Ool07`0O17oo0W`00goo
00D07gooOomoog`000Eoo`0501moogooOoml0005Ool01@0OOomoogooO0000goo0P0O17oo0W`000=o
o`0OOol017oo00<07g`0O0000goo00H07gooO01oog`001l3O000200OO01l000OOol07goo01mKOol0
05Yoo`06O01oog`0Ool07g`00P0O00El000OOol07g`000807`9oo`03O01oo`0O009oo`03O01oogoo
00Aoo`0301moogoo00Ioo`03O01oo`0O00Eoo`05O01oogooOol07`05Ool01G`0Oomoogoo01l01Goo
00=l07oo01l027oo00=l07ooOol017oo00l07gooOoml07oo01moog`0Ooml000OO01oog`001l00W`0
00H07g`0Ool07goo01mKOol005Yoo`04O01oogooO00201l017`001l07g`00P0O00Moog`0Ool07goo
O0007`04Ool00g`0Oomoo`02Ool00`0OOoml0008Ool00`0OOomoo`05Ool2O0000`0OOomoo`05Ool0
0g`001l07`07Ool00g`0Oomoo`06Ool00`0OOoml0004Ool00`0OOomoo`02Ool01g`001moog`0Ool0
7goo009l000401ml07`001l2O0000`0OOol07`1LOol005]oo`03O01oog`000807`08O0007`0OO01o
o`0OOoml00807`03Ool07g`000Eoo`04O01oogoo01l3Ool00g`0Oomoo`03Ool201l00gooO01oo`05
Ool00`0OOoml0007Ool00`0OOoml0006Ool0100OOoml07`01Goo00D07gooOomoog`0009oo`0301mo
ogoo00=oo`0:01ml07`0Ooml000OOoml07oo01l2O0001P0OO01l000OOol07eaoo`00Fgoo00Al07oo
Ooml00807`05O0007`0OO0007`02Ool00g`001l07`02Ool00g`0Oomoo`03Ool00g`001moo`04Ool0
1G`0Oomoogoo01l017oo00Al07ooOomoo`807`=oo`03O01oogoo00=oo`0401moogooOol2O003Ool0
0`0OOomoo`02Ool01G`0Oomoogoo01l01Goo00=l000OOol017oo00<07gooOol00W`000D07gooOoml
000O009l000601ml07`001moo`0OGGoo001LOol017`0Ool07g`00P0O00Yl000O01ml000OOol07g`0
Ool07`9oo`07O01oogooOol07gooO0001Woo00=l000O01l01Woo00=l07oo01l01Woo00El07ooOomo
o`0O00Ioo`03O01oo`0O00Ioo`9l000301moogoo00Aoo`0301moog`000=oo`0:01moogooO01oo`0O
O01oog`001l2O0001`0OO01l000OO01oo`0O05eoo`00G7oo00Al000O01ml00807`0:O0007goo01ml
000OOol07g`001l2Ool017`0Oomoo`0O0goo00=l07ooOol00goo00<07g`0Ool01goo00=l07ooOol0
1Woo00=l07oo01l027oo00<07gooOol01Woo00<07g`0Ool017oo00L07gooOomoog`0Ool07`03Ool0
2W`001ml07ooO0007g`0Ooml000O0W`000<07g`001l0GWoo001MOol047`001l07g`0Ool07g`0Ool0
7g`001moo`0OO01oo`0O0Woo00=l000OOol017oo00=l07ooOol00P0O0Woo00=l07ooOol00goo0P0O
00=oog`0Ool01Woo0P0O00=l07ooOol01Goo00@07gooO01l00Eoo`0301moogoo009l009oo`0301mo
ogoo00=oo`07O0007gooOoml000OO0000Woo00P07g`0O01oo`0OO01oo`0O0W`000<07gooOol0G7oo
001LOol00`0OO0007`0201l01g`001l07g`001moog`0009oo`0401ml000OOol201l00g`0Oomoo`04
Ool201l5Ool2O002Ool00`0OOomoo`02Ool00g`0Oomoo`03Ool01@0OOomoogooO0001Goo00<07goo
Ool00Woo00=l07ooOol00P0O1Goo0W`01Woo00L07g`0O01oog`001ml0002Ool02@0OOoml000OOoml
000OO01oo`03O01MOol005aoo`807`04O01oo`0OO00201l02W`001moo`0OO01oo`0OOoml000O0goo
00=l07ooOol00Woo00<07gooO0001goo00=l000OOol01Goo00El07ooOomoo`0O00Eoo`05O01oogoo
Ool07`06Ool00g`001moo`06Ool00`0OOoml0004Ool03P0OOomoogooO0007gooO01oo`0OOoml07oo
01l2O000100OO01oo`0O0W`0GGoo001KOol401l037`001l07g`0Ool07g`001moo`0OO01oo`807`03
O01oogoo009oo`04O01oogoo01l3Ool2O005Ool00`0OO01oo`06Ool2O0000`0OOomoo`05Ool00g`0
01l07`07Ool00`0OO01oo`04Ool201l3Ool017`0Oomoo`0O0goo00el000OO01l07oo01ml07ooO000
7g`0Ool07`02O000100OO01l07`0GGoo001KOol301l00goo01ml000201l01G`001moog`0Ool0100O
0Woo00=l07ooOol00Woo00=l000OOol01Goo00=l07ooOol00P0O0Woo00=l07ooOol017oo0P0O00=l
07ooOol01Goo00<07g`0O0001Woo00<07gooOol00W`00Woo00<07gooOol017oo00=l000OOol00goo
00<07gooOol00g`00Woo00T07g`0Ool07gooO0007g`0Ool017`0Fgoo001JOol401l01goo01ml000O
Ool07g`000807`09O0007`0OOoml000OOol07g`0009oo`0401moog`0O006Ool00g`001moo`04Ool0
0g`0Oomoo`02Ool01@0OOomoogooO0001Goo00D07gooOomoog`000Aoo`0301moogoo00=oo`03O000
7goo00Eoo`807`05Ooml07ooOol07`02Ool00g`001moo`02O0002P0OOoml000OO01oog`001ml07oo
17`0Fgoo001IOol801l017`0Ool07g`00P0O00Il07oo01moog`001l2Ool00`0OO0007`04Ool00g`0
Oomoo`03Ool00`0OO01oo`05Ool2O0000goo01moo`04Ool2O0000goo01l07`05Ool017`0Ool07`0O
1Woo00<07g`0Ool017oo00<07gooOol00Woo00=l000OO0000Woo00D07gooO01oo`0O009l0005Ool0
7g`0O0007`08O01JOol005Qoo`0301moo`0O00H07`05Ooml07oo01ml000201l01G`0Ool07gooO000
100O00=l07ooOol00goo00=l07ooOol00P0O0Woo00=l07ooOol017oo00<07g`0Ool01goo00<07goo
Ool01Woo00<07g`0Ool01Goo00<07gooOol00W`00Woo00<07gooOol00goo00<07g`0O0000W`000`0
7gooO01oo`0OOoml000OO01oo`0OOol7O0000gooO01oo`1HOol005Yoo`L07`0:Ool07`0O01moog`0
Ool07g`001l2Ool01P0OOomoo`0OOoml00Eoo`807`Eoo`04O01oogooOol201l2Ool00g`0Oomoo`03
Ool201l00gooO01l0005Ool00`0OOomoo`02O003Ool00`0OOomoo`03Ool2O005Ool0100OO01oogoo
0W`000Aoog`0Ool07`9l000301moog`0009l0003Ooml07`000El05]oo`00Fgoo100O00aoo`0O01mo
o`0OO0007gooO01oo`0OO00201l01gooO01oogoo01moog`0009oo`807`03Ooml07oo00Eoo`03O000
7`0O00Eoo`05O01oogooOol07`05Ool01G`0Oomoogoo01l01Goo0W`000<07gooOol017oo00@07goo
O01l009oo`0301moog`0009oo`0=01moog`0O0007g`0Ool07gooO0007g`0Ool00W`000=oog`0O000
0W`0G7oo001LOol601l01goo01moog`0Ool07g`000807`05O0007gooOoml0002Ool0100OOoml000O
17oo00=l07ooOol00Woo0P0O00=l07ooOol01Goo0W`000<07gooOol01Goo00=l000O01l01goo00<0
7g`0O00017oo00<07gooOol00Woo00Al000OOoml009oo`0501moogooO0007`02O0001`0OOoml000O
Ooml07oo00Il05eoo`00GGoo0`0O00Aoo`0O01moo`@07`05O01oo`0OOoml0002Ool00`0OO01l0002
01l00gooO01oo`04Ool017`0Ool07`0O0goo0W`017oo0P0O00=oog`0Ool01Woo00@07gooO01l00Ao
o`807`=oo`9l0003Ool07goo00Aoo`0401moog`0O00201l2Ool01W`001moog`0Ool07`Al0004Ooml
07`0Ool3O01NOol005moo`H07`09Ool07g`0Ooml07oo01moog`0009oo`807`05O0007gooOoml0004
Ool00`0OO01oo`06Ool017`0Oomoo`0O17oo00=l07ooOol00goo00<07gooOol00Woo00Al07ooOol0
7`Moo`0301ml07oo00=oo`0501moog`0Ool07`02O002Ool0200OOoml07oo01moo`0OOol7O01POol0
061oo`0<01moo`0O01moo`0OOol07g`001ml07oo1@0O0Woo00Il000OOomoog`0Ool201l2Ool2O006
Ool2O006Ool2O0000goo01l07`06Ool201l6Ool201l2Ool2O0002Goo01moogooO0007gooO01oo`04
O00027oo01ml000OO01oog`0Ool4O01QOol0065oo`P07`04O0007`0O01l2Ool00g`0Ool07`02Ool0
0g`001moo`0201l6Ool017`0Oomoogoo0P0O0Woo00=l07ooOol017oo0P0O00=l07ooOol017oo00<0
7gooOol00W`00goo00<07gooOol017oo0W`000=oog`001l00Woo00=l07oo01l00Woo0g`000<07g`0
O0001W`0HWoo001ROol201l027oo01l07goo01ml000OOol2O002Ool00g`0Ool07`02Ool2O002Ool2
O005Ool2O0000`0OOomoo`03Ool2O002Ool201l3Ool2O002Ool201l5Ool00g`001l07`05Ool201l2
Ool201l2Ool00g`0Ool07`02Ool201l01G`0Ool07g`0Ool00W`000=oog`0O000Hgoo001TOol401l0
17oo01ml000O0Woo00Al07ooOoml00<07`9oo`05O01oogooOoml0003Ool201l00gooO01oo`06Ool2
O007Ool201l7Ool0100OOoml07`00goo00D07gooOomoo`0O009oo`=l000401moogoo01l2Ool017`0
01ml07oo17`0IGoo001UOol601l00g`001l07`0401l017`0Oomoo`0O0Woo00El07ooOomoog`00080
7`Aoo`9l00=oo`807`9oo`03O01oogoo00=oo`0301moogoo009l00=oo`807`Aoo`9l000501moogoo
Ool07`02Ool017`0Oomoo`0O1W`000<07g`0O00017`0IWoo001WOol301l02Woo01ml07`0Ool07g`0
Ool07g`00Woo00@07gooOoml00807`03Ooml07`000Ioo`9l000301moogoo00=oo`9l0003Ool07`0O
00Eoo`03O0007`0O00Ioo`807`04Ooml07`001l2Ool017`0Oomoo`0O0Woo00<07g`0Ool00P0O00=l
07ooO0000W`0J7oo001XOol601l2O000100OO01l000O0W`0100O0W`00goo0W`00goo0P0O00=oog`0
Ool01Goo0P0O00=l07ooOol017oo00@07gooO01l00=oo`807`=oo`807`Al00807`04O0007`0OO002
01l6O01YOol006Yoo`807`03Ool07`0O00@07`03O0007goo009l000501moogooOoml0003Ool0100O
O0007`0O17oo0W`000Aoo`0O01l07`=oo`=l0003Ool07`0O00Aoo`9l000301ml07oo009oo`0501mo
ogooOoml000201l00gooO0007`06O0000gooO01l001[Ool006aoo`D07`9l000801ml000O01moog`0
01moo`807`03O0007`0O00=oo`9l00Aoo`0301ml07`000Moo`807`03O01oogoo009oo`807`=oo`9l
000701ml07`0Ooml000OOol00W`000@07g`001l07`El06eoo`00KWoo1@0O00Al000OO01l00D07`9o
o`9l00Eoo`9l00807`=oo`9l00=oo`807`=oo`9l00807`Eoo`807`9oo`El00807`03O0007g`000Al
06moo`00L7oo100O00=oog`001l00W`00Woo0W`00goo0W`00`0O0Woo0W`01Goo0`0O1Goo0P0O0Woo
0g`00P0O0goo0P0O0Woo0P0O00=l000OOol017`0LGoo001cOol601l01G`001l07`0OO0000P0O00Ao
o`0OO01l00Eoo`9l00<07`=oo`=l00807`Eoo`807`05O01oog`0O0007`03O0000`0OO01l0004O01d
Ool007Eoo`<07`El009oo`9l009oo`0301ml07`000@07`04Ooml07`0O003Ool301l00gooO01l0002
O00201l00g`0Oomoo`0201l2Ool501l3O01fOol007Qoo`D07`9l00807`03O0007`0O00807`Al00Ao
o`<07`Aoo`@07`Al000301ml07`000807`El07Uoo`00O7oo00@07g`0O0007`9l0003Ool07g`0009l
00<07`9l00807`03O01oo`0O009l00807`=l00<07`05O01oo`0O01ml000201l00g`0Oomoo`1kOol0
085oo`0301ml000O00<07`Al00D07`Al00@07`Al000301ml07oo085oo`00QWoo0W`00`0O0g`01P0O
0g`00P0OQgoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000
\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {583.688, 354.313}} -> {-0.399192, \
1.5447, 0.00348777, 0.00348777}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["The rotation matrix about the z-axis by ",
    FontFamily->"New York"],
  Cell[BoxData[
      \(TraditionalForm\`\(-\(\[Pi]\/4\)\)\)]],
  StyleBox[", is given by \"zrotneg.\" Thus,",
    FontFamily->"New York"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[\[Theta]]\), "\[IndentingNewLine]", 
    \(\(Equ5 = zrot[\(-\(\[Pi]\/4\)\)] . Equ1;\)\), "\[IndentingNewLine]", 
    \(MatrixForm[%]\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/2 + Cos[\[Theta]]\/2\), \(1\/2 - 
                Cos[\[Theta]]\/2\), \(-\(Sin[\[Theta]]\/\@2\)\)},
            {\(1\/2 - Cos[\[Theta]]\/2\), \(1\/2 + 
                Cos[\[Theta]]\/2\), \(Sin[\[Theta]]\/\@2\)},
            {\(Sin[\[Theta]]\/\@2\), \(-\(Sin[\[Theta]]\/\@2\)\), \(Cos[\
\[Theta]]\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ComponentFunct[Equ5, {R\ \ Cos[\[Phi]], 0, R\ \ Sin[\[Phi]]}, 
        Blue];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.38348 .3637 m
.3999 .34991 L
s
.36783 .37838 m
.38348 .3637 L
s
.35303 .39386 m
.36783 .37838 L
s
.3999 .34991 m
.41699 .33708 L
s
.33916 .41008 m
.35303 .39386 L
s
.41699 .33708 m
.43469 .32527 L
s
.32629 .42694 m
.33916 .41008 L
s
.43469 .32527 m
.45289 .31455 L
s
.3145 .44437 m
.32629 .42694 L
s
.45289 .31455 m
.47151 .305 L
s
.30386 .46228 m
.3145 .44437 L
s
.47151 .305 m
.49044 .29667 L
s
.29444 .48057 m
.30386 .46228 L
s
.49044 .29667 m
.5096 .28962 L
s
.2863 .49915 m
.29444 .48057 L
s
.5096 .28962 m
.52887 .28391 L
s
.27951 .51792 m
.2863 .49915 L
s
.52887 .28391 m
.54816 .27958 L
s
.27413 .53679 m
.27951 .51792 L
s
.54816 .27958 m
.56735 .2767 L
s
.27021 .55563 m
.27413 .53679 L
s
.56735 .2767 m
.58632 .2753 L
s
.26781 .57434 m
.27021 .55563 L
s
.58632 .2753 m
.60497 .27541 L
s
.26696 .5928 m
.26781 .57434 L
s
.60497 .27541 m
.62316 .27708 L
s
.26772 .6109 m
.26696 .5928 L
s
.62316 .27708 m
.64078 .28032 L
s
.27011 .62851 m
.26772 .6109 L
s
.64078 .28032 m
.65769 .28515 L
s
.27416 .64551 m
.27011 .62851 L
s
.65769 .28515 m
.67377 .29158 L
s
.27987 .66175 m
.27416 .64551 L
s
.67377 .29158 m
.68889 .29961 L
s
.28727 .67713 m
.27987 .66175 L
s
.68889 .29961 m
.70292 .30922 L
s
.29632 .69149 m
.28727 .67713 L
s
.70292 .30922 m
.71572 .32039 L
s
.30702 .70472 m
.29632 .69149 L
s
.71572 .32039 m
.72717 .33307 L
s
.31934 .71668 m
.30702 .70472 L
s
.72717 .33307 m
.73715 .34721 L
s
.33321 .72725 m
.31934 .71668 L
s
.73715 .34721 m
.74554 .36274 L
s
.34857 .73631 m
.33321 .72725 L
s
.74554 .36274 m
.75224 .37957 L
s
.36534 .74374 m
.34857 .73631 L
s
.75224 .37957 m
.75713 .3976 L
s
.38342 .74944 m
.36534 .74374 L
s
.75713 .3976 m
.76014 .41671 L
s
.40268 .75332 m
.38342 .74944 L
s
.76014 .41671 m
.7612 .43677 L
s
.423 .75531 m
.40268 .75332 L
s
.7612 .43677 m
.76025 .45762 L
s
.44421 .75534 m
.423 .75531 L
s
.76025 .45762 m
.75725 .47909 L
s
.46614 .75338 m
.44421 .75534 L
s
.75725 .47909 m
.7522 .501 L
s
.48862 .74939 m
.46614 .75338 L
s
.7522 .501 m
.74509 .52317 L
s
.51144 .74339 m
.48862 .74939 L
s
.74509 .52317 m
.73596 .54538 L
s
.53439 .73539 m
.51144 .74339 L
s
.73596 .54538 m
.72487 .56743 L
s
.55727 .72544 m
.53439 .73539 L
s
.72487 .56743 m
.7119 .58912 L
s
.57985 .71362 m
.55727 .72544 L
s
.7119 .58912 m
.69714 .61022 L
s
.60191 .70002 m
.57985 .71362 L
s
.69714 .61022 m
.68074 .63053 L
s
.62323 .68476 m
.60191 .70002 L
s
.68074 .63053 m
.66284 .64985 L
s
.64361 .66798 m
.62323 .68476 L
s
.66284 .64985 m
.64361 .66798 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00:1ooaD07f]oo`00Vgoo1@0O5Goo1@0OIWoo002FOol5
01lOOol401mROol009Aoo`807bQoo`807f1oo`00TGoo0`0O;7oo0P0OGWoo002>Ool301laOol201mL
Ool008]oo`<07cIoo`807eYoo`00RGoo0P0O>goo00<07gooOol0Egoo0027Ool201lnOol201mGOol0
08Eoo`807d9oo`0301moogoo05Aoo`00Pgoo0P0OAGoo00<07gooOol0Dgoo0021Ool201m8Ool201mC
Ool007moo`807daoo`0301moogoo051oo`00OGoo0P0OCgoo00<07gooOol0Cgoo001lOol00`0OOomo
o`1?Ool00`0OOomoo`1?Ool007Yoo`807e=oo`0301moogoo04ioo`00N7oo0P0OEWoo00<07gooOol0
CGoo001gOol00`0OOomoo`1GOol00`0OOomoo`1<Ool007Ioo`0301moogoo05Qoo`0301moogoo04ao
o`00M7oo0P0OG7oo00<07gooOol0Bgoo001cOol00`0OOomoo`1MOol00`0OOomoo`1:Ool0079oo`03
01moogoo05ioo`0301moogoo04Yoo`00LGoo00<07gooOol0H7oo00<07gooOol0BGoo001`Ool00`0O
Oomoo`1QOol00`0OOomoo`19Ool006moo`0301moogoo06=oo`0301moogoo04Qoo`00KWoo00<07goo
Ool0I7oo00<07gooOol0B7oo001]Ool00`0OOomoo`1UOol00`0OOomoo`18Ool006]oo`807fUoo`03
01moogoo04Moo`00JWoo00<07gooOol0JGoo00<07gooOol0Agoo001YOol00`0OOomoo`1[Ool00`0O
Oomoo`16Ool006Qoo`0301moogoo06aoo`0301moogoo04Ioo`00Igoo00<07gooOol0KWoo00<07goo
Ool0AGoo001WOol00`0OOomoo`1^Ool00`0OOomoo`15Ool006Ioo`0301moogoo06moo`0301moogoo
04Eoo`00IGoo00<07gooOol0LGoo00<07gooOol0A7oo001TOol00`0OOomoo`1bOol00`0OOomoo`14
Ool006=oo`0301moogoo07=oo`0301moogoo04Aoo`00HWoo00<07gooOol0M7oo00<07gooOol0A7oo
001QOol00`0OOomoo`1fOol00`0OOomoo`13Ool0061oo`0301moogoo07Moo`0301moogoo04=oo`00
Ggoo00<07gooOol0N7oo00<07gooOol0@goo001OOol00`0OOomoo`1hOol00`0OOomoo`13Ool005io
o`0301moogoo07Uoo`0301moogoo04=oo`00GGoo00<07gooOol0NWoo00<07gooOol0@goo001LOol0
0`0OOomoo`1kOol00`0OOomoo`13Ool005aoo`0301moogoo07]oo`0301moogoo04=oo`00Fgoo00<0
7gooOol0O7oo00<07gooOol0@goo001KOol00`0OOomoo`1lOol00`0OOomoo`13Ool005Yoo`0301mo
ogoo07eoo`0301moogoo04=oo`00FGoo00<07gooOol0OWoo00<07gooOol0@goo001IOol00`0OOomo
o`1nOol00`0OOomoo`13Ool005Qoo`0301moogoo07moo`0301moogoo04=oo`00F7oo00<07gooOol0
Ogoo00<07gooOol0@goo001GOol00`0OOomoo`20Ool00`0OOomoo`13Ool005Ioo`0301moogoo085o
o`0301moogoo04=oo`00EWoo00<07gooOol0P7oo00<07gooOol0A7oo001EOol00`0OOomoo`21Ool0
0`0OOomoo`14Ool005Eoo`0301moogoo085oo`0301moogoo04Aoo`00E7oo00<07gooOol0PWoo00<0
7gooOol0A7oo001DOol00`0OOomoo`22Ool00`0OOomoo`14Ool005=oo`0301moogoo089oo`0301mo
ogoo04Eoo`00Dgoo00<07gooOol0PWoo00<07gooOol0AGoo001COol00`0OOomoo`22Ool00`0OOomo
o`15Ool0059oo`0301moogoo089oo`0301moogoo04Ioo`00DWoo00<07gooOol0PWoo00<07gooOol0
AWoo001BOol00`0OOomoo`22Ool00`0OOomoo`16Ool0055oo`0301moogoo089oo`0301moogoo04Mo
o`00DGoo00<07gooOol0PWoo00<07gooOol0Agoo001@Ool00`0OOomoo`23Ool00`0OOomoo`17Ool0
051oo`0301moogoo08=oo`0301moogoo04Moo`00D7oo00<07gooOol0PWoo00<07gooOol0B7oo001?
Ool00`0OOomoo`23Ool00`0OOomoo`18Ool004moo`0301moogoo08=oo`0301moogoo04Qoo`00Cgoo
00<07gooOol0PWoo00<07gooOol0BGoo001>Ool00`0OOomoo`23Ool00`0OOomoo`19Ool004ioo`03
01moogoo08=oo`0301moogoo04Uoo`00CWoo00<07gooOol0PWoo00<07gooOol0BWoo001>Ool00`0O
Oomoo`22Ool00`0OOomoo`1:Ool004eoo`0301moogoo089oo`0301moogoo04]oo`00CGoo00<07goo
Ool0PWoo00<07gooOol0Bgoo001=Ool00`0OOomoo`21Ool00`0OOomoo`1<Ool004eoo`0301moogoo
085oo`0301moogoo04aoo`00CGoo00<07gooOol0P7oo00<07gooOol0CGoo001<Ool00`0OOomoo`21
Ool00`0OOomoo`1=Ool004aoo`0301moogoo081oo`0301moogoo04ioo`00C7oo00<07gooOol0P7oo
00<07gooOol0CWoo001<Ool00`0OOomoo`1oOol00`0OOomoo`1?Ool004aoo`0301moogoo07moo`03
01moogoo04moo`00C7oo00<07gooOol0OWoo00<07gooOol0D7oo001<Ool00`0OOomoo`1nOol00`0O
Oomoo`1@Ool004aoo`0301moogoo07eoo`0301moogoo055oo`00C7oo00<07gooOol0O7oo00<07goo
Ool0DWoo001<Ool00`0OOomoo`1lOol00`0OOomoo`1BOol004aoo`0301moogoo07]oo`0301moogoo
05=oo`00C7oo00<07gooOol0NWoo00<07gooOol0E7oo001<Ool00`0OOomoo`1jOol00`0OOomoo`1D
Ool004aoo`0301moogoo07Uoo`0301moogoo05Eoo`00C7oo00<07gooOol0N7oo00<07gooOol0EWoo
001<Ool00`0OOomoo`1gOol00`0OOomoo`1GOol004eoo`0301moogoo07Eoo`0301moogoo05Qoo`00
CGoo00<07gooOol0M7oo00<07gooOol0FGoo001=Ool00`0OOomoo`1cOol00`0OOomoo`1JOol004eo
o`0301moogoo079oo`0301moogoo05]oo`00CGoo00<07gooOol0LGoo00<07gooOol0G7oo001>Ool0
0`0OOomoo`1_Ool00`0OOomoo`1MOol004ioo`0301moogoo06moo`0301moogoo05eoo`00CWoo00<0
7gooOol0KWoo00<07gooOol0GWoo001>Ool00`0OOomoo`1]Ool00`0OOomoo`1OOol004moo`0301mo
ogoo06]oo`0301moogoo061oo`00Cgoo00<07gooOol0JWoo00<07gooOol0HGoo001@Ool00`0OOomo
o`1WOol201mTOol0051oo`0301moogoo06Ioo`0301moogoo06Aoo`00DGoo00<07gooOol0I7oo00<0
7gooOol0IGoo001AOol00`0OOomoo`1SOol00`0OOomoo`1VOol0059oo`0301moogoo065oo`0301mo
ogoo06Moo`00DWoo00<07gooOol0Ggoo0P0OJWoo001COol00`0OOomoo`1MOol00`0OOomoo`1ZOol0
05=oo`0301moogoo05aoo`0301moogoo06]oo`00E7oo00<07gooOol0FGoo0P0OKWoo001EOol00`0O
Oomoo`1GOol00`0OOomoo`1^Ool005Ioo`0301moogoo05Aoo`807g5oo`00EWoo00<07gooOol0Dgoo
00<07gooOol0LGoo001GOol00`0OOomoo`1@Ool201mdOol005Qoo`0301moogoo04ioo`0301moogoo
07Aoo`00FGoo00<07gooOol0Bgoo0P0OMgoo001JOol00`0OOomoo`19Ool00`0OOomoo`1gOol005]o
o`0301moogoo04Ioo`807gYoo`00G7oo00<07gooOol0@goo0P0OO7oo001MOol201m1Ool201mnOol0
05moo`0301moogoo03eoo`0301moogoo07ioo`00H7oo0P0O>goo0P0OPGoo001ROol201lgOol201n3
Ool006Aoo`0301moogoo035oo`<07hEoo`00IGoo0P0O;Goo100OR7oo001WOol301lWOol301n<Ool0
06Yoo`<07b5oo`<07hmoo`00KGoo100O67oo1@0OTWoo001aOolH01nGOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.3319 .34888 m
.34984 .33064 L
s
.31507 .36812 m
.3319 .34888 L
s
.34984 .33064 m
.36878 .31351 L
s
.29943 .38826 m
.31507 .36812 L
s
.36878 .31351 m
.38863 .29757 L
s
.28508 .40919 m
.29943 .38826 L
s
.38863 .29757 m
.40928 .28292 L
s
.27209 .43082 m
.28508 .40919 L
s
.40928 .28292 m
.43063 .26964 L
s
.26055 .45301 m
.27209 .43082 L
s
.43063 .26964 m
.45256 .25782 L
s
.25053 .47566 m
.26055 .45301 L
s
.45256 .25782 m
.47495 .24754 L
s
.24211 .49864 m
.25053 .47566 L
s
.47495 .24754 m
.4977 .23887 L
s
.23535 .52182 m
.24211 .49864 L
s
.4977 .23887 m
.52066 .23188 L
s
.23032 .54508 m
.23535 .52182 L
s
.52066 .23188 m
.54371 .22664 L
s
.22706 .56828 m
.23032 .54508 L
s
.54371 .22664 m
.56672 .2232 L
s
.22564 .59128 m
.22706 .56828 L
s
.56672 .2232 m
.58954 .22163 L
s
.22609 .61393 m
.22564 .59128 L
s
.58954 .22163 m
.61204 .22195 L
s
.22844 .6361 m
.22609 .61393 L
s
.61204 .22195 m
.63405 .22421 L
s
.23271 .65761 m
.22844 .6361 L
s
.63405 .22421 m
.65544 .22843 L
s
.23893 .67834 m
.23271 .65761 L
s
.65544 .22843 m
.67605 .23463 L
s
.24709 .6981 m
.23893 .67834 L
s
.67605 .23463 m
.69572 .24281 L
s
.25718 .71676 m
.24709 .6981 L
s
.69572 .24281 m
.71429 .25296 L
s
.26918 .73415 m
.25718 .71676 L
s
.71429 .25296 m
.73161 .26505 L
s
.28303 .75012 m
.26918 .73415 L
s
.73161 .26505 m
.74752 .27904 L
s
.2987 .76452 m
.28303 .75012 L
s
.74752 .27904 m
.76187 .29488 L
s
.3161 .7772 m
.2987 .76452 L
s
.76187 .29488 m
.77451 .31248 L
s
.33514 .78802 m
.3161 .7772 L
s
.77451 .31248 m
.78531 .33176 L
s
.35571 .79686 m
.33514 .78802 L
s
.78531 .33176 m
.79413 .3526 L
s
.37767 .80359 m
.35571 .79686 L
s
.79413 .3526 m
.80086 .37486 L
s
.40089 .80812 m
.37767 .80359 L
s
.80086 .37486 m
.80539 .3984 L
s
.42519 .81035 m
.40089 .80812 L
s
.80539 .3984 m
.80765 .42304 L
s
.45039 .81023 m
.42519 .81035 L
s
.80765 .42304 m
.80757 .44859 L
s
.47629 .80771 m
.45039 .81023 L
s
.80757 .44859 m
.8051 .47484 L
s
.50267 .80276 m
.47629 .80771 L
s
.8051 .47484 m
.80022 .50159 L
s
.52931 .7954 m
.50267 .80276 L
s
.80022 .50159 m
.79294 .52859 L
s
.55596 .78565 m
.52931 .7954 L
s
.79294 .52859 m
.7833 .5556 L
s
.58238 .77357 m
.55596 .78565 L
s
.7833 .5556 m
.77135 .58237 L
s
.60834 .75924 m
.58238 .77357 L
s
.77135 .58237 m
.75717 .60866 L
s
.63357 .74278 m
.60834 .75924 L
s
.75717 .60866 m
.74089 .63421 L
s
.65784 .72433 m
.63357 .74278 L
s
.74089 .63421 m
.72265 .65878 L
s
.68093 .70406 m
.65784 .72433 L
s
.72265 .65878 m
.70259 .68214 L
s
.70259 .68214 m
.68093 .70406 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo002VOol<01m^Ool00:1oo`H07`aoo`L07fMoo`00VGoo1`0O6Goo1@0O
HWoo002DOol501lUOol301mOOol0091oo`@07beoo`<07eaoo`00SWoo0P0O=7oo0P0OFWoo002<Ool2
01lhOol201mHOol008Yoo`807caoo`807eIoo`00Qgoo0`0O@7oo0P0OE7oo0023Ool401m5Ool201mB
Ool0085oo`807d]oo`0301moogoo04moo`00Ogoo0P0OCWoo00<07gooOol0CWoo001nOol00`0OOomo
o`1?Ool00`0OOomoo`1=Ool007aoo`807e=oo`0301moogoo04aoo`00Ngoo00<07gooOol0E7oo00<0
7gooOol0Bgoo001iOol201mHOol201m;Ool007Qoo`0301moogoo05Yoo`0301moogoo04Qoo`00MWoo
0P0OGWoo00<07gooOol0Agoo001eOol00`0OOomoo`1OOol00`0OOomoo`16Ool007=oo`807f=oo`03
01moogoo04Eoo`00LWoo00<07gooOol0I7oo00<07gooOol0A7oo001`Ool201mXOol00`0OOomoo`13
Ool006moo`0301moogoo06Uoo`0301moogoo049oo`00KGoo0P0OKGoo00<07gooOol0@Goo001/Ool0
0`0OOomoo`1]Ool00`0OOomoo`11Ool006Yoo`807g5oo`0301moogoo041oo`00JGoo00<07gooOol0
LWoo00<07gooOol0?goo001XOol00`0OOomoo`1cOol00`0OOomoo`0oOol006Moo`0301moogoo07Eo
o`0301moogoo03ioo`00IWoo00<07gooOol0MWoo00<07gooOol0?Woo001UOol00`0OOomoo`1hOol0
0`0OOomoo`0mOol006Aoo`0301moogoo07Uoo`0301moogoo03eoo`00Hgoo00<07gooOol0Ngoo00<0
7gooOol0?7oo001ROol00`0OOomoo`1lOol00`0OOomoo`0lOol0065oo`0301moogoo07ioo`0301mo
ogoo03]oo`00HGoo00<07gooOol0OWoo00<07gooOol0>goo001POol00`0OOomoo`1oOol00`0OOomo
o`0kOol005moo`0301moogoo085oo`0301moogoo03Yoo`00GWoo00<07gooOol0PWoo00<07gooOol0
>Woo001MOol00`0OOomoo`23Ool00`0OOomoo`0jOol005aoo`0301moogoo08Eoo`0301moogoo03Uo
o`00Fgoo00<07gooOol0QWoo00<07gooOol0>Goo001JOol00`0OOomoo`27Ool00`0OOomoo`0iOol0
05Uoo`0301moogoo08Uoo`0301moogoo03Qoo`00F7oo00<07gooOol0RWoo00<07gooOol0>7oo001G
Ool00`0OOomoo`2;Ool00`0OOomoo`0hOol005Moo`0301moogoo08aoo`0301moogoo03Moo`00EWoo
00<07gooOol0SGoo00<07gooOol0=goo001EOol00`0OOomoo`2>Ool00`0OOomoo`0gOol005Aoo`03
01moogoo08moo`0301moogoo03Moo`00E7oo00<07gooOol0T7oo00<07gooOol0=Woo001COol00`0O
Oomoo`2AOol00`0OOomoo`0fOol0059oo`0301moogoo099oo`0301moogoo03Ioo`00DWoo00<07goo
Ool0TWoo00<07gooOol0=Woo001AOol00`0OOomoo`2COol00`0OOomoo`0fOol0051oo`0301moogoo
09Aoo`0301moogoo03Ioo`00D7oo00<07gooOol0U7oo00<07gooOol0=Woo001?Ool00`0OOomoo`2E
Ool00`0OOomoo`0fOol004moo`0301moogoo09Eoo`0301moogoo03Ioo`00CWoo00<07gooOol0UWoo
00<07gooOol0=Woo001>Ool00`0OOomoo`2FOol00`0OOomoo`0fOol004eoo`0301moogoo09Moo`03
01moogoo03Ioo`00CGoo00<07gooOol0Ugoo00<07gooOol0=Woo001<Ool00`0OOomoo`2HOol00`0O
Oomoo`0fOol004aoo`0301moogoo09Qoo`0301moogoo03Ioo`00Bgoo00<07gooOol0VGoo00<07goo
Ool0=Woo001;Ool00`0OOomoo`2IOol00`0OOomoo`0fOol004Yoo`0301moogoo09Yoo`0301moogoo
03Ioo`00BGoo00<07gooOol0Vgoo00<07gooOol0=Woo0019Ool00`0OOomoo`2KOol00`0OOomoo`0f
Ool004Qoo`0301moogoo09aoo`0301moogoo03Ioo`00B7oo00<07gooOol0W7oo00<07gooOol0=Woo
0017Ool00`0OOomoo`2MOol00`0OOomoo`0fOol004Moo`0301moogoo09eoo`0301moogoo03Ioo`00
Agoo00<07gooOol0WGoo00<07gooOol0=Woo0016Ool00`0OOomoo`2MOol00`0OOomoo`0gOol004Io
o`0301moogoo09eoo`0301moogoo03Moo`00AWoo00<07gooOol0WGoo00<07gooOol0=goo0016Ool0
0`0OOomoo`2MOol00`0OOomoo`0gOol004Eoo`0301moogoo09eoo`0301moogoo03Qoo`00AGoo00<0
7gooOol0WGoo00<07gooOol0>7oo0015Ool00`0OOomoo`2MOol00`0OOomoo`0hOol004Aoo`0301mo
ogoo09eoo`0301moogoo03Uoo`00A7oo00<07gooOol0WGoo00<07gooOol0>Goo0014Ool00`0OOomo
o`2MOol00`0OOomoo`0iOol004=oo`0301moogoo09ioo`0301moogoo03Uoo`00@goo00<07gooOol0
WGoo00<07gooOol0>Woo0013Ool00`0OOomoo`2MOol00`0OOomoo`0jOol004=oo`0301moogoo09eo
o`0301moogoo03Yoo`00@goo00<07gooOol0WGoo00<07gooOol0>Woo0012Ool00`0OOomoo`2MOol0
0`0OOomoo`0kOol0049oo`0301moogoo09eoo`0301moogoo03]oo`00@Woo00<07gooOol0W7oo00<0
7gooOol0?7oo0012Ool00`0OOomoo`2LOol00`0OOomoo`0lOol0049oo`0301moogoo09aoo`0301mo
ogoo03aoo`00@Woo00<07gooOol0Vgoo00<07gooOol0?Goo0012Ool00`0OOomoo`2KOol00`0OOomo
o`0mOol0045oo`0301moogoo09aoo`0301moogoo03eoo`00@Goo00<07gooOol0Vgoo00<07gooOol0
?Woo0011Ool00`0OOomoo`2KOol00`0OOomoo`0nOol0045oo`0301moogoo09Yoo`0301moogoo03mo
o`00@Goo00<07gooOol0VWoo00<07gooOol0?goo0011Ool00`0OOomoo`2JOol00`0OOomoo`0oOol0
041oo`0301moogoo09Yoo`0301moogoo041oo`00@7oo00<07gooOol0VWoo00<07gooOol0@7oo0010
Ool00`0OOomoo`2IOol00`0OOomoo`11Ool0041oo`0301moogoo09Uoo`0301moogoo045oo`00@7oo
00<07gooOol0V7oo00<07gooOol0@Woo0010Ool00`0OOomoo`2HOol00`0OOomoo`12Ool0041oo`03
01moogoo09Moo`0301moogoo04=oo`00@7oo00<07gooOol0Ugoo00<07gooOol0@goo0010Ool00`0O
Oomoo`2FOol00`0OOomoo`14Ool0041oo`0301moogoo09Eoo`0301moogoo04Eoo`00@7oo00<07goo
Ool0UGoo00<07gooOol0AGoo0010Ool00`0OOomoo`2DOol00`0OOomoo`16Ool0041oo`0301moogoo
09=oo`0301moogoo04Moo`00@7oo00<07gooOol0Tgoo00<07gooOol0Agoo0011Ool00`0OOomoo`2A
Ool00`0OOomoo`18Ool0045oo`0301moogoo095oo`0301moogoo04Qoo`00@Goo00<07gooOol0T7oo
00<07gooOol0BGoo0011Ool00`0OOomoo`2?Ool00`0OOomoo`1:Ool0045oo`0301moogoo08moo`03
01moogoo04Yoo`00@Goo00<07gooOol0SWoo00<07gooOol0Bgoo0012Ool00`0OOomoo`2<Ool00`0O
Oomoo`1<Ool0049oo`0301moogoo08]oo`0301moogoo04eoo`00@Woo00<07gooOol0Rgoo00<07goo
Ool0CGoo0012Ool00`0OOomoo`2:Ool00`0OOomoo`1>Ool004=oo`0301moogoo08Qoo`0301moogoo
04moo`00@goo00<07gooOol0Qgoo00<07gooOol0D7oo0013Ool00`0OOomoo`26Ool00`0OOomoo`1A
Ool004Aoo`0301moogoo08Aoo`0301moogoo059oo`00A7oo00<07gooOol0Pgoo00<07gooOol0Dgoo
0014Ool00`0OOomoo`22Ool00`0OOomoo`1DOol004Eoo`0301moogoo081oo`0301moogoo05Eoo`00
AGoo00<07gooOol0Ogoo00<07gooOol0EWoo0015Ool00`0OOomoo`1nOol00`0OOomoo`1GOol004Io
o`0301moogoo07eoo`0301moogoo05Moo`00AWoo00<07gooOol0O7oo00<07gooOol0F7oo0017Ool0
0`0OOomoo`1jOol00`0OOomoo`1IOol004Moo`0301moogoo07Uoo`0301moogoo05Yoo`00B7oo00<0
7gooOol0MWoo0P0OGGoo0018Ool00`0OOomoo`1eOol00`0OOomoo`1MOol004Uoo`0301moogoo07=o
o`0301moogoo05ioo`00BWoo00<07gooOol0L7oo0P0OHGoo001;Ool00`0OOomoo`1^Ool00`0OOomo
o`1QOol004]oo`0301moogoo06eoo`0301moogoo069oo`00C7oo00<07gooOol0Jgoo00<07gooOol0
Hgoo001=Ool00`0OOomoo`1XOol201mVOol004ioo`0301moogoo06Ioo`0301moogoo06Ioo`00Cgoo
00<07gooOol0I7oo00<07gooOol0Igoo001?Ool00`0OOomoo`1SOol00`0OOomoo`1XOol0051oo`03
01moogoo061oo`807f]oo`00DGoo00<07gooOol0GGoo0P0OKGoo001BOol00`0OOomoo`1JOol201m_
Ool005=oo`0301moogoo05Qoo`0301moogoo06moo`00E7oo00<07gooOol0EGoo0P0OLWoo001EOol0
0`0OOomoo`1COol00`0OOomoo`1bOol005Ioo`0301moogoo055oo`0301moogoo07=oo`00Egoo0P0O
Cgoo0P0OMWoo001IOol00`0OOomoo`1:Ool201mhOol005Yoo`0301moogoo04Moo`807gYoo`00Fgoo
0P0OA7oo0`0OO7oo001MOol201loOol301moOol005moo`<07cYoo`807h9oo`00HWoo0`0O=7oo0`0O
Q7oo001UOol301l^Ool301n7Ool006Qoo`<07bMoo`@07hYoo`00Jgoo1@0O7Goo1@0OSWoo001`Ool7
01l>Ool801nCOol007Moo`h07i]oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.32109 .34365 m
.33831 .32458 L
s
.30506 .36376 m
.32109 .34365 L
s
.29031 .38478 m
.30506 .36376 L
s
.33831 .32458 m
.35663 .30663 L
s
.27693 .40662 m
.29031 .38478 L
s
.35663 .30663 m
.37595 .28993 L
s
.26499 .42914 m
.27693 .40662 L
s
.37595 .28993 m
.39616 .27456 L
s
.25457 .45223 m
.26499 .42914 L
s
.39616 .27456 m
.41718 .26062 L
s
.24573 .47576 m
.25457 .45223 L
s
.41718 .26062 m
.43887 .24821 L
s
.23854 .4996 m
.24573 .47576 L
s
.43887 .24821 m
.46113 .23739 L
s
.23306 .52363 m
.23854 .4996 L
s
.46113 .23739 m
.48383 .22827 L
s
.22934 .54769 m
.23306 .52363 L
s
.48383 .22827 m
.50685 .22091 L
s
.22742 .57166 m
.22934 .54769 L
s
.50685 .22091 m
.53005 .21538 L
s
.22735 .59539 m
.22742 .57166 L
s
.53005 .21538 m
.55329 .21174 L
s
.22915 .61873 m
.22735 .59539 L
s
.55329 .21174 m
.57644 .21005 L
s
.23285 .64152 m
.22915 .61873 L
s
.57644 .21005 m
.59934 .21035 L
s
.23846 .66361 m
.23285 .64152 L
s
.59934 .21035 m
.62184 .21268 L
s
.24597 .68485 m
.23846 .66361 L
s
.62184 .21268 m
.64379 .21706 L
s
.25538 .70508 m
.24597 .68485 L
s
.64379 .21706 m
.66504 .22352 L
s
.26667 .72414 m
.25538 .70508 L
s
.66504 .22352 m
.6854 .23204 L
s
.27978 .74186 m
.26667 .72414 L
s
.6854 .23204 m
.70474 .24261 L
s
.29468 .75811 m
.27978 .74186 L
s
.70474 .24261 m
.72288 .25521 L
s
.3113 .77272 m
.29468 .75811 L
s
.72288 .25521 m
.73966 .26979 L
s
.32955 .78556 m
.3113 .77272 L
s
.73966 .26979 m
.75493 .28627 L
s
.34933 .79647 m
.32955 .78556 L
s
.75493 .28627 m
.76854 .30459 L
s
.37051 .80535 m
.34933 .79647 L
s
.76854 .30459 m
.78034 .32463 L
s
.39298 .81207 m
.37051 .80535 L
s
.78034 .32463 m
.7902 .34627 L
s
.41656 .81653 m
.39298 .81207 L
s
.7902 .34627 m
.798 .36937 L
s
.44109 .81865 m
.41656 .81653 L
s
.798 .36937 m
.80364 .39377 L
s
.46639 .81837 m
.44109 .81865 L
s
.80364 .39377 m
.80702 .41928 L
s
.49226 .81564 m
.46639 .81837 L
s
.80702 .41928 m
.80807 .44571 L
s
.51847 .81044 m
.49226 .81564 L
s
.80807 .44571 m
.80675 .47285 L
s
.54482 .80278 m
.51847 .81044 L
s
.80675 .47285 m
.80303 .50046 L
s
.57106 .79269 m
.54482 .80278 L
s
.80303 .50046 m
.79691 .52831 L
s
.59696 .78023 m
.57106 .79269 L
s
.79691 .52831 m
.78842 .55614 L
s
.62228 .76548 m
.59696 .78023 L
s
.78842 .55614 m
.77761 .58371 L
s
.64678 .74856 m
.62228 .76548 L
s
.77761 .58371 m
.76456 .61075 L
s
.67024 .7296 m
.64678 .74856 L
s
.76456 .61075 m
.74937 .63702 L
s
.69243 .70878 m
.67024 .7296 L
s
.74937 .63702 m
.73218 .66227 L
s
.71314 .68626 m
.69243 .70878 L
s
.73218 .66227 m
.71314 .68626 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002LOolC
01maOol009Moo`D07a=oo`H07f]oo`00Tgoo100O7Woo1@0OIWoo002@Ool301lWOol301mSOol008ao
o`@07beoo`<07f1oo`00RWoo0P0O=7oo0`0OGGoo0028Ool201liOol201mKOol008Ioo`807ceoo`80
7eUoo`00Pgoo0`0O@Goo0P0OEgoo0021Ool201m6Ool201mEOol007moo`807dYoo`0301moogoo059o
o`00OGoo0P0OCGoo0P0ODWoo001kOol201mAOol00`0OOomoo`1?Ool007Uoo`807eAoo`0301moogoo
04ioo`00Mgoo0P0OEgoo00<07gooOol0CGoo001eOol201mJOol201m=Ool007Aoo`0301moogoo05ao
o`0301moogoo04Yoo`00LWoo0P0OH7oo00<07gooOol0BGoo001aOol00`0OOomoo`1QOol00`0OOomo
o`18Ool0071oo`0301moogoo06=oo`0301moogoo04Moo`00Kgoo00<07gooOol0I7oo00<07gooOol0
Agoo001]Ool201mXOol00`0OOomoo`16Ool006aoo`0301moogoo06Uoo`0301moogoo04Eoo`00Jgoo
00<07gooOol0Jgoo00<07gooOol0A7oo001ZOol00`0OOomoo`1]Ool00`0OOomoo`13Ool006Uoo`03
01moogoo06ioo`0301moogoo04=oo`00J7oo00<07gooOol0L7oo00<07gooOol0@Woo001WOol00`0O
Oomoo`1bOol00`0OOomoo`11Ool006Ioo`0301moogoo07=oo`0301moogoo045oo`00IGoo00<07goo
Ool0MGoo00<07gooOol0@7oo001TOol00`0OOomoo`1fOol00`0OOomoo`10Ool006=oo`0301moogoo
07Qoo`0301moogoo03moo`00HWoo00<07gooOol0NGoo00<07gooOol0?goo001QOol00`0OOomoo`1k
Ool00`0OOomoo`0nOol0061oo`0301moogoo07aoo`0301moogoo03ioo`00Ggoo00<07gooOol0OWoo
00<07gooOol0?Goo001NOol00`0OOomoo`1oOol00`0OOomoo`0mOol005eoo`0301moogoo085oo`03
01moogoo03aoo`00G7oo00<07gooOol0PWoo00<07gooOol0?7oo001KOol00`0OOomoo`24Ool00`0O
Oomoo`0kOol005Yoo`0301moogoo08Eoo`0301moogoo03]oo`00FGoo00<07gooOol0Qgoo00<07goo
Ool0>Woo001IOol00`0OOomoo`27Ool00`0OOomoo`0jOol005Qoo`0301moogoo08Uoo`0301moogoo
03Uoo`00Egoo00<07gooOol0RWoo00<07gooOol0>Goo001FOol00`0OOomoo`2<Ool00`0OOomoo`0h
Ool005Ioo`0301moogoo08aoo`0301moogoo03Qoo`00EGoo00<07gooOol0SGoo00<07gooOol0>7oo
001DOol00`0OOomoo`2>Ool00`0OOomoo`0hOol005Aoo`0301moogoo08ioo`0301moogoo03Qoo`00
Dgoo00<07gooOol0T7oo00<07gooOol0=goo001BOol00`0OOomoo`2AOol00`0OOomoo`0gOol0059o
o`0301moogoo095oo`0301moogoo03Moo`00DGoo00<07gooOol0TWoo00<07gooOol0=goo001@Ool0
0`0OOomoo`2COol00`0OOomoo`0gOol0051oo`0301moogoo09=oo`0301moogoo03Moo`00Cgoo00<0
7gooOol0U7oo00<07gooOol0=goo001?Ool00`0OOomoo`2EOol00`0OOomoo`0fOol004ioo`0301mo
ogoo09Ioo`0301moogoo03Ioo`00CWoo00<07gooOol0UWoo00<07gooOol0=Woo001=Ool00`0OOomo
o`2GOol00`0OOomoo`0fOol004eoo`0301moogoo09Moo`0301moogoo03Ioo`00C7oo00<07gooOol0
V7oo00<07gooOol0=Woo001<Ool00`0OOomoo`2HOol00`0OOomoo`0fOol004]oo`0301moogoo09Uo
o`0301moogoo03Ioo`00Bgoo00<07gooOol0VGoo00<07gooOol0=Woo001:Ool00`0OOomoo`2JOol0
0`0OOomoo`0fOol004Yoo`0301moogoo09Yoo`0301moogoo03Ioo`00BGoo00<07gooOol0Vgoo00<0
7gooOol0=Woo0019Ool00`0OOomoo`2KOol00`0OOomoo`0fOol004Uoo`0301moogoo09]oo`0301mo
ogoo03Ioo`00B7oo00<07gooOol0W7oo00<07gooOol0=Woo0018Ool00`0OOomoo`2LOol00`0OOomo
o`0fOol004Moo`0301moogoo09eoo`0301moogoo03Ioo`00Agoo00<07gooOol0WGoo00<07gooOol0
=Woo0016Ool00`0OOomoo`2NOol00`0OOomoo`0fOol004Ioo`0301moogoo09ioo`0301moogoo03Io
o`00AWoo00<07gooOol0WWoo00<07gooOol0=Woo0015Ool00`0OOomoo`2OOol00`0OOomoo`0fOol0
04Eoo`0301moogoo09ioo`0301moogoo03Moo`00AGoo00<07gooOol0WWoo00<07gooOol0=goo0015
Ool00`0OOomoo`2NOol00`0OOomoo`0gOol004Aoo`0301moogoo09moo`0301moogoo03Moo`00A7oo
00<07gooOol0Wgoo00<07gooOol0=goo0014Ool00`0OOomoo`2OOol00`0OOomoo`0gOol004=oo`03
01moogoo09moo`0301moogoo03Qoo`00@goo00<07gooOol0Wgoo00<07gooOol0>7oo0013Ool00`0O
Oomoo`2OOol00`0OOomoo`0hOol004=oo`0301moogoo09moo`0301moogoo03Qoo`00@Woo00<07goo
Ool0Wgoo00<07gooOol0>Goo0012Ool00`0OOomoo`2OOol00`0OOomoo`0iOol0049oo`0301moogoo
09moo`0301moogoo03Uoo`00@Woo00<07gooOol0Wgoo00<07gooOol0>Goo0012Ool00`0OOomoo`2N
Ool00`0OOomoo`0jOol0045oo`0301moogoo09moo`0301moogoo03Yoo`00@Goo00<07gooOol0Wgoo
00<07gooOol0>Woo0011Ool00`0OOomoo`2OOol00`0OOomoo`0jOol0045oo`0301moogoo09ioo`03
01moogoo03]oo`00@Goo00<07gooOol0WWoo00<07gooOol0>goo0011Ool00`0OOomoo`2NOol00`0O
Oomoo`0kOol0045oo`0301moogoo09ioo`0301moogoo03]oo`00@Goo00<07gooOol0WGoo00<07goo
Ool0?7oo0011Ool00`0OOomoo`2MOol00`0OOomoo`0lOol0045oo`0301moogoo09aoo`0301moogoo
03eoo`00@Goo00<07gooOol0W7oo00<07gooOol0?Goo0011Ool00`0OOomoo`2LOol00`0OOomoo`0m
Ool0045oo`0301moogoo09]oo`0301moogoo03ioo`00@Goo00<07gooOol0Vgoo00<07gooOol0?Woo
0011Ool00`0OOomoo`2JOol00`0OOomoo`0oOol0045oo`0301moogoo09Yoo`0301moogoo03moo`00
@Goo00<07gooOol0VGoo00<07gooOol0@7oo0011Ool00`0OOomoo`2IOol00`0OOomoo`10Ool0045o
o`0301moogoo09Qoo`0301moogoo045oo`00@Goo00<07gooOol0V7oo00<07gooOol0@Goo0011Ool0
0`0OOomoo`2GOol00`0OOomoo`12Ool0045oo`0301moogoo09Moo`0301moogoo049oo`00@Goo00<0
7gooOol0UWoo00<07gooOol0@goo0011Ool00`0OOomoo`2FOol00`0OOomoo`13Ool0045oo`0301mo
ogoo09Eoo`0301moogoo04Aoo`00@Goo00<07gooOol0UGoo00<07gooOol0A7oo0011Ool00`0OOomo
o`2DOol00`0OOomoo`15Ool0049oo`0301moogoo09=oo`0301moogoo04Eoo`00@Woo00<07gooOol0
TWoo00<07gooOol0AWoo0012Ool00`0OOomoo`2AOol00`0OOomoo`17Ool0049oo`0301moogoo095o
o`0301moogoo04Moo`00@Woo00<07gooOol0T7oo00<07gooOol0B7oo0013Ool00`0OOomoo`2>Ool0
0`0OOomoo`19Ool004=oo`0301moogoo08ioo`0301moogoo04Uoo`00@goo00<07gooOol0SGoo00<0
7gooOol0BWoo0014Ool00`0OOomoo`2<Ool00`0OOomoo`1:Ool004Aoo`0301moogoo08]oo`0301mo
ogoo04]oo`00A7oo00<07gooOol0RWoo00<07gooOol0C7oo0015Ool00`0OOomoo`28Ool00`0OOomo
o`1=Ool004Eoo`0301moogoo08Moo`0301moogoo04ioo`00AGoo00<07gooOol0QWoo00<07gooOol0
Cgoo0016Ool00`0OOomoo`24Ool00`0OOomoo`1@Ool004Ioo`0301moogoo08=oo`0301moogoo055o
o`00AWoo00<07gooOol0PWoo00<07gooOol0DWoo0017Ool00`0OOomoo`20Ool00`0OOomoo`1COol0
04Moo`0301moogoo07moo`0301moogoo05Aoo`00B7oo00<07gooOol0OWoo00<07gooOol0E7oo0018
Ool00`0OOomoo`1mOol00`0OOomoo`1EOol004Uoo`0301moogoo07]oo`0301moogoo05Ioo`00BWoo
00<07gooOol0NGoo00<07gooOol0Egoo001:Ool00`0OOomoo`1hOol00`0OOomoo`1HOol004]oo`03
01moogoo07Ioo`0301moogoo05Uoo`00Bgoo00<07gooOol0MGoo00<07gooOol0FWoo001<Ool00`0O
Oomoo`1cOol00`0OOomoo`1KOol004eoo`0301moogoo075oo`0301moogoo05aoo`00CWoo00<07goo
Ool0Kgoo00<07gooOol0GGoo001>Ool00`0OOomoo`1]Ool201mPOol004moo`0301moogoo06]oo`03
01moogoo061oo`00D7oo00<07gooOol0JGoo00<07gooOol0HGoo001AOol00`0OOomoo`1VOol201mT
Ool0059oo`0301moogoo06Aoo`0301moogoo06Aoo`00DWoo00<07gooOol0HWoo0P0OIgoo001COol0
0`0OOomoo`1POol00`0OOomoo`1WOol005Aoo`0301moogoo05ioo`0301moogoo06Qoo`00EGoo00<0
7gooOol0Fgoo0P0OJgoo001FOol201mJOol00`0OOomoo`1[Ool005Qoo`0301moogoo05Eoo`807fio
o`00FGoo00<07gooOol0DWoo0P0OL7oo001JOol00`0OOomoo`1?Ool201mbOol005]oo`807dioo`03
01moogoo079oo`00GGoo00<07gooOol0BGoo0P0OMGoo001NOol00`0OOomoo`16Ool201mgOol005mo
o`807dAoo`807gUoo`00HGoo0P0O?goo0`0ONgoo001SOol201lkOol201mnOol006Eoo`807cMoo`80
7h1oo`00Igoo0P0O<Woo0`0OPWoo001YOol301l[Ool401n5Ool006aoo`<07bAoo`@07hUoo`00Kgoo
1@0O6goo100OSGoo001dOolK01nAOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.29578 .36102 m
.3109 .34008 L
s
.28201 .38288 m
.29578 .36102 L
s
.26969 .40554 m
.28201 .38288 L
s
.3109 .34008 m
.3273 .32018 L
s
.25888 .42888 m
.26969 .40554 L
s
.3273 .32018 m
.34489 .30144 L
s
.24965 .45277 m
.25888 .42888 L
s
.34489 .30144 m
.36358 .28396 L
s
.24205 .47708 m
.24965 .45277 L
s
.36358 .28396 m
.38327 .26785 L
s
.23615 .50167 m
.24205 .47708 L
s
.38327 .26785 m
.40385 .25322 L
s
.23199 .5264 m
.23615 .50167 L
s
.40385 .25322 m
.42521 .24016 L
s
.22961 .55113 m
.23199 .5264 L
s
.42521 .24016 m
.44723 .22876 L
s
.22906 .57572 m
.22961 .55113 L
s
.44723 .22876 m
.4698 .21911 L
s
.23034 .60002 m
.22906 .57572 L
s
.4698 .21911 m
.49278 .21129 L
s
.2335 .62387 m
.23034 .60002 L
s
.49278 .21129 m
.51605 .20538 L
s
.23852 .64711 m
.2335 .62387 L
s
.51605 .20538 m
.53945 .20144 L
s
.24542 .66961 m
.23852 .64711 L
s
.53945 .20144 m
.56286 .19953 L
s
.25418 .69118 m
.24542 .66961 L
s
.56286 .19953 m
.5861 .19969 L
s
.26478 .71169 m
.25418 .69118 L
s
.5861 .19969 m
.60904 .20198 L
s
.27718 .73096 m
.26478 .71169 L
s
.60904 .20198 m
.6315 .2064 L
s
.29134 .74885 m
.27718 .73096 L
s
.6315 .2064 m
.65333 .21298 L
s
.30719 .7652 m
.29134 .74885 L
s
.65333 .21298 m
.67436 .22172 L
s
.32465 .77986 m
.30719 .7652 L
s
.67436 .22172 m
.69442 .23259 L
s
.34364 .79269 m
.32465 .77986 L
s
.69442 .23259 m
.71335 .24556 L
s
.36404 .80356 m
.34364 .79269 L
s
.71335 .24556 m
.73098 .26058 L
s
.38573 .81234 m
.36404 .80356 L
s
.73098 .26058 m
.74715 .27758 L
s
.40856 .81892 m
.38573 .81234 L
s
.74715 .27758 m
.7617 .29647 L
s
.43239 .82321 m
.40856 .81892 L
s
.7617 .29647 m
.77449 .31713 L
s
.45704 .82512 m
.43239 .82321 L
s
.77449 .31713 m
.78538 .33944 L
s
.48232 .82459 m
.45704 .82512 L
s
.78538 .33944 m
.79424 .36324 L
s
.50804 .82158 m
.48232 .82459 L
s
.79424 .36324 m
.80096 .38837 L
s
.53398 .81608 m
.50804 .82158 L
s
.80096 .38837 m
.80545 .41463 L
s
.55994 .80809 m
.53398 .81608 L
s
.80545 .41463 m
.80763 .44182 L
s
.58567 .79764 m
.55994 .80809 L
s
.80763 .44182 m
.80745 .46971 L
s
.61096 .78479 m
.58567 .79764 L
s
.80745 .46971 m
.80489 .49807 L
s
.63558 .76963 m
.61096 .78479 L
s
.80489 .49807 m
.79993 .52665 L
s
.65929 .75227 m
.63558 .76963 L
s
.79993 .52665 m
.79259 .5552 L
s
.68188 .73284 m
.65929 .75227 L
s
.79259 .5552 m
.78293 .58345 L
s
.70313 .71151 m
.68188 .73284 L
s
.78293 .58345 m
.77102 .61116 L
s
.72285 .68846 m
.70313 .71151 L
s
.77102 .61116 m
.75695 .63806 L
s
.74084 .6639 m
.72285 .68846 L
s
.75695 .63806 m
.74084 .6639 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002HOolH01m`Ool009=oo`D07aQoo`@07faoo`00
Sgoo100O8Goo0`0OJGoo002<Ool301lXOol301mVOol008Qoo`@07bioo`<07f=oo`00QWoo0P0O=Goo
0`0OH7oo0024Ool201ljOol201mNOol0089oo`807cioo`807eaoo`00P7oo0P0O@Woo0P0OFWoo001n
Ool201m6Ool201mHOol007aoo`807dYoo`0301moogoo05Eoo`00NWoo0P0OCGoo0P0OEGoo001hOol2
01mAOol00`0OOomoo`1BOol007Ioo`807eAoo`0301moogoo055oo`00M7oo0P0OEgoo00<07gooOol0
D7oo001cOol00`0OOomoo`1HOol201m@Ool0079oo`0301moogoo05]oo`0301moogoo04eoo`00L7oo
0P0OGgoo00<07gooOol0C7oo001_Ool00`0OOomoo`1POol00`0OOomoo`1;Ool006ioo`0301moogoo
069oo`0301moogoo04Yoo`00KGoo00<07gooOol0I7oo00<07gooOol0BGoo001/Ool00`0OOomoo`1V
Ool00`0OOomoo`18Ool006Yoo`807fYoo`0301moogoo04Moo`00JGoo00<07gooOol0Jgoo00<07goo
Ool0AWoo001XOol00`0OOomoo`1/Ool00`0OOomoo`16Ool006Moo`0301moogoo06ioo`0301moogoo
04Eoo`00IWoo00<07gooOol0L7oo00<07gooOol0A7oo001TOol201mcOol00`0OOomoo`14Ool006=o
o`0301moogoo07Aoo`0301moogoo04=oo`00HWoo00<07gooOol0MWoo00<07gooOol0@Woo001QOol0
0`0OOomoo`1gOol00`0OOomoo`12Ool0061oo`0301moogoo07Uoo`0301moogoo045oo`00Ggoo00<0
7gooOol0Ngoo00<07gooOol0@7oo001NOol00`0OOomoo`1lOol00`0OOomoo`10Ool005eoo`0301mo
ogoo07ioo`0301moogoo03moo`00G7oo00<07gooOol0Ogoo00<07gooOol0?goo001LOol00`0OOomo
o`20Ool00`0OOomoo`0nOol005]oo`0301moogoo085oo`0301moogoo03ioo`00FWoo00<07gooOol0
Pgoo00<07gooOol0?Goo001JOol00`0OOomoo`23Ool00`0OOomoo`0mOol005Uoo`0301moogoo08Eo
o`0301moogoo03aoo`00F7oo00<07gooOol0QWoo00<07gooOol0?7oo001GOol00`0OOomoo`28Ool0
0`0OOomoo`0kOol005Ioo`0301moogoo08Uoo`0301moogoo03]oo`00EWoo00<07gooOol0RGoo00<0
7gooOol0>goo001EOol00`0OOomoo`2:Ool00`0OOomoo`0kOol005Aoo`0301moogoo08aoo`0301mo
ogoo03Yoo`00Dgoo00<07gooOol0SGoo00<07gooOol0>Woo001COol00`0OOomoo`2=Ool00`0OOomo
o`0jOol0059oo`0301moogoo08moo`0301moogoo03Uoo`00DGoo00<07gooOol0T7oo00<07gooOol0
>Goo001AOol00`0OOomoo`2@Ool00`0OOomoo`0iOol0051oo`0301moogoo095oo`0301moogoo03Uo
o`00D7oo00<07gooOol0TWoo00<07gooOol0>7oo001?Ool00`0OOomoo`2COol00`0OOomoo`0hOol0
04moo`0301moogoo09=oo`0301moogoo03Qoo`00CWoo00<07gooOol0UGoo00<07gooOol0=goo001>
Ool00`0OOomoo`2EOol00`0OOomoo`0gOol004eoo`0301moogoo09Ioo`0301moogoo03Moo`00CGoo
00<07gooOol0UWoo00<07gooOol0=goo001=Ool00`0OOomoo`2GOol00`0OOomoo`0fOol004aoo`03
01moogoo09Qoo`0301moogoo03Ioo`00C7oo00<07gooOol0V7oo00<07gooOol0=Woo001;Ool00`0O
Oomoo`2IOol00`0OOomoo`0fOol004]oo`0301moogoo09Uoo`0301moogoo03Ioo`00BWoo00<07goo
Ool0VWoo00<07gooOol0=Woo001:Ool00`0OOomoo`2JOol00`0OOomoo`0fOol004Uoo`0301moogoo
09]oo`0301moogoo03Ioo`00BGoo00<07gooOol0Vgoo00<07gooOol0=Woo0018Ool00`0OOomoo`2L
Ool00`0OOomoo`0fOol004Qoo`0301moogoo09aoo`0301moogoo03Ioo`00Agoo00<07gooOol0WGoo
00<07gooOol0=Woo0017Ool00`0OOomoo`2MOol00`0OOomoo`0fOol004Moo`0301moogoo09eoo`03
01moogoo03Ioo`00AWoo00<07gooOol0WWoo00<07gooOol0=Woo0016Ool00`0OOomoo`2NOol00`0O
Oomoo`0fOol004Ioo`0301moogoo09ioo`0301moogoo03Ioo`00AWoo00<07gooOol0WWoo00<07goo
Ool0=Woo0015Ool00`0OOomoo`2OOol00`0OOomoo`0fOol004Eoo`0301moogoo09moo`0301moogoo
03Ioo`00AGoo00<07gooOol0Wgoo00<07gooOol0=Woo0014Ool00`0OOomoo`2POol00`0OOomoo`0f
Ool004Aoo`0301moogoo0:1oo`0301moogoo03Ioo`00A7oo00<07gooOol0X7oo00<07gooOol0=Woo
0014Ool00`0OOomoo`2POol00`0OOomoo`0fOol004=oo`0301moogoo0:5oo`0301moogoo03Ioo`00
@goo00<07gooOol0XGoo00<07gooOol0=Woo0013Ool00`0OOomoo`2QOol00`0OOomoo`0fOol004=o
o`0301moogoo0:1oo`0301moogoo03Moo`00@goo00<07gooOol0X7oo00<07gooOol0=goo0012Ool0
0`0OOomoo`2QOol00`0OOomoo`0gOol0049oo`0301moogoo0:5oo`0301moogoo03Moo`00@Woo00<0
7gooOol0X7oo00<07gooOol0>7oo0012Ool00`0OOomoo`2POol00`0OOomoo`0hOol0049oo`0301mo
ogoo0:1oo`0301moogoo03Qoo`00@Woo00<07gooOol0X7oo00<07gooOol0>7oo0012Ool00`0OOomo
o`2OOol00`0OOomoo`0iOol0049oo`0301moogoo09moo`0301moogoo03Uoo`00@Goo00<07gooOol0
X7oo00<07gooOol0>Goo0011Ool00`0OOomoo`2POol00`0OOomoo`0iOol0045oo`0301moogoo09mo
o`0301moogoo03Yoo`00@Goo00<07gooOol0Wgoo00<07gooOol0>Woo0011Ool00`0OOomoo`2OOol0
0`0OOomoo`0jOol0045oo`0301moogoo09moo`0301moogoo03Yoo`00@Goo00<07gooOol0WWoo00<0
7gooOol0>goo0011Ool00`0OOomoo`2NOol00`0OOomoo`0kOol0045oo`0301moogoo09eoo`0301mo
ogoo03aoo`00@Goo00<07gooOol0WGoo00<07gooOol0?7oo0011Ool00`0OOomoo`2MOol00`0OOomo
o`0lOol0045oo`0301moogoo09aoo`0301moogoo03eoo`00@Goo00<07gooOol0W7oo00<07gooOol0
?Goo0011Ool00`0OOomoo`2LOol00`0OOomoo`0mOol0049oo`0301moogoo09Yoo`0301moogoo03io
o`00@Woo00<07gooOol0VWoo00<07gooOol0?Woo0012Ool00`0OOomoo`2IOol00`0OOomoo`0oOol0
049oo`0301moogoo09Uoo`0301moogoo03moo`00@Woo00<07gooOol0VGoo00<07gooOol0?goo0012
Ool00`0OOomoo`2HOol00`0OOomoo`10Ool0049oo`0301moogoo09Qoo`0301moogoo041oo`00@goo
00<07gooOol0UWoo00<07gooOol0@Goo0013Ool00`0OOomoo`2FOol00`0OOomoo`11Ool004=oo`03
01moogoo09Eoo`0301moogoo049oo`00@goo00<07gooOol0UGoo00<07gooOol0@Woo0013Ool00`0O
Oomoo`2DOol00`0OOomoo`13Ool004=oo`0301moogoo09Aoo`0301moogoo04=oo`00@goo00<07goo
Ool0Tgoo00<07gooOol0A7oo0014Ool00`0OOomoo`2BOol00`0OOomoo`14Ool004Aoo`0301moogoo
095oo`0301moogoo04Eoo`00A7oo00<07gooOol0TGoo00<07gooOol0AGoo0014Ool00`0OOomoo`2@
Ool00`0OOomoo`16Ool004Eoo`0301moogoo08ioo`0301moogoo04Moo`00AGoo00<07gooOol0SGoo
00<07gooOol0B7oo0015Ool00`0OOomoo`2=Ool00`0OOomoo`18Ool004Eoo`0301moogoo08aoo`03
01moogoo04Uoo`00AWoo00<07gooOol0RWoo00<07gooOol0BWoo0016Ool00`0OOomoo`2:Ool00`0O
Oomoo`1:Ool004Ioo`0301moogoo08Uoo`0301moogoo04]oo`00Agoo00<07gooOol0Qgoo00<07goo
Ool0C7oo0017Ool00`0OOomoo`26Ool00`0OOomoo`1=Ool004Moo`0301moogoo08Ioo`0301moogoo
04eoo`00B7oo00<07gooOol0Q7oo00<07gooOol0CWoo0018Ool00`0OOomoo`23Ool00`0OOomoo`1?
Ool004Qoo`0301moogoo089oo`0301moogoo051oo`00BGoo00<07gooOol0P7oo00<07gooOol0DGoo
0019Ool00`0OOomoo`20Ool00`0OOomoo`1AOol004Yoo`0301moogoo07ioo`0301moogoo059oo`00
BWoo00<07gooOol0OGoo00<07gooOol0Dgoo001;Ool00`0OOomoo`1kOol00`0OOomoo`1DOol004ao
o`0301moogoo07Uoo`0301moogoo05Eoo`00CGoo00<07gooOol0Mgoo00<07gooOol0EWoo001=Ool0
0`0OOomoo`1fOol00`0OOomoo`1GOol004ioo`0301moogoo07Aoo`0301moogoo05Qoo`00Cgoo00<0
7gooOol0LWoo00<07gooOol0FGoo001@Ool00`0OOomoo`1`Ool00`0OOomoo`1JOol0055oo`0301mo
ogoo06ioo`0301moogoo05]oo`00DGoo00<07gooOol0KGoo00<07gooOol0G7oo001BOol00`0OOomo
o`1ZOol201mOOol005=oo`0301moogoo06Qoo`0301moogoo05moo`00E7oo00<07gooOol0IWoo00<0
7gooOol0H7oo001EOol00`0OOomoo`1SOol201mSOol005Ioo`0301moogoo065oo`0301moogoo06=o
o`00Egoo00<07gooOol0Ggoo00<07gooOol0I7oo001HOol00`0OOomoo`1LOol201mWOol005Uoo`03
01moogoo05Yoo`0301moogoo06Moo`00FWoo0P0OF7oo0P0OJWoo001LOol00`0OOomoo`1DOol00`0O
Oomoo`1ZOol005eoo`0301moogoo059oo`0301moogoo06]oo`00GWoo00<07gooOol0Cgoo0P0OKWoo
001OOol201m=Ool201m`Ool0065oo`0301moogoo04Qoo`807g9oo`00HWoo00<07gooOol0AGoo0P0O
M7oo001SOol201m2Ool301mfOol006Eoo`807cioo`807gUoo`00Igoo0P0O>Goo0`0ONgoo001YOol2
01ldOol301mnOol006]oo`807c1oo`807h5oo`00KGoo0`0O:goo0P0OPgoo001`Ool401lROol501n5
Ool007Aoo`D07aEoo`P07hYoo`00NGoo5@0OTWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.27466 .38242 m
.28734 .35981 L
s
.26348 .40582 m
.27466 .38242 L
s
.25388 .42987 m
.26348 .40582 L
s
.28734 .35981 m
.30146 .3381 L
s
.24591 .45444 m
.25388 .42987 L
s
.30146 .3381 m
.31694 .31744 L
s
.23961 .47939 m
.24591 .45444 L
s
.31694 .31744 m
.3337 .29794 L
s
.23504 .50458 m
.23961 .47939 L
s
.3337 .29794 m
.35164 .27971 L
s
.23224 .52986 m
.23504 .50458 L
s
.35164 .27971 m
.37068 .26287 L
s
.23123 .5551 m
.23224 .52986 L
s
.37068 .26287 m
.39072 .24754 L
s
.23203 .58013 m
.23123 .5551 L
s
.39072 .24754 m
.41163 .23381 L
s
.23467 .60482 m
.23203 .58013 L
s
.41163 .23381 m
.43332 .22179 L
s
.23916 .629 m
.23467 .60482 L
s
.43332 .22179 m
.45565 .21158 L
s
.24547 .65252 m
.23916 .629 L
s
.45565 .21158 m
.4785 .20325 L
s
.25362 .67523 m
.24547 .65252 L
s
.4785 .20325 m
.50174 .19688 L
s
.26356 .69696 m
.25362 .67523 L
s
.50174 .19688 m
.52522 .19256 L
s
.27528 .71757 m
.26356 .69696 L
s
.52522 .19256 m
.54879 .19035 L
s
.28872 .73689 m
.27528 .71757 L
s
.54879 .19035 m
.57231 .19028 L
s
.30382 .75477 m
.28872 .73689 L
s
.57231 .19028 m
.5956 .19242 L
s
.32051 .77107 m
.30382 .75477 L
s
.5956 .19242 m
.61851 .19678 L
s
.33871 .78563 m
.32051 .77107 L
s
.61851 .19678 m
.64087 .20337 L
s
.35832 .79833 m
.33871 .78563 L
s
.64087 .20337 m
.66251 .21219 L
s
.37922 .80902 m
.35832 .79833 L
s
.66251 .21219 m
.68326 .22323 L
s
.40129 .81759 m
.37922 .80902 L
s
.68326 .22323 m
.70294 .23645 L
s
.42437 .82394 m
.40129 .81759 L
s
.70294 .23645 m
.72139 .25178 L
s
.44832 .82797 m
.42437 .82394 L
s
.72139 .25178 m
.73843 .26916 L
s
.47296 .8296 m
.44832 .82797 L
s
.73843 .26916 m
.75391 .28848 L
s
.49811 .82877 m
.47296 .8296 L
s
.75391 .28848 m
.76767 .30963 L
s
.52358 .82545 m
.49811 .82877 L
s
.76767 .30963 m
.77956 .33247 L
s
.54915 .81962 m
.52358 .82545 L
s
.77956 .33247 m
.78947 .35684 L
s
.57461 .8113 m
.54915 .81962 L
s
.78947 .35684 m
.79727 .38256 L
s
.59976 .8005 m
.57461 .8113 L
s
.79727 .38256 m
.80287 .40943 L
s
.62436 .78729 m
.59976 .8005 L
s
.80287 .40943 m
.80618 .43724 L
s
.6482 .77175 m
.62436 .78729 L
s
.80618 .43724 m
.80714 .46575 L
s
.67105 .75399 m
.6482 .77175 L
s
.80714 .46575 m
.80573 .49472 L
s
.69272 .73416 m
.67105 .75399 L
s
.80573 .49472 m
.80194 .5239 L
s
.71298 .7124 m
.69272 .73416 L
s
.80194 .5239 m
.79577 .55304 L
s
.73166 .68891 m
.71298 .7124 L
s
.79577 .55304 m
.78727 .58186 L
s
.74858 .66388 m
.73166 .68891 L
s
.78727 .58186 m
.77651 .61011 L
s
.76357 .63753 m
.74858 .66388 L
s
.77651 .61011 m
.76357 .63753 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.25844 .40725 m
.26839 .38325 L
s
.25012 .43187 m
.25844 .40725 L
s
.24346 .45697 m
.25012 .43187 L
s
.26839 .38325 m
.27989 .35999 L
s
.23852 .48241 m
.24346 .45697 L
s
.27989 .35999 m
.29291 .33763 L
s
.23532 .50803 m
.23852 .48241 L
s
.29291 .33763 m
.30736 .31629 L
s
.23389 .53369 m
.23532 .50803 L
s
.30736 .31629 m
.32317 .29609 L
s
.23425 .55925 m
.23389 .53369 L
s
.32317 .29609 m
.34025 .27717 L
s
.23642 .58455 m
.23425 .55925 L
s
.34025 .27717 m
.35853 .25965 L
s
.24039 .60945 m
.23642 .58455 L
s
.35853 .25965 m
.37789 .24365 L
s
.24616 .63378 m
.24039 .60945 L
s
.37789 .24365 m
.39825 .22927 L
s
.25373 .6574 m
.24616 .63378 L
s
.39825 .22927 m
.41947 .21663 L
s
.26305 .68014 m
.25373 .6574 L
s
.41947 .21663 m
.44145 .20582 L
s
.27411 .70186 m
.26305 .68014 L
s
.44145 .20582 m
.46406 .19695 L
s
.28685 .7224 m
.27411 .70186 L
s
.46406 .19695 m
.48716 .1901 L
s
.30123 .74161 m
.28685 .7224 L
s
.48716 .1901 m
.51061 .18535 L
s
.31717 .75934 m
.30123 .74161 L
s
.51061 .18535 m
.53425 .18276 L
s
.3346 .77545 m
.31717 .75934 L
s
.53425 .18276 m
.55795 .18239 L
s
.35342 .78979 m
.3346 .77545 L
s
.55795 .18239 m
.58152 .18429 L
s
.37353 .80223 m
.35342 .78979 L
s
.58152 .18429 m
.60481 .18849 L
s
.39481 .81265 m
.37353 .80223 L
s
.60481 .18849 m
.62763 .19499 L
s
.41713 .82094 m
.39481 .81265 L
s
.62763 .19499 m
.64982 .2038 L
s
.44034 .82698 m
.41713 .82094 L
s
.64982 .2038 m
.6712 .21489 L
s
.46429 .8307 m
.44034 .82698 L
s
.6712 .21489 m
.69159 .22823 L
s
.48881 .83201 m
.46429 .8307 L
s
.69159 .22823 m
.71081 .24375 L
s
.51371 .83087 m
.48881 .83201 L
s
.71081 .24375 m
.72869 .26137 L
s
.53881 .82723 m
.51371 .83087 L
s
.72869 .26137 m
.74507 .281 L
s
.5639 .82109 m
.53881 .82723 L
s
.74507 .281 m
.75978 .3025 L
s
.58879 .81245 m
.5639 .82109 L
s
.75978 .3025 m
.77268 .32573 L
s
.61326 .80134 m
.58879 .81245 L
s
.77268 .32573 m
.78362 .35052 L
s
.63709 .78782 m
.61326 .80134 L
s
.78362 .35052 m
.79249 .37669 L
s
.66008 .77197 m
.63709 .78782 L
s
.79249 .37669 m
.79919 .40402 L
s
.68202 .7539 m
.66008 .77197 L
s
.79919 .40402 m
.80363 .4323 L
s
.70271 .73374 m
.68202 .7539 L
s
.80363 .4323 m
.80574 .46129 L
s
.72194 .71165 m
.70271 .73374 L
s
.80574 .46129 m
.8055 .49073 L
s
.73954 .68781 m
.72194 .71165 L
s
.8055 .49073 m
.80288 .52038 L
s
.75534 .66242 m
.73954 .68781 L
s
.80288 .52038 m
.79789 .54996 L
s
.7692 .6357 m
.75534 .66242 L
s
.79789 .54996 m
.79057 .57922 L
s
.78098 .60788 m
.7692 .6357 L
s
.79057 .57922 m
.78098 .60788 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.24761 .43461 m
.25459 .40957 L
s
.24233 .46008 m
.24761 .43461 L
s
.23877 .48583 m
.24233 .46008 L
s
.25459 .40957 m
.26323 .38509 L
s
.23696 .51172 m
.23877 .48583 L
s
.26323 .38509 m
.27349 .36134 L
s
.23691 .53759 m
.23696 .51172 L
s
.27349 .36134 m
.2853 .33843 L
s
.23864 .5633 m
.23691 .53759 L
s
.2853 .33843 m
.29862 .31651 L
s
.24214 .58869 m
.23864 .5633 L
s
.29862 .31651 m
.31337 .29573 L
s
.24741 .61363 m
.24214 .58869 L
s
.31337 .29573 m
.32949 .2762 L
s
.25443 .63794 m
.24741 .61363 L
s
.32949 .2762 m
.34688 .25806 L
s
.26317 .66149 m
.25443 .63794 L
s
.34688 .25806 m
.36545 .24143 L
s
.27361 .68411 m
.26317 .66149 L
s
.36545 .24143 m
.38512 .22644 L
s
.2857 .70567 m
.27361 .68411 L
s
.38512 .22644 m
.40576 .2132 L
s
.29938 .72601 m
.2857 .70567 L
s
.40576 .2132 m
.42727 .20182 L
s
.3146 .74498 m
.29938 .72601 L
s
.42727 .20182 m
.44951 .19241 L
s
.33127 .76244 m
.3146 .74498 L
s
.44951 .19241 m
.47236 .18505 L
s
.34932 .77825 m
.33127 .76244 L
s
.47236 .18505 m
.49567 .17983 L
s
.36865 .79228 m
.34932 .77825 L
s
.49567 .17983 m
.51929 .17683 L
s
.38914 .80439 m
.36865 .79228 L
s
.51929 .17683 m
.54307 .1761 L
s
.41069 .81448 m
.38914 .80439 L
s
.54307 .1761 m
.56683 .1777 L
s
.43314 .82243 m
.41069 .81448 L
s
.56683 .1777 m
.59041 .18165 L
s
.45637 .82814 m
.43314 .82243 L
s
.59041 .18165 m
.61363 .18798 L
s
.48021 .83153 m
.45637 .82814 L
s
.61363 .18798 m
.63631 .19668 L
s
.5045 .83252 m
.48021 .83153 L
s
.63631 .19668 m
.65827 .20772 L
s
.52905 .83108 m
.5045 .83252 L
s
.65827 .20772 m
.67932 .22108 L
s
.5537 .82715 m
.52905 .83108 L
s
.67932 .22108 m
.69929 .23668 L
s
.57823 .82073 m
.5537 .82715 L
s
.69929 .23668 m
.71798 .25443 L
s
.60246 .81182 m
.57823 .82073 L
s
.71798 .25443 m
.73523 .27424 L
s
.62618 .80046 m
.60246 .81182 L
s
.73523 .27424 m
.75088 .29597 L
s
.64918 .7867 m
.62618 .80046 L
s
.75088 .29597 m
.76476 .31947 L
s
.67127 .77062 m
.64918 .7867 L
s
.76476 .31947 m
.77674 .34455 L
s
.69224 .75232 m
.67127 .77062 L
s
.77674 .34455 m
.78668 .37104 L
s
.7119 .73194 m
.69224 .75232 L
s
.78668 .37104 m
.79448 .39871 L
s
.73006 .70962 m
.7119 .73194 L
s
.79448 .39871 m
.80005 .42733 L
s
.74656 .68555 m
.73006 .70962 L
s
.80005 .42733 m
.80333 .45666 L
s
.76122 .65991 m
.74656 .68555 L
s
.80333 .45666 m
.80426 .48645 L
s
.77391 .63293 m
.76122 .65991 L
s
.80426 .48645 m
.80282 .51642 L
s
.7845 .60484 m
.77391 .63293 L
s
.80282 .51642 m
.79903 .54633 L
s
.7929 .57589 m
.7845 .60484 L
s
.79903 .54633 m
.7929 .57589 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.24037 .48936 m
.24253 .46346 L
s
.23996 .51534 m
.24037 .48936 L
s
.24253 .46346 m
.24641 .43778 L
s
.24129 .54125 m
.23996 .51534 L
s
.24641 .43778 m
.252 .41247 L
s
.24437 .56694 m
.24129 .54125 L
s
.252 .41247 m
.25927 .38769 L
s
.24917 .59227 m
.24437 .56694 L
s
.25927 .38769 m
.26819 .36357 L
s
.25569 .61708 m
.24917 .59227 L
s
.26819 .36357 m
.27873 .34026 L
s
.26389 .64122 m
.25569 .61708 L
s
.27873 .34026 m
.29082 .31789 L
s
.27375 .66456 m
.26389 .64122 L
s
.29082 .31789 m
.30441 .29663 L
s
.28522 .68693 m
.27375 .66456 L
s
.30441 .29663 m
.31943 .27659 L
s
.29824 .7082 m
.28522 .68693 L
s
.31943 .27659 m
.33582 .25792 L
s
.31277 .72822 m
.29824 .7082 L
s
.33582 .25792 m
.35349 .24075 L
s
.32872 .74686 m
.31277 .72822 L
s
.35349 .24075 m
.37234 .22521 L
s
.34602 .76396 m
.32872 .74686 L
s
.37234 .22521 m
.39227 .21143 L
s
.36459 .77941 m
.34602 .76396 L
s
.39227 .21143 m
.41318 .19951 L
s
.3843 .79306 m
.36459 .77941 L
s
.41318 .19951 m
.43494 .18957 L
s
.40507 .80481 m
.3843 .79306 L
s
.43494 .18957 m
.45741 .18171 L
s
.42676 .81454 m
.40507 .80481 L
s
.45741 .18171 m
.48047 .17602 L
s
.44925 .82213 m
.42676 .81454 L
s
.48047 .17602 m
.50395 .17258 L
s
.47238 .82751 m
.44925 .82213 L
s
.50395 .17258 m
.52771 .17147 L
s
.49601 .83058 m
.47238 .82751 L
s
.52771 .17147 m
.55156 .17272 L
s
.51997 .83129 m
.49601 .83058 L
s
.55156 .17272 m
.57535 .17638 L
s
.5441 .82957 m
.51997 .83129 L
s
.57535 .17638 m
.59889 .18247 L
s
.5682 .8254 m
.5441 .82957 L
s
.59889 .18247 m
.62199 .19099 L
s
.5921 .81876 m
.5682 .8254 L
s
.62199 .19099 m
.64447 .20191 L
s
.6156 .80966 m
.5921 .81876 L
s
.64447 .20191 m
.66613 .2152 L
s
.63851 .79813 m
.6156 .80966 L
s
.66613 .2152 m
.6868 .23078 L
s
.66063 .78422 m
.63851 .79813 L
s
.6868 .23078 m
.70627 .24857 L
s
.68176 .768 m
.66063 .78422 L
s
.70627 .24857 m
.72438 .26846 L
s
.70172 .74958 m
.68176 .768 L
s
.72438 .26846 m
.74094 .2903 L
s
.72032 .72908 m
.70172 .74958 L
s
.74094 .2903 m
.7558 .31395 L
s
.73737 .70664 m
.72032 .72908 L
s
.7558 .31395 m
.7688 .33922 L
s
.75272 .68245 m
.73737 .70664 L
s
.7688 .33922 m
.77982 .36591 L
s
.76621 .65668 m
.75272 .68245 L
s
.77982 .36591 m
.78873 .39379 L
s
.77771 .62957 m
.76621 .65668 L
s
.78873 .39379 m
.79545 .42263 L
s
.7871 .60133 m
.77771 .62957 L
s
.79545 .42263 m
.79989 .45218 L
s
.79429 .57221 m
.7871 .60133 L
s
.79989 .45218 m
.80201 .48218 L
s
.7992 .54247 m
.79429 .57221 L
s
.80201 .48218 m
.80178 .51237 L
s
.80178 .51237 m
.7992 .54247 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.2444 .51859 m
.24342 .49268 L
s
.24708 .54438 m
.2444 .51859 L
s
.24342 .49268 m
.24415 .4668 L
s
.25147 .5699 m
.24708 .54438 L
s
.24415 .4668 m
.24661 .44108 L
s
.25753 .595 m
.25147 .5699 L
s
.24661 .44108 m
.25077 .41568 L
s
.26523 .61954 m
.25753 .595 L
s
.25077 .41568 m
.25662 .39075 L
s
.27455 .64338 m
.26523 .61954 L
s
.25662 .39075 m
.26415 .36643 L
s
.28544 .66638 m
.27455 .64338 L
s
.26415 .36643 m
.27331 .34286 L
s
.29785 .68839 m
.28544 .66638 L
s
.27331 .34286 m
.28408 .3202 L
s
.31171 .70927 m
.29785 .68839 L
s
.28408 .3202 m
.29641 .29859 L
s
.32697 .72889 m
.31171 .70927 L
s
.29641 .29859 m
.31024 .27818 L
s
.34356 .74712 m
.32697 .72889 L
s
.31024 .27818 m
.32551 .2591 L
s
.36137 .76381 m
.34356 .74712 L
s
.32551 .2591 m
.34213 .24149 L
s
.38033 .77884 m
.36137 .76381 L
s
.34213 .24149 m
.36004 .22549 L
s
.40032 .7921 m
.38033 .77884 L
s
.36004 .22549 m
.37913 .21123 L
s
.42125 .80347 m
.40032 .7921 L
s
.37913 .21123 m
.3993 .19884 L
s
.44298 .81283 m
.42125 .80347 L
s
.3993 .19884 m
.42043 .18842 L
s
.46538 .82009 m
.44298 .81283 L
s
.42043 .18842 m
.4424 .18009 L
s
.48832 .82516 m
.46538 .82009 L
s
.4424 .18009 m
.46507 .17396 L
s
.51164 .82795 m
.48832 .82516 L
s
.46507 .17396 m
.48829 .17009 L
s
.53518 .82842 m
.51164 .82795 L
s
.48829 .17009 m
.51191 .16858 L
s
.55879 .8265 m
.53518 .82842 L
s
.51191 .16858 m
.53575 .16947 L
s
.58227 .82216 m
.55879 .8265 L
s
.53575 .16947 m
.55964 .17281 L
s
.60546 .81539 m
.58227 .82216 L
s
.55964 .17281 m
.5834 .17863 L
s
.62816 .80619 m
.60546 .81539 L
s
.5834 .17863 m
.60684 .18691 L
s
.6502 .79458 m
.62816 .80619 L
s
.60684 .18691 m
.62976 .19764 L
s
.67137 .78062 m
.6502 .79458 L
s
.62976 .19764 m
.65198 .21079 L
s
.6915 .76438 m
.67137 .78062 L
s
.65198 .21079 m
.67329 .22628 L
s
.7104 .74595 m
.6915 .76438 L
s
.67329 .22628 m
.6935 .24402 L
s
.72789 .72545 m
.7104 .74595 L
s
.6935 .24402 m
.71242 .2639 L
s
.7438 .70302 m
.72789 .72545 L
s
.71242 .2639 m
.72988 .28577 L
s
.75797 .67882 m
.7438 .70302 L
s
.72988 .28577 m
.7457 .30947 L
s
.77026 .65306 m
.75797 .67882 L
s
.7457 .30947 m
.75973 .33481 L
s
.78054 .62593 m
.77026 .65306 L
s
.75973 .33481 m
.77182 .36159 L
s
.7887 .59767 m
.78054 .62593 L
s
.77182 .36159 m
.78185 .38957 L
s
.79465 .56851 m
.7887 .59767 L
s
.78185 .38957 m
.78972 .41852 L
s
.79831 .53871 m
.79465 .56851 L
s
.78972 .41852 m
.79534 .44818 L
s
.79966 .50855 m
.79831 .53871 L
s
.79534 .44818 m
.79867 .47828 L
s
.79867 .47828 m
.79966 .50855 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.25434 .5467 m
.25033 .52119 L
s
.25998 .57189 m
.25434 .5467 L
s
.26724 .59663 m
.25998 .57189 L
s
.25033 .52119 m
.24798 .49552 L
s
.27606 .62079 m
.26724 .59663 L
s
.24798 .49552 m
.24731 .46982 L
s
.28641 .64421 m
.27606 .62079 L
s
.24731 .46982 m
.24832 .44423 L
s
.29823 .66676 m
.28641 .64421 L
s
.24832 .44423 m
.25103 .41892 L
s
.31148 .68831 m
.29823 .66676 L
s
.25103 .41892 m
.25542 .39401 L
s
.32608 .70873 m
.31148 .68831 L
s
.25542 .39401 m
.2615 .36965 L
s
.34196 .72789 m
.32608 .70873 L
s
.2615 .36965 m
.26923 .346 L
s
.35905 .74565 m
.34196 .72789 L
s
.26923 .346 m
.2786 .32321 L
s
.37726 .7619 m
.35905 .74565 L
s
.2786 .32321 m
.28957 .30141 L
s
.3965 .77651 m
.37726 .7619 L
s
.28957 .30141 m
.30209 .28077 L
s
.41665 .78936 m
.3965 .77651 L
s
.30209 .28077 m
.31611 .26141 L
s
.43762 .80035 m
.41665 .78936 L
s
.31611 .26141 m
.33157 .24349 L
s
.45927 .80937 m
.43762 .80035 L
s
.33157 .24349 m
.3484 .22715 L
s
.48148 .81633 m
.45927 .80937 L
s
.3484 .22715 m
.3665 .21253 L
s
.50411 .82114 m
.48148 .81633 L
s
.3665 .21253 m
.38579 .19975 L
s
.52702 .82373 m
.50411 .82114 L
s
.38579 .19975 m
.40615 .18893 L
s
.55005 .82403 m
.52702 .82373 L
s
.40615 .18893 m
.42746 .18021 L
s
.57304 .82198 m
.55005 .82403 L
s
.42746 .18021 m
.44959 .17367 L
s
.59582 .81757 m
.57304 .82198 L
s
.44959 .17367 m
.47241 .16942 L
s
.61821 .81076 m
.59582 .81757 L
s
.47241 .16942 m
.49574 .16753 L
s
.64005 .80157 m
.61821 .81076 L
s
.49574 .16753 m
.51943 .16807 L
s
.66114 .79001 m
.64005 .80157 L
s
.51943 .16807 m
.5433 .17109 L
s
.68131 .77612 m
.66114 .79001 L
s
.5433 .17109 m
.56717 .1766 L
s
.70038 .75998 m
.68131 .77612 L
s
.56717 .1766 m
.59084 .18463 L
s
.71816 .74167 m
.70038 .75998 L
s
.59084 .18463 m
.61412 .19514 L
s
.7345 .7213 m
.71816 .74167 L
s
.61412 .19514 m
.6368 .2081 L
s
.74922 .699 m
.7345 .7213 L
s
.6368 .2081 m
.65868 .22343 L
s
.76217 .67495 m
.74922 .699 L
s
.65868 .22343 m
.67957 .24106 L
s
.77322 .64932 m
.76217 .67495 L
s
.67957 .24106 m
.69927 .26085 L
s
.78224 .62232 m
.77322 .64932 L
s
.69927 .26085 m
.71759 .28266 L
s
.78913 .59416 m
.78224 .62232 L
s
.71759 .28266 m
.73434 .30632 L
s
.79381 .5651 m
.78913 .59416 L
s
.73434 .30632 m
.74937 .33164 L
s
.79621 .53538 m
.79381 .5651 L
s
.74937 .33164 m
.76252 .35841 L
s
.7963 .50527 m
.79621 .53538 L
s
.76252 .35841 m
.77367 .38638 L
s
.79406 .47504 m
.7963 .50527 L
s
.77367 .38638 m
.78269 .41532 L
s
.78951 .44497 m
.79406 .47504 L
s
.78269 .41532 m
.78951 .44497 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.27002 .57269 m
.26318 .54796 L
s
.27838 .59694 m
.27002 .57269 L
s
.26318 .54796 m
.2579 .52289 L
s
.28823 .62058 m
.27838 .59694 L
s
.2579 .52289 m
.25422 .49761 L
s
.29951 .64348 m
.28823 .62058 L
s
.25422 .49761 m
.25216 .47226 L
s
.31216 .66551 m
.29951 .64348 L
s
.25216 .47226 m
.25175 .44698 L
s
.32613 .68653 m
.31216 .66551 L
s
.25175 .44698 m
.25299 .42192 L
s
.34134 .70642 m
.32613 .68653 L
s
.25299 .42192 m
.25591 .39722 L
s
.35772 .72507 m
.34134 .70642 L
s
.25591 .39722 m
.26048 .37302 L
s
.37519 .74235 m
.35772 .72507 L
s
.26048 .37302 m
.26673 .34947 L
s
.39366 .75813 m
.37519 .74235 L
s
.26673 .34947 m
.27461 .32671 L
s
.41304 .77231 m
.39366 .75813 L
s
.27461 .32671 m
.28413 .30491 L
s
.43323 .78478 m
.41304 .77231 L
s
.28413 .30491 m
.29524 .2842 L
s
.4541 .79543 m
.43323 .78478 L
s
.29524 .2842 m
.3079 .26473 L
s
.47555 .80415 m
.4541 .79543 L
s
.3079 .26473 m
.32206 .24666 L
s
.49745 .81087 m
.47555 .80415 L
s
.32206 .24666 m
.33766 .23012 L
s
.51966 .81549 m
.49745 .81087 L
s
.33766 .23012 m
.35462 .21526 L
s
.54205 .81795 m
.51966 .81549 L
s
.35462 .21526 m
.37287 .20222 L
s
.56445 .81817 m
.54205 .81795 L
s
.37287 .20222 m
.39229 .19112 L
s
.58673 .81611 m
.56445 .81817 L
s
.39229 .19112 m
.41278 .18208 L
s
.6087 .81173 m
.58673 .81611 L
s
.41278 .18208 m
.43421 .17523 L
s
.63022 .80501 m
.6087 .81173 L
s
.43421 .17523 m
.45645 .17065 L
s
.6511 .79595 m
.63022 .80501 L
s
.45645 .17065 m
.47934 .16844 L
s
.67117 .78456 m
.6511 .79595 L
s
.47934 .16844 m
.50272 .16866 L
s
.69026 .77089 m
.67117 .78456 L
s
.50272 .16866 m
.52641 .17138 L
s
.7082 .75498 m
.69026 .77089 L
s
.52641 .17138 m
.55024 .1766 L
s
.72481 .73693 m
.7082 .75498 L
s
.55024 .1766 m
.57401 .18436 L
s
.73994 .71684 m
.72481 .73693 L
s
.57401 .18436 m
.59751 .19462 L
s
.75341 .69483 m
.73994 .71684 L
s
.59751 .19462 m
.62055 .20736 L
s
.7651 .67107 m
.75341 .69483 L
s
.62055 .20736 m
.64291 .2225 L
s
.77486 .64572 m
.7651 .67107 L
s
.64291 .2225 m
.66439 .23995 L
s
.78258 .61899 m
.77486 .64572 L
s
.66439 .23995 m
.68479 .25958 L
s
.78817 .59109 m
.78258 .61899 L
s
.68479 .25958 m
.7039 .28126 L
s
.79154 .56226 m
.78817 .59109 L
s
.7039 .28126 m
.72154 .3048 L
s
.79264 .53275 m
.79154 .56226 L
s
.72154 .3048 m
.73754 .33001 L
s
.79145 .50284 m
.79264 .53275 L
s
.73754 .33001 m
.75173 .35666 L
s
.78795 .47278 m
.79145 .50284 L
s
.75173 .35666 m
.76397 .38453 L
s
.78217 .44285 m
.78795 .47278 L
s
.76397 .38453 m
.77415 .41335 L
s
.77415 .41335 m
.78217 .44285 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.29058 .59595 m
.28118 .57226 L
s
.30136 .61903 m
.29058 .59595 L
s
.28118 .57226 m
.27321 .54807 L
s
.31347 .64136 m
.30136 .61903 L
s
.27321 .54807 m
.26673 .52352 L
s
.32685 .66283 m
.31347 .64136 L
s
.26673 .52352 m
.26177 .49873 L
s
.34144 .6833 m
.32685 .66283 L
s
.26177 .49873 m
.25836 .47385 L
s
.35716 .70268 m
.34144 .6833 L
s
.25836 .47385 m
.25654 .449 L
s
.37393 .72083 m
.35716 .70268 L
s
.25654 .449 m
.25633 .42432 L
s
.39168 .73764 m
.37393 .72083 L
s
.25633 .42432 m
.25775 .39995 L
s
.41031 .753 m
.39168 .73764 L
s
.25775 .39995 m
.26082 .37604 L
s
.42973 .7668 m
.41031 .753 L
s
.26082 .37604 m
.26553 .35272 L
s
.44984 .77894 m
.42973 .7668 L
s
.26553 .35272 m
.27189 .33016 L
s
.47054 .78932 m
.44984 .77894 L
s
.27189 .33016 m
.27989 .30848 L
s
.49169 .79783 m
.47054 .78932 L
s
.27989 .30848 m
.28951 .28785 L
s
.51319 .8044 m
.49169 .79783 L
s
.28951 .28785 m
.30072 .26841 L
s
.5349 .80893 m
.51319 .8044 L
s
.30072 .26841 m
.31347 .25031 L
s
.55669 .81136 m
.5349 .80893 L
s
.31347 .25031 m
.32774 .23371 L
s
.5784 .81162 m
.55669 .81136 L
s
.32774 .23371 m
.34344 .21874 L
s
.5999 .80965 m
.5784 .81162 L
s
.34344 .21874 m
.36051 .20554 L
s
.62102 .80542 m
.5999 .80965 L
s
.36051 .20554 m
.37885 .19426 L
s
.6416 .79891 m
.62102 .80542 L
s
.37885 .19426 m
.39838 .18501 L
s
.66148 .79011 m
.6416 .79891 L
s
.39838 .18501 m
.41896 .17792 L
s
.6805 .77902 m
.66148 .79011 L
s
.41896 .17792 m
.44048 .1731 L
s
.69847 .76568 m
.6805 .77902 L
s
.44048 .1731 m
.46279 .17063 L
s
.71524 .75013 m
.69847 .76568 L
s
.46279 .17063 m
.48572 .17059 L
s
.73065 .73246 m
.71524 .75013 L
s
.48572 .17059 m
.50912 .17305 L
s
.74453 .71276 m
.73065 .73246 L
s
.50912 .17305 m
.53279 .17802 L
s
.75673 .69116 m
.74453 .71276 L
s
.53279 .17802 m
.55654 .18554 L
s
.76712 .66778 m
.75673 .69116 L
s
.55654 .18554 m
.58018 .19558 L
s
.77556 .64282 m
.76712 .66778 L
s
.58018 .19558 m
.60348 .20811 L
s
.78196 .61645 m
.77556 .64282 L
s
.60348 .20811 m
.62624 .22305 L
s
.78622 .5889 m
.78196 .61645 L
s
.62624 .22305 m
.64825 .24033 L
s
.78826 .56039 m
.78622 .5889 L
s
.64825 .24033 m
.66929 .2598 L
s
.78804 .53117 m
.78826 .56039 L
s
.66929 .2598 m
.68916 .28132 L
s
.78554 .50152 m
.78804 .53117 L
s
.68916 .28132 m
.70766 .30472 L
s
.78076 .47169 m
.78554 .50152 L
s
.70766 .30472 m
.7246 .32978 L
s
.77373 .44198 m
.78076 .47169 L
s
.7246 .32978 m
.73982 .35629 L
s
.7645 .41266 m
.77373 .44198 L
s
.73982 .35629 m
.75317 .38401 L
s
.75317 .38401 m
.7645 .41266 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.30408 .59345 m
.29375 .57039 L
s
.31569 .6159 m
.30408 .59345 L
s
.32852 .63762 m
.31569 .6159 L
s
.29375 .57039 m
.28476 .54683 L
s
.3425 .65849 m
.32852 .63762 L
s
.28476 .54683 m
.27715 .52291 L
s
.35758 .67841 m
.3425 .65849 L
s
.27715 .52291 m
.27098 .49873 L
s
.37367 .69725 m
.35758 .67841 L
s
.27098 .49873 m
.26628 .47443 L
s
.3907 .71491 m
.37367 .69725 L
s
.26628 .47443 m
.2631 .45014 L
s
.40859 .73128 m
.3907 .71491 L
s
.2631 .45014 m
.26146 .42599 L
s
.42724 .74626 m
.40859 .73128 L
s
.26146 .42599 m
.2614 .40211 L
s
.44658 .75973 m
.42724 .74626 L
s
.2614 .40211 m
.26294 .37865 L
s
.46649 .77161 m
.44658 .75973 L
s
.26294 .37865 m
.2661 .35573 L
s
.48687 .78178 m
.46649 .77161 L
s
.2661 .35573 m
.27089 .33352 L
s
.50762 .79017 m
.48687 .78178 L
s
.27089 .33352 m
.27731 .31214 L
s
.5286 .79668 m
.50762 .79017 L
s
.27731 .31214 m
.28535 .29175 L
s
.5497 .80122 m
.5286 .79668 L
s
.28535 .29175 m
.29501 .27251 L
s
.57078 .80374 m
.5497 .80122 L
s
.29501 .27251 m
.30625 .25455 L
s
.5917 .80415 m
.57078 .80374 L
s
.30625 .25455 m
.31904 .23803 L
s
.61233 .80241 m
.5917 .80415 L
s
.31904 .23803 m
.33334 .2231 L
s
.6325 .79847 m
.61233 .80241 L
s
.33334 .2231 m
.34908 .2099 L
s
.65207 .7923 m
.6325 .79847 L
s
.34908 .2099 m
.36618 .19857 L
s
.67087 .78389 m
.65207 .7923 L
s
.36618 .19857 m
.38457 .18923 L
s
.68875 .77324 m
.67087 .78389 L
s
.38457 .18923 m
.40413 .18203 L
s
.70554 .76038 m
.68875 .77324 L
s
.40413 .18203 m
.42475 .17706 L
s
.72108 .74534 m
.70554 .76038 L
s
.42475 .17706 m
.44629 .17443 L
s
.73522 .7282 m
.72108 .74534 L
s
.44629 .17443 m
.46859 .17421 L
s
.7478 .70904 m
.73522 .7282 L
s
.46859 .17421 m
.49151 .17647 L
s
.75867 .68797 m
.7478 .70904 L
s
.49151 .17647 m
.51485 .18125 L
s
.76772 .66513 m
.75867 .68797 L
s
.51485 .18125 m
.53842 .18857 L
s
.77481 .64068 m
.76772 .66513 L
s
.53842 .18857 m
.56203 .19841 L
s
.77984 .61481 m
.77481 .64068 L
s
.56203 .19841 m
.58546 .21075 L
s
.78273 .58772 m
.77984 .61481 L
s
.58546 .21075 m
.60849 .22551 L
s
.78341 .55964 m
.78273 .58772 L
s
.60849 .22551 m
.63091 .2426 L
s
.78185 .53083 m
.78341 .55964 L
s
.63091 .2426 m
.6525 .2619 L
s
.77803 .50154 m
.78185 .53083 L
s
.6525 .2619 m
.67304 .28325 L
s
.77196 .47204 m
.77803 .50154 L
s
.67304 .28325 m
.69232 .30646 L
s
.76368 .44263 m
.77196 .47204 L
s
.69232 .30646 m
.71016 .33134 L
s
.75325 .41357 m
.76368 .44263 L
s
.71016 .33134 m
.72636 .35766 L
s
.74077 .38515 m
.75325 .41357 L
s
.72636 .35766 m
.74077 .38515 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol008Aoo`H07iIoo`00N7oo300O1Woo1@0OTGoo001eOol3
01lGOol301n>Ool0079oo`<07aeoo`<07h]oo`00L7oo0P0O8goo100OQgoo001]Ool301lYOol301n4
Ool006]oo`807bmoo`@07h1oo`00JGoo0P0O=Goo0P0OOWoo001XOol00`0OOomoo`0gOol201mlOol0
06Ioo`807caoo`807gYoo`00IGoo00<07gooOol0?Woo0P0ON7oo001TOol00`0OOomoo`11Ool00`0O
Oomoo`1eOol006=oo`0301moogoo04=oo`807gEoo`00HGoo0P0OB7oo00<07gooOol0LWoo001POol0
0`0OOomoo`19Ool201mbOol005moo`0301moogoo04aoo`0301moogoo06moo`00GWoo00<07gooOol0
CWoo0P0OKgoo001MOol00`0OOomoo`1AOol00`0OOomoo`1/Ool005aoo`0301moogoo05=oo`0301mo
ogoo06]oo`00Fgoo00<07gooOol0EGoo0P0OJgoo001JOol00`0OOomoo`1HOol00`0OOomoo`1XOol0
05Uoo`0301moogoo05Yoo`0301moogoo06Moo`00FGoo00<07gooOol0Fgoo00<07gooOol0IWoo001H
Ool00`0OOomoo`1MOol00`0OOomoo`1UOol005Moo`0301moogoo05moo`0301moogoo06Aoo`00EWoo
00<07gooOol0HGoo00<07gooOol0Hgoo001FOol00`0OOomoo`1ROol00`0OOomoo`1ROol005Eoo`03
01moogoo06Aoo`0301moogoo065oo`00EGoo00<07gooOol0IGoo00<07gooOol0H7oo001DOol00`0O
Oomoo`1WOol00`0OOomoo`1OOol005=oo`0301moogoo06Uoo`0301moogoo05ioo`00Dgoo00<07goo
Ool0JWoo00<07gooOol0GGoo001BOol00`0OOomoo`1/Ool00`0OOomoo`1LOol0059oo`0301moogoo
06eoo`0301moogoo05]oo`00DGoo00<07gooOol0Kgoo00<07gooOol0FWoo001AOol00`0OOomoo`1_
Ool00`0OOomoo`1JOol0051oo`0301moogoo075oo`0301moogoo05Uoo`00D7oo00<07gooOol0LWoo
00<07gooOol0F7oo001@Ool00`0OOomoo`1cOol00`0OOomoo`1GOol004moo`0301moogoo07Eoo`03
01moogoo05Ioo`00Cgoo00<07gooOol0MGoo00<07gooOol0EWoo001?Ool00`0OOomoo`1fOol00`0O
Oomoo`1EOol004ioo`0301moogoo07Moo`0301moogoo05Eoo`00CWoo00<07gooOol0N7oo00<07goo
Ool0E7oo001>Ool00`0OOomoo`1iOol00`0OOomoo`1COol004eoo`0301moogoo07Yoo`0301moogoo
05=oo`00CGoo00<07gooOol0Ngoo00<07gooOol0DWoo001=Ool00`0OOomoo`1lOol00`0OOomoo`1A
Ool004eoo`0301moogoo07aoo`0301moogoo055oo`00CGoo00<07gooOol0OGoo00<07gooOol0D7oo
001<Ool00`0OOomoo`1oOol00`0OOomoo`1?Ool004aoo`0301moogoo081oo`0301moogoo04ioo`00
C7oo00<07gooOol0P7oo00<07gooOol0CWoo001<Ool00`0OOomoo`21Ool00`0OOomoo`1=Ool004ao
o`0301moogoo085oo`0301moogoo04eoo`00C7oo00<07gooOol0PWoo00<07gooOol0C7oo001;Ool0
0`0OOomoo`23Ool00`0OOomoo`1<Ool004]oo`0301moogoo08Aoo`0301moogoo04]oo`00Bgoo00<0
7gooOol0Q7oo00<07gooOol0Bgoo001;Ool00`0OOomoo`25Ool00`0OOomoo`1:Ool004]oo`0301mo
ogoo08Eoo`0301moogoo04Yoo`00Bgoo00<07gooOol0QWoo00<07gooOol0BGoo001;Ool00`0OOomo
o`26Ool00`0OOomoo`19Ool004]oo`0301moogoo08Moo`0301moogoo04Qoo`00Bgoo00<07gooOol0
Qgoo00<07gooOol0B7oo001;Ool00`0OOomoo`28Ool00`0OOomoo`17Ool004]oo`0301moogoo08Qo
o`0301moogoo04Moo`00Bgoo00<07gooOol0RGoo00<07gooOol0AWoo001;Ool00`0OOomoo`29Ool0
0`0OOomoo`16Ool004]oo`0301moogoo08Yoo`0301moogoo04Eoo`00Bgoo00<07gooOol0RWoo00<0
7gooOol0AGoo001;Ool00`0OOomoo`2;Ool00`0OOomoo`14Ool004]oo`0301moogoo08]oo`0301mo
ogoo04Aoo`00Bgoo00<07gooOol0Rgoo00<07gooOol0A7oo001;Ool00`0OOomoo`2<Ool00`0OOomo
o`13Ool004]oo`0301moogoo08aoo`0301moogoo04=oo`00Bgoo00<07gooOol0S7oo00<07gooOol0
@goo001;Ool00`0OOomoo`2=Ool00`0OOomoo`12Ool004]oo`0301moogoo08eoo`0301moogoo049o
o`00Bgoo00<07gooOol0SGoo00<07gooOol0@Woo001;Ool00`0OOomoo`2=Ool00`0OOomoo`12Ool0
04]oo`0301moogoo08ioo`0301moogoo045oo`00Bgoo00<07gooOol0SWoo00<07gooOol0@Goo001;
Ool00`0OOomoo`2>Ool00`0OOomoo`11Ool004aoo`0301moogoo08eoo`0301moogoo045oo`00C7oo
00<07gooOol0SWoo00<07gooOol0@7oo001<Ool00`0OOomoo`2>Ool00`0OOomoo`10Ool004aoo`03
01moogoo08ioo`0301moogoo041oo`00C7oo00<07gooOol0SWoo00<07gooOol0@7oo001<Ool00`0O
Oomoo`2?Ool00`0OOomoo`0oOol004aoo`0301moogoo08moo`0301moogoo03moo`00CGoo00<07goo
Ool0SWoo00<07gooOol0?goo001=Ool00`0OOomoo`2>Ool00`0OOomoo`0oOol004eoo`0301moogoo
08moo`0301moogoo03ioo`00CGoo00<07gooOol0Sgoo00<07gooOol0?Woo001=Ool00`0OOomoo`2?
Ool00`0OOomoo`0nOol004ioo`0301moogoo08ioo`0301moogoo03ioo`00CWoo00<07gooOol0SWoo
00<07gooOol0?Woo001>Ool00`0OOomoo`2>Ool00`0OOomoo`0nOol004ioo`0301moogoo08moo`03
01moogoo03eoo`00Cgoo00<07gooOol0SWoo00<07gooOol0?Goo001?Ool00`0OOomoo`2>Ool00`0O
Oomoo`0mOol004moo`0301moogoo08ioo`0301moogoo03eoo`00D7oo00<07gooOol0SGoo00<07goo
Ool0?Goo001@Ool00`0OOomoo`2=Ool00`0OOomoo`0mOol0051oo`0301moogoo08eoo`0301moogoo
03eoo`00DGoo00<07gooOol0S7oo00<07gooOol0?Goo001AOol00`0OOomoo`2<Ool00`0OOomoo`0m
Ool0055oo`0301moogoo08aoo`0301moogoo03eoo`00DWoo00<07gooOol0Rgoo00<07gooOol0?Goo
001BOol00`0OOomoo`2;Ool00`0OOomoo`0mOol005=oo`0301moogoo08Yoo`0301moogoo03eoo`00
Dgoo00<07gooOol0RWoo00<07gooOol0?Goo001DOol00`0OOomoo`29Ool00`0OOomoo`0mOol005Ao
o`0301moogoo08Uoo`0301moogoo03eoo`00E7oo00<07gooOol0RGoo00<07gooOol0?Goo001EOol0
0`0OOomoo`28Ool00`0OOomoo`0mOol005Eoo`0301moogoo08Qoo`0301moogoo03eoo`00EWoo00<0
7gooOol0Qgoo00<07gooOol0?Goo001FOol00`0OOomoo`27Ool00`0OOomoo`0mOol005Moo`0301mo
ogoo08Ioo`0301moogoo03eoo`00Egoo00<07gooOol0QWoo00<07gooOol0?Goo001GOol00`0OOomo
o`26Ool00`0OOomoo`0mOol005Qoo`0301moogoo08Aoo`0301moogoo03ioo`00F7oo00<07gooOol0
Q7oo00<07gooOol0?Woo001IOol00`0OOomoo`23Ool00`0OOomoo`0nOol005Uoo`0301moogoo08=o
o`0301moogoo03ioo`00FWoo00<07gooOol0PWoo00<07gooOol0?Woo001KOol00`0OOomoo`21Ool0
0`0OOomoo`0nOol005]oo`0301moogoo085oo`0301moogoo03ioo`00G7oo00<07gooOol0P7oo00<0
7gooOol0?Woo001MOol00`0OOomoo`1nOol00`0OOomoo`0oOol005eoo`0301moogoo07ioo`0301mo
ogoo03moo`00GWoo00<07gooOol0OGoo00<07gooOol0?goo001OOol00`0OOomoo`1lOol00`0OOomo
o`0oOol005moo`0301moogoo07aoo`0301moogoo03moo`00H7oo00<07gooOol0NWoo00<07gooOol0
@7oo001QOol00`0OOomoo`1iOol00`0OOomoo`10Ool0065oo`0301moogoo07Uoo`0301moogoo041o
o`00HWoo00<07gooOol0N7oo00<07gooOol0@7oo001SOol00`0OOomoo`1fOol00`0OOomoo`11Ool0
06=oo`0301moogoo07Ioo`0301moogoo045oo`00I7oo00<07gooOol0MGoo00<07gooOol0@Goo001U
Ool00`0OOomoo`1cOol00`0OOomoo`12Ool006Eoo`0301moogoo07=oo`0301moogoo049oo`00IWoo
00<07gooOol0LGoo00<07gooOol0@goo001WOol00`0OOomoo`1`Ool00`0OOomoo`13Ool006Qoo`03
01moogoo06ioo`0301moogoo04Aoo`00J7oo00<07gooOol0KWoo00<07gooOol0A7oo001YOol00`0O
Oomoo`1/Ool00`0OOomoo`15Ool006Yoo`0301moogoo06]oo`0301moogoo04Eoo`00Jgoo00<07goo
Ool0JGoo00<07gooOol0AWoo001/Ool00`0OOomoo`1XOol00`0OOomoo`16Ool006eoo`0301moogoo
06Ioo`0301moogoo04Moo`00KWoo00<07gooOol0IGoo00<07gooOol0Agoo001_Ool00`0OOomoo`1S
Ool00`0OOomoo`18Ool0071oo`0301moogoo069oo`0301moogoo04Qoo`00LGoo00<07gooOol0H7oo
00<07gooOol0BGoo001bOol201mPOol00`0OOomoo`19Ool007Aoo`0301moogoo05aoo`0301moogoo
04Yoo`00MGoo00<07gooOol0FWoo00<07gooOol0Bgoo001fOol00`0OOomoo`1HOol00`0OOomoo`1<
Ool007Moo`0301moogoo05Ioo`0301moogoo04eoo`00N7oo00<07gooOol0E7oo00<07gooOol0CWoo
001iOol00`0OOomoo`1BOol00`0OOomoo`1?Ool007Yoo`0301moogoo051oo`0301moogoo051oo`00
Ngoo0P0OCgoo00<07gooOol0DGoo001mOol00`0OOomoo`1<Ool00`0OOomoo`1AOol007ioo`807d]o
o`0301moogoo059oo`00P7oo00<07gooOol0Agoo00<07gooOol0Dgoo0021Ool201m5Ool201mFOol0
08=oo`807d5oo`807eQoo`00QGoo00<07gooOol0?Goo00<07gooOol0F7oo0026Ool201lkOol201mK
Ool008Qoo`807cMoo`807eeoo`00RWoo0`0O<goo00<07gooOol0GGoo002=Ool301l^Ool201mPOol0
091oo`<07bUoo`807f9oo`00Tgoo0`0O97oo0P0OI7oo002FOol401lMOol301mVOol009Yoo`H07a=o
o`@07fUoo`00X7oo4`0OKGoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.31862 .58953 m
.30747 .56713 L
s
.33094 .61133 m
.31862 .58953 L
s
.34437 .63244 m
.33094 .61133 L
s
.30747 .56713 m
.29754 .54424 L
s
.35884 .65273 m
.34437 .63244 L
s
.29754 .54424 m
.2889 .52099 L
s
.37428 .6721 m
.35884 .65273 L
s
.2889 .52099 m
.2816 .49749 L
s
.39063 .69045 m
.37428 .6721 L
s
.2816 .49749 m
.27567 .47386 L
s
.40779 .70767 m
.39063 .69045 L
s
.27567 .47386 m
.27118 .45022 L
s
.4257 .72366 m
.40779 .70767 L
s
.27118 .45022 m
.26816 .42669 L
s
.44427 .73832 m
.4257 .72366 L
s
.26816 .42669 m
.26665 .40341 L
s
.4634 .75154 m
.44427 .73832 L
s
.26665 .40341 m
.26668 .38051 L
s
.48301 .76324 m
.4634 .75154 L
s
.26668 .38051 m
.26829 .35812 L
s
.50297 .77331 m
.48301 .76324 L
s
.26829 .35812 m
.27148 .33638 L
s
.5232 .78168 m
.50297 .77331 L
s
.27148 .33638 m
.27628 .31544 L
s
.54357 .78824 m
.5232 .78168 L
s
.27628 .31544 m
.2827 .29544 L
s
.56397 .79291 m
.54357 .78824 L
s
.2827 .29544 m
.29073 .27653 L
s
.58426 .79563 m
.56397 .79291 L
s
.29073 .27653 m
.30037 .25886 L
s
.60431 .79633 m
.58426 .79563 L
s
.30037 .25886 m
.31159 .24257 L
s
.62398 .79493 m
.60431 .79633 L
s
.31159 .24257 m
.32436 .22782 L
s
.64314 .79141 m
.62398 .79493 L
s
.32436 .22782 m
.33864 .21475 L
s
.66162 .78572 m
.64314 .79141 L
s
.33864 .21475 m
.35436 .2035 L
s
.67929 .77784 m
.66162 .78572 L
s
.35436 .2035 m
.37145 .19421 L
s
.69597 .76776 m
.67929 .77784 L
s
.37145 .19421 m
.38983 .18701 L
s
.71152 .75551 m
.69597 .76776 L
s
.38983 .18701 m
.40937 .18202 L
s
.72578 .74111 m
.71152 .75551 L
s
.40937 .18202 m
.42997 .17932 L
s
.7386 .72462 m
.72578 .74111 L
s
.42997 .17932 m
.45148 .17903 L
s
.74984 .70611 m
.7386 .72462 L
s
.45148 .17903 m
.47374 .18119 L
s
.75935 .68569 m
.74984 .70611 L
s
.47374 .18119 m
.49658 .18585 L
s
.76701 .6635 m
.75935 .68569 L
s
.49658 .18585 m
.51982 .19304 L
s
.77271 .63967 m
.76701 .6635 L
s
.51982 .19304 m
.54324 .20276 L
s
.77634 .61439 m
.77271 .63967 L
s
.54324 .20276 m
.56666 .21496 L
s
.77784 .58785 m
.77634 .61439 L
s
.56666 .21496 m
.58983 .22958 L
s
.77714 .5603 m
.77784 .58785 L
s
.58983 .22958 m
.61254 .24652 L
s
.77421 .53195 m
.77714 .5603 L
s
.61254 .24652 m
.63457 .26567 L
s
.76905 .50309 m
.77421 .53195 L
s
.63457 .26567 m
.65569 .28686 L
s
.76168 .47398 m
.76905 .50309 L
s
.65569 .28686 m
.67569 .30991 L
s
.75215 .4449 m
.76168 .47398 L
s
.67569 .30991 m
.69435 .33461 L
s
.74054 .41614 m
.75215 .4449 L
s
.69435 .33461 m
.7115 .36072 L
s
.72694 .38798 m
.74054 .41614 L
s
.7115 .36072 m
.72694 .38798 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001iOol;01nLOol007=oo`H0
7`]oo`L07iEoo`00KWoo1@0O67oo1@0OT7oo001/Ool201lROol401n<Ool006Yoo`807bQoo`807hYo
o`00J7oo0P0O;7oo0P0OR7oo001VOol201l`Ool201n6Ool006Eoo`0301moogoo039oo`<07h=oo`00
I7oo00<07gooOol0=Woo0P0OPGoo001ROol201lkOol201moOol0065oo`0301moogoo03eoo`807geo
o`00H7oo00<07gooOol0@7oo0P0ONgoo001OOol00`0OOomoo`13Ool201miOol005ioo`0301moogoo
04Ioo`807gMoo`00GGoo00<07gooOol0BGoo00<07gooOol0M7oo001LOol00`0OOomoo`1;Ool00`0O
Oomoo`1cOol005]oo`0301moogoo04eoo`0301moogoo079oo`00FWoo00<07gooOol0Cgoo0P0OLWoo
001IOol00`0OOomoo`1BOol00`0OOomoo`1_Ool005Qoo`0301moogoo05Aoo`0301moogoo06ioo`00
F7oo00<07gooOol0EGoo00<07gooOol0KGoo001GOol00`0OOomoo`1GOol00`0OOomoo`1/Ool005Mo
o`0301moogoo05Qoo`807faoo`00EWoo00<07gooOol0Fgoo00<07gooOol0JGoo001EOol00`0OOomo
o`1MOol00`0OOomoo`1XOol005Eoo`0301moogoo05ioo`0301moogoo06Moo`00E7oo00<07gooOol0
H7oo00<07gooOol0IWoo001DOol00`0OOomoo`1QOol00`0OOomoo`1UOol005=oo`0301moogoo06=o
o`0301moogoo06Aoo`00Dgoo00<07gooOol0I7oo00<07gooOol0Hgoo001BOol00`0OOomoo`1VOol0
0`0OOomoo`1ROol0059oo`0301moogoo06Moo`0301moogoo065oo`00DGoo00<07gooOol0JGoo00<0
7gooOol0H7oo001AOol00`0OOomoo`1ZOol00`0OOomoo`1OOol0055oo`0301moogoo06Yoo`0301mo
ogoo05moo`00D7oo00<07gooOol0K7oo00<07gooOol0GWoo001@Ool00`0OOomoo`1]Ool00`0OOomo
o`1MOol0051oo`0301moogoo06ioo`0301moogoo05aoo`00Cgoo00<07gooOol0L7oo00<07gooOol0
Fgoo001?Ool00`0OOomoo`1`Ool00`0OOomoo`1KOol004moo`0301moogoo075oo`0301moogoo05Yo
o`00CWoo00<07gooOol0Lgoo00<07gooOol0FGoo001>Ool00`0OOomoo`1dOol00`0OOomoo`1HOol0
04ioo`0301moogoo07Aoo`0301moogoo05Qoo`00CGoo00<07gooOol0MWoo00<07gooOol0Egoo001=
Ool00`0OOomoo`1gOol00`0OOomoo`1FOol004eoo`0301moogoo07Qoo`0301moogoo05Eoo`00CGoo
00<07gooOol0N7oo00<07gooOol0EGoo001=Ool00`0OOomoo`1iOol00`0OOomoo`1DOol004eoo`03
01moogoo07Yoo`0301moogoo05=oo`00CGoo00<07gooOol0Ngoo00<07gooOol0DWoo001=Ool00`0O
Oomoo`1kOol00`0OOomoo`1BOol004eoo`0301moogoo07aoo`0301moogoo055oo`00CGoo00<07goo
Ool0O7oo00<07gooOol0DGoo001=Ool00`0OOomoo`1mOol00`0OOomoo`1@Ool004aoo`0301moogoo
07ioo`0301moogoo051oo`00C7oo00<07gooOol0Ogoo00<07gooOol0Cgoo001<Ool00`0OOomoo`1o
Ool00`0OOomoo`1?Ool004aoo`0301moogoo081oo`0301moogoo04ioo`00C7oo00<07gooOol0P7oo
00<07gooOol0CWoo001<Ool00`0OOomoo`21Ool00`0OOomoo`1=Ool004aoo`0301moogoo085oo`03
01moogoo04eoo`00C7oo00<07gooOol0PWoo00<07gooOol0C7oo001<Ool00`0OOomoo`22Ool00`0O
Oomoo`1<Ool004aoo`0301moogoo08=oo`0301moogoo04]oo`00C7oo00<07gooOol0Pgoo00<07goo
Ool0Bgoo001<Ool00`0OOomoo`24Ool00`0OOomoo`1:Ool004aoo`0301moogoo08Aoo`0301moogoo
04Yoo`00C7oo00<07gooOol0QGoo00<07gooOol0BGoo001<Ool00`0OOomoo`25Ool00`0OOomoo`19
Ool004aoo`0301moogoo08Ioo`0301moogoo04Qoo`00C7oo00<07gooOol0QWoo00<07gooOol0B7oo
001<Ool00`0OOomoo`26Ool00`0OOomoo`18Ool004aoo`0301moogoo08Moo`0301moogoo04Moo`00
C7oo00<07gooOol0Qgoo00<07gooOol0Agoo001=Ool00`0OOomoo`27Ool00`0OOomoo`16Ool004eo
o`0301moogoo08Moo`0301moogoo04Ioo`00CGoo00<07gooOol0Qgoo00<07gooOol0AWoo001=Ool0
0`0OOomoo`28Ool00`0OOomoo`15Ool004eoo`0301moogoo08Qoo`0301moogoo04Eoo`00CWoo00<0
7gooOol0Qgoo00<07gooOol0AGoo001>Ool00`0OOomoo`28Ool00`0OOomoo`14Ool004ioo`0301mo
ogoo08Qoo`0301moogoo04Aoo`00Cgoo00<07gooOol0Qgoo00<07gooOol0A7oo001?Ool00`0OOomo
o`28Ool00`0OOomoo`13Ool004moo`0301moogoo08Qoo`0301moogoo04=oo`00Cgoo00<07gooOol0
R7oo00<07gooOol0@goo001?Ool00`0OOomoo`28Ool00`0OOomoo`13Ool0051oo`0301moogoo08Qo
o`0301moogoo049oo`00D7oo00<07gooOol0R7oo00<07gooOol0@Woo001@Ool00`0OOomoo`28Ool0
0`0OOomoo`12Ool0051oo`0301moogoo08Qoo`0301moogoo049oo`00D7oo00<07gooOol0RGoo00<0
7gooOol0@Goo001AOol00`0OOomoo`28Ool00`0OOomoo`11Ool0055oo`0301moogoo08Qoo`0301mo
ogoo045oo`00DGoo00<07gooOol0R7oo00<07gooOol0@Goo001AOol00`0OOomoo`29Ool00`0OOomo
o`10Ool0059oo`0301moogoo08Qoo`0301moogoo041oo`00DWoo00<07gooOol0R7oo00<07gooOol0
@7oo001BOol00`0OOomoo`28Ool00`0OOomoo`10Ool005=oo`0301moogoo08Qoo`0301moogoo03mo
o`00Dgoo00<07gooOol0R7oo00<07gooOol0?goo001DOol00`0OOomoo`27Ool00`0OOomoo`0oOol0
05Aoo`0301moogoo08Moo`0301moogoo03moo`00EGoo00<07gooOol0QWoo00<07gooOol0?goo001E
Ool00`0OOomoo`26Ool00`0OOomoo`0oOol005Eoo`0301moogoo08Moo`0301moogoo03ioo`00EWoo
00<07gooOol0QWoo00<07gooOol0?Woo001FOol00`0OOomoo`26Ool00`0OOomoo`0nOol005Moo`03
01moogoo08Eoo`0301moogoo03ioo`00Egoo00<07gooOol0QGoo00<07gooOol0?Woo001HOol00`0O
Oomoo`24Ool00`0OOomoo`0nOol005Qoo`0301moogoo08Aoo`0301moogoo03ioo`00FGoo00<07goo
Ool0Pgoo00<07gooOol0?Woo001IOol00`0OOomoo`23Ool00`0OOomoo`0nOol005Yoo`0301moogoo
089oo`0301moogoo03ioo`00FWoo00<07gooOol0PWoo00<07gooOol0?Woo001KOol00`0OOomoo`21
Ool00`0OOomoo`0nOol005]oo`0301moogoo085oo`0301moogoo03ioo`00Fgoo00<07gooOol0PGoo
00<07gooOol0?Woo001LOol00`0OOomoo`20Ool00`0OOomoo`0nOol005aoo`0301moogoo07moo`03
01moogoo03moo`00GGoo00<07gooOol0OWoo00<07gooOol0?goo001MOol00`0OOomoo`1nOol00`0O
Oomoo`0oOol005ioo`0301moogoo07eoo`0301moogoo03moo`00Ggoo00<07gooOol0O7oo00<07goo
Ool0?goo001OOol00`0OOomoo`1lOol00`0OOomoo`0oOol0061oo`0301moogoo07]oo`0301moogoo
03moo`00HGoo00<07gooOol0NWoo00<07gooOol0?goo001QOol00`0OOomoo`1iOol00`0OOomoo`10
Ool0069oo`0301moogoo07Qoo`0301moogoo041oo`00Hgoo00<07gooOol0Mgoo00<07gooOol0@7oo
001SOol00`0OOomoo`1gOol00`0OOomoo`10Ool006Aoo`0301moogoo07Ioo`0301moogoo041oo`00
IGoo00<07gooOol0MGoo00<07gooOol0@7oo001UOol00`0OOomoo`1eOol00`0OOomoo`10Ool006Io
o`0301moogoo07=oo`0301moogoo045oo`00Igoo00<07gooOol0LWoo00<07gooOol0@Goo001XOol0
0`0OOomoo`1aOol00`0OOomoo`11Ool006Uoo`0301moogoo071oo`0301moogoo045oo`00JWoo00<0
7gooOol0KWoo00<07gooOol0@Woo001[Ool00`0OOomoo`1]Ool00`0OOomoo`12Ool006aoo`0301mo
ogoo06]oo`0301moogoo04=oo`00KGoo00<07gooOol0JWoo00<07gooOol0@goo001]Ool00`0OOomo
o`1YOol00`0OOomoo`14Ool006ioo`0301moogoo06Qoo`0301moogoo04Aoo`00Kgoo00<07gooOol0
Igoo00<07gooOol0A7oo001`Ool00`0OOomoo`1UOol00`0OOomoo`15Ool0075oo`0301moogoo06Ao
o`0301moogoo04Eoo`00LWoo00<07gooOol0Hgoo00<07gooOol0AGoo001cOol00`0OOomoo`1QOol0
0`0OOomoo`16Ool007Aoo`0301moogoo061oo`0301moogoo04Ioo`00MGoo00<07gooOol0GWoo00<0
7gooOol0Agoo001fOol00`0OOomoo`1LOol00`0OOomoo`18Ool007Moo`807eaoo`0301moogoo04Qo
o`00NGoo00<07gooOol0F7oo00<07gooOol0BGoo001jOol00`0OOomoo`1FOol00`0OOomoo`1:Ool0
07]oo`0301moogoo05Aoo`0301moogoo04]oo`00O7oo0P0OE7oo00<07gooOol0Bgoo001nOol00`0O
Oomoo`1@Ool00`0OOomoo`1<Ool007moo`0301moogoo04moo`0301moogoo04aoo`00P7oo00<07goo
Ool0CGoo00<07gooOol0CGoo0021Ool201m<Ool00`0OOomoo`1>Ool008=oo`0301moogoo04Qoo`03
01moogoo04moo`00Q7oo00<07gooOol0AWoo00<07gooOol0D7oo0025Ool201m5Ool00`0OOomoo`1A
Ool008Moo`0301moogoo045oo`0301moogoo059oo`00R7oo0P0O?goo0P0OEGoo002:Ool201llOol0
0`0OOomoo`1EOol008aoo`<07cQoo`0301moogoo05Ioo`00Sgoo0P0O=7oo0P0OFGoo002AOol201l`
Ool201mKOol009=oo`807baoo`807eeoo`00UGoo0`0O9goo0P0OGgoo002HOol301lQOol301mQOol0
09]oo`@07a]oo`807fAoo`00Wgoo1@0O4Woo100OIWoo002TOolB01mZOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.34713 .60534 m
.33422 .58418 L
s
.36103 .62583 m
.34713 .60534 L
s
.33422 .58418 m
.32237 .56246 L
s
.37585 .64556 m
.36103 .62583 L
s
.32237 .56246 m
.31163 .54028 L
s
.39153 .66442 m
.37585 .64556 L
s
.31163 .54028 m
.30206 .51775 L
s
.40799 .68232 m
.39153 .66442 L
s
.30206 .51775 m
.29372 .49497 L
s
.42516 .69915 m
.40799 .68232 L
s
.29372 .49497 m
.28667 .47207 L
s
.44296 .71482 m
.42516 .69915 L
s
.28667 .47207 m
.28094 .44916 L
s
.4613 .72924 m
.44296 .71482 L
s
.28094 .44916 m
.2766 .42634 L
s
.48011 .7423 m
.4613 .72924 L
s
.2766 .42634 m
.27368 .40376 L
s
.49928 .75391 m
.48011 .7423 L
s
.27368 .40376 m
.27223 .38152 L
s
.51871 .76399 m
.49928 .75391 L
s
.27223 .38152 m
.27229 .35977 L
s
.53831 .77244 m
.51871 .76399 L
s
.27229 .35977 m
.27389 .33864 L
s
.55796 .77917 m
.53831 .77244 L
s
.27389 .33864 m
.27705 .31826 L
s
.57755 .7841 m
.55796 .77917 L
s
.27705 .31826 m
.2818 .29878 L
s
.59696 .78715 m
.57755 .7841 L
s
.2818 .29878 m
.28815 .28034 L
s
.61605 .78826 m
.59696 .78715 L
s
.28815 .28034 m
.2961 .26308 L
s
.63469 .78736 m
.61605 .78826 L
s
.2961 .26308 m
.30565 .24717 L
s
.65275 .78439 m
.63469 .78736 L
s
.30565 .24717 m
.31678 .23273 L
s
.67008 .77932 m
.65275 .78439 L
s
.31678 .23273 m
.32946 .21993 L
s
.68654 .7721 m
.67008 .77932 L
s
.32946 .21993 m
.34364 .2089 L
s
.70197 .76274 m
.68654 .7721 L
s
.34364 .2089 m
.35928 .19979 L
s
.71622 .75123 m
.70197 .76274 L
s
.35928 .19979 m
.37629 .19272 L
s
.72915 .7376 m
.71622 .75123 L
s
.37629 .19272 m
.39459 .18781 L
s
.74061 .72189 m
.72915 .7376 L
s
.39459 .18781 m
.41406 .18517 L
s
.75046 .70417 m
.74061 .72189 L
s
.41406 .18517 m
.43458 .1849 L
s
.75857 .68452 m
.75046 .70417 L
s
.43458 .1849 m
.45599 .18706 L
s
.76481 .66307 m
.75857 .68452 L
s
.45599 .18706 m
.47815 .1917 L
s
.76908 .63997 m
.76481 .66307 L
s
.47815 .1917 m
.50086 .19885 L
s
.77129 .61537 m
.76908 .63997 L
s
.50086 .19885 m
.52393 .20851 L
s
.77137 .58947 m
.77129 .61537 L
s
.52393 .20851 m
.54716 .22064 L
s
.76927 .5625 m
.77137 .58947 L
s
.54716 .22064 m
.57032 .23518 L
s
.76497 .53469 m
.76927 .5625 L
s
.57032 .23518 m
.59319 .25204 L
s
.75847 .5063 m
.76497 .53469 L
s
.59319 .25204 m
.61553 .27108 L
s
.74981 .4776 m
.75847 .5063 L
s
.61553 .27108 m
.63712 .29215 L
s
.73905 .44889 m
.74981 .4776 L
s
.63712 .29215 m
.65773 .31507 L
s
.72627 .42044 m
.73905 .44889 L
s
.65773 .31507 m
.67715 .3396 L
s
.7116 .39256 m
.72627 .42044 L
s
.67715 .3396 m
.69517 .36552 L
s
.69517 .36552 m
.7116 .39256 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
L7oo500OW7oo001]Ool301lDOol401nHOol006]oo`807a]oo`<07iEoo`00JGoo0P0O87oo0`0OTWoo
001VOol301lUOol301n?Ool006Aoo`807b]oo`@07h]oo`00HWoo0P0O<Goo0P0ORGoo001QOol00`0O
Oomoo`0cOol201n7Ool0061oo`0301moogoo03Ioo`807hEoo`00Ggoo00<07gooOol0>Goo0P0OPgoo
001NOol00`0OOomoo`0lOol00`0OOomoo`20Ool005eoo`0301moogoo03ioo`807h1oo`00Fgoo0P0O
@goo00<07gooOol0OGoo001JOol00`0OOomoo`14Ool201mmOol005Uoo`0301moogoo04Moo`0301mo
ogoo07Yoo`00F7oo00<07gooOol0BGoo0P0ONWoo001HOol00`0OOomoo`1;Ool00`0OOomoo`1gOol0
05Moo`0301moogoo04eoo`0301moogoo07Ioo`00EWoo00<07gooOol0Cgoo0P0OMWoo001FOol00`0O
Oomoo`1AOol00`0OOomoo`1cOol005Eoo`0301moogoo05=oo`0301moogoo079oo`00EGoo00<07goo
Ool0E7oo00<07gooOol0LGoo001DOol00`0OOomoo`1FOol201maOol005Aoo`0301moogoo05Qoo`03
01moogoo06ioo`00Dgoo00<07gooOol0FWoo00<07gooOol0KGoo001COol00`0OOomoo`1KOol00`0O
Oomoo`1/Ool0059oo`0301moogoo05eoo`0301moogoo06]oo`00DWoo00<07gooOol0GWoo00<07goo
Ool0JWoo001BOol00`0OOomoo`1OOol00`0OOomoo`1YOol0055oo`0301moogoo065oo`0301moogoo
06Qoo`00DGoo00<07gooOol0HWoo00<07gooOol0Igoo001@Ool00`0OOomoo`1TOol00`0OOomoo`1V
Ool0051oo`0301moogoo06Eoo`0301moogoo06Eoo`00D7oo00<07gooOol0IWoo00<07gooOol0I7oo
001@Ool00`0OOomoo`1VOol00`0OOomoo`1TOol004moo`0301moogoo06Qoo`0301moogoo06=oo`00
Cgoo00<07gooOol0JGoo00<07gooOol0HWoo001?Ool00`0OOomoo`1ZOol00`0OOomoo`1QOol004mo
o`0301moogoo06]oo`0301moogoo061oo`00Cgoo00<07gooOol0K7oo00<07gooOol0Ggoo001?Ool0
0`0OOomoo`1]Ool00`0OOomoo`1NOol004ioo`0301moogoo06ioo`0301moogoo05ioo`00CWoo00<0
7gooOol0Kgoo00<07gooOol0GGoo001>Ool00`0OOomoo`1`Ool00`0OOomoo`1LOol004ioo`0301mo
ogoo075oo`0301moogoo05]oo`00CWoo00<07gooOol0LWoo00<07gooOol0FWoo001>Ool00`0OOomo
o`1bOol00`0OOomoo`1JOol004ioo`0301moogoo07=oo`0301moogoo05Uoo`00CWoo00<07gooOol0
M7oo00<07gooOol0F7oo001>Ool00`0OOomoo`1eOol00`0OOomoo`1GOol004ioo`0301moogoo07Eo
o`0301moogoo05Moo`00CWoo00<07gooOol0MWoo00<07gooOol0EWoo001>Ool00`0OOomoo`1gOol0
0`0OOomoo`1EOol004ioo`0301moogoo07Moo`0301moogoo05Eoo`00CWoo00<07gooOol0N7oo00<0
7gooOol0E7oo001>Ool00`0OOomoo`1hOol00`0OOomoo`1DOol004ioo`0301moogoo07Uoo`0301mo
ogoo05=oo`00CWoo00<07gooOol0NWoo00<07gooOol0DWoo001>Ool00`0OOomoo`1jOol00`0OOomo
o`1BOol004ioo`0301moogoo07]oo`0301moogoo055oo`00CWoo00<07gooOol0Ngoo00<07gooOol0
DGoo001>Ool00`0OOomoo`1lOol00`0OOomoo`1@Ool004ioo`0301moogoo07aoo`0301moogoo051o
o`00CWoo00<07gooOol0OGoo00<07gooOol0Cgoo001>Ool00`0OOomoo`1mOol00`0OOomoo`1?Ool0
04ioo`0301moogoo07ioo`0301moogoo04ioo`00Cgoo00<07gooOol0OGoo00<07gooOol0CWoo001?
Ool00`0OOomoo`1nOol00`0OOomoo`1=Ool004moo`0301moogoo07ioo`0301moogoo04eoo`00Cgoo
00<07gooOol0Ogoo00<07gooOol0C7oo001?Ool00`0OOomoo`1oOol00`0OOomoo`1<Ool004moo`03
01moogoo081oo`0301moogoo04]oo`00Cgoo00<07gooOol0P7oo00<07gooOol0Bgoo001@Ool00`0O
Oomoo`20Ool00`0OOomoo`1:Ool0051oo`0301moogoo081oo`0301moogoo04Yoo`00D7oo00<07goo
Ool0PGoo00<07gooOol0BGoo001@Ool00`0OOomoo`21Ool00`0OOomoo`19Ool0055oo`0301moogoo
085oo`0301moogoo04Qoo`00DGoo00<07gooOol0PGoo00<07gooOol0B7oo001AOol00`0OOomoo`21
Ool00`0OOomoo`18Ool0055oo`0301moogoo089oo`0301moogoo04Moo`00DWoo00<07gooOol0PGoo
00<07gooOol0Agoo001BOol00`0OOomoo`21Ool00`0OOomoo`17Ool0059oo`0301moogoo089oo`03
01moogoo04Ioo`00Dgoo00<07gooOol0PGoo00<07gooOol0AWoo001COol00`0OOomoo`21Ool00`0O
Oomoo`16Ool005=oo`0301moogoo085oo`0301moogoo04Ioo`00Dgoo00<07gooOol0PWoo00<07goo
Ool0AGoo001DOol00`0OOomoo`21Ool00`0OOomoo`15Ool005Aoo`0301moogoo085oo`0301moogoo
04Eoo`00E7oo00<07gooOol0PGoo00<07gooOol0AGoo001EOol00`0OOomoo`21Ool00`0OOomoo`14
Ool005Eoo`0301moogoo085oo`0301moogoo04Aoo`00EGoo00<07gooOol0PGoo00<07gooOol0A7oo
001FOol00`0OOomoo`20Ool00`0OOomoo`14Ool005Ioo`0301moogoo085oo`0301moogoo04=oo`00
EWoo00<07gooOol0PGoo00<07gooOol0@goo001GOol00`0OOomoo`20Ool00`0OOomoo`13Ool005Mo
o`0301moogoo081oo`0301moogoo04=oo`00F7oo00<07gooOol0P7oo00<07gooOol0@Woo001HOol0
0`0OOomoo`20Ool00`0OOomoo`12Ool005Uoo`0301moogoo07moo`0301moogoo049oo`00FGoo00<0
7gooOol0Ogoo00<07gooOol0@Woo001IOol00`0OOomoo`1oOol00`0OOomoo`12Ool005Yoo`0301mo
ogoo07ioo`0301moogoo049oo`00FWoo00<07gooOol0Ogoo00<07gooOol0@Goo001KOol00`0OOomo
o`1nOol00`0OOomoo`11Ool005]oo`0301moogoo07ioo`0301moogoo045oo`00G7oo00<07gooOol0
OGoo00<07gooOol0@Goo001LOol00`0OOomoo`1mOol00`0OOomoo`11Ool005eoo`0301moogoo07ao
o`0301moogoo045oo`00GGoo00<07gooOol0O7oo00<07gooOol0@Goo001NOol00`0OOomoo`1kOol0
0`0OOomoo`11Ool005ioo`0301moogoo07aoo`0301moogoo041oo`00Ggoo00<07gooOol0Ngoo00<0
7gooOol0@7oo001POol00`0OOomoo`1jOol00`0OOomoo`10Ool0061oo`0301moogoo07Yoo`0301mo
ogoo041oo`00HGoo00<07gooOol0NGoo00<07gooOol0@7oo001ROol00`0OOomoo`1hOol00`0OOomo
o`10Ool0069oo`0301moogoo07Qoo`0301moogoo041oo`00Hgoo00<07gooOol0Mgoo00<07gooOol0
@7oo001TOol00`0OOomoo`1fOol00`0OOomoo`10Ool006Aoo`0301moogoo07Ioo`0301moogoo041o
o`00IGoo00<07gooOol0MGoo00<07gooOol0@7oo001VOol00`0OOomoo`1dOol00`0OOomoo`10Ool0
06Ioo`0301moogoo07Aoo`0301moogoo041oo`00Igoo00<07gooOol0Lgoo00<07gooOol0@7oo001X
Ool00`0OOomoo`1aOol00`0OOomoo`11Ool006Qoo`0301moogoo075oo`0301moogoo045oo`00JGoo
00<07gooOol0L7oo00<07gooOol0@Goo001ZOol00`0OOomoo`1_Ool00`0OOomoo`11Ool006Yoo`03
01moogoo06moo`0301moogoo045oo`00Jgoo00<07gooOol0KWoo00<07gooOol0@Goo001/Ool00`0O
Oomoo`1]Ool00`0OOomoo`11Ool006eoo`0301moogoo06]oo`0301moogoo049oo`00KWoo00<07goo
Ool0JWoo00<07gooOol0@Woo001_Ool00`0OOomoo`1YOol00`0OOomoo`12Ool0071oo`0301moogoo
06Qoo`0301moogoo049oo`00LGoo00<07gooOol0Igoo00<07gooOol0@Woo001bOol00`0OOomoo`1U
Ool00`0OOomoo`13Ool007=oo`0301moogoo06Aoo`0301moogoo04=oo`00M7oo00<07gooOol0Hgoo
00<07gooOol0@goo001eOol00`0OOomoo`1QOol00`0OOomoo`14Ool007Ioo`0301moogoo061oo`03
01moogoo04Aoo`00Mgoo00<07gooOol0Ggoo00<07gooOol0A7oo001hOol00`0OOomoo`1MOol00`0O
Oomoo`15Ool007Uoo`0301moogoo05aoo`0301moogoo04Eoo`00NWoo00<07gooOol0Fgoo00<07goo
Ool0AGoo001kOol00`0OOomoo`1IOol00`0OOomoo`16Ool007aoo`0301moogoo05Qoo`0301moogoo
04Ioo`00OGoo00<07gooOol0EWoo00<07gooOol0Agoo001nOol00`0OOomoo`1EOol00`0OOomoo`17
Ool007moo`0301moogoo05=oo`0301moogoo04Qoo`00P7oo00<07gooOol0DWoo00<07gooOol0B7oo
0021Ool201mAOol00`0OOomoo`19Ool008=oo`0301moogoo04eoo`0301moogoo04Yoo`00Q7oo00<0
7gooOol0Bgoo00<07gooOol0Bgoo0025Ool00`0OOomoo`1:Ool00`0OOomoo`1;Ool008Ioo`807dUo
o`0301moogoo04aoo`00R7oo00<07gooOol0AGoo00<07gooOol0CGoo0029Ool00`0OOomoo`13Ool0
0`0OOomoo`1>Ool008Yoo`807d9oo`0301moogoo04moo`00S7oo0P0O?goo00<07gooOol0D7oo002>
Ool201llOol00`0OOomoo`1AOol0091oo`807cQoo`807eAoo`00TWoo0P0O=Goo00<07gooOol0E7oo
002DOol201lbOol00`0OOomoo`1EOol009Ioo`<07beoo`807eQoo`00VGoo0`0O:7oo0P0OFWoo002L
Ool301lSOol201mLOol009moo`<07aeoo`<07eioo`00XWoo0P0O6Goo0P0OHGoo002TOol:01l6Ool9
01mSOol00:ioo`H07faoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}]
}, Closed]]
}, Closed]],

Cell[TextData[{
  StyleBox["The RHCP photon-e&mvf that is generated by the rotation of the \
great-circle basis elements in the xz- and yz-planes about the ",
    FontFamily->"New York"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`i\_x\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`i\_y\)]],
  ",0",
  Cell[BoxData[
      \(TraditionalForm\`i\_z\)]],
  ")",
  StyleBox["-axis by ",
    FontFamily->"New York"],
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]],
  StyleBox[" corresponding to the output of the matrix given by Eq. (5) is \
shown in Figure 2.",
    FontFamily->"New York"]
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(EFieldRHCP\  = \ 
        Show[Array[p, {Steps}], ViewPoint \[Rule] {0, 0, 2}];\)\)], "Input",
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.49116 .5 m
.50884 .5 L
s
.47352 .5 m
.49116 .5 L
s
.50884 .5 m
.52648 .5 L
s
.50657 .48459 m
.52423 .48462 L
s
.48888 .48465 m
.50657 .48459 L
s
.47123 .4848 m
.48888 .48465 L
s
.45595 .5 m
.47352 .5 L
s
.52648 .5 m
.54405 .5 L
s
.52423 .48462 m
.54182 .48474 L
s
.50421 .46929 m
.52191 .46923 L
s
.48651 .46953 m
.50421 .46929 L
s
.45367 .48504 m
.47123 .4848 L
s
.46884 .46994 m
.48651 .46953 L
s
.52191 .46923 m
.53954 .46934 L
s
.45126 .47053 m
.46884 .46994 L
s
.4385 .5 m
.45595 .5 L
s
.54405 .5 m
.5615 .5 L
s
.54182 .48474 m
.55929 .48495 L
s
.50169 .45424 m
.51944 .45397 L
s
.48394 .45478 m
.50169 .45424 L
s
.46625 .45557 m
.48394 .45478 L
s
.43624 .48537 m
.45367 .48504 L
s
.51944 .45397 m
.53713 .45397 L
s
.53954 .46934 m
.55706 .46964 L
s
.44865 .45664 m
.46625 .45557 L
s
.43383 .4713 m
.45126 .47053 L
s
.53713 .45397 m
.55471 .45423 L
s
.49892 .43961 m
.51672 .43901 L
s
.48112 .44056 m
.49892 .43961 L
s
.55929 .48495 m
.57658 .48525 L
s
.42125 .5 m
.4385 .5 L
s
.5615 .5 m
.57875 .5 L
s
.46339 .44185 m
.48112 .44056 L
s
.51672 .43901 m
.53448 .43877 L
s
.55706 .46964 m
.57441 .47012 L
s
.419 .48578 m
.43624 .48537 L
s
.43122 .45796 m
.44865 .45664 L
s
.44578 .4435 m
.46339 .44185 L
s
.53448 .43877 m
.55215 .43888 L
s
.55471 .45423 m
.57213 .45477 L
s
.41661 .47225 m
.43383 .4713 L
s
.49582 .42555 m
.51369 .42451 L
s
.47798 .42702 m
.49582 .42555 L
s
.46022 .42892 m
.47798 .42702 L
s
.51369 .42451 m
.53153 .42392 L
s
.57658 .48525 m
.59364 .48563 L
s
.42835 .44548 m
.44578 .4435 L
s
.40423 .5 m
.42125 .5 L
s
.57875 .5 m
.59577 .5 L
s
.57441 .47012 m
.59153 .47077 L
s
.55215 .43888 m
.56965 .43936 L
s
.414 .45955 m
.43122 .45796 L
s
.44261 .43125 m
.46022 .42892 L
s
.40202 .48629 m
.419 .48578 L
s
.53153 .42392 m
.54928 .42376 L
s
.57213 .45477 m
.58933 .45557 L
s
.39964 .47337 m
.41661 .47225 L
s
.49235 .41221 m
.51027 .41062 L
s
.47448 .41431 m
.49235 .41221 L
s
.45671 .41692 m
.47448 .41431 L
s
.42519 .434 m
.44261 .43125 L
s
.51027 .41062 m
.52818 .40956 L
s
.41115 .44782 m
.42835 .44548 L
s
.54928 .42376 m
.56689 .42406 L
s
.56965 .43936 m
.58695 .4402 L
s
.43911 .42003 m
.45671 .41692 L
s
.52818 .40956 m
.54603 .40902 L
s
.59364 .48563 m
.61041 .48611 L
s
.39706 .4614 m
.414 .45955 L
s
.38752 .5 m
.40423 .5 L
s
.59577 .5 m
.61248 .5 L
s
.59153 .47077 m
.60836 .47162 L
s
.38534 .48688 m
.40202 .48629 L
s
.40803 .43718 m
.42519 .434 L
s
.58933 .45557 m
.60624 .45666 L
s
.42174 .42364 m
.43911 .42003 L
s
.48847 .39972 m
.50642 .39749 L
s
.47059 .40255 m
.48847 .39972 L
s
.56689 .42406 m
.5843 .42481 L
s
.45285 .40596 m
.47059 .40255 L
s
.54603 .40902 m
.56375 .40902 L
s
.50642 .39749 m
.5244 .39585 L
s
.39425 .45049 m
.41115 .44782 L
s
.383 .47467 m
.39964 .47337 L
s
.4353 .40995 m
.45285 .40596 L
s
.58695 .4402 m
.60397 .44141 L
s
.5244 .39585 m
.54233 .39482 L
s
.40465 .42775 m
.42174 .42364 L
s
.38046 .4635 m
.39706 .4614 L
s
.41801 .4145 m
.4353 .40995 L
s
.56375 .40902 m
.58128 .40957 L
s
.61041 .48611 m
.62681 .48669 L
s
.39119 .44077 m
.40803 .43718 L
s
.60836 .47162 m
.62483 .47264 L
s
.37117 .5 m
.38752 .5 L
s
.61248 .5 m
.62883 .5 L
s
.48417 .38823 m
.50213 .38525 L
s
.46632 .39188 m
.48417 .38823 L
s
.5843 .42481 m
.60144 .42602 L
s
.44865 .39617 m
.46632 .39188 L
s
.54233 .39482 m
.56015 .39441 L
s
.60624 .45666 m
.62281 .45802 L
s
.50213 .38525 m
.52013 .38294 L
s
.36904 .48756 m
.38534 .48688 L
s
.4312 .40111 m
.44865 .39617 L
s
.3777 .45351 m
.39425 .45049 L
s
.40104 .41961 m
.41801 .4145 L
s
.52013 .38294 m
.53812 .38131 L
s
.60397 .44141 m
.62065 .44299 L
s
.38791 .43234 m
.40465 .42775 L
s
.36675 .47615 m
.383 .47467 L
s
.41405 .40667 m
.4312 .40111 L
s
.56015 .39441 m
.57781 .39464 L
s
.58128 .40957 m
.59856 .41066 L
s
.46171 .38238 m
.47947 .37784 L
s
.44416 .38764 m
.46171 .38238 L
s
.47947 .37784 m
.49737 .37403 L
s
.37473 .44478 m
.39119 .44077 L
s
.53812 .38131 m
.55603 .38039 L
s
.36427 .46587 m
.38046 .4635 L
s
.42688 .39358 m
.44416 .38764 L
s
.60144 .42602 m
.61825 .4277 L
s
.49737 .37403 m
.51537 .37095 L
s
.39726 .41284 m
.41405 .40667 L
s
.38445 .42527 m
.40104 .41961 L
s
.62681 .48669 m
.64279 .48735 L
s
.62483 .47264 m
.64089 .47386 L
s
.35525 .5 m
.37117 .5 L
s
.62883 .5 m
.64475 .5 L
s
.40995 .4002 m
.42688 .39358 L
s
.62281 .45802 m
.63896 .45967 L
s
.51537 .37095 m
.53338 .36863 L
s
.36159 .45686 m
.3777 .45351 L
s
.37159 .43741 m
.38791 .43234 L
s
.57781 .39464 m
.59523 .3955 L
s
.35318 .48834 m
.36904 .48756 L
s
.55603 .38039 m
.5738 .38018 L
s
.59856 .41066 m
.61552 .41232 L
s
.4568 .37416 m
.47441 .36866 L
s
.43946 .38041 m
.4568 .37416 L
s
.62065 .44299 m
.63692 .44494 L
s
.47441 .36866 m
.4922 .36394 L
s
.42243 .38741 m
.43946 .38041 L
s
.39342 .40747 m
.40995 .4002 L
s
.3809 .41961 m
.39726 .41284 L
s
.35095 .4778 m
.36675 .47615 L
s
.53338 .36863 m
.55136 .36709 L
s
.4922 .36394 m
.51013 .36002 L
s
.40579 .39512 m
.42243 .38741 L
s
.35874 .4492 m
.37473 .44478 L
s
.36832 .43147 m
.38445 .42527 L
s
.61825 .4277 m
.63466 .42985 L
s
.34855 .4685 m
.36427 .46587 L
s
.51013 .36002 m
.52812 .35692 L
s
.5738 .38018 m
.59136 .38069 L
s
.38961 .40352 m
.40579 .39512 L
s
.37735 .41539 m
.39342 .40747 L
s
.4517 .36725 m
.46906 .36074 L
s
.43465 .37455 m
.4517 .36725 L
s
.59523 .3955 m
.61234 .39701 L
s
.41797 .38262 m
.43465 .37455 L
s
.55136 .36709 m
.56922 .36634 L
s
.46906 .36074 m
.48667 .35506 L
s
.35575 .44296 m
.37159 .43741 L
s
.40172 .39143 m
.41797 .38262 L
s
.64089 .47386 m
.65645 .47526 L
s
.64279 .48735 m
.65827 .48811 L
s
.36503 .42697 m
.3809 .41961 L
s
.63896 .45967 m
.65463 .4616 L
s
.33985 .5 m
.35525 .5 L
s
.64475 .5 m
.66015 .5 L
s
.34598 .46055 m
.36159 .45686 L
s
.61552 .41232 m
.63208 .41454 L
s
.48667 .35506 m
.50445 .35024 L
s
.52812 .35692 m
.5461 .35467 L
s
.38598 .40097 m
.40172 .39143 L
s
.37394 .4126 m
.38961 .40352 L
s
.33784 .4892 m
.35318 .48834 L
s
.63692 .44494 m
.65271 .44728 L
s
.42986 .37005 m
.44652 .36169 L
s
.41363 .3792 m
.42986 .37005 L
s
.44652 .36169 m
.46354 .35415 L
s
.35272 .43819 m
.36832 .43147 L
s
.39788 .38911 m
.41363 .3792 L
s
.36183 .42394 m
.37735 .41539 L
s
.50445 .35024 m
.52234 .34629 L
s
.34327 .45403 m
.35874 .4492 L
s
.59136 .38069 m
.60863 .38195 L
s
.46354 .35415 m
.48086 .34748 L
s
.56922 .36634 m
.58689 .3664 L
s
.33569 .47963 m
.35095 .4778 L
s
.38269 .39974 m
.39788 .38911 L
s
.3708 .41118 m
.38598 .40097 L
s
.63466 .42985 m
.65059 .43248 L
s
.61234 .39701 m
.62908 .39919 L
s
.5461 .35467 m
.56401 .35328 L
s
.40958 .3771 m
.42526 .36688 L
s
.39444 .38807 m
.40958 .3771 L
s
.42526 .36688 m
.44141 .35747 L
s
.35886 .42232 m
.37394 .4126 L
s
.34974 .43491 m
.36503 .42697 L
s
.48086 .34748 m
.49841 .34169 L
s
.3799 .39977 m
.39444 .38807 L
s
.44141 .35747 m
.45798 .3489 L
s
.3681 .41106 m
.38269 .39974 L
s
.33339 .47139 m
.34855 .4685 L
s
.34049 .44898 m
.35575 .44296 L
s
.52234 .34629 m
.54027 .34324 L
s
.40599 .37624 m
.421 .365 L
s
.39157 .38822 m
.40599 .37624 L
s
.37778 .40092 m
.39157 .38822 L
s
.421 .365 m
.43654 .35456 L
s
.36601 .41214 m
.3799 .39977 L
s
.35626 .42205 m
.3708 .41118 L
s
.45798 .3489 m
.4749 .34121 L
s
.63208 .41454 m
.64818 .41734 L
s
.3647 .41426 m
.37778 .40092 L
s
.34693 .43308 m
.36183 .42394 L
s
.49841 .34169 m
.51612 .33683 L
s
.65645 .47526 m
.67144 .47685 L
s
.43654 .35456 m
.45254 .34497 L
s
.65827 .48811 m
.67317 .48896 L
s
.33095 .46458 m
.34598 .46055 L
s
.3542 .42304 m
.3681 .41106 L
s
.65463 .4616 m
.66972 .46381 L
s
.58689 .3664 m
.60431 .36729 L
s
.33772 .44544 m
.35272 .43819 L
s
.56401 .35328 m
.58177 .35279 L
s
.32503 .5 m
.33985 .5 L
s
.66015 .5 m
.67497 .5 L
s
.35237 .42822 m
.3647 .41426 L
s
.35285 .42515 m
.36601 .41214 L
s
.60863 .38195 m
.62555 .38396 L
s
.4749 .34121 m
.49211 .33444 L
s
.34444 .43266 m
.35886 .42232 L
s
.65271 .44728 m
.66793 .45001 L
s
.54027 .34324 m
.55818 .34114 L
s
.45254 .34497 m
.46895 .33627 L
s
.32311 .49016 m
.33784 .4892 L
s
.32841 .45925 m
.34327 .45403 L
s
.34243 .43355 m
.35626 .42205 L
s
.33509 .44339 m
.34974 .43491 L
s
.62908 .39919 m
.64536 .40204 L
s
.51612 .33683 m
.53392 .33293 L
s
.34085 .44273 m
.35237 .42822 L
s
.34105 .43563 m
.3542 .42304 L
s
.65059 .43248 m
.66597 .43559 L
s
.34048 .43875 m
.35285 .42515 L
s
.32106 .48164 m
.33569 .47963 L
s
.49211 .33444 m
.50954 .32863 L
s
.46895 .33627 m
.4857 .3285 L
s
.33271 .4428 m
.34693 .43308 L
s
.32587 .45545 m
.34049 .44898 L
s
.58177 .35279 m
.59931 .3532 L
s
.60431 .36729 m
.62139 .36903 L
s
.31887 .47454 m
.33339 .47139 L
s
.33021 .45775 m
.34085 .44273 L
s
.55818 .34114 m
.57598 .33999 L
s
.33075 .44358 m
.34444 .43266 L
s
.64818 .41734 m
.66372 .42072 L
s
.53392 .33293 m
.55175 .33002 L
s
.32895 .45289 m
.34048 .43875 L
s
.62555 .38396 m
.64202 .38674 L
s
.32937 .44563 m
.34243 .43355 L
s
.32341 .45318 m
.33772 .44544 L
s
.32871 .44878 m
.34105 .43563 L
s
.50954 .32863 m
.52712 .32381 L
s
.4857 .3285 m
.50273 .32171 L
s
.31658 .46893 m
.33095 .46458 L
s
.67144 .47685 m
.68577 .47863 L
s
.67317 .48896 m
.6874 .4899 L
s
.66972 .46381 m
.68416 .46632 L
s
.32116 .45242 m
.33509 .44339 L
s
.3205 .47321 m
.33021 .45775 L
s
.31089 .5 m
.32503 .5 L
s
.67497 .5 m
.68911 .5 L
s
.66793 .45001 m
.6825 .45312 L
s
.64536 .40204 m
.66109 .40557 L
s
.31426 .46487 m
.32841 .45925 L
s
.31927 .45308 m
.33271 .4428 L
s
.57598 .33999 m
.5936 .33983 L
s
.30907 .49121 m
.32311 .49016 L
s
.59931 .3532 m
.61655 .35455 L
s
.31834 .46752 m
.32895 .45289 L
s
.55175 .33002 m
.56952 .32814 L
s
.66597 .43559 m
.68069 .43919 L
s
.52712 .32381 m
.54477 .32005 L
s
.50273 .32171 m
.51997 .31596 L
s
.31788 .45507 m
.33075 .44358 L
s
.62139 .36903 m
.63806 .37162 L
s
.31727 .46247 m
.32871 .44878 L
s
.31716 .45826 m
.32937 .44563 L
s
.31198 .46237 m
.32587 .45545 L
s
.30713 .48382 m
.32106 .48164 L
s
.31179 .48907 m
.3205 .47321 L
s
.64202 .38674 m
.65796 .39031 L
s
.66372 .42072 m
.67863 .42469 L
s
.30987 .46142 m
.32341 .45318 L
s
.30508 .47794 m
.31887 .47454 L
s
.30871 .4826 m
.31834 .46752 L
s
.30806 .46195 m
.32116 .45242 L
s
.51997 .31596 m
.53735 .31129 L
s
.56952 .32814 m
.58716 .32731 L
s
.54477 .32005 m
.56243 .31736 L
s
.5936 .33983 m
.61095 .34068 L
s
.30298 .47361 m
.31658 .46893 L
s
.61655 .35455 m
.63339 .35685 L
s
.30678 .47663 m
.31727 .46247 L
s
.30668 .46388 m
.31927 .45308 L
s
.66109 .40557 m
.6762 .40979 L
s
.68577 .47863 m
.69935 .4806 L
s
.68416 .46632 m
.69786 .46912 L
s
.30589 .4714 m
.31716 .45826 L
s
.30591 .46708 m
.31788 .45507 L
s
.6874 .4899 m
.70087 .49094 L
s
.6825 .45312 m
.69633 .45663 L
s
.63806 .37162 m
.65421 .3751 L
s
.30414 .50525 m
.31179 .48907 L
s
.30089 .47088 m
.31426 .46487 L
s
.29752 .5 m
.31089 .5 L
s
.68911 .5 m
.70248 .5 L
s
.68069 .43919 m
.69467 .44329 L
s
.29581 .49234 m
.30907 .49121 L
s
.29893 .46972 m
.31198 .46237 L
s
.30013 .49805 m
.30871 .4826 L
s
.65796 .39031 m
.67328 .39466 L
s
.53735 .31129 m
.55479 .30774 L
s
.56243 .31736 m
.58001 .31579 L
s
.58716 .32731 m
.60458 .32758 L
s
.294 .48618 m
.30713 .48382 L
s
.67863 .42469 m
.69279 .42926 L
s
.2972 .47012 m
.30987 .46142 L
s
.61095 .34068 m
.62795 .34258 L
s
.29733 .49122 m
.30678 .47663 L
s
.63339 .35685 m
.64975 .36012 L
s
.29585 .47197 m
.30806 .46195 L
s
.2976 .5217 m
.30414 .50525 L
s
.29212 .48159 m
.30508 .47794 L
s
.29563 .485 m
.30589 .4714 L
s
.29504 .47518 m
.30668 .46388 L
s
.29491 .47958 m
.30591 .46708 L
s
.6762 .40979 m
.69057 .41472 L
s
.65421 .3751 m
.66976 .37947 L
s
.29023 .47861 m
.30298 .47361 L
s
.29268 .51382 m
.30013 .49805 L
s
.55479 .30774 m
.57221 .30537 L
s
.69786 .46912 m
.7107 .47221 L
s
.69935 .4806 m
.71207 .48277 L
s
.58001 .31579 m
.59742 .31539 L
s
.69633 .45663 m
.70931 .46053 L
s
.70087 .49094 m
.71348 .49208 L
s
.28842 .47725 m
.30089 .47088 L
s
.60458 .32758 m
.62168 .32897 L
s
.28503 .5 m
.29752 .5 L
s
.70248 .5 m
.71497 .5 L
s
.69467 .44329 m
.70782 .44788 L
s
.67328 .39466 m
.68788 .39982 L
s
.289 .50618 m
.29733 .49122 L
s
.62795 .34258 m
.6445 .34554 L
s
.28679 .47749 m
.29893 .46972 L
s
.29225 .53833 m
.2976 .5217 L
s
.28344 .49357 m
.29581 .49234 L
s
.28647 .49901 m
.29563 .485 L
s
.64975 .36012 m
.66554 .36439 L
s
.28549 .47926 m
.2972 .47012 L
s
.69279 .42926 m
.70612 .43443 L
s
.28465 .48246 m
.29585 .47197 L
s
.28499 .49252 m
.29491 .47958 L
s
.28443 .48693 m
.29504 .47518 L
s
.28179 .48871 m
.294 .48618 L
s
.57221 .30537 m
.58952 .30422 L
s
.28642 .52984 m
.29268 .51382 L
s
.66976 .37947 m
.68461 .38474 L
s
.2801 .48548 m
.29212 .48159 L
s
.59742 .31539 m
.61457 .31618 L
s
.69057 .41472 m
.70411 .42035 L
s
.62168 .32897 m
.63838 .33152 L
s
.27845 .48391 m
.29023 .47861 L
s
.28186 .52145 m
.289 .50618 L
s
.28815 .55508 m
.29225 .53833 L
s
.6445 .34554 m
.6605 .34959 L
s
.7107 .47221 m
.72259 .47558 L
s
.71207 .48277 m
.72383 .48512 L
s
.27694 .48398 m
.28842 .47725 L
s
.68788 .39982 m
.70167 .40579 L
s
.70931 .46053 m
.72134 .46482 L
s
.27849 .51337 m
.28647 .49901 L
s
.71348 .49208 m
.72512 .4933 L
s
.66554 .36439 m
.68064 .36966 L
s
.70782 .44788 m
.72001 .45297 L
s
.27569 .48565 m
.28679 .47749 L
s
.27352 .5 m
.28503 .5 L
s
.71497 .5 m
.72648 .5 L
s
.27623 .50584 m
.28499 .49252 L
s
.58952 .30422 m
.60664 .30434 L
s
.27485 .48882 m
.28549 .47926 L
s
.28143 .54604 m
.28642 .52984 L
s
.27496 .4991 m
.28443 .48693 L
s
.27455 .49336 m
.28465 .48246 L
s
.70612 .43443 m
.71851 .4402 L
s
.61457 .31618 m
.63137 .31821 L
s
.27208 .49488 m
.28344 .49357 L
s
.68461 .38474 m
.69865 .39093 L
s
.63838 .33152 m
.65457 .33524 L
s
.27059 .4914 m
.28179 .48871 L
s
.28536 .57184 m
.28815 .55508 L
s
.70411 .42035 m
.71671 .42668 L
s
.27599 .53695 m
.28186 .52145 L
s
.6605 .34959 m
.67584 .35475 L
s
.26912 .48961 m
.2801 .48548 L
s
.27178 .52802 m
.27849 .51337 L
s
.26774 .48951 m
.27845 .48391 L
s
.70167 .40579 m
.71451 .41257 L
s
.68064 .36966 m
.69495 .37595 L
s
.60664 .30434 m
.62345 .30577 L
s
.27779 .56233 m
.28143 .54604 L
s
.26657 .49106 m
.27694 .48398 L
s
.26873 .5195 m
.27623 .50584 L
s
.72259 .47558 m
.7334 .47925 L
s
.72134 .46482 m
.7323 .4695 L
s
.63137 .31821 m
.6477 .32152 L
s
.72383 .48512 m
.73451 .48766 L
s
.26573 .49418 m
.27569 .48565 L
s
.72001 .45297 m
.73114 .45855 L
s
.26673 .51163 m
.27496 .4991 L
s
.72512 .4933 m
.73567 .49462 L
s
.26538 .49877 m
.27485 .48882 L
s
.26566 .50465 m
.27455 .49336 L
s
.65457 .33524 m
.67014 .34018 L
s
.28394 .58854 m
.28536 .57184 L
s
.26311 .5 m
.27352 .5 L
s
.72648 .5 m
.73689 .5 L
s
.71851 .4402 m
.72983 .44658 L
s
.69865 .39093 m
.71177 .39804 L
s
.27148 .55261 m
.27599 .53695 L
s
.26183 .49627 m
.27208 .49488 L
s
.67584 .35475 m
.69042 .36103 L
s
.71671 .42668 m
.72826 .43372 L
s
.26054 .49425 m
.27059 .4914 L
s
.26643 .54289 m
.27178 .52802 L
s
.62345 .30577 m
.63985 .30856 L
s
.27555 .57862 m
.27779 .56233 L
s
.69495 .37595 m
.70835 .38328 L
s
.25931 .49396 m
.26912 .48961 L
s
.71451 .41257 m
.72631 .42016 L
s
.6477 .32152 m
.66345 .32612 L
s
.26258 .53343 m
.26873 .5195 L
s
.25823 .49538 m
.26774 .48951 L
s
.67014 .34018 m
.68498 .34634 L
s
.28397 .60508 m
.28394 .58854 L
s
.25983 .52447 m
.26673 .51163 L
s
.25742 .49845 m
.26657 .49106 L
s
.7323 .4695 m
.74208 .47456 L
s
.7334 .47925 m
.74302 .48319 L
s
.25703 .50305 m
.26573 .49418 L
s
.25809 .51627 m
.26566 .50465 L
s
.26841 .56834 m
.27148 .55261 L
s
.2572 .50906 m
.26538 .49877 L
s
.73114 .45855 m
.74109 .46462 L
s
.73451 .48766 m
.74399 .49039 L
s
.71177 .39804 m
.72384 .40607 L
s
.73567 .49462 m
.745 .49602 L
s
.69042 .36103 m
.70412 .36845 L
s
.72983 .44658 m
.73997 .45354 L
s
.25393 .5 m
.26311 .5 L
s
.73689 .5 m
.74607 .5 L
s
.63985 .30856 m
.65574 .31273 L
s
.26254 .5579 m
.26643 .54289 L
s
.72826 .43372 m
.73862 .44146 L
s
.2748 .59482 m
.27555 .57862 L
s
.25283 .49775 m
.26183 .49627 L
s
.66345 .32612 m
.67852 .33205 L
s
.70835 .38328 m
.72072 .39163 L
s
.25176 .49726 m
.26054 .49425 L
s
.25788 .54756 m
.26258 .53343 L
s
.72631 .42016 m
.73693 .42857 L
s
.28549 .62134 m
.28397 .60508 L
s
.68498 .34634 m
.69896 .35374 L
s
.25079 .49853 m
.25931 .49396 L
s
.25439 .53756 m
.25983 .52447 L
s
.26686 .58405 m
.26841 .56834 L
s
.25004 .50151 m
.25823 .49538 L
s
.25194 .52817 m
.25809 .51627 L
s
.24963 .50612 m
.25742 .49845 L
s
.72384 .40607 m
.73475 .41502 L
s
.70412 .36845 m
.71681 .37701 L
s
.25043 .51965 m
.2572 .50906 L
s
.24971 .51223 m
.25703 .50305 L
s
.74208 .47456 m
.75053 .48 L
s
.65574 .31273 m
.67098 .31833 L
s
.74302 .48319 m
.75132 .48741 L
s
.74109 .46462 m
.74972 .47117 L
s
.74399 .49039 m
.75213 .49329 L
s
.2756 .61082 m
.2748 .59482 L
s
.26018 .57297 m
.26254 .5579 L
s
.73997 .45354 m
.7488 .46108 L
s
.745 .49602 m
.75299 .49751 L
s
.67852 .33205 m
.69277 .33933 L
s
.73862 .44146 m
.74768 .44989 L
s
.72072 .39163 m
.73194 .40101 L
s
.24611 .5 m
.25393 .5 L
s
.74607 .5 m
.75389 .5 L
s
.28856 .63722 m
.28549 .62134 L
s
.25474 .56181 m
.25788 .54756 L
s
.69896 .35374 m
.71197 .3624 L
s
.24521 .4993 m
.25283 .49775 L
s
.73693 .42857 m
.74624 .43777 L
s
.26691 .59965 m
.26686 .58405 L
s
.24438 .5004 m
.25176 .49726 L
s
.25049 .55082 m
.25439 .53756 L
s
.2437 .50329 m
.25079 .49853 L
s
.71681 .37701 m
.72836 .38671 L
s
.67098 .31833 m
.68546 .32538 L
s
.24734 .54029 m
.25194 .52817 L
s
.73475 .41502 m
.74436 .42488 L
s
.2433 .50788 m
.25004 .50151 L
s
.27801 .62652 m
.2756 .61082 L
s
.24519 .53048 m
.25043 .51965 L
s
.24332 .51406 m
.24963 .50612 L
s
.2439 .52166 m
.24971 .51223 L
s
.25946 .58799 m
.26018 .57297 L
s
.69277 .33933 m
.70608 .34796 L
s
.75053 .48 m
.75754 .48579 L
s
.74972 .47117 m
.7569 .47818 L
s
.75132 .48741 m
.75816 .49189 L
s
.7488 .46108 m
.75619 .46919 L
s
.29322 .65258 m
.28856 .63722 L
s
.73194 .40101 m
.74187 .41141 L
s
.75213 .49329 m
.75881 .49636 L
s
.74768 .44989 m
.7553 .45899 L
s
.71197 .3624 m
.72386 .3723 L
s
.25325 .57608 m
.25474 .56181 L
s
.75299 .49751 m
.7595 .49908 L
s
.26863 .61501 m
.26691 .59965 L
s
.23979 .5 m
.24611 .5 L
s
.75389 .5 m
.76021 .5 L
s
.74624 .43777 m
.75413 .44774 L
s
.24826 .56418 m
.25049 .55082 L
s
.68546 .32538 m
.69904 .33389 L
s
.23911 .50092 m
.24521 .4993 L
s
.72836 .38671 m
.73863 .39753 L
s
.2821 .64178 m
.27801 .62652 L
s
.23854 .50368 m
.24438 .5004 L
s
.74436 .42488 m
.75254 .43562 L
s
.24441 .55256 m
.24734 .54029 L
s
.70608 .34796 m
.71831 .35796 L
s
.26045 .60286 m
.25946 .58799 L
s
.23818 .50822 m
.2437 .50329 L
s
.2416 .54151 m
.24519 .53048 L
s
.23816 .51445 m
.2433 .50788 L
s
.29952 .66731 m
.29322 .65258 L
s
.23972 .5313 m
.2439 .52166 L
s
.23862 .5222 m
.24332 .51406 L
s
.74187 .41141 m
.75038 .4228 L
s
.72386 .3723 m
.7345 .38344 L
s
.7569 .47818 m
.7625 .48563 L
s
.75754 .48579 m
.76295 .49193 L
s
.75619 .46919 m
.76199 .47784 L
s
.25351 .59028 m
.25325 .57608 L
s
.75816 .49189 m
.7634 .49662 L
s
.27208 .63002 m
.26863 .61501 L
s
.7553 .45899 m
.76134 .46874 L
s
.75881 .49636 m
.76387 .49958 L
s
.69904 .33389 m
.71159 .34387 L
s
.75413 .44774 m
.76044 .45847 L
s
.7595 .49908 m
.76438 .50073 L
s
.73863 .39753 m
.74751 .40946 L
s
.24779 .57754 m
.24826 .56418 L
s
.28791 .65647 m
.2821 .64178 L
s
.23511 .5 m
.23979 .5 L
s
.76021 .5 m
.76489 .5 L
s
.71831 .35796 m
.72932 .36931 L
s
.75254 .43562 m
.75915 .44721 L
s
.26323 .61747 m
.26045 .60286 L
s
.23467 .50261 m
.23911 .50092 L
s
.24324 .56489 m
.24441 .55256 L
s
.30749 .68126 m
.29952 .66731 L
s
.23438 .50707 m
.23854 .50368 L
s
.23978 .55264 m
.2416 .54151 L
s
.7345 .38344 m
.74375 .3958 L
s
.23436 .51331 m
.23818 .50822 L
s
.75038 .4228 m
.75734 .43515 L
s
.2373 .54109 m
.23972 .5313 L
s
.23474 .52118 m
.23816 .51445 L
s
.23567 .53052 m
.23862 .5222 L
s
.27732 .64456 m
.27208 .63002 L
s
.25559 .60431 m
.25351 .59028 L
s
.7625 .48563 m
.76638 .49349 L
s
.76199 .47784 m
.76609 .487 L
s
.71159 .34387 m
.72295 .35532 L
s
.76295 .49193 m
.76663 .49839 L
s
.76134 .46874 m
.76567 .47909 L
s
.7634 .49662 m
.76689 .50158 L
s
.74751 .40946 m
.75483 .42246 L
s
.29547 .67047 m
.28791 .65647 L
s
.76044 .45847 m
.76504 .4699 L
s
.24918 .59079 m
.24779 .57754 L
s
.76387 .49958 m
.76719 .50295 L
s
.72932 .36931 m
.73897 .38198 L
s
.26787 .63168 m
.26323 .61747 L
s
.76438 .50073 m
.76749 .50244 L
s
.31714 .69429 m
.30749 .68126 L
s
.75915 .44721 m
.76407 .45962 L
s
.24395 .5772 m
.24324 .56489 L
s
.23222 .5 m
.23511 .5 L
s
.76489 .5 m
.76778 .5 L
s
.74375 .3958 m
.75148 .40933 L
s
.23204 .50435 m
.23467 .50261 L
s
.75734 .43515 m
.7626 .44842 L
s
.28441 .65848 m
.27732 .64456 L
s
.23985 .56382 m
.23978 .55264 L
s
.23205 .51056 m
.23438 .50707 L
s
.25959 .61804 m
.25559 .60431 L
s
.72295 .35532 m
.733 .3682 L
s
.23677 .55096 m
.2373 .54109 L
s
.23239 .51851 m
.23436 .51331 L
s
.2346 .53894 m
.23567 .53052 L
s
.23319 .52804 m
.23474 .52118 L
s
.30481 .68363 m
.29547 .67047 L
s
.75483 .42246 m
.76048 .43648 L
s
.76609 .487 m
.76832 .49663 L
s
.76638 .49349 m
.76839 .50172 L
s
.76567 .47909 m
.76816 .49 L
s
.73897 .38198 m
.74712 .39595 L
s
.76663 .49839 m
.76844 .50513 L
s
.25253 .60384 m
.24918 .59079 L
s
.76504 .4699 m
.76781 .48199 L
s
.32847 .70626 m
.31714 .69429 L
s
.27442 .64538 m
.26787 .63168 L
s
.76689 .50158 m
.76851 .50674 L
s
.76407 .45962 m
.76715 .47278 L
s
.76719 .50295 m
.7686 .50645 L
s
.75148 .40933 m
.75755 .424 L
s
.24665 .58938 m
.24395 .5772 L
s
.76749 .50244 m
.7687 .50421 L
s
.29337 .67164 m
.28441 .65848 L
s
.7626 .44842 m
.76604 .46254 L
s
.733 .3682 m
.74157 .3825 L
s
.23126 .5 m
.23222 .5 L
s
.76778 .5 m
.76874 .5 L
s
.26557 .63134 m
.25959 .61804 L
s
.24192 .57494 m
.23985 .56382 L
s
.31595 .69579 m
.30481 .68363 L
s
.23135 .50614 m
.23204 .50435 L
s
.23825 .56084 m
.23677 .55096 L
s
.76048 .43648 m
.76432 .45146 L
s
.74712 .39595 m
.75363 .41116 L
s
.23168 .51412 m
.23205 .51056 L
s
.23553 .54742 m
.2346 .53894 L
s
.2324 .52379 m
.23239 .51851 L
s
.34147 .71701 m
.32847 .70626 L
s
.23363 .53498 m
.23319 .52804 L
s
.76832 .49663 m
.76858 .50667 L
s
.76816 .49 m
.76867 .50141 L
s
.28293 .65841 m
.27442 .64538 L
s
.2579 .61656 m
.25253 .60384 L
s
.76839 .50172 m
.76842 .51028 L
s
.76781 .48199 m
.76861 .49467 L
s
.76844 .50513 m
.76825 .51212 L
s
.75755 .424 m
.76182 .43973 L
s
.76715 .47278 m
.76828 .48662 L
s
.76851 .50674 m
.7681 .51207 L
s
.30423 .6839 m
.29337 .67164 L
s
.74157 .3825 m
.74854 .39814 L
s
.25142 .60132 m
.24665 .58938 L
s
.76604 .46254 m
.76753 .47744 L
s
.7686 .50645 m
.76798 .51005 L
s
.27358 .64407 m
.26557 .63134 L
s
.32886 .70681 m
.31595 .69579 L
s
.7687 .50421 m
.76785 .50602 L
s
.75363 .41116 m
.75836 .42753 L
s
.24609 .5859 m
.24192 .57494 L
s
.76432 .45146 m
.76622 .46731 L
s
.35611 .72639 m
.34147 .71701 L
s
.23237 .5 m
.23126 .5 L
s
.76874 .5 m
.76763 .5 L
s
.24185 .57064 m
.23825 .56084 L
s
.29343 .67063 m
.28293 .65841 L
s
.23275 .50795 m
.23135 .50614 L
s
.26538 .62882 m
.2579 .61656 L
s
.23342 .51772 m
.23168 .51412 L
s
.23859 .55588 m
.23553 .54742 L
s
.76867 .50141 m
.76709 .51326 L
s
.76182 .43973 m
.76417 .45643 L
s
.76861 .49467 m
.76733 .50787 L
s
.76858 .50667 m
.76672 .51706 L
s
.23452 .52912 m
.2324 .52379 L
s
.23619 .54193 m
.23363 .53498 L
s
.76842 .51028 m
.76632 .51912 L
s
.76828 .48662 m
.76733 .50107 L
s
.74854 .39814 m
.75377 .41506 L
s
.31696 .6951 m
.30423 .6839 L
s
.76825 .51212 m
.76592 .51931 L
s
.76753 .47744 m
.76696 .49303 L
s
.34352 .71654 m
.32886 .70681 L
s
.25833 .6129 m
.25142 .60132 L
s
.7681 .51207 m
.76555 .51753 L
s
.28366 .6561 m
.27358 .64407 L
s
.75836 .42753 m
.7612 .44498 L
s
.37232 .73427 m
.35611 .72639 L
s
.76622 .46731 m
.76607 .48394 L
s
.76798 .51005 m
.76519 .51372 L
s
.25244 .59661 m
.24609 .5859 L
s
.30591 .68189 m
.29343 .67063 L
s
.76785 .50602 m
.76481 .50787 L
s
.76417 .45643 m
.76449 .474 L
s
.27499 .64048 m
.26538 .62882 L
s
.24765 .58027 m
.24185 .57064 L
s
.23567 .5 m
.23237 .5 L
s
.76763 .5 m
.76433 .5 L
s
.75377 .41506 m
.75713 .43316 L
s
.33156 .70509 m
.31696 .6951 L
s
.76733 .50787 m
.76385 .5215 L
s
.76709 .51326 m
.7633 .52546 L
s
.23636 .50979 m
.23275 .50795 L
s
.76733 .50107 m
.7642 .51602 L
s
.24387 .56423 m
.23859 .55588 L
s
.76672 .51706 m
.76265 .52773 L
s
.23738 .52134 m
.23342 .51772 L
s
.35987 .72482 m
.34352 .71654 L
s
.24099 .54885 m
.23619 .54193 L
s
.23888 .53445 m
.23452 .52912 L
s
.76696 .49303 m
.76423 .5092 L
s
.76632 .51912 m
.76198 .52817 L
s
.7612 .44498 m
.76203 .46339 L
s
.39003 .74049 m
.37232 .73427 L
s
.29581 .66728 m
.28366 .6561 L
s
.26745 .624 m
.25833 .6129 L
s
.76592 .51931 m
.76134 .52665 L
s
.76607 .48394 m
.76378 .50123 L
s
.76555 .51753 m
.76073 .52309 L
s
.32035 .69204 m
.30591 .68189 L
s
.76449 .474 m
.76268 .4923 L
s
.26105 .60693 m
.25244 .59661 L
s
.75713 .43316 m
.7585 .4523 L
s
.76519 .51372 m
.76013 .51745 L
s
.34795 .71371 m
.33156 .70509 L
s
.28676 .6514 m
.27499 .64048 L
s
.76481 .50787 m
.75948 .50973 L
s
.37783 .73151 m
.35987 .72482 L
s
.25575 .58962 m
.24765 .58027 L
s
.76385 .5215 m
.7581 .53543 L
s
.7642 .51602 m
.75882 .53134 L
s
.76203 .46339 m
.76075 .48262 L
s
.7633 .52546 m
.75722 .5379 L
s
.40913 .74493 m
.39003 .74049 L
s
.76423 .5092 m
.75925 .52581 L
s
.24129 .5 m
.23567 .5 L
s
.76433 .5 m
.75871 .5 L
s
.76265 .52773 m
.75627 .53859 L
s
.25147 .5724 m
.24387 .56423 L
s
.31003 .67745 m
.29581 .66728 L
s
.2423 .51162 m
.23636 .50979 L
s
.76378 .50123 m
.75926 .51903 L
s
.24812 .55564 m
.24099 .54885 L
s
.2788 .63447 m
.26745 .624 L
s
.76198 .52817 m
.75532 .53735 L
s
.24368 .52494 m
.23738 .52134 L
s
.24557 .53971 m
.23888 .53445 L
s
.3367 .70092 m
.32035 .69204 L
s
.7585 .4523 m
.75779 .47236 L
s
.76268 .4923 m
.75866 .5112 L
s
.76134 .52665 m
.75441 .53407 L
s
.36606 .72083 m
.34795 .71371 L
s
.27195 .61676 m
.26105 .60693 L
s
.39728 .73648 m
.37783 .73151 L
s
.76073 .52309 m
.75354 .5287 L
s
.30068 .66143 m
.28676 .6514 L
s
.76075 .48262 m
.75729 .50251 L
s
.42948 .74747 m
.40913 .74493 L
s
.76013 .51745 m
.75267 .52119 L
s
.75882 .53134 m
.75111 .54691 L
s
.75925 .52581 m
.75198 .54273 L
s
.7581 .53543 m
.75 .54956 L
s
.26618 .59857 m
.25575 .58962 L
s
.75722 .5379 m
.74877 .55048 L
s
.32625 .68646 m
.31003 .67745 L
s
.75926 .51903 m
.75246 .5372 L
s
.75948 .50973 m
.75175 .51159 L
s
.75779 .47236 m
.75493 .49316 L
s
.75627 .53859 m
.74751 .54953 L
s
.35488 .70838 m
.3367 .70092 L
s
.75866 .5112 m
.75239 .53052 L
s
.29238 .64418 m
.2788 .63447 L
s
.26145 .58028 m
.25147 .5724 L
s
.24932 .5 m
.24129 .5 L
s
.75871 .5 m
.75068 .5 L
s
.38578 .7263 m
.36606 .72083 L
s
.75532 .53735 m
.74626 .54657 L
s
.25066 .51343 m
.2423 .51162 L
s
.25765 .56225 m
.24812 .55564 L
s
.41809 .73961 m
.39728 .73648 L
s
.2524 .52848 m
.24368 .52494 L
s
.25468 .54486 m
.24557 .53971 L
s
.45091 .74801 m
.42948 .74747 L
s
.75729 .50251 m
.75159 .52289 L
s
.75441 .53407 m
.74507 .54151 L
s
.31672 .67043 m
.30068 .66143 L
s
.28515 .62595 m
.27195 .61676 L
s
.75198 .54273 m
.74237 .55979 L
s
.75111 .54691 m
.74105 .56258 L
s
.75246 .5372 m
.74335 .55556 L
s
.75354 .5287 m
.74392 .53429 L
s
.75493 .49316 m
.74986 .51451 L
s
.75 .54956 m
.73954 .56374 L
s
.34442 .69417 m
.32625 .68646 L
s
.75239 .53052 m
.74383 .55008 L
s
.37478 .71429 m
.35488 .70838 L
s
.74877 .55048 m
.73793 .56308 L
s
.27898 .60703 m
.26618 .59857 L
s
.75267 .52119 m
.74277 .52491 L
s
.40696 .73 m
.38578 .7263 L
s
.44009 .7408 m
.41809 .73961 L
s
.47325 .74647 m
.45091 .74801 L
s
.30816 .65299 m
.29238 .64418 L
s
.75159 .52289 m
.74364 .54356 L
s
.74751 .54953 m
.73632 .56046 L
s
.75175 .51159 m
.74155 .51344 L
s
.27383 .58778 m
.26145 .58028 L
s
.25983 .5 m
.24932 .5 L
s
.75068 .5 m
.74017 .5 L
s
.74626 .54657 m
.73476 .55575 L
s
.74986 .51451 m
.74257 .5362 L
s
.33479 .67825 m
.31672 .67043 L
s
.26962 .56858 m
.25765 .56225 L
s
.2615 .51521 m
.25066 .51343 L
s
.74237 .55979 m
.73043 .57681 L
s
.74335 .55556 m
.73194 .57391 L
s
.26625 .54983 m
.25468 .54486 L
s
.26359 .53192 m
.2524 .52848 L
s
.30063 .63437 m
.28515 .62595 L
s
.74105 .56258 m
.72864 .57818 L
s
.74383 .55008 m
.733 .56967 L
s
.36441 .70043 m
.34442 .69417 L
s
.74507 .54151 m
.73326 .54888 L
s
.39624 .71852 m
.37478 .71429 L
s
.46307 .73996 m
.44009 .7408 L
s
.42942 .73183 m
.40696 .73 L
s
.49628 .7428 m
.47325 .74647 L
s
.73954 .56374 m
.72669 .57781 L
s
.74364 .54356 m
.73344 .5643 L
s
.74392 .53429 m
.73181 .5398 L
s
.73793 .56308 m
.72469 .57555 L
s
.29412 .61485 m
.27898 .60703 L
s
.32607 .66076 m
.30816 .65299 L
s
.74257 .5362 m
.73306 .558 L
s
.74277 .52491 m
.73037 .52856 L
s
.73632 .56046 m
.72271 .57124 L
s
.73194 .57391 m
.71827 .59205 L
s
.733 .56967 m
.71994 .58907 L
s
.35479 .68475 m
.33479 .67825 L
s
.73043 .57681 m
.71621 .5936 L
s
.51976 .73698 m
.49628 .7428 L
s
.48681 .73705 m
.46307 .73996 L
s
.28862 .59478 m
.27383 .58778 L
s
.45295 .7317 m
.42942 .73183 L
s
.73344 .5643 m
.72104 .58488 L
s
.38606 .70512 m
.36441 .70043 L
s
.74155 .51344 m
.72885 .51524 L
s
.41908 .72097 m
.39624 .71852 L
s
.72864 .57818 m
.71391 .59352 L
s
.73476 .55575 m
.72081 .56477 L
s
.31832 .64189 m
.30063 .63437 L
s
.28404 .57455 m
.26962 .56858 L
s
.27285 .5 m
.25983 .5 L
s
.74017 .5 m
.72715 .5 L
s
.73306 .558 m
.72138 .57967 L
s
.72669 .57781 m
.7115 .59162 L
s
.28031 .55456 m
.26625 .54983 L
s
.27485 .51692 m
.2615 .51521 L
s
.27729 .53522 m
.26359 .53192 L
s
.73326 .54888 m
.71898 .55609 L
s
.54343 .72902 m
.51976 .73698 L
s
.51106 .73204 m
.48681 .73705 L
s
.71994 .58907 m
.70473 .60807 L
s
.72469 .57555 m
.70908 .58774 L
s
.71827 .59205 m
.70243 .60977 L
s
.34601 .66734 m
.32607 .66076 L
s
.72104 .58488 m
.70652 .60506 L
s
.47733 .72957 m
.45295 .7317 L
s
.31156 .62192 m
.29412 .61485 L
s
.71621 .5936 m
.69979 .60996 L
s
.44308 .72154 m
.41908 .72097 L
s
.72138 .57967 m
.70762 .60095 L
s
.73181 .5398 m
.71722 .54517 L
s
.37656 .6898 m
.35479 .68475 L
s
.4092 .70813 m
.38606 .70512 L
s
.72271 .57124 m
.70671 .58174 L
s
.71391 .59352 m
.69695 .60843 L
s
.56703 .71897 m
.54343 .72902 L
s
.53555 .72493 m
.51106 .73204 L
s
.73037 .52856 m
.71547 .53209 L
s
.70652 .60506 m
.69001 .6246 L
s
.30576 .60119 m
.28862 .59478 L
s
.70473 .60807 m
.68749 .62642 L
s
.70762 .60095 m
.69189 .6216 L
s
.50227 .72539 m
.47733 .72957 L
s
.33814 .64839 m
.31832 .64189 L
s
.7115 .59162 m
.69406 .605 L
s
.70243 .60977 m
.68452 .62685 L
s
.72081 .56477 m
.70444 .57352 L
s
.72885 .51524 m
.71364 .51697 L
s
.59029 .70691 m
.56703 .71897 L
s
.468 .72018 m
.44308 .72154 L
s
.30087 .58007 m
.28404 .57455 L
s
.69979 .60996 m
.68127 .62568 L
s
.56 .71578 m
.53555 .72493 L
s
.36782 .67262 m
.34601 .66734 L
s
.69001 .6246 m
.67166 .64326 L
s
.69189 .6216 m
.67436 .64136 L
s
.28837 .5 m
.27285 .5 L
s
.72715 .5 m
.71163 .5 L
s
.43359 .70937 m
.4092 .70813 L
s
.70908 .58774 m
.69118 .5995 L
s
.3999 .69329 m
.37656 .6898 L
s
.29681 .55897 m
.28031 .55456 L
s
.68749 .62642 m
.66839 .6439 L
s
.71898 .55609 m
.70228 .56304 L
s
.29069 .51854 m
.27485 .51692 L
s
.61291 .69295 m
.59029 .70691 L
s
.29346 .53833 m
.27729 .53522 L
s
.52751 .71919 m
.50227 .72539 L
s
.69695 .60843 m
.67788 .62271 L
s
.67436 .64136 m
.6552 .65998 L
s
.33119 .62813 m
.31156 .62192 L
s
.58413 .70467 m
.56 .71578 L
s
.68452 .62685 m
.66473 .64308 L
s
.67166 .64326 m
.65166 .66081 L
s
.63464 .67725 m
.61291 .69295 L
s
.6552 .65998 m
.63464 .67725 L
s
.49356 .71687 m
.468 .72018 L
s
.70671 .58174 m
.6884 .59182 L
s
.71722 .54517 m
.70019 .55033 L
s
.66839 .6439 m
.64761 .66029 L
s
.60763 .6917 m
.58413 .70467 L
s
.65166 .66081 m
.63023 .67702 L
s
.55274 .71099 m
.52751 .71919 L
s
.69406 .605 m
.67447 .61776 L
s
.68127 .62568 m
.66084 .64056 L
s
.63023 .67702 m
.60763 .6917 L
s
.45898 .70877 m
.43359 .70937 L
s
.35991 .65373 m
.33814 .64839 L
s
.32517 .60689 m
.30576 .60119 L
s
.66473 .64308 m
.64323 .65823 L
s
.64761 .66029 m
.62539 .67537 L
s
.71547 .53209 m
.69812 .53546 L
s
.4246 .69513 m
.3999 .69329 L
s
.57767 .70088 m
.55274 .71099 L
s
.3913 .67648 m
.36782 .67262 L
s
.70444 .57352 m
.68575 .58188 L
s
.51947 .71159 m
.49356 .71687 L
s
.67788 .62271 m
.65686 .63617 L
s
.62539 .67537 m
.60198 .68896 L
s
.69118 .5995 m
.67112 .61067 L
s
.60198 .68896 m
.57767 .70088 L
s
.32003 .58504 m
.30087 .58007 L
s
.71364 .51697 m
.69597 .51861 L
s
.66084 .64056 m
.63869 .6544 L
s
.64323 .65823 m
.62028 .6721 L
s
.48508 .70631 m
.45898 .70877 L
s
.54541 .70439 m
.51947 .71159 L
s
.35288 .63336 m
.33119 .62813 L
s
.70228 .56304 m
.68322 .56966 L
s
.30635 .5 m
.28837 .5 L
s
.71163 .5 m
.69365 .5 L
s
.31569 .563 m
.29681 .55897 L
s
.67447 .61776 m
.65291 .62973 L
s
.30898 .52006 m
.29069 .51854 L
s
.31204 .54119 m
.29346 .53833 L
s
.62028 .6721 m
.59612 .68453 L
s
.6884 .59182 m
.66791 .60135 L
s
.57107 .69533 m
.54541 .70439 L
s
.45038 .69525 m
.4246 .69513 L
s
.59612 .68453 m
.57107 .69533 L
s
.38346 .65782 m
.35991 .65373 L
s
.65686 .63617 m
.6341 .64862 L
s
.63869 .6544 m
.61505 .667 L
s
.41623 .67883 m
.3913 .67648 L
s
.51158 .70197 m
.48508 .70631 L
s
.70019 .55033 m
.68079 .5552 L
s
.34671 .61179 m
.32517 .60689 L
s
.67112 .61067 m
.64907 .6211 L
s
.68575 .58188 m
.66485 .58973 L
s
.61505 .667 m
.59022 .6782 L
s
.53815 .6958 m
.51158 .70197 L
s
.47694 .69362 m
.45038 .69525 L
s
.69812 .53546 m
.6784 .53862 L
s
.65291 .62973 m
.6296 .64073 L
s
.6341 .64862 m
.60985 .65989 L
s
.59022 .6782 m
.56448 .68784 L
s
.56448 .68784 m
.53815 .6958 L
s
.34138 .58939 m
.32003 .58504 L
s
.37642 .6375 m
.35288 .63336 L
s
.44232 .6796 m
.41623 .67883 L
s
.69597 .51861 m
.67595 .52013 L
s
.40854 .66055 m
.38346 .65782 L
s
.66791 .60135 m
.64541 .61018 L
s
.68322 .56966 m
.66196 .57582 L
s
.50396 .69022 m
.47694 .69362 L
s
.33682 .56657 m
.31569 .563 L
s
.60985 .65989 m
.58439 .66981 L
s
.69365 .5 m
.67333 .5 L
s
.32667 .5 m
.30635 .5 L
s
.33292 .54377 m
.31204 .54119 L
s
.32958 .52143 m
.30898 .52006 L
s
.64907 .6211 m
.62525 .63061 L
s
.6296 .64073 m
.60478 .65061 L
s
.53111 .68508 m
.50396 .69022 L
s
.37019 .61579 m
.34671 .61179 L
s
.58439 .66981 m
.55803 .67825 L
s
.68079 .5552 m
.65918 .5597 L
s
.46926 .67875 m
.44232 .6796 L
s
.66485 .58973 m
.64194 .59695 L
s
.55803 .67825 m
.53111 .68508 L
s
.40158 .64046 m
.37642 .6375 L
s
.43486 .66187 m
.40854 .66055 L
s
.60478 .65061 m
.57875 .65922 L
s
.6784 .53862 m
.65646 .54152 L
s
.64541 .61018 m
.62112 .61818 L
s
.36474 .59303 m
.34138 .58939 L
s
.49674 .67625 m
.46926 .67875 L
s
.62525 .63061 m
.59992 .63907 L
s
.66196 .57582 m
.63866 .58144 L
s
.57875 .65922 m
.55184 .66643 L
s
.67595 .52013 m
.65371 .52151 L
s
.52438 .67213 m
.49674 .67625 L
s
.36001 .56962 m
.33682 .56657 L
s
.46212 .66171 m
.43486 .66187 L
s
.55184 .66643 m
.52438 .67213 L
s
.39536 .6188 m
.37019 .61579 L
s
.67333 .5 m
.65081 .5 L
s
.34919 .5 m
.32667 .5 L
s
.35592 .54601 m
.33292 .54377 L
s
.64194 .59695 m
.61724 .60342 L
s
.35235 .52265 m
.32958 .52143 L
s
.42807 .64218 m
.40158 .64046 L
s
.59992 .63907 m
.57338 .64635 L
s
.65918 .5597 m
.63554 .56376 L
s
.62112 .61818 m
.59533 .62521 L
s
.48997 .66005 m
.46212 .66171 L
s
.38987 .59588 m
.36474 .59303 L
s
.57338 .64635 m
.54597 .65232 L
s
.65646 .54152 m
.63251 .5441 L
s
.63866 .58144 m
.61358 .58642 L
s
.51804 .65691 m
.48997 .66005 L
s
.45556 .6426 m
.42807 .64218 L
s
.54597 .65232 m
.51804 .65691 L
s
.42195 .62075 m
.39536 .6188 L
s
.59533 .62521 m
.56834 .63116 L
s
.38505 .57209 m
.36001 .56962 L
s
.61724 .60342 m
.59103 .60904 L
s
.65371 .52151 m
.62947 .52273 L
s
.38081 .54787 m
.35592 .54601 L
s
.65081 .5 m
.62632 .5 L
s
.37368 .5 m
.34919 .5 L
s
.63554 .56376 m
.61012 .56731 L
s
.37706 .52368 m
.35235 .52265 L
s
.48372 .6417 m
.45556 .6426 L
s
.56834 .63116 m
.54049 .63594 L
s
.41648 .59788 m
.38987 .59588 L
s
.44961 .62161 m
.42195 .62075 L
s
.61358 .58642 m
.58701 .59068 L
s
.51215 .63947 m
.48372 .6417 L
s
.59103 .60904 m
.56363 .61371 L
s
.54049 .63594 m
.51215 .63947 L
s
.63251 .5441 m
.60679 .54632 L
s
.41163 .57393 m
.38505 .57209 L
s
.478 .62133 m
.44961 .62161 L
s
.62947 .52273 m
.6035 .52376 L
s
.56363 .61371 m
.53541 .61735 L
s
.61012 .56731 m
.58323 .57029 L
s
.44425 .59899 m
.41648 .59788 L
s
.40732 .54932 m
.38081 .54787 L
s
.62632 .5 m
.60013 .5 L
s
.39987 .5 m
.37368 .5 L
s
.58701 .59068 m
.55926 .59413 L
s
.40343 .52451 m
.37706 .52368 L
s
.50673 .6199 m
.478 .62133 L
s
.53541 .61735 m
.50673 .6199 L
s
.60679 .54632 m
.57962 .54814 L
s
.43944 .57509 m
.41163 .57393 L
s
.47281 .59917 m
.44425 .59899 L
s
.55926 .59413 m
.53072 .59673 L
s
.58323 .57029 m
.55519 .57264 L
s
.6035 .52376 m
.5761 .52457 L
s
.4351 .55031 m
.40732 .54932 L
s
.50177 .59841 m
.47281 .59917 L
s
.53072 .59673 m
.50177 .59841 L
s
.60013 .5 m
.57255 .5 L
s
.42745 .5 m
.39987 .5 L
s
.43114 .52512 m
.40343 .52451 L
s
.4681 .57555 m
.43944 .57509 L
s
.57962 .54814 m
.55134 .54952 L
s
.55519 .57264 m
.52639 .57431 L
s
.4638 .55084 m
.4351 .55031 L
s
.49722 .57529 m
.4681 .57555 L
s
.5761 .52457 m
.54763 .52517 L
s
.52639 .57431 m
.49722 .57529 L
s
.45982 .5255 m
.43114 .52512 L
s
.45605 .5 m
.42745 .5 L
s
.57255 .5 m
.54395 .5 L
s
.55134 .54952 m
.52234 .55044 L
s
.49302 .55089 m
.4638 .55084 L
s
.52234 .55044 m
.49302 .55089 L
s
.54763 .52517 m
.51849 .52552 L
s
.48908 .52563 m
.45982 .5255 L
s
.54395 .5 m
.51472 .5 L
s
.48528 .5 m
.45605 .5 L
s
.51849 .52552 m
.48908 .52563 L
s
.51472 .5 m
.48528 .5 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002ROolC01m[Ool009eoo`D07a=oo`D07fIoo`00
V7oo1@0O7Goo0`0OHgoo002DOol401l<Ool?01l:Ool201mQOol0099oo`807`Ioo`X07`moo`@07`Qo
o`807emoo`00Sgoo0`0O17oo100O7Goo1@0O1Goo0P0OGGoo002=Ool201l5Ool201l@Ool501lAOol3
01l4Ool201mKOol008Yoo`<07`=oo`@07`Qoo`X07`Eoo`X07`Yoo`807`Aoo`807eUoo`00R7oo0P0O
0Woo100O1goo1@0O6Goo100O27oo0P0O17oo0P0OEgoo0026Ool201l2Ool201l7Ool401lROol501l5
Ool201l4Ool00`0OOomoo`1DOol008Aoo`807`9oo`807`Moo`807`]ooa@07`aoo`<07`Aoo`807`=o
o`807eAoo`00PWoo0P0O0Woo0P0O1Goo100O27oo1@0O57oo100O2goo0P0O17oo0P0O0goo00<07goo
Ool0DGoo0021Ool00`0OOomoo`0201l3Ool401l6Ool601lMOol501l8Ool201l4Ool201l2Ool00`0O
Oomoo`1@Ool007moo`807`03Ool07`0O00=oo`807`Eoo`D07bQoo`@07`Ioo`807`Aoo`0401moogoo
01mAOol007eoo`807`03Ool07`0O009oo`<07`=oo`@07`aooaT07`aoo`@07`Aoo`807`=oo`807`03
Ool07goo04moo`00Ngoo0P0O00=oo`0O01l00Woo0P0O17oo0P0O2goo1@0O6Goo1@0O2goo0P0O17oo
00<07gooOol00Woo00<07goo01l0Cgoo001iOol201l2Ool00`0OOomoo`0201l3Ool301l8Ool501lS
Ool501l8Ool201l3Ool201l3Ool201m?Ool007Qoo`0301moogoo00807`03Ool07`0O00=oo`807`Io
o`D07beoo`<07`Moo`807`=oo`0401moogooOol201m>Ool007Moo`0501moogoo01moo`0201l2Ool3
01l4Ool401l<OolN01l;Ool201l7Ool201l2Ool201l2Ool201m=Ool007Eoo`807`03Ool07`0O0080
7`9oo`807`Eoo`807`Yoo`H07aioo`@07`Uoo`<07`Ioo`0501moogooOol07`02Ool00`0OOomoo`1;
Ool007Aoo`0301moo`0O00<07`04Ool07`0O01l4Ool301l7Ool501lXOol501l7Ool301l4Ool01P0O
Oomoogoo01moo`807daoo`00Lgoo00<07goo01l00P0O00=oo`0O01l01Goo0P0O1Goo1@0O<Woo0`0O
1goo0P0O0goo00@07gooOol07`9oo`0301moogoo04Yoo`00LWoo00D07goo01l07goo00807`Aoo`<0
7`=oo`@07`aooah07a1oo`807`Moo`807`9oo`807`05Ool07gooOol07`1;Ool0075oo`@07`03Ool0
7goo00=oo`807`Aoo`807`]oo`D07aioo`P07`Yoo`807`Moo`0401moogooOol301l00goo01moo`1:
Ool0071oo`<07`03Ool07`0O009oo`<07`9oo`@07`Moo`H07b]oo`807`Yoo`807`Ioo`0901moogoo
Ool07goo01moo`0O04Yoo`00Kgoo0`0O00Aoo`0OOomoo`807`03Ool07`0O00807`Ioo`D07c=oo`@0
7`Qoo`807`Eoo`0601moogooOol07goo0P0OBWoo001^Ool201l00goo01l07`0301l00goo01l07`06
Ool401lAOolN01l=Ool401l6Ool201l4Ool0100OOomoo`0O0Woo0P0OBGoo001]Ool00`0OOol07`03
01l017oo01l07`0O1Woo0P0O2goo2P0O7Woo1@0O37oo0`0O1Goo0P0O0goo0P0O00=oo`0OOol00P0O
BGoo001/Ool00`0OOol07`0201l00goo01l07`05Ool401l8Ool501l]Ool401l;Ool201l5Ool201l3
Ool0100OOol07goo0P0OB7oo001ZOol201l017oo01l07goo0P0O17oo0`0O1Woo1P0O=Woo1@0O27oo
0P0O1Goo00H07gooOomoo`0OOol301m8Ool006Uoo`D07`03Ool07goo00=oo`807`Aoo`D07a5ooah0
7a9oo`<07`Moo`807`Aoo`0401moogoo01l2Ool301m7Ool006Qoo`@07`03Ool07`0O009oo`<07`=o
o`<07`aoo`X07aioo`X07`]oo`807`Moo`807`=oo`0501moogoo01moo`0301m7Ool006Moo`H07`9o
o`807`Aoo`807`Yoo`D07c9oo`@07`Uoo`<07`Ioo`807`9oo`0501moogoo01moo`0201m7Ool006Io
o`D07`04Ool07`0O01l3Ool301l7Ool501lkOol401l8Ool301l5Ool00`0OOomoo`0201l017oo01l0
7`0OAgoo001UOol401l00goo01l07`04Ool201l5Ool501lEOolI01lFOol301l8Ool201l4Ool201l2
Ool00`0OOol07`0201m6Ool006Aoo`<07`03Ool07`0O009oo`@07`=oo`@07a1oo`X07aUoo`X07`mo
o`807`Qoo`0301moogoo00=oo`0301moo`0O009oo`807dIoo`00Hgoo1@0O00Aoo`0O01l07`Eoo`80
7`Yoo`X07beoo`@07`eoo`<07`Ioo`807`Aoo`0401moo`0OOol201m6Ool0069oo`@07`03Ool07`0O
00Aoo`@07`Moo`D07c]oo`D07`]oo`<07`Eoo`807`=oo`807`9oo`807dEoo`00HGoo1P0O0goo0`0O
1Woo1@0O6Woo3`0O77oo100O2Woo0P0O1Goo00@07gooOomoo`807`03Ool07`0O04Eoo`00Ggoo1@0O
17oo0P0O17oo1@0O3goo400O3goo3`0O4Goo100O27oo0P0O17oo00@07gooOomoo`@07dEoo`00GWoo
100O0Woo100O00=oo`0O01l00`0O2goo2@0O;Woo2@0O37oo100O1Woo0P0O0goo00<07gooOol0100O
AGoo001MOol701l2Ool301l;Ool501m0Ool401l<Ool301l5Ool01@0OOomoogoo01l00Woo100OA7oo
001LOol501l3Ool201l9Ool501m9Ool401l;Ool201l4Ool201l2Ool00`0OOomoo`0301m4Ool005]o
o`D07`04Ool07`0O01l6Ool501lDOolX01lFOol401l9Ool201l4Ool01@0OOomoo`0OOol00`0OA7oo
001IOol801l5Ool401l:Ool?01lXOol>01l<Ool401l7Ool201l3Ool00`0OOomoo`0401m4Ool005Qo
o`H07`=oo`D07`Yoo`@07dEoo`D07`]oo`@07`Eoo`807`9oo`0301moogoo00<07dAoo`00EWoo2`0O
1Woo2@0OCWoo200O1goo100O0goo00<07gooOol01@0OA7oo001EOol801l5Ool501lMOolS01lOOol4
01l7Ool201l2Ool201l2Ool401m3Ool005Aoo`P07`9oo`@07`iooa@07b=ooa<07a1oo`<07`Ioo`06
01moogooOol07goo100O@goo001BOol501l00goo01l07`0401l9Ool901m:Ool801l;Ool401l3Ool2
01l2Ool501m3Ool0051oo`/07`Aoo`P07e]oo`P07`Moo`<07`9oo`807`03Ool07`0O00807d=oo`00
Cgoo400OJgoo100O1Woo0P0O0Woo1@0O@goo001=Ool;01l00goo01moo`0=OomB01lDOol601l2Ool7
01m3Ool004aoo`P07`03Ool07goo01407e9ooa407`Uoo`807`9oo`D07d=oo`00BWoo3@0O0Woo00<0
7gooOol0Kgoo2@0O0Woo1`0O@goo0018Ool901l027oo01moo`0OOol07goo01mkOol901m3Ool0049o
oi/07d=oo`00@Woo1@0O00Aoo`0O01moo`<07`0:Ool07goo01moo`0OOol07goo01moOol0100OOol0
7goo0P0O@goo0012Ool401l017oo01l07goo0P0O00=oo`0OOol00P0O00Moo`0OOomoo`0OOol07`1o
Ool00`0OOol07`0301m3Ool0049oo`D07`04Ool07`0OOol201l00goo01moo`0201l2Ool00`0OOol0
7`1oOol701m3Ool0049oo`/07`05Ool07`0OOol07`02Ool00`0OOol07`1hOol701l00goo01l07`04
01m3Ool0049oo`<07`05Ool07goo01moo`0201l00goo01l07`0701m_Ool:01l8Ool601m3Ool0049o
o`<07`04Ool07`0OOol201l2Ool201l01Woo01moogoo01mooa@07dmoo`d07a5oo`H07dAoo`00@Woo
00<07goo01l00`0O00Uoo`0O01moo`0OOol07goo01l00Woo00<07goo01l04gooC`0O77oo200OA7oo
0012Ool201l00goo01l07`0401l02Woo01moo`0OOol07goo01moo`0ONgoo100O0Woo1@0OAGoo0012
Ool301l017oo01l07goo1@0O00Moo`0OOomoo`0OOol07`1fOol501l5Ool601m5Ool004=oo`807`08
Ool07`0OOol07goo01moo`D07`03Ool07goo075oo`D07`Uoo`H07dIoo`00@goo100O0Woo00@07goo
01l07`9oo`0301moo`0O00D07fUoo`H07`]oo`<07`03Ool07`0O00<07dIoo`00@goo1P0O00Qoo`0O
Ool07goo01moo`0O0Woo00@07gooOomoo`D07eeoo`L07`moo`807`=oo`D07dMoo`00@goo100O00Yo
o`0O01l07goo01moo`0OOol07`9oo`0301moogoo00Ioo`h07d5oo`h07a9oo`@07`Aoo`D07dQoo`00
@goo1@0O0Woo100O0Woo00<07goo01l05goo5`0O4Goo6@0O77oo100O1goo1P0OB7oo0013Ool201l0
0goo01l07`02Ool201l01goo01l07goo01moo`0O02iooa407c=oo`807`Uoo`807`03Ool07`0O0080
7dUoo`00@goo0P0O00Yoo`0O01moo`0OOol07goo01moo`@07fioo`@07`Qoo`<07`9oo`@07dYoo`00
A7oo0P0O00Yoo`0O01l07goo01moo`0OOol07`9oo`H07f9oo`L07`Yoo`807`Aoo`D07dYoo`00A7oo
0P0O00Yoo`0OOol07goo01moo`0OOol07`9oo`0301moogoo00=oo`D07eIoo`L07`ioo`<07`Aoo`H0
7d]oo`00A7oo100O00Yoo`0O01l07goo01moo`0OOol07`]oo`L07dQoo`L07a=oo`807`Ioo`0301mo
o`0O00<07daoo`00A7oo0P0O00Ioo`0O01moo`0OOol401l00goo01moo`0AOol701liOol801lGOol3
01l6Ool201l00goo01l07`0301m<Ool004Eoo`@07`06Ool07gooOol07goo100O67oo3`0O6Goo4@0O
6goo100O1Woo0`0O00Aoo`0O01moo`<07deoo`00AGoo1P0O00Qoo`0OOomoo`0OOol07goo0P0O9Goo
6@0O:7oo100O1goo0`0O0Woo0P0O0Woo0`0OCWoo0015Ool401l017oo01l07`0O0Woo00<07goo01l0
0goo100OGGoo1@0O2Goo0P0O17oo00@07gooOomoo`<07dmoo`00AWoo0`0O00=oo`0OOol00P0O00Ao
o`0OOol07`Moo`@07eEoo`@07`aoo`807`Aoo`807`9oo`D07dmoo`00AWoo0`0O00Ioo`0OOol07goo
01l2Ool00`0OOomoo`09Ool301m=Ool501l>Ool201l4Ool201l3Ool00`0OOol07`0201m@Ool004Io
o`D07`03Ool07goo00@07`ioo`D07d1oo`P07a1oo`<07`Eoo`0301moogoo009oo`0301moo`0O0080
7e5oo`00Agoo0P0O00Ioo`0O01l07goo01l2Ool301lAOol701laOol801lEOol301l6Ool201l3Ool2
01l017oo01l07`0ODWoo0017Ool201l01Woo01moo`0OOol07`9oo`0301moogoo00807aIooc407aYo
o`<07`Moo`807`Aoo`0301moo`0O00<07e=oo`00B7oo0`0O00Aoo`0O01l07`9oo`0301moogoo009o
o`<07eYoo`@07`Qoo`807`Eoo`0401moo`0OOol301mCOol004Qoo`<07`03Ool07goo00807`03Ool0
7goo00Ioo`<07e9oo`D07`Yoo`807`Eoo`807`03Ool07goo00<07eAoo`00BGoo0P0O00Aoo`0OOomo
o`<07`Yoo`@07dQoo`H07`eoo`807`Eoo`807`04Ool07`0OOol301mEOol004Uoo`<07`05Ool07goo
01moo`0201l=Ool701lmOol401l@Ool301l5Ool201l2Ool00`0OOol07`0301mFOol004Yoo`@07`05
Ool07goo01moo`0301lAOol701l`Ool601l@Ool401l6Ool201l2Ool201l00goo01moo`0201mGOol0
04Yoo`807`06Ool07`0O01moo`0O17oo0P0O5Woo1`0O6Goo400O4goo0`0O27oo0P0O0goo00<07goo
01l0100OF7oo001:Ool201l00goo01moo`0301l6Ool301lJOolI01lOOol401l8Ool301l3Ool201l0
0goo01moo`0401mHOol004]oo`807`05Ool07`0OOol07`09Ool301m;Ool401l8Ool401l4Ool201l0
17oo01l07goo100OFGoo001;Ool501l017oo01l07`0O2Woo100O@goo100O2Goo0`0O1Goo0`0O0Woo
00<07goo01l0100OFWoo001<Ool401l2Ool0100OOol07`0O37oo1`0O=goo1@0O2goo0P0O1Woo0P0O
0goo0P0O00=oo`0OOol00`0OFgoo001<Ool301l017oo01moo`0O0goo0P0O4Goo1`0O9goo2@0O3Woo
0P0O1Woo0P0O17oo00<07goo01l01@0OG7oo001=Ool601l5Ool201lFOol701lHOol801lDOol301l5
Ool301l4Ool201l00goo01moo`0401mMOol004eoo`@07`9oo`0301moogoo00Aoo`<07aYooaP07aQo
o`@07`Ioo`807`Eoo`807`04Ool07`0OOol401mNOol004ioo`@07`04Ool07`0O01l7Ool301m3Ool4
01l8Ool201l5Ool201l2Ool00`0OOol07`0401mOOol004moo`@07`03Ool07goo00807`Qoo`@07c]o
o`@07`Uoo`<07`Ioo`0301moogoo00807`03Ool07goo00<07f1oo`00D7oo0P0O00=oo`0O01l00goo
0P0O2Woo1`0O;Woo1P0O2goo0P0O1goo0P0O0Woo00<07goo01l01@0OHGoo001AOol201l00goo01l0
7`04Ool201l?Ool701lOOol801l?Ool201l7Ool201l2Ool201l01Goo01moo`0OOol00P0OHWoo001B
Ool01@0OOol07goo01l01Goo0`0O4goo7`0O57oo0`0O1Woo0`0O0Woo0P0O00Ioo`0O01moo`0OOol2
01mSOol0059oo`807`04Ool07goo01l7Ool301loOol401l7Ool201l3Ool201l2Ool00`0OOol07`04
01mTOol005=oo`<07`9oo`807`Qoo`<07cIoo`H07`Qoo`<07`=oo`807`9oo`807`06Ool07goo01mo
o`0OIGoo001DOol301l3Ool201l9Ool301l]Ool601l;Ool301l4Ool201l3Ool01@0OOol07`0OOol0
0`0OIWoo001EOol301l4Ool301l9Ool501lTOol401l=Ool401l5Ool201l3Ool201l00goo01moo`03
01mXOol005Eoo`@07`Ioo`<07`]oo`h07`Qoo`h07`ioo`<07`Ioo`<07`=oo`807`07Ool07`0OOol0
7goo01l0JGoo001FOol501l7Ool201lGOol801lHOol401l7Ool201l4Ool201l017oo01l07goo100O
JWoo001GOol301l00goo01l07`07Ool501l^Ool401l9Ool201l4Ool201l00goo01l07`02Ool301m/
Ool005Qoo`<07`9oo`807`Yoo`H07bAoo`@07`Yoo`<07`Aoo`807`9oo`0301moogoo00<07fioo`00
FGoo0`0O0goo0P0O3Woo1`0O5goo1P0O2Woo100O17oo0`0O0Woo0P0O0Woo0P0OL7oo001JOol401l3
Ool301lBOolG01l<Ool401l5Ool301l3Ool201l2Ool301maOol005]oo`807`03Ool07`0O00Aoo`<0
7bioo`@07`Moo`807`Aoo`807`9oo`<07g=oo`00G7oo0`0O00=oo`0O01l01Goo100O97oo1P0O2Goo
0P0O17oo0P0O0Woo100OM7oo001NOol201l2Ool201l7Ool701lFOol701l<Ool301l4Ool201l2Ool2
01l00goo01moo`1eOol005moo`<07`9oo`@07`YooaH07`moo`@07`Eoo`807`9oo`807`03Ool07`0O
07Moo`00H7oo1@0O0goo1@0O9Goo1@0O1Woo0`0O0Woo0P0O00=oo`0O01l0NGoo001ROol00`0OOomo
o`0301l5Ool301lJOol801l7Ool401l2Ool301l00goo01l07`1kOol006=oo`807`=oo`<07`Eoo``0
7`Moo`L07`aoo`<07`Aoo`807`9oo`807geoo`00I7oo0`0O17oo0P0O3goo1`0O3goo100O1Goo0P0O
0Woo0P0OOgoo001VOol401l3Ool401lLOol501l6Ool301l2Ool201n1Ool006Moo`807`03Ool07`0O
00807`=oo`L07`Moo`h07`Moo`@07`9oo`<07h=oo`00JGoo0`0O0Woo0`0O1goo1`0O47oo1@0O0goo
0`0OQWoo001/Ool201l3Ool401lCOol701l5Ool301n9Ool006ioo`@07`=ooa<07`Qoo`@07haoo`00
LWoo1P0O4goo1@0OT7oo001hOolC01nEOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00001\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {505.875, 276.5}} -> {-0.399192, \
1.20546, 0.00348777, 0.00348777}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[\[Theta]];\)\), "\[IndentingNewLine]", 
    \(\(ComponentFunct[Equ5, {0, R\ \ Cos[\[Phi]], R\ \ Sin[\[Phi]]}, 
        Red];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.591 .47486 m
.59696 .49481 L
s
.58446 .45507 m
.591 .47486 L
s
.57738 .43553 m
.58446 .45507 L
s
.59696 .49481 m
.60231 .51484 L
s
.56978 .41635 m
.57738 .43553 L
s
.60231 .51484 m
.60704 .53485 L
s
.56171 .3976 m
.56978 .41635 L
s
.60704 .53485 m
.61111 .55475 L
s
.55318 .37939 m
.56171 .3976 L
s
.61111 .55475 m
.61449 .57444 L
s
.54424 .36181 m
.55318 .37939 L
s
.61449 .57444 m
.61717 .59383 L
s
.53493 .34494 m
.54424 .36181 L
s
.61717 .59383 m
.61911 .6128 L
s
.52528 .32889 m
.53493 .34494 L
s
.61911 .6128 m
.6203 .63127 L
s
.51535 .31376 m
.52528 .32889 L
s
.6203 .63127 m
.62072 .64913 L
s
.50517 .29963 m
.51535 .31376 L
s
.62072 .64913 m
.62035 .66627 L
s
.49479 .28662 m
.50517 .29963 L
s
.62035 .66627 m
.61916 .68257 L
s
.48427 .27481 m
.49479 .28662 L
s
.61916 .68257 m
.61715 .69793 L
s
.47367 .26432 m
.48427 .27481 L
s
.61715 .69793 m
.61431 .71224 L
s
.46303 .25523 m
.47367 .26432 L
s
.61431 .71224 m
.61062 .72537 L
s
.45244 .24765 m
.46303 .25523 L
s
.61062 .72537 m
.6061 .73721 L
s
.44195 .24167 m
.45244 .24765 L
s
.6061 .73721 m
.60072 .74764 L
s
.43164 .23738 m
.44195 .24167 L
s
.60072 .74764 m
.59452 .75655 L
s
.42159 .23488 m
.43164 .23738 L
s
.59452 .75655 m
.58749 .76382 L
s
.41186 .23423 m
.42159 .23488 L
s
.58749 .76382 m
.57966 .76935 L
s
.40256 .23551 m
.41186 .23423 L
s
.57966 .76935 m
.57107 .77302 L
s
.39376 .23878 m
.40256 .23551 L
s
.57107 .77302 m
.56174 .77475 L
s
.38554 .24409 m
.39376 .23878 L
s
.56174 .77475 m
.55173 .77446 L
s
.378 .25145 m
.38554 .24409 L
s
.55173 .77446 m
.54109 .77207 L
s
.37122 .26089 m
.378 .25145 L
s
.54109 .77207 m
.52989 .76754 L
s
.36529 .2724 m
.37122 .26089 L
s
.52989 .76754 m
.51822 .76082 L
s
.36028 .28593 m
.36529 .2724 L
s
.51822 .76082 m
.50615 .75191 L
s
.35628 .30143 m
.36028 .28593 L
s
.50615 .75191 m
.49379 .74083 L
s
.35334 .31882 m
.35628 .30143 L
s
.49379 .74083 m
.48124 .7276 L
s
.35153 .33799 m
.35334 .31882 L
s
.48124 .7276 m
.46863 .71231 L
s
.35089 .35879 m
.35153 .33799 L
s
.46863 .71231 m
.45606 .69504 L
s
.35146 .38106 m
.35089 .35879 L
s
.45606 .69504 m
.44368 .67592 L
s
.35327 .40459 m
.35146 .38106 L
s
.44368 .67592 m
.4316 .65512 L
s
.3563 .42919 m
.35327 .40459 L
s
.4316 .65512 m
.41996 .63281 L
s
.36055 .45459 m
.3563 .42919 L
s
.41996 .63281 m
.40889 .60921 L
s
.366 .48056 m
.36055 .45459 L
s
.40889 .60921 m
.39851 .58456 L
s
.37259 .50682 m
.366 .48056 L
s
.39851 .58456 m
.38893 .55909 L
s
.38026 .53309 m
.37259 .50682 L
s
.38893 .55909 m
.38026 .53309 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol007=oo`Ml0:Io
o`00LGoo0W`01goo0g`0Xgoo001_Ool2O00<Ool2O02QOol006ioo`03O01oogoo00ioo`9l09moo`00
KGoo00=l07ooOol04Goo00=l07ooOol0W7oo001/Ool00g`0Oomoo`0COol2O02LOol006]oo`03O01o
ogoo01Ioo`03O01oogoo09Uoo`00JWoo00=l07ooOol067oo0W`0VGoo001YOol00g`0Oomoo`0KOol0
0g`0Oomoo`2FOol006Uoo`03O01oogoo01aoo`03O01oogoo09Eoo`00J7oo00=l07ooOol07Woo00=l
07ooOol0U7oo001XOol00g`0Oomoo`0OOol00g`0Oomoo`2COol006Qoo`03O01oogoo021oo`03O01o
ogoo099oo`00Igoo00=l07ooOol08Woo00=l07ooOol0TGoo001WOol00g`0Oomoo`0SOol00g`0Oomo
o`2@Ool006Moo`03O01oogoo02Aoo`03O01oogoo08moo`00Igoo00=l07ooOol09Goo00=l07ooOol0
SWoo001VOol00g`0Oomoo`0VOol00g`0Oomoo`2>Ool006Ioo`03O01oogoo02Moo`03O01oogoo08eo
o`00IWoo00=l07ooOol0:7oo00=l07ooOol0S7oo001VOol00g`0Oomoo`0XOol00g`0Oomoo`2<Ool0
06Ioo`03O01oogoo02Uoo`03O01oogoo08]oo`00IGoo00=l07ooOol0:Woo00=l07ooOol0Rgoo001U
Ool00g`0Oomoo`0[Ool00g`0Oomoo`2:Ool006Eoo`03O01oogoo02aoo`03O01oogoo08Uoo`00IGoo
00=l07ooOol0;7oo00=l07ooOol0RGoo001UOol00g`0Oomoo`0]Ool00g`0Oomoo`28Ool006Aoo`03
O01oogoo02moo`03O01oogoo08Moo`00I7oo00=l07ooOol0<7oo00=l07ooOol0QWoo001TOol00g`0
Oomoo`0`Ool00g`0Oomoo`26Ool006Aoo`03O01oogoo035oo`03O01oogoo08Eoo`00I7oo00=l07oo
Ool0<Woo00=l07ooOol0Q7oo001TOol00g`0Oomoo`0cOol00g`0Oomoo`23Ool006Aoo`03O01oogoo
03=oo`03O01oogoo08=oo`00I7oo00=l07ooOol0=7oo00=l07ooOol0PWoo001TOol00g`0Oomoo`0d
Ool00g`0Oomoo`22Ool006Aoo`03O01oogoo03Eoo`03O01oogoo085oo`00I7oo00=l07ooOol0=Goo
00=l07ooOol0PGoo001TOol00g`0Oomoo`0fOol00g`0Oomoo`20Ool006Aoo`03O01oogoo03Ioo`03
O01oogoo081oo`00I7oo00=l07ooOol0=goo00=l07ooOol0Ogoo001TOol00g`0Oomoo`0gOol00g`0
Oomoo`1oOol006Aoo`03O01oogoo03Moo`03O01oogoo07moo`00I7oo00=l07ooOol0>7oo00=l07oo
Ool0OWoo001TOol00g`0Oomoo`0hOol00g`0Oomoo`1nOol006Aoo`03O01oogoo03Uoo`03O01oogoo
07eoo`00IGoo00=l07ooOol0>7oo00=l07ooOol0OGoo001UOol00g`0Oomoo`0iOol00g`0Oomoo`1l
Ool006Eoo`03O01oogoo03Uoo`03O01oogoo07aoo`00IGoo00=l07ooOol0>Woo00=l07ooOol0Ngoo
001UOol00g`0Oomoo`0jOol00g`0Oomoo`1kOol006Eoo`03O01oogoo03]oo`03O01oogoo07Yoo`00
IGoo00=l07ooOol0>goo00=l07ooOol0NWoo001VOol00g`0Oomoo`0jOol00g`0Oomoo`1jOol006Io
o`03O01oogoo03]oo`03O01oogoo07Uoo`00IWoo00=l07ooOol0>goo00=l07ooOol0NGoo001VOol0
0g`0Oomoo`0lOol00g`0Oomoo`1hOol006Ioo`03O01oogoo03aoo`03O01oogoo07Qoo`00IWoo00=l
07ooOol0?7oo00=l07ooOol0N7oo001VOol00g`0Oomoo`0mOol00g`0Oomoo`1gOol006Moo`03O01o
ogoo03aoo`03O01oogoo07Moo`00Igoo00=l07ooOol0?7oo00=l07ooOol0Mgoo001WOol00g`0Oomo
o`0mOol00g`0Oomoo`1fOol006Moo`03O01oogoo03eoo`03O01oogoo07Ioo`00Igoo00=l07ooOol0
?Goo00=l07ooOol0MWoo001XOol00g`0Oomoo`0mOol00g`0Oomoo`1eOol006Qoo`03O01oogoo03eo
o`03O01oogoo07Eoo`00J7oo00=l07ooOol0?Goo00=l07ooOol0MGoo001XOol00g`0Oomoo`0nOol0
0g`0Oomoo`1dOol006Uoo`03O01oogoo03eoo`03O01oogoo07Aoo`00JGoo00=l07ooOol0?Goo00=l
07ooOol0M7oo001YOol00g`0Oomoo`0nOol00g`0Oomoo`1cOol006Uoo`03O01oogoo03ioo`03O01o
ogoo07=oo`00JGoo00=l07ooOol0?Woo00=l07ooOol0Lgoo001YOol00g`0Oomoo`0oOol00g`0Oomo
o`1bOol006Yoo`03O01oogoo03ioo`03O01oogoo079oo`00JWoo00=l07ooOol0?Woo00=l07ooOol0
LWoo001ZOol00g`0Oomoo`0nOol00g`0Oomoo`1bOol006Yoo`03O01oogoo03moo`03O01oogoo075o
o`00JWoo00=l07ooOol0?goo00=l07ooOol0LGoo001[Ool00g`0Oomoo`0nOol00g`0Oomoo`1aOol0
06]oo`03O01oogoo03ioo`03O01oogoo075oo`00K7oo00=l07ooOol0?Woo00=l07ooOol0L7oo001/
Ool00g`0Oomoo`0nOol00g`0Oomoo`1`Ool006eoo`03O01oogoo03eoo`03O01oogoo071oo`00KGoo
00=l07ooOol0?Woo00=l07ooOol0Kgoo001]Ool00g`0Oomoo`0nOol00g`0Oomoo`1_Ool006eoo`03
O01oogoo03ioo`03O01oogoo06moo`00KWoo00=l07ooOol0?Goo00=l07ooOol0Kgoo001^Ool00g`0
Oomoo`0mOol00g`0Oomoo`1_Ool006ioo`03O01oogoo03ioo`03O01oogoo06ioo`00KWoo00=l07oo
Ool0?Woo00=l07ooOol0KWoo001_Ool00g`0Oomoo`0mOol00g`0Oomoo`1^Ool006moo`03O01oogoo
03eoo`03O01oogoo06ioo`00Kgoo00=l07ooOol0?Goo00=l07ooOol0KWoo001`Ool00g`0Oomoo`0m
Ool00g`0Oomoo`1]Ool0071oo`03O01oogoo03eoo`03O01oogoo06eoo`00LGoo00=l07ooOol0?7oo
00=l07ooOol0KGoo001aOol00g`0Oomoo`0lOol00g`0Oomoo`1]Ool0079oo`03O01oogoo03]oo`03
O01oogoo06eoo`00LWoo00=l07ooOol0>goo00=l07ooOol0KGoo001bOol00g`0Oomoo`0lOol00g`0
Oomoo`1/Ool007=oo`03O01oogoo03]oo`03O01oogoo06aoo`00Lgoo00=l07ooOol0>goo00=l07oo
Ool0K7oo001dOol00g`0Oomoo`0jOol00g`0Oomoo`1/Ool007Aoo`03O01oogoo03Yoo`03O01oogoo
06aoo`00MGoo00=l07ooOol0>Goo00=l07ooOol0K7oo001eOol00g`0Oomoo`0iOol00g`0Oomoo`1/
Ool007Eoo`03O01oogoo03Uoo`03O01oogoo06aoo`00MWoo00=l07ooOol0>7oo00=l07ooOol0K7oo
001fOol00g`0Oomoo`0hOol00g`0Oomoo`1/Ool007Moo`03O01oogoo03Moo`03O01oogoo06aoo`00
Mgoo00=l07ooOol0>7oo00=l07ooOol0Jgoo001hOol00g`0Oomoo`0gOol00g`0Oomoo`1[Ool007Qo
o`03O01oogoo03Moo`03O01oogoo06]oo`00N7oo00=l07ooOol0=goo00=l07ooOol0Jgoo001iOol0
0g`0Oomoo`0fOol00g`0Oomoo`1[Ool007Uoo`03O01oogoo03Ioo`03O01oogoo06]oo`00NWoo00=l
07ooOol0=Goo00=l07ooOol0Jgoo001jOol00g`0Oomoo`0eOol00g`0Oomoo`1[Ool007]oo`03O01o
ogoo03Aoo`03O01oogoo06]oo`00Ngoo00=l07ooOol0=7oo00=l07ooOol0Jgoo001lOol00g`0Oomo
o`0cOol00g`0Oomoo`1[Ool007eoo`03O01oogoo039oo`03O01oogoo06]oo`00OGoo00=l07ooOol0
<Woo00=l07ooOol0Jgoo001nOol00g`0Oomoo`0aOol00g`0Oomoo`1[Ool007moo`03O01oogoo02mo
o`03O01oogoo06aoo`00Ogoo00=l07ooOol0;goo00=l07ooOol0K7oo0020Ool00g`0Oomoo`0^Ool0
0g`0Oomoo`1/Ool0081oo`03O01oogoo02ioo`03O01oogoo06aoo`00PGoo00=l07ooOol0;Goo00=l
07ooOol0K7oo0021Ool00g`0Oomoo`0]Ool00g`0Oomoo`1/Ool0089oo`03O01oogoo02aoo`03O01o
ogoo06aoo`00Pgoo00=l07ooOol0:goo00=l07ooOol0K7oo0024Ool00g`0Oomoo`0ZOol00g`0Oomo
o`1/Ool008Aoo`03O01oogoo02Uoo`03O01oogoo06eoo`00QGoo00=l07ooOol0:7oo00=l07ooOol0
KGoo0026Ool00g`0Oomoo`0WOol00g`0Oomoo`1]Ool008Moo`03O01oogoo02Ioo`03O01oogoo06eo
o`00R7oo00=l07ooOol097oo00=l07ooOol0KWoo0029Ool00g`0Oomoo`0SOol00g`0Oomoo`1^Ool0
08Yoo`03O01oogoo029oo`03O01oogoo06ioo`00Rgoo00=l07ooOol087oo00=l07ooOol0Kgoo002;
Ool00g`0Oomoo`0POol00g`0Oomoo`1_Ool008aoo`03O01oogoo01ioo`03O01oogoo071oo`00SGoo
00=l07ooOol07Goo00=l07ooOol0L7oo002>Ool00g`0Oomoo`0KOol00g`0Oomoo`1aOol008moo`9l
01]oo`03O01oogoo075oo`00TGoo00=l07ooOol05goo00=l07ooOol0LWoo002BOol00g`0Oomoo`0F
Ool00g`0Oomoo`1bOol009=oo`03O01oogoo01Aoo`03O01oogoo07=oo`00U7oo00=l07ooOol04Woo
00=l07ooOol0M7oo002EOol2O00AOol00g`0Oomoo`1eOol009Moo`=l00]oo`=l07Qoo`00VWoo0g`0
1Woo0W`0Ngoo002MOol6O01mOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.62043 .4699 m
.62606 .49405 L
s
.61403 .44595 m
.62043 .4699 L
s
.60689 .42231 m
.61403 .44595 L
s
.62606 .49405 m
.63089 .51827 L
s
.59904 .39909 m
.60689 .42231 L
s
.63089 .51827 m
.6349 .54245 L
s
.59052 .37641 m
.59904 .39909 L
s
.6349 .54245 m
.63806 .56647 L
s
.58135 .35437 m
.59052 .37641 L
s
.63806 .56647 m
.64035 .59023 L
s
.57159 .33311 m
.58135 .35437 L
s
.64035 .59023 m
.64174 .61358 L
s
.56127 .31273 m
.57159 .33311 L
s
.64174 .61358 m
.64223 .63642 L
s
.55043 .29335 m
.56127 .31273 L
s
.64223 .63642 m
.64179 .65862 L
s
.53912 .27509 m
.55043 .29335 L
s
.64179 .65862 m
.64041 .68004 L
s
.5274 .25808 m
.53912 .27509 L
s
.64041 .68004 m
.63807 .70057 L
s
.51532 .24243 m
.5274 .25808 L
s
.63807 .70057 m
.63478 .72006 L
s
.50293 .22827 m
.51532 .24243 L
s
.63478 .72006 m
.63052 .73838 L
s
.49032 .21571 m
.50293 .22827 L
s
.63052 .73838 m
.6253 .7554 L
s
.47753 .20488 m
.49032 .21571 L
s
.6253 .7554 m
.61912 .77097 L
s
.46466 .19588 m
.47753 .20488 L
s
.61912 .77097 m
.612 .78497 L
s
.45177 .18884 m
.46466 .19588 L
s
.612 .78497 m
.60394 .79724 L
s
.43896 .18386 m
.45177 .18884 L
s
.60394 .79724 m
.59498 .80766 L
s
.42631 .18104 m
.43896 .18386 L
s
.59498 .80766 m
.58515 .8161 L
s
.41392 .18047 m
.42631 .18104 L
s
.58515 .8161 m
.57449 .82244 L
s
.40189 .18222 m
.41392 .18047 L
s
.57449 .82244 m
.56305 .82655 L
s
.39033 .18637 m
.40189 .18222 L
s
.56305 .82655 m
.55089 .82833 L
s
.37932 .19296 m
.39033 .18637 L
s
.55089 .82833 m
.53808 .82769 L
s
.369 .20201 m
.37932 .19296 L
s
.53808 .82769 m
.52471 .82457 L
s
.35945 .21353 m
.369 .20201 L
s
.52471 .82457 m
.51086 .81889 L
s
.35079 .2275 m
.35945 .21353 L
s
.51086 .81889 m
.49665 .81064 L
s
.34313 .24387 m
.35079 .2275 L
s
.49665 .81064 m
.48217 .7998 L
s
.33655 .26257 m
.34313 .24387 L
s
.48217 .7998 m
.46757 .78639 L
s
.33115 .28348 m
.33655 .26257 L
s
.46757 .78639 m
.45295 .77048 L
s
.32701 .30648 m
.33115 .28348 L
s
.45295 .77048 m
.43848 .75213 L
s
.3242 .33138 m
.32701 .30648 L
s
.43848 .75213 m
.42427 .73148 L
s
.32278 .35799 m
.3242 .33138 L
s
.42427 .73148 m
.41049 .70867 L
s
.32279 .38608 m
.32278 .35799 L
s
.41049 .70867 m
.39728 .68388 L
s
.32425 .41538 m
.32279 .38608 L
s
.39728 .68388 m
.38477 .65734 L
s
.32716 .44561 m
.32425 .41538 L
s
.38477 .65734 m
.3731 .62929 L
s
.33152 .47649 m
.32716 .44561 L
s
.3731 .62929 m
.36241 .6 L
s
.33729 .50768 m
.33152 .47649 L
s
.36241 .6 m
.35281 .56976 L
s
.34441 .53888 m
.33729 .50768 L
s
.35281 .56976 m
.34441 .53888 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001eOol7O02TOol0079oo`=l
00Moo`9l0:9oo`00L7oo0W`037oo0W`0X7oo001^Ool2O00@Ool2O02NOol006aoo`9l01Aoo`9l09ao
o`00JWoo0W`067oo0W`0VWoo001YOol00g`0Oomoo`0JOol2O02HOol006Qoo`03O01oogoo01eoo`9l
09Ioo`00J7oo00=l07ooOol07goo00=l07ooOol0Tgoo001WOol00g`0Oomoo`0QOol00g`0Oomoo`2B
Ool006Moo`03O01oogoo029oo`03O01oogoo095oo`00IWoo00=l07ooOol097oo00=l07ooOol0T7oo
001UOol00g`0Oomoo`0VOol00g`0Oomoo`2?Ool006Eoo`03O01oogoo02Moo`03O01oogoo08ioo`00
I7oo00=l07ooOol0:Goo00=l07ooOol0SGoo001SOol00g`0Oomoo`0[Ool00g`0Oomoo`2<Ool006=o
o`03O01oogoo02]oo`03O01oogoo08aoo`00HWoo00=l07ooOol0;Goo00=l07ooOol0Rgoo001ROol0
0g`0Oomoo`0^Ool00g`0Oomoo`2:Ool0069oo`03O01oogoo02moo`03O01oogoo08Uoo`00HGoo00=l
07ooOol0<Goo00=l07ooOol0R7oo001QOol00g`0Oomoo`0aOol00g`0Oomoo`28Ool0065oo`03O01o
ogoo039oo`03O01oogoo08Moo`00H7oo00=l07ooOol0=7oo00=l07ooOol0QWoo001POol00g`0Oomo
o`0eOol00g`0Oomoo`25Ool0061oo`03O01oogoo03Eoo`03O01oogoo08Eoo`00H7oo00=l07ooOol0
=Woo00=l07ooOol0Q7oo001OOol00g`0Oomoo`0hOol00g`0Oomoo`23Ool005moo`03O01oogoo03Qo
o`03O01oogoo08=oo`00Ggoo00=l07ooOol0>Goo00=l07ooOol0PWoo001OOol00g`0Oomoo`0iOol0
0g`0Oomoo`22Ool005moo`03O01oogoo03Yoo`03O01oogoo085oo`00GWoo00=l07ooOol0>goo00=l
07ooOol0PGoo001NOol00g`0Oomoo`0lOol00g`0Oomoo`20Ool005ioo`03O01oogoo03eoo`03O01o
ogoo07moo`00GGoo00=l07ooOol0?goo00=l07ooOol0OWoo001MOol00g`0Oomoo`0oOol00g`0Oomo
o`1nOol005eoo`03O01oogoo041oo`03O01oogoo07eoo`00GGoo00=l07ooOol0@Goo00=l07ooOol0
O7oo001MOol00g`0Oomoo`11Ool00g`0Oomoo`1lOol005eoo`03O01oogoo049oo`03O01oogoo07]o
o`00GGoo00=l07ooOol0@Woo00=l07ooOol0Ngoo001MOol00g`0Oomoo`13Ool00g`0Oomoo`1jOol0
05eoo`03O01oogoo04=oo`03O01oogoo07Yoo`00GGoo00=l07ooOol0A7oo00=l07ooOol0NGoo001M
Ool00g`0Oomoo`14Ool00g`0Oomoo`1iOol005eoo`03O01oogoo04Eoo`03O01oogoo07Qoo`00GGoo
00=l07ooOol0AGoo00=l07ooOol0N7oo001LOol00g`0Oomoo`16Ool00g`0Oomoo`1hOol005aoo`03
O01oogoo04Moo`03O01oogoo07Moo`00G7oo00=l07ooOol0Agoo00=l07ooOol0Mgoo001LOol00g`0
Oomoo`17Ool00g`0Oomoo`1gOol005aoo`03O01oogoo04Qoo`03O01oogoo07Ioo`00G7oo00=l07oo
Ool0B7oo00=l07ooOol0MWoo001LOol00g`0Oomoo`19Ool00g`0Oomoo`1eOol005aoo`03O01oogoo
04Uoo`03O01oogoo07Eoo`00G7oo00=l07ooOol0BWoo00=l07ooOol0M7oo001LOol00g`0Oomoo`1:
Ool00g`0Oomoo`1dOol005aoo`03O01oogoo04Yoo`03O01oogoo07Aoo`00G7oo00=l07ooOol0Bgoo
00=l07ooOol0Lgoo001LOol00g`0Oomoo`1;Ool00g`0Oomoo`1cOol005aoo`03O01oogoo04]oo`03
O01oogoo07=oo`00G7oo00=l07ooOol0C7oo00=l07ooOol0LWoo001LOol00g`0Oomoo`1<Ool00g`0
Oomoo`1bOol005eoo`03O01oogoo04]oo`03O01oogoo079oo`00GGoo00=l07ooOol0C7oo00=l07oo
Ool0LGoo001MOol00g`0Oomoo`1<Ool00g`0Oomoo`1aOol005eoo`03O01oogoo04eoo`03O01oogoo
071oo`00GGoo00=l07ooOol0CGoo00=l07ooOol0L7oo001MOol00g`0Oomoo`1>Ool00g`0Oomoo`1_
Ool005eoo`03O01oogoo04ioo`03O01oogoo06moo`00GGoo00=l07ooOol0CWoo00=l07ooOol0Kgoo
001MOol00g`0Oomoo`1?Ool00g`0Oomoo`1^Ool005eoo`03O01oogoo04moo`03O01oogoo06ioo`00
GGoo00=l07ooOol0Cgoo00=l07ooOol0KWoo001MOol00g`0Oomoo`1@Ool00g`0Oomoo`1]Ool005eo
o`03O01oogoo051oo`03O01oogoo06eoo`00GGoo00=l07ooOol0D7oo00=l07ooOol0KGoo001MOol0
0g`0Oomoo`1AOol00g`0Oomoo`1/Ool005ioo`03O01oogoo051oo`03O01oogoo06aoo`00GWoo00=l
07ooOol0D7oo00=l07ooOol0K7oo001NOol00g`0Oomoo`1@Ool00g`0Oomoo`1/Ool005ioo`03O01o
ogoo055oo`03O01oogoo06]oo`00Ggoo00=l07ooOol0D7oo00=l07ooOol0Jgoo001OOol00g`0Oomo
o`1@Ool00g`0Oomoo`1[Ool005moo`03O01oogoo051oo`03O01oogoo06]oo`00Ggoo00=l07ooOol0
D7oo00=l07ooOol0Jgoo001OOol00g`0Oomoo`1AOol00g`0Oomoo`1ZOol005moo`03O01oogoo055o
o`03O01oogoo06Yoo`00Ggoo00=l07ooOol0DGoo00=l07ooOol0JWoo001POol00g`0Oomoo`1@Ool0
0g`0Oomoo`1ZOol0061oo`03O01oogoo051oo`03O01oogoo06Yoo`00H7oo00=l07ooOol0DGoo00=l
07ooOol0JGoo001POol00g`0Oomoo`1AOol00g`0Oomoo`1YOol0061oo`03O01oogoo055oo`03O01o
ogoo06Uoo`00H7oo00=l07ooOol0DGoo00=l07ooOol0JGoo001POol00g`0Oomoo`1BOol00g`0Oomo
o`1XOol0065oo`03O01oogoo055oo`03O01oogoo06Qoo`00HGoo00=l07ooOol0DGoo00=l07ooOol0
J7oo001QOol00g`0Oomoo`1AOol00g`0Oomoo`1XOol0065oo`03O01oogoo055oo`03O01oogoo06Qo
o`00HWoo00=l07ooOol0DGoo00=l07ooOol0Igoo001ROol00g`0Oomoo`1AOol00g`0Oomoo`1WOol0
069oo`03O01oogoo055oo`03O01oogoo06Moo`00HWoo00=l07ooOol0DGoo00=l07ooOol0Igoo001S
Ool00g`0Oomoo`1@Ool00g`0Oomoo`1WOol006=oo`03O01oogoo051oo`03O01oogoo06Moo`00Hgoo
00=l07ooOol0D7oo00=l07ooOol0Igoo001TOol00g`0Oomoo`1@Ool00g`0Oomoo`1VOol006Aoo`03
O01oogoo051oo`03O01oogoo06Ioo`00I7oo00=l07ooOol0D7oo00=l07ooOol0IWoo001UOol00g`0
Oomoo`1?Ool00g`0Oomoo`1VOol006Eoo`03O01oogoo04moo`03O01oogoo06Ioo`00IGoo00=l07oo
Ool0Cgoo00=l07ooOol0IWoo001VOol00g`0Oomoo`1>Ool00g`0Oomoo`1VOol006Ioo`03O01oogoo
04ioo`03O01oogoo06Ioo`00IWoo00=l07ooOol0CWoo00=l07ooOol0IWoo001WOol00g`0Oomoo`1=
Ool00g`0Oomoo`1VOol006Moo`03O01oogoo04eoo`03O01oogoo06Ioo`00Igoo00=l07ooOol0CGoo
00=l07ooOol0IWoo001XOol00g`0Oomoo`1<Ool00g`0Oomoo`1VOol006Qoo`03O01oogoo04aoo`03
O01oogoo06Ioo`00J7oo00=l07ooOol0CGoo00=l07ooOol0IGoo001YOol00g`0Oomoo`1<Ool00g`0
Oomoo`1UOol006Uoo`03O01oogoo04aoo`03O01oogoo06Eoo`00JGoo00=l07ooOol0C7oo00=l07oo
Ool0IGoo001ZOol00g`0Oomoo`1;Ool00g`0Oomoo`1UOol006Yoo`03O01oogoo04]oo`03O01oogoo
06Eoo`00Jgoo00=l07ooOol0BWoo00=l07ooOol0IGoo001[Ool00g`0Oomoo`1:Ool00g`0Oomoo`1U
Ool006]oo`03O01oogoo04Yoo`03O01oogoo06Eoo`00K7oo00=l07ooOol0BGoo00=l07ooOol0IGoo
001/Ool00g`0Oomoo`19Ool00g`0Oomoo`1UOol006aoo`03O01oogoo04Uoo`03O01oogoo06Eoo`00
KGoo00=l07ooOol0B7oo00=l07ooOol0IGoo001]Ool00g`0Oomoo`18Ool00g`0Oomoo`1UOol006io
o`03O01oogoo04Moo`03O01oogoo06Eoo`00KWoo00=l07ooOol0Agoo00=l07ooOol0IGoo001^Ool0
0g`0Oomoo`17Ool00g`0Oomoo`1UOol006moo`03O01oogoo04Ioo`03O01oogoo06Eoo`00Kgoo00=l
07ooOol0AWoo00=l07ooOol0IGoo001`Ool00g`0Oomoo`14Ool00g`0Oomoo`1VOol0071oo`03O01o
ogoo04Aoo`03O01oogoo06Ioo`00LGoo00=l07ooOol0@goo00=l07ooOol0IWoo001aOol00g`0Oomo
o`13Ool00g`0Oomoo`1VOol0079oo`03O01oogoo049oo`03O01oogoo06Ioo`00LWoo00=l07ooOol0
@Woo00=l07ooOol0IWoo001cOol00g`0Oomoo`11Ool00g`0Oomoo`1VOol007=oo`03O01oogoo045o
o`03O01oogoo06Ioo`00M7oo00=l07ooOol0@7oo00=l07ooOol0IWoo001dOol00g`0Oomoo`10Ool0
0g`0Oomoo`1VOol007Eoo`03O01oogoo03moo`03O01oogoo06Ioo`00MGoo00=l07ooOol0?goo00=l
07ooOol0IWoo001fOol00g`0Oomoo`0mOol00g`0Oomoo`1WOol007Ioo`03O01oogoo03eoo`03O01o
ogoo06Moo`00Mgoo00=l07ooOol0?7oo00=l07ooOol0Igoo001hOol00g`0Oomoo`0kOol00g`0Oomo
o`1WOol007Qoo`03O01oogoo03Yoo`03O01oogoo06Qoo`00NGoo00=l07ooOol0>Goo00=l07ooOol0
J7oo001jOol00g`0Oomoo`0gOol00g`0Oomoo`1YOol007Yoo`03O01oogoo03Moo`03O01oogoo06Uo
o`00Ngoo00=l07ooOol0=Woo00=l07ooOol0JGoo001lOol00g`0Oomoo`0eOol00g`0Oomoo`1YOol0
07aoo`03O01oogoo03Aoo`03O01oogoo06Yoo`00OGoo00=l07ooOol0<goo00=l07ooOol0JWoo001n
Ool00g`0Oomoo`0bOol00g`0Oomoo`1ZOol007ioo`03O01oogoo039oo`03O01oogoo06Yoo`00Ogoo
00=l07ooOol0<7oo00=l07ooOol0Jgoo0020Ool00g`0Oomoo`0_Ool00g`0Oomoo`1[Ool0081oo`03
O01oogoo02ioo`03O01oogoo06aoo`00PGoo00=l07ooOol0;Goo00=l07ooOol0K7oo0022Ool00g`0
Oomoo`0[Ool00g`0Oomoo`1]Ool008=oo`9l02]oo`03O01oogoo06eoo`00QGoo00=l07ooOol09goo
00=l07ooOol0KWoo0026Ool00g`0Oomoo`0VOol00g`0Oomoo`1^Ool008Moo`03O01oogoo02Aoo`03
O01oogoo06moo`00R7oo00=l07ooOol08goo00=l07ooOol0Kgoo0029Ool00g`0Oomoo`0QOol00g`0
Oomoo`1`Ool008Yoo`03O01oogoo01moo`03O01oogoo075oo`00Rgoo00=l07ooOol07Goo00=l07oo
Ool0LWoo002<Ool2O00LOol00g`0Oomoo`1cOol008ioo`03O01oogoo01Qoo`03O01oogoo07Aoo`00
Sgoo00=l07ooOol05Woo00=l07ooOol0MGoo002@Ool2O00EOol00g`0Oomoo`1fOol0099oo`9l015o
o`9l07Uoo`00U7oo17`02goo0W`0Ngoo002HOol;O01mOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.63131 .47081 m
.63541 .49532 L
s
.62638 .44648 m
.63131 .47081 L
s
.63541 .49532 m
.63863 .51989 L
s
.62063 .42244 m
.62638 .44648 L
s
.63863 .51989 m
.64098 .5444 L
s
.61407 .39882 m
.62063 .42244 L
s
.64098 .5444 m
.64243 .56874 L
s
.60675 .37573 m
.61407 .39882 L
s
.64243 .56874 m
.64297 .59277 L
s
.59869 .35328 m
.60675 .37573 L
s
.64297 .59277 m
.64258 .61638 L
s
.58992 .33161 m
.59869 .35328 L
s
.64258 .61638 m
.64126 .63945 L
s
.58048 .31082 m
.58992 .33161 L
s
.64126 .63945 m
.639 .66184 L
s
.5704 .29105 m
.58048 .31082 L
s
.639 .66184 m
.6358 .68344 L
s
.55973 .27241 m
.5704 .29105 L
s
.6358 .68344 m
.63165 .7041 L
s
.54852 .25503 m
.55973 .27241 L
s
.63165 .7041 m
.62656 .72369 L
s
.5368 .23904 m
.54852 .25503 L
s
.62656 .72369 m
.62054 .74208 L
s
.52465 .22455 m
.5368 .23904 L
s
.62054 .74208 m
.61359 .75914 L
s
.51212 .21169 m
.52465 .22455 L
s
.61359 .75914 m
.60574 .77472 L
s
.49928 .20059 m
.51212 .21169 L
s
.60574 .77472 m
.59701 .78869 L
s
.48619 .19136 m
.49928 .20059 L
s
.59701 .78869 m
.58743 .80091 L
s
.47294 .18412 m
.48619 .19136 L
s
.58743 .80091 m
.57704 .81124 L
s
.45962 .17897 m
.47294 .18412 L
s
.57704 .81124 m
.56587 .81957 L
s
.4463 .17603 m
.45962 .17897 L
s
.56587 .81957 m
.554 .82577 L
s
.43308 .17537 m
.4463 .17603 L
s
.554 .82577 m
.54148 .82972 L
s
.42008 .17709 m
.43308 .17537 L
s
.54148 .82972 m
.52838 .83132 L
s
.40738 .18123 m
.42008 .17709 L
s
.52838 .83132 m
.51478 .83048 L
s
.39511 .18785 m
.40738 .18123 L
s
.51478 .83048 m
.50079 .82714 L
s
.38337 .19698 m
.39511 .18785 L
s
.50079 .82714 m
.48649 .82123 L
s
.37228 .20862 m
.38337 .19698 L
s
.48649 .82123 m
.47201 .81274 L
s
.36195 .22275 m
.37228 .20862 L
s
.47201 .81274 m
.45746 .80164 L
s
.3525 .2393 m
.36195 .22275 L
s
.45746 .80164 m
.44297 .78797 L
s
.34404 .25822 m
.3525 .2393 L
s
.44297 .78797 m
.42867 .77179 L
s
.33667 .27938 m
.34404 .25822 L
s
.42867 .77179 m
.4147 .75317 L
s
.33049 .30264 m
.33667 .27938 L
s
.4147 .75317 m
.40121 .73223 L
s
.32559 .32782 m
.33049 .30264 L
s
.40121 .73223 m
.38832 .70913 L
s
.32203 .35473 m
.32559 .32782 L
s
.38832 .70913 m
.37619 .68406 L
s
.31989 .38312 m
.32203 .35473 L
s
.37619 .68406 m
.36495 .65722 L
s
.31919 .41274 m
.31989 .38312 L
s
.36495 .65722 m
.35471 .62887 L
s
.31997 .4433 m
.31919 .41274 L
s
.35471 .62887 m
.3456 .59927 L
s
.32224 .47449 m
.31997 .4433 L
s
.3456 .59927 m
.33772 .56872 L
s
.32598 .50601 m
.32224 .47449 L
s
.33772 .56872 m
.33116 .53753 L
s
.33116 .53753 m
.32598 .50601 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.64306 .49749 m
.64461 .5223 L
s
.64058 .47272 m
.64306 .49749 L
s
.6372 .4481 m
.64058 .47272 L
s
.64461 .5223 m
.64525 .54703 L
s
.63293 .42375 m
.6372 .4481 L
s
.64525 .54703 m
.64494 .57154 L
s
.62779 .3998 m
.63293 .42375 L
s
.64494 .57154 m
.6437 .59573 L
s
.62179 .37636 m
.62779 .3998 L
s
.6437 .59573 m
.64152 .61946 L
s
.61496 .35356 m
.62179 .37636 L
s
.64152 .61946 m
.6384 .64261 L
s
.60732 .33152 m
.61496 .35356 L
s
.6384 .64261 m
.63433 .66506 L
s
.5989 .31037 m
.60732 .33152 L
s
.63433 .66506 m
.62934 .68668 L
s
.58973 .29022 m
.5989 .31037 L
s
.62934 .68668 m
.62342 .70733 L
s
.57984 .27121 m
.58973 .29022 L
s
.62342 .70733 m
.6166 .72688 L
s
.56929 .25347 m
.57984 .27121 L
s
.6166 .72688 m
.60889 .7452 L
s
.55811 .23711 m
.56929 .25347 L
s
.60889 .7452 m
.60031 .76215 L
s
.54634 .22228 m
.55811 .23711 L
s
.60031 .76215 m
.5909 .77759 L
s
.53406 .20909 m
.54634 .22228 L
s
.5909 .77759 m
.58068 .7914 L
s
.52132 .19768 m
.53406 .20909 L
s
.58068 .7914 m
.56971 .80343 L
s
.50818 .18816 m
.52132 .19768 L
s
.56971 .80343 m
.55803 .81357 L
s
.49473 .18065 m
.50818 .18816 L
s
.55803 .81357 m
.5457 .82167 L
s
.48104 .17527 m
.49473 .18065 L
s
.5457 .82167 m
.53278 .82762 L
s
.4672 .17212 m
.48104 .17527 L
s
.53278 .82762 m
.51935 .83132 L
s
.4533 .17129 m
.4672 .17212 L
s
.51935 .83132 m
.50549 .83266 L
s
.43946 .17287 m
.4533 .17129 L
s
.50549 .83266 m
.4913 .83155 L
s
.42577 .1769 m
.43946 .17287 L
s
.4913 .83155 m
.47688 .82793 L
s
.41236 .18346 m
.42577 .1769 L
s
.47688 .82793 m
.46233 .82175 L
s
.39933 .19255 m
.41236 .18346 L
s
.46233 .82175 m
.44777 .81297 L
s
.3868 .20418 m
.39933 .19255 L
s
.44777 .81297 m
.43334 .8016 L
s
.37491 .21833 m
.3868 .20418 L
s
.43334 .8016 m
.41915 .78767 L
s
.36378 .23495 m
.37491 .21833 L
s
.41915 .78767 m
.40535 .77122 L
s
.35352 .25394 m
.36378 .23495 L
s
.40535 .77122 m
.39207 .75235 L
s
.34425 .27521 m
.35352 .25394 L
s
.39207 .75235 m
.37944 .73117 L
s
.33609 .2986 m
.34425 .27521 L
s
.37944 .73117 m
.36762 .70783 L
s
.32914 .32393 m
.33609 .2986 L
s
.36762 .70783 m
.35671 .68253 L
s
.32348 .35099 m
.32914 .32393 L
s
.35671 .68253 m
.34686 .65547 L
s
.3192 .37956 m
.32348 .35099 L
s
.34686 .65547 m
.33817 .62689 L
s
.31636 .40936 m
.3192 .37956 L
s
.33817 .62689 m
.33074 .59709 L
s
.315 .4401 m
.31636 .40936 L
s
.33074 .59709 m
.32467 .56633 L
s
.31516 .47149 m
.315 .4401 L
s
.32467 .56633 m
.32001 .53493 L
s
.31683 .50321 m
.31516 .47149 L
s
.32001 .53493 m
.31683 .50321 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.6489 .50034 m
.64874 .52526 L
s
.6481 .47543 m
.6489 .50034 L
s
.64635 .45064 m
.6481 .47543 L
s
.64874 .52526 m
.64762 .55006 L
s
.64365 .4261 m
.64635 .45064 L
s
.64762 .55006 m
.64555 .57461 L
s
.64001 .40192 m
.64365 .4261 L
s
.64555 .57461 m
.64253 .5988 L
s
.63545 .37823 m
.64001 .40192 L
s
.64253 .5988 m
.63856 .62251 L
s
.62996 .35516 m
.63545 .37823 L
s
.63856 .62251 m
.63365 .6456 L
s
.62358 .33283 m
.62996 .35516 L
s
.63365 .6456 m
.62783 .66795 L
s
.61631 .31137 m
.62358 .33283 L
s
.62783 .66795 m
.6211 .68944 L
s
.60819 .2909 m
.61631 .31137 L
s
.6211 .68944 m
.61349 .70993 L
s
.59925 .27156 m
.60819 .2909 L
s
.61349 .70993 m
.60502 .72929 L
s
.58951 .25348 m
.59925 .27156 L
s
.60502 .72929 m
.59572 .74739 L
s
.57901 .23679 m
.58951 .25348 L
s
.59572 .74739 m
.58562 .7641 L
s
.5678 .22162 m
.57901 .23679 L
s
.58562 .7641 m
.57477 .77928 L
s
.55593 .20809 m
.5678 .22162 L
s
.57477 .77928 m
.56321 .79281 L
s
.54345 .19635 m
.55593 .20809 L
s
.56321 .79281 m
.551 .80454 L
s
.53043 .18652 m
.54345 .19635 L
s
.551 .80454 m
.53819 .81436 L
s
.51693 .17871 m
.53043 .18652 L
s
.53819 .81436 m
.52485 .82215 L
s
.50304 .17304 m
.51693 .17871 L
s
.52485 .82215 m
.51107 .82777 L
s
.48884 .16962 m
.50304 .17304 L
s
.51107 .82777 m
.49692 .83114 L
s
.47443 .16855 m
.48884 .16962 L
s
.49692 .83114 m
.4825 .83216 L
s
.4599 .1699 m
.47443 .16855 L
s
.4825 .83216 m
.4679 .83073 L
s
.44537 .17374 m
.4599 .1699 L
s
.4679 .83073 m
.45324 .8268 L
s
.43095 .18012 m
.44537 .17374 L
s
.45324 .8268 m
.43863 .82033 L
s
.41676 .18907 m
.43095 .18012 L
s
.43863 .82033 m
.42419 .81127 L
s
.40293 .20058 m
.41676 .18907 L
s
.42419 .81127 m
.41005 .79964 L
s
.38959 .21463 m
.40293 .20058 L
s
.41005 .79964 m
.39635 .78547 L
s
.37688 .23118 m
.38959 .21463 L
s
.39635 .78547 m
.38322 .7688 L
s
.36491 .25012 m
.37688 .23118 L
s
.38322 .7688 m
.37079 .74973 L
s
.35384 .27136 m
.36491 .25012 L
s
.37079 .74973 m
.35919 .72836 L
s
.34377 .29473 m
.35384 .27136 L
s
.35919 .72836 m
.34855 .70487 L
s
.33482 .32006 m
.34377 .29473 L
s
.34855 .70487 m
.33901 .67942 L
s
.32712 .34714 m
.33482 .32006 L
s
.33901 .67942 m
.33066 .65224 L
s
.32074 .37573 m
.32712 .34714 L
s
.33066 .65224 m
.32361 .62356 L
s
.31578 .40556 m
.32074 .37573 L
s
.32361 .62356 m
.31795 .59366 L
s
.31229 .43635 m
.31578 .40556 L
s
.31795 .59366 m
.31375 .56282 L
s
.31032 .46779 m
.31229 .43635 L
s
.31375 .56282 m
.31106 .53134 L
s
.30991 .49956 m
.31032 .46779 L
s
.31106 .53134 m
.30991 .49956 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.65286 .50362 m
.65095 .52849 L
s
.65378 .47871 m
.65286 .50362 L
s
.65095 .52849 m
.64808 .55321 L
s
.65371 .4539 m
.65378 .47871 L
s
.64808 .55321 m
.64424 .57765 L
s
.65265 .42929 m
.65371 .4539 L
s
.64424 .57765 m
.63945 .60169 L
s
.6506 .40501 m
.65265 .42929 L
s
.63945 .60169 m
.63373 .62521 L
s
.64755 .3812 m
.6506 .40501 L
s
.63373 .62521 m
.62709 .64809 L
s
.64352 .35797 m
.64755 .3812 L
s
.62709 .64809 m
.61957 .67019 L
s
.6385 .33545 m
.64352 .35797 L
s
.61957 .67019 m
.61119 .6914 L
s
.63252 .31378 m
.6385 .33545 L
s
.61119 .6914 m
.60197 .71159 L
s
.62559 .29307 m
.63252 .31378 L
s
.60197 .71159 m
.59196 .73062 L
s
.61772 .27348 m
.62559 .29307 L
s
.59196 .73062 m
.58119 .74837 L
s
.60894 .25512 m
.61772 .27348 L
s
.58119 .74837 m
.56971 .76471 L
s
.59929 .23814 m
.60894 .25512 L
s
.56971 .76471 m
.55756 .77952 L
s
.58879 .22266 m
.59929 .23814 L
s
.55756 .77952 m
.54481 .79265 L
s
.5775 .20883 m
.58879 .22266 L
s
.54481 .79265 m
.53152 .80399 L
s
.56545 .19677 m
.5775 .20883 L
s
.53152 .80399 m
.51776 .81342 L
s
.55271 .18662 m
.56545 .19677 L
s
.51776 .81342 m
.5036 .82081 L
s
.53935 .1785 m
.55271 .18662 L
s
.5036 .82081 m
.48913 .82605 L
s
.52543 .17252 m
.53935 .1785 L
s
.48913 .82605 m
.47445 .82905 L
s
.51104 .1688 m
.52543 .17252 L
s
.47445 .82905 m
.45965 .82971 L
s
.49627 .16743 m
.51104 .1688 L
s
.45965 .82971 m
.44484 .82795 L
s
.48122 .16849 m
.49627 .16743 L
s
.44484 .82795 m
.43013 .82371 L
s
.466 .17207 m
.48122 .16849 L
s
.43013 .82371 m
.41564 .81695 L
s
.45072 .17819 m
.466 .17207 L
s
.41564 .81695 m
.4015 .80765 L
s
.43552 .18689 m
.45072 .17819 L
s
.4015 .80765 m
.38785 .7958 L
s
.42052 .19818 m
.43552 .18689 L
s
.38785 .7958 m
.3748 .78143 L
s
.40587 .21203 m
.42052 .19818 L
s
.3748 .78143 m
.36249 .76461 L
s
.39169 .22837 m
.40587 .21203 L
s
.36249 .76461 m
.35105 .74542 L
s
.37814 .24714 m
.39169 .22837 L
s
.35105 .74542 m
.34062 .72397 L
s
.36535 .2682 m
.37814 .24714 L
s
.34062 .72397 m
.3313 .70042 L
s
.35346 .29142 m
.36535 .2682 L
s
.3313 .70042 m
.32322 .67495 L
s
.3426 .3166 m
.35346 .29142 L
s
.32322 .67495 m
.31647 .64777 L
s
.33291 .34355 m
.3426 .3166 L
s
.31647 .64777 m
.31115 .61911 L
s
.32449 .37201 m
.33291 .34355 L
s
.31115 .61911 m
.30732 .58925 L
s
.31744 .40171 m
.32449 .37201 L
s
.30732 .58925 m
.30505 .55848 L
s
.31184 .43239 m
.31744 .40171 L
s
.30505 .55848 m
.30435 .52708 L
s
.30777 .46372 m
.31184 .43239 L
s
.30435 .52708 m
.30526 .49539 L
s
.30526 .49539 m
.30777 .46372 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.65493 .50705 m
.65128 .53172 L
s
.65128 .53172 m
.64666 .55621 L
s
.65759 .4823 m
.65493 .50705 L
s
.64666 .55621 m
.64108 .58038 L
s
.65924 .4576 m
.65759 .4823 L
s
.64108 .58038 m
.63457 .60412 L
s
.65986 .43307 m
.65924 .4576 L
s
.63457 .60412 m
.62715 .62731 L
s
.65945 .40884 m
.65986 .43307 L
s
.62715 .62731 m
.61886 .64983 L
s
.658 .38503 m
.65945 .40884 L
s
.61886 .64983 m
.60972 .67154 L
s
.65551 .36177 m
.658 .38503 L
s
.60972 .67154 m
.59978 .69234 L
s
.65196 .33919 m
.65551 .36177 L
s
.59978 .69234 m
.58907 .7121 L
s
.64737 .31741 m
.65196 .33919 L
s
.58907 .7121 m
.57764 .73069 L
s
.64175 .29657 m
.64737 .31741 L
s
.57764 .73069 m
.56553 .74798 L
s
.63509 .27681 m
.64175 .29657 L
s
.56553 .74798 m
.5528 .76386 L
s
.62742 .25826 m
.63509 .27681 L
s
.5528 .76386 m
.53952 .77819 L
s
.61875 .24106 m
.62742 .25826 L
s
.53952 .77819 m
.52574 .79086 L
s
.60913 .22534 m
.61875 .24106 L
s
.52574 .79086 m
.51154 .80174 L
s
.59857 .21124 m
.60913 .22534 L
s
.51154 .80174 m
.49699 .81072 L
s
.58712 .1989 m
.59857 .21124 L
s
.49699 .81072 m
.48219 .81768 L
s
.57483 .18846 m
.58712 .1989 L
s
.48219 .81768 m
.46722 .82251 L
s
.56177 .18003 m
.57483 .18846 L
s
.46722 .82251 m
.45218 .82512 L
s
.54799 .17373 m
.56177 .18003 L
s
.45218 .82512 m
.43718 .82543 L
s
.53357 .16969 m
.54799 .17373 L
s
.43718 .82543 m
.42233 .82335 L
s
.51861 .16799 m
.53357 .16969 L
s
.42233 .82335 m
.40775 .81883 L
s
.50321 .16874 m
.51861 .16799 L
s
.40775 .81883 m
.39356 .81183 L
s
.48746 .17198 m
.50321 .16874 L
s
.39356 .81183 m
.37988 .80232 L
s
.47148 .17779 m
.48746 .17198 L
s
.37988 .80232 m
.36686 .79032 L
s
.45542 .18618 m
.47148 .17779 L
s
.36686 .79032 m
.3546 .77585 L
s
.43939 .19715 m
.45542 .18618 L
s
.3546 .77585 m
.34326 .75896 L
s
.42355 .21069 m
.43939 .19715 L
s
.34326 .75896 m
.33295 .73975 L
s
.40803 .22674 m
.42355 .21069 L
s
.33295 .73975 m
.32378 .71832 L
s
.393 .24521 m
.40803 .22674 L
s
.32378 .71832 m
.31589 .69483 L
s
.3786 .26598 m
.393 .24521 L
s
.31589 .69483 m
.30936 .66946 L
s
.36499 .28892 m
.3786 .26598 L
s
.30936 .66946 m
.30429 .6424 L
s
.35231 .31382 m
.36499 .28892 L
s
.30429 .6424 m
.30075 .61391 L
s
.3407 .34049 m
.35231 .31382 L
s
.30075 .61391 m
.2988 .58423 L
s
.33029 .36868 m
.3407 .34049 L
s
.2988 .58423 m
.29848 .55366 L
s
.32119 .39812 m
.33029 .36868 L
s
.29848 .55366 m
.29981 .52249 L
s
.31353 .42853 m
.32119 .39812 L
s
.29981 .52249 m
.30277 .49103 L
s
.30736 .45961 m
.31353 .42853 L
s
.30277 .49103 m
.30736 .45961 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.64977 .53466 m
.64343 .55876 L
s
.65515 .51033 m
.64977 .53466 L
s
.64343 .55876 m
.63616 .58253 L
s
.65954 .48589 m
.65515 .51033 L
s
.63616 .58253 m
.62799 .60582 L
s
.66291 .46147 m
.65954 .48589 L
s
.62799 .60582 m
.61895 .62854 L
s
.66525 .43717 m
.66291 .46147 L
s
.61895 .62854 m
.60909 .65057 L
s
.66653 .41314 m
.66525 .43717 L
s
.60909 .65057 m
.59844 .67178 L
s
.66673 .38948 m
.66653 .41314 L
s
.59844 .67178 m
.58705 .69205 L
s
.66584 .36633 m
.66673 .38948 L
s
.58705 .69205 m
.57497 .71127 L
s
.66385 .34381 m
.66584 .36633 L
s
.57497 .71127 m
.56225 .72932 L
s
.66074 .32206 m
.66385 .34381 L
s
.56225 .72932 m
.54896 .74607 L
s
.65653 .30121 m
.66074 .32206 L
s
.54896 .74607 m
.53514 .76141 L
s
.6512 .2814 m
.65653 .30121 L
s
.53514 .76141 m
.52087 .77521 L
s
.64476 .26275 m
.6512 .2814 L
s
.52087 .77521 m
.50622 .78737 L
s
.63723 .24543 m
.64476 .26275 L
s
.50622 .78737 m
.49128 .79775 L
s
.62861 .22955 m
.63723 .24543 L
s
.49128 .79775 m
.47612 .80626 L
s
.61895 .21526 m
.62861 .22955 L
s
.47612 .80626 m
.46084 .81278 L
s
.60826 .2027 m
.61895 .21526 L
s
.46084 .81278 m
.44554 .81721 L
s
.59658 .192 m
.60826 .2027 L
s
.44554 .81721 m
.43032 .81945 L
s
.58398 .1833 m
.59658 .192 L
s
.43032 .81945 m
.41529 .81943 L
s
.57052 .17671 m
.58398 .1833 L
s
.41529 .81943 m
.40057 .81708 L
s
.55625 .17236 m
.57052 .17671 L
s
.40057 .81708 m
.38627 .81233 L
s
.54127 .17033 m
.55625 .17236 L
s
.38627 .81233 m
.37253 .80516 L
s
.52567 .17073 m
.54127 .17033 L
s
.37253 .80516 m
.35946 .79553 L
s
.50956 .17362 m
.52567 .17073 L
s
.35946 .79553 m
.3472 .78346 L
s
.49305 .17906 m
.50956 .17362 L
s
.3472 .78346 m
.33587 .76898 L
s
.47627 .18708 m
.49305 .17906 L
s
.33587 .76898 m
.32561 .75213 L
s
.45936 .19768 m
.47627 .18708 L
s
.32561 .75213 m
.31652 .73301 L
s
.44247 .21084 m
.45936 .19768 L
s
.31652 .73301 m
.30873 .71173 L
s
.42575 .2265 m
.44247 .21084 L
s
.30873 .71173 m
.30233 .68843 L
s
.40936 .24458 m
.42575 .2265 L
s
.30233 .68843 m
.29743 .66328 L
s
.39346 .26496 m
.40936 .24458 L
s
.29743 .66328 m
.29409 .6365 L
s
.37822 .2875 m
.39346 .26496 L
s
.29409 .6365 m
.29238 .6083 L
s
.3638 .31201 m
.37822 .2875 L
s
.29238 .6083 m
.29234 .57895 L
s
.35035 .33828 m
.3638 .31201 L
s
.29234 .57895 m
.294 .54873 L
s
.33802 .36607 m
.35035 .33828 L
s
.294 .54873 m
.29735 .51792 L
s
.32694 .39511 m
.33802 .36607 L
s
.29735 .51792 m
.30237 .48684 L
s
.31724 .42512 m
.32694 .39511 L
s
.30237 .48684 m
.30902 .45581 L
s
.30902 .45581 m
.31724 .42512 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.64647 .53701 m
.63847 .56059 L
s
.65353 .51318 m
.64647 .53701 L
s
.63847 .56059 m
.62957 .5838 L
s
.65962 .48921 m
.65353 .51318 L
s
.62957 .5838 m
.61982 .60652 L
s
.66471 .46521 m
.65962 .48921 L
s
.61982 .60652 m
.60926 .62865 L
s
.66876 .44131 m
.66471 .46521 L
s
.60926 .62865 m
.59793 .65006 L
s
.67174 .41762 m
.66876 .44131 L
s
.59793 .65006 m
.58589 .67065 L
s
.67363 .39428 m
.67174 .41762 L
s
.58589 .67065 m
.57318 .69031 L
s
.6744 .37139 m
.67363 .39428 L
s
.57318 .69031 m
.55987 .7089 L
s
.67402 .34909 m
.6744 .37139 L
s
.55987 .7089 m
.54601 .72634 L
s
.67248 .32752 m
.67402 .34909 L
s
.54601 .72634 m
.53167 .74249 L
s
.66977 .3068 m
.67248 .32752 L
s
.53167 .74249 m
.51692 .75724 L
s
.66588 .28707 m
.66977 .3068 L
s
.51692 .75724 m
.50183 .77048 L
s
.66079 .26846 m
.66588 .28707 L
s
.50183 .77048 m
.48648 .7821 L
s
.65451 .25113 m
.66079 .26846 L
s
.48648 .7821 m
.47096 .79198 L
s
.64705 .2352 m
.65451 .25113 L
s
.47096 .79198 m
.45536 .80002 L
s
.63842 .22082 m
.64705 .2352 L
s
.45536 .80002 m
.43978 .80612 L
s
.62864 .20812 m
.63842 .22082 L
s
.43978 .80612 m
.42431 .81017 L
s
.61775 .19725 m
.62864 .20812 L
s
.42431 .81017 m
.40907 .8121 L
s
.60578 .18834 m
.61775 .19725 L
s
.40907 .8121 m
.39416 .81181 L
s
.5928 .1815 m
.60578 .18834 L
s
.39416 .81181 m
.37972 .80925 L
s
.57885 .17687 m
.5928 .1815 L
s
.37972 .80925 m
.36586 .80436 L
s
.56403 .17454 m
.57885 .17687 L
s
.36586 .80436 m
.3527 .7971 L
s
.54841 .1746 m
.56403 .17454 L
s
.3527 .7971 m
.34037 .78746 L
s
.53211 .17714 m
.54841 .1746 L
s
.34037 .78746 m
.329 .77544 L
s
.51523 .1822 m
.53211 .17714 L
s
.329 .77544 m
.31871 .76106 L
s
.4979 .18981 m
.51523 .1822 L
s
.31871 .76106 m
.30962 .74439 L
s
.48027 .19999 m
.4979 .18981 L
s
.30962 .74439 m
.30185 .72549 L
s
.46248 .21271 m
.48027 .19999 L
s
.30185 .72549 m
.2955 .70449 L
s
.44469 .22792 m
.46248 .21271 L
s
.2955 .70449 m
.29068 .68152 L
s
.42707 .24553 m
.44469 .22792 L
s
.29068 .68152 m
.28745 .65675 L
s
.4098 .26544 m
.42707 .24553 L
s
.28745 .65675 m
.28588 .63038 L
s
.39304 .28748 m
.4098 .26544 L
s
.28588 .63038 m
.28603 .60263 L
s
.37698 .31149 m
.39304 .28748 L
s
.28603 .60263 m
.28793 .57375 L
s
.36178 .33725 m
.37698 .31149 L
s
.28793 .57375 m
.29156 .54402 L
s
.3476 .36452 m
.36178 .33725 L
s
.29156 .54402 m
.29693 .51373 L
s
.3346 .39304 m
.3476 .36452 L
s
.29693 .51373 m
.304 .48317 L
s
.32292 .42252 m
.3346 .39304 L
s
.304 .48317 m
.31269 .45267 L
s
.31269 .45267 m
.32292 .42252 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.63184 .56141 m
.62141 .58393 L
s
.64142 .5385 m
.63184 .56141 L
s
.65011 .51531 m
.64142 .5385 L
s
.62141 .58393 m
.61019 .60596 L
s
.65786 .49196 m
.65011 .51531 L
s
.61019 .60596 m
.59821 .62738 L
s
.66463 .46855 m
.65786 .49196 L
s
.59821 .62738 m
.58554 .64809 L
s
.67037 .4452 m
.66463 .46855 L
s
.58554 .64809 m
.57224 .66797 L
s
.67505 .42203 m
.67037 .4452 L
s
.57224 .66797 m
.55836 .68692 L
s
.67863 .39915 m
.67505 .42203 L
s
.55836 .68692 m
.54396 .70484 L
s
.68108 .3767 m
.67863 .39915 L
s
.54396 .70484 m
.52911 .7216 L
s
.68236 .35479 m
.68108 .3767 L
s
.52911 .7216 m
.51389 .73711 L
s
.68245 .33355 m
.68236 .35479 L
s
.51389 .73711 m
.49837 .75125 L
s
.68131 .31312 m
.68245 .33355 L
s
.49837 .75125 m
.48262 .76391 L
s
.67894 .29363 m
.68131 .31312 L
s
.48262 .76391 m
.46674 .775 L
s
.6753 .27522 m
.67894 .29363 L
s
.46674 .775 m
.45081 .78439 L
s
.67039 .25802 m
.6753 .27522 L
s
.45081 .78439 m
.43493 .792 L
s
.66421 .24217 m
.67039 .25802 L
s
.43493 .792 m
.4192 .79771 L
s
.65676 .22782 m
.66421 .24217 L
s
.4192 .79771 m
.40373 .80145 L
s
.64804 .21511 m
.65676 .22782 L
s
.40373 .80145 m
.38862 .80312 L
s
.63809 .20417 m
.64804 .21511 L
s
.38862 .80312 m
.374 .80265 L
s
.62692 .19514 m
.63809 .20417 L
s
.374 .80265 m
.35997 .79998 L
s
.61459 .18815 m
.62692 .19514 L
s
.35997 .79998 m
.34668 .79505 L
s
.60114 .1833 m
.61459 .18815 L
s
.34668 .79505 m
.33423 .78782 L
s
.58665 .18072 m
.60114 .1833 L
s
.33423 .78782 m
.32276 .77828 L
s
.5712 .18049 m
.58665 .18072 L
s
.32276 .77828 m
.31239 .76644 L
s
.55488 .18269 m
.5712 .18049 L
s
.31239 .76644 m
.30323 .75231 L
s
.53781 .18738 m
.55488 .18269 L
s
.30323 .75231 m
.29541 .73595 L
s
.52011 .19459 m
.53781 .18738 L
s
.29541 .73595 m
.28904 .71744 L
s
.50192 .20433 m
.52011 .19459 L
s
.28904 .71744 m
.2842 .69687 L
s
.4834 .21658 m
.50192 .20433 L
s
.2842 .69687 m
.281 .67439 L
s
.4647 .23129 m
.4834 .21658 L
s
.281 .67439 m
.27949 .65015 L
s
.446 .24837 m
.4647 .23129 L
s
.27949 .65015 m
.27973 .62435 L
s
.42749 .26773 m
.446 .24837 L
s
.27973 .62435 m
.28176 .59721 L
s
.40934 .2892 m
.42749 .26773 L
s
.28176 .59721 m
.28559 .56897 L
s
.39175 .31261 m
.40934 .2892 L
s
.28559 .56897 m
.29121 .53989 L
s
.3749 .33775 m
.39175 .31261 L
s
.29121 .53989 m
.29858 .51026 L
s
.35897 .36438 m
.3749 .33775 L
s
.29858 .51026 m
.30765 .48038 L
s
.34413 .39225 m
.35897 .36438 L
s
.30765 .48038 m
.31834 .45055 L
s
.33054 .42107 m
.34413 .39225 L
s
.31834 .45055 m
.33054 .42107 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.62363 .56096 m
.61178 .58268 L
s
.63469 .53885 m
.62363 .56096 L
s
.61178 .58268 m
.5992 .60389 L
s
.64491 .51645 m
.63469 .53885 L
s
.5992 .60389 m
.58595 .62451 L
s
.65423 .49386 m
.64491 .51645 L
s
.58595 .62451 m
.57208 .64442 L
s
.66262 .4712 m
.65423 .49386 L
s
.57208 .64442 m
.55766 .66352 L
s
.67001 .44857 m
.66262 .4712 L
s
.55766 .66352 m
.54276 .68171 L
s
.67636 .42609 m
.67001 .44857 L
s
.54276 .68171 m
.52744 .69889 L
s
.68162 .40387 m
.67636 .42609 L
s
.52744 .69889 m
.51177 .71496 L
s
.68575 .38202 m
.68162 .40387 L
s
.51177 .71496 m
.49584 .7298 L
s
.6887 .36068 m
.68575 .38202 L
s
.49584 .7298 m
.47971 .74332 L
s
.69044 .33996 m
.6887 .36068 L
s
.47971 .74332 m
.46348 .75542 L
s
.69094 .32 m
.69044 .33996 L
s
.46348 .75542 m
.44724 .76599 L
s
.69014 .30093 m
.69094 .32 L
s
.44724 .76599 m
.43107 .77493 L
s
.68804 .28287 m
.69014 .30093 L
s
.43107 .77493 m
.41507 .78216 L
s
.68461 .26598 m
.68804 .28287 L
s
.41507 .78216 m
.39936 .78756 L
s
.67982 .25038 m
.68461 .26598 L
s
.39936 .78756 m
.38404 .79106 L
s
.67367 .23622 m
.67982 .25038 L
s
.38404 .79106 m
.36922 .79257 L
s
.66616 .22363 m
.67367 .23622 L
s
.36922 .79257 m
.35502 .79202 L
s
.65729 .21276 m
.66616 .22363 L
s
.35502 .79202 m
.34155 .78935 L
s
.64709 .20374 m
.65729 .21276 L
s
.34155 .78935 m
.32895 .7845 L
s
.63558 .19669 m
.64709 .20374 L
s
.32895 .7845 m
.31734 .77744 L
s
.62282 .19173 m
.63558 .19669 L
s
.31734 .77744 m
.30683 .76816 L
s
.60885 .18898 m
.62282 .19173 L
s
.30683 .76816 m
.29755 .75664 L
s
.59375 .18852 m
.60885 .18898 L
s
.29755 .75664 m
.28962 .74292 L
s
.57761 .19044 m
.59375 .18852 L
s
.28962 .74292 m
.28314 .72704 L
s
.56054 .19479 m
.57761 .19044 L
s
.28314 .72704 m
.27823 .70907 L
s
.54266 .20162 m
.56054 .19479 L
s
.27823 .70907 m
.27496 .68911 L
s
.5241 .21092 m
.54266 .20162 L
s
.27496 .68911 m
.27341 .66729 L
s
.50502 .22269 m
.5241 .21092 L
s
.27341 .66729 m
.27365 .64377 L
s
.48559 .23688 m
.50502 .22269 L
s
.27365 .64377 m
.27572 .61872 L
s
.46598 .2534 m
.48559 .23688 L
s
.27572 .61872 m
.27963 .59236 L
s
.44638 .27214 m
.46598 .2534 L
s
.27963 .59236 m
.28539 .56492 L
s
.42699 .29297 m
.44638 .27214 L
s
.28539 .56492 m
.29297 .53666 L
s
.40801 .31569 m
.42699 .29297 L
s
.29297 .53666 m
.30231 .50786 L
s
.38964 .34012 m
.40801 .31569 L
s
.30231 .50786 m
.31334 .47881 L
s
.37206 .36601 m
.38964 .34012 L
s
.31334 .47881 m
.32597 .4498 L
s
.35548 .3931 m
.37206 .36601 L
s
.32597 .4498 m
.34006 .42113 L
s
.34006 .42113 m
.35548 .3931 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.61416 .55916 m
.601 .58 L
s
.6266 .53792 m
.61416 .55916 L
s
.601 .58 m
.58719 .60034 L
s
.63826 .5164 m
.6266 .53792 L
s
.58719 .60034 m
.57279 .62011 L
s
.64908 .49468 m
.63826 .5164 L
s
.57279 .62011 m
.55785 .63919 L
s
.65901 .47288 m
.64908 .49468 L
s
.55785 .63919 m
.54246 .65749 L
s
.66799 .45108 m
.65901 .47288 L
s
.54246 .65749 m
.52668 .67491 L
s
.67596 .42941 m
.66799 .45108 L
s
.52668 .67491 m
.51058 .69136 L
s
.68287 .40797 m
.67596 .42941 L
s
.51058 .69136 m
.49423 .70674 L
s
.68867 .38687 m
.68287 .40797 L
s
.49423 .70674 m
.47773 .72096 L
s
.6933 .36624 m
.68867 .38687 L
s
.47773 .72096 m
.46114 .7339 L
s
.69671 .34619 m
.6933 .36624 L
s
.46114 .7339 m
.44457 .74549 L
s
.69886 .32685 m
.69671 .34619 L
s
.44457 .74549 m
.4281 .75562 L
s
.6997 .30834 m
.69886 .32685 L
s
.4281 .75562 m
.41182 .76419 L
s
.69919 .2908 m
.6997 .30834 L
s
.41182 .76419 m
.39585 .77112 L
s
.6973 .27435 m
.69919 .2908 L
s
.39585 .77112 m
.38027 .77631 L
s
.694 .25915 m
.6973 .27435 L
s
.38027 .77631 m
.36522 .77968 L
s
.68926 .24532 m
.694 .25915 L
s
.36522 .77968 m
.3508 .78115 L
s
.68306 .233 m
.68926 .24532 L
s
.3508 .78115 m
.33712 .78064 L
s
.67542 .22232 m
.68306 .233 L
s
.33712 .78064 m
.32431 .7781 L
s
.66632 .21343 m
.67542 .22232 L
s
.32431 .7781 m
.3125 .77348 L
s
.65579 .20645 m
.66632 .21343 L
s
.3125 .77348 m
.30179 .76673 L
s
.64386 .20149 m
.65579 .20645 L
s
.30179 .76673 m
.29232 .75784 L
s
.63057 .19866 m
.64386 .20149 L
s
.29232 .75784 m
.2842 .7468 L
s
.61599 .19807 m
.63057 .19866 L
s
.2842 .7468 m
.27755 .73364 L
s
.6002 .19979 m
.61599 .19807 L
s
.27755 .73364 m
.27246 .71838 L
s
.5833 .20388 m
.6002 .19979 L
s
.27246 .71838 m
.26904 .70111 L
s
.5654 .21038 m
.5833 .20388 L
s
.26904 .70111 m
.26737 .6819 L
s
.54663 .2193 m
.5654 .21038 L
s
.26737 .6819 m
.26751 .66088 L
s
.52715 .23062 m
.54663 .2193 L
s
.26751 .66088 m
.26951 .6382 L
s
.50713 .2443 m
.52715 .23062 L
s
.26951 .6382 m
.2734 .61403 L
s
.48675 .26027 m
.50713 .2443 L
s
.2734 .61403 m
.2792 .58858 L
s
.4662 .27841 m
.48675 .26027 L
s
.2792 .58858 m
.28687 .56206 L
s
.44569 .29858 m
.4662 .27841 L
s
.28687 .56206 m
.29639 .53473 L
s
.42543 .3206 m
.44569 .29858 L
s
.29639 .53473 m
.30767 .50686 L
s
.40563 .34428 m
.42543 .3206 L
s
.30767 .50686 m
.32063 .47872 L
s
.3865 .36938 m
.40563 .34428 L
s
.32063 .47872 m
.33514 .45061 L
s
.36825 .39566 m
.3865 .36938 L
s
.33514 .45061 m
.35107 .42283 L
s
.35107 .42283 m
.36825 .39566 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.58911 .57565 m
.57422 .59507 L
s
.60344 .55577 m
.58911 .57565 L
s
.61712 .5355 m
.60344 .55577 L
s
.57422 .59507 m
.55881 .61394 L
s
.6301 .51495 m
.61712 .5355 L
s
.55881 .61394 m
.54297 .63215 L
s
.64231 .49422 m
.6301 .51495 L
s
.54297 .63215 m
.52676 .64963 L
s
.65368 .47339 m
.64231 .49422 L
s
.52676 .64963 m
.51026 .66627 L
s
.66416 .45256 m
.65368 .47339 L
s
.51026 .66627 m
.49354 .682 L
s
.67368 .43185 m
.66416 .45256 L
s
.49354 .682 m
.47669 .69672 L
s
.68218 .41134 m
.67368 .43185 L
s
.47669 .69672 m
.45977 .71034 L
s
.68959 .39115 m
.68218 .41134 L
s
.45977 .71034 m
.44289 .72276 L
s
.69587 .37139 m
.68959 .39115 L
s
.44289 .72276 m
.42613 .73389 L
s
.70094 .35217 m
.69587 .37139 L
s
.42613 .73389 m
.40958 .74365 L
s
.70475 .33362 m
.70094 .35217 L
s
.40958 .74365 m
.39335 .75194 L
s
.70724 .31585 m
.70475 .33362 L
s
.39335 .75194 m
.37753 .75867 L
s
.70837 .29899 m
.70724 .31585 L
s
.37753 .75867 m
.36224 .76376 L
s
.70808 .28318 m
.70837 .29899 L
s
.36224 .76376 m
.34758 .76712 L
s
.70634 .26855 m
.70808 .28318 L
s
.34758 .76712 m
.33368 .76868 L
s
.7031 .25522 m
.70634 .26855 L
s
.33368 .76868 m
.32064 .76836 L
s
.69834 .24334 m
.7031 .25522 L
s
.32064 .76836 m
.30859 .7661 L
s
.69204 .23303 m
.69834 .24334 L
s
.30859 .7661 m
.29765 .76185 L
s
.68419 .22442 m
.69204 .23303 L
s
.29765 .76185 m
.28794 .75558 L
s
.67479 .21765 m
.68419 .22442 L
s
.28794 .75558 m
.27957 .74725 L
s
.66386 .21283 m
.67479 .21765 L
s
.27957 .74725 m
.27268 .73686 L
s
.65143 .21007 m
.66386 .21283 L
s
.27268 .73686 m
.26735 .72442 L
s
.63755 .20946 m
.65143 .21007 L
s
.26735 .72442 m
.2637 .70997 L
s
.6223 .21108 m
.63755 .20946 L
s
.2637 .70997 m
.26181 .69356 L
s
.60576 .215 m
.6223 .21108 L
s
.26181 .69356 m
.26175 .67528 L
s
.58804 .22125 m
.60576 .215 L
s
.26175 .67528 m
.26359 .65524 L
s
.56926 .22985 m
.58804 .22125 L
s
.26359 .65524 m
.26736 .63357 L
s
.54957 .24078 m
.56926 .22985 L
s
.26736 .63357 m
.27307 .61044 L
s
.52915 .25399 m
.54957 .24078 L
s
.27307 .61044 m
.28073 .58605 L
s
.50818 .26942 m
.52915 .25399 L
s
.28073 .58605 m
.29029 .5606 L
s
.48685 .28696 m
.50818 .26942 L
s
.29029 .5606 m
.30171 .53434 L
s
.46538 .30646 m
.48685 .28696 L
s
.30171 .53434 m
.31488 .50752 L
s
.44399 .32775 m
.46538 .30646 L
s
.31488 .50752 m
.3297 .48042 L
s
.42291 .35064 m
.44399 .32775 L
s
.3297 .48042 m
.34603 .45333 L
s
.40235 .37491 m
.42291 .35064 L
s
.34603 .45333 m
.3637 .42652 L
s
.38254 .40029 m
.40235 .37491 L
s
.3637 .42652 m
.38254 .40029 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002`Ool<
O01TOol00:aoo`Al00aoo`Al061oo`00ZWoo0W`057oo0W`0GWoo002WOol3O00HOol2O01LOol00:Eo
o`9l01eoo`03O01oogoo05Uoo`00Xgoo0W`087oo00=l07ooOol0F7oo002QOol2O00SOol00g`0Oomo
o`1GOol00:1oo`03O01oogoo02Aoo`03O01oogoo05Ioo`00WWoo0W`09goo00=l07ooOol0EWoo002M
Ool00g`0Oomoo`0XOol00g`0Oomoo`1EOol009]oo`9l02]oo`03O01oogoo05Eoo`00VGoo0W`0;Goo
00=l07ooOol0EGoo002GOol2O00`Ool00g`0Oomoo`1DOol009Ioo`03O01oogoo031oo`03O01oogoo
05Aoo`00UGoo00=l07ooOol0<Goo00=l07ooOol0E7oo002COol2O00dOol00g`0Oomoo`1DOol0099o
o`03O01oogoo03Eoo`03O01oogoo05=oo`00TGoo00=l07ooOol0=Woo00=l07ooOol0Dgoo002@Ool0
0g`0Oomoo`0gOol00g`0Oomoo`1COol008moo`03O01oogoo03Qoo`03O01oogoo05=oo`00SGoo0W`0
?7oo00=l07ooOol0DWoo002<Ool00g`0Oomoo`0lOol00g`0Oomoo`1BOol008]oo`03O01oogoo03eo
o`03O01oogoo059oo`00RWoo00=l07ooOol0?Woo00=l07ooOol0DWoo0029Ool00g`0Oomoo`0oOol0
0g`0Oomoo`1BOol008Moo`9l049oo`03O01oogoo059oo`00QWoo00=l07ooOol0@Woo00=l07ooOol0
DWoo0025Ool00g`0Oomoo`13Ool00g`0Oomoo`1BOol008Aoo`03O01oogoo04=oo`03O01oogoo05=o
o`00Pgoo00=l07ooOol0A7oo00=l07ooOol0Dgoo0022Ool00g`0Oomoo`15Ool00g`0Oomoo`1COol0
089oo`03O01oogoo04Eoo`03O01oogoo05=oo`00PGoo00=l07ooOol0AWoo00=l07ooOol0Dgoo0020
Ool00g`0Oomoo`17Ool00g`0Oomoo`1COol007moo`03O01oogoo04Qoo`03O01oogoo05=oo`00OWoo
00=l07ooOol0BGoo00=l07ooOol0Dgoo001mOol00g`0Oomoo`1:Ool00g`0Oomoo`1COol007aoo`03
O01oogoo04]oo`03O01oogoo05=oo`00Ngoo00=l07ooOol0Bgoo00=l07ooOol0E7oo001jOol00g`0
Oomoo`1<Ool00g`0Oomoo`1DOol007Uoo`03O01oogoo04eoo`03O01oogoo05Aoo`00N7oo00=l07oo
Ool0CWoo00=l07ooOol0E7oo001gOol00g`0Oomoo`1?Ool00g`0Oomoo`1DOol007Ioo`03O01oogoo
04moo`03O01oogoo05Eoo`00MWoo00=l07ooOol0Cgoo00=l07ooOol0EGoo001eOol00g`0Oomoo`1?
Ool00g`0Oomoo`1FOol007Aoo`03O01oogoo051oo`03O01oogoo05Ioo`00Lgoo00=l07ooOol0DGoo
00=l07ooOol0EWoo001bOol00g`0Oomoo`1AOol00g`0Oomoo`1GOol0075oo`03O01oogoo059oo`03
O01oogoo05Moo`00L7oo00=l07ooOol0Dgoo00=l07ooOol0Egoo001`Ool00g`0Oomoo`1BOol00g`0
Oomoo`1HOol006moo`03O01oogoo05=oo`03O01oogoo05Qoo`00KWoo00=l07ooOol0E7oo00=l07oo
Ool0F7oo001]Ool00g`0Oomoo`1DOol00g`0Oomoo`1IOol006aoo`03O01oogoo05Eoo`03O01oogoo
05Uoo`00K7oo00=l07ooOol0EGoo00=l07ooOol0FGoo001[Ool00g`0Oomoo`1EOol00g`0Oomoo`1J
Ool006Yoo`03O01oogoo05Ioo`03O01oogoo05Yoo`00JWoo00=l07ooOol0EWoo00=l07ooOol0FWoo
001YOol00g`0Oomoo`1FOol00g`0Oomoo`1KOol006Uoo`03O01oogoo05Ioo`03O01oogoo05]oo`00
J7oo00=l07ooOol0EWoo00=l07ooOol0G7oo001WOol00g`0Oomoo`1GOol00g`0Oomoo`1LOol006Mo
o`03O01oogoo05Ioo`03O01oogoo05eoo`00IWoo00=l07ooOol0Egoo00=l07ooOol0GGoo001UOol0
0g`0Oomoo`1GOol00g`0Oomoo`1NOol006Eoo`03O01oogoo05Moo`03O01oogoo05ioo`00I7oo00=l
07ooOol0Egoo00=l07ooOol0Ggoo001TOol00g`0Oomoo`1GOol00g`0Oomoo`1OOol006=oo`03O01o
ogoo05Moo`03O01oogoo061oo`00HWoo00=l07ooOol0F7oo00=l07ooOol0H7oo001ROol00g`0Oomo
o`1GOol00g`0Oomoo`1QOol0065oo`03O01oogoo05Qoo`03O01oogoo065oo`00H7oo00=l07ooOol0
F7oo00=l07ooOol0HWoo001OOol00g`0Oomoo`1IOol00g`0Oomoo`1ROol005moo`03O01oogoo05Qo
o`03O01oogoo06=oo`00GWoo00=l07ooOol0FGoo00=l07ooOol0Hgoo001MOol00g`0Oomoo`1IOol0
0g`0Oomoo`1TOol005eoo`03O01oogoo05Uoo`03O01oogoo06Aoo`00G7oo00=l07ooOol0FGoo00=l
07ooOol0IGoo001LOol00g`0Oomoo`1IOol00g`0Oomoo`1UOol005]oo`03O01oogoo05Uoo`03O01o
ogoo06Ioo`00Fgoo00=l07ooOol0FGoo00=l07ooOol0IWoo001JOol00g`0Oomoo`1IOol00g`0Oomo
o`1WOol005Yoo`03O01oogoo05Qoo`03O01oogoo06Qoo`00FGoo00=l07ooOol0FGoo00=l07ooOol0
J7oo001IOol00g`0Oomoo`1HOol00g`0Oomoo`1YOol005Qoo`03O01oogoo05Qoo`03O01oogoo06Yo
o`00F7oo00=l07ooOol0F7oo00=l07ooOol0JWoo001GOol00g`0Oomoo`1HOol00g`0Oomoo`1[Ool0
05Moo`03O01oogoo05Qoo`03O01oogoo06]oo`00EWoo00=l07ooOol0F7oo00=l07ooOol0K7oo001F
Ool00g`0Oomoo`1HOol00g`0Oomoo`1/Ool005Ioo`03O01oogoo05Moo`03O01oogoo06eoo`00EGoo
00=l07ooOol0F7oo00=l07ooOol0KGoo001EOol00g`0Oomoo`1GOol00g`0Oomoo`1^Ool005Aoo`03
O01oogoo05Moo`03O01oogoo06moo`00E7oo00=l07ooOol0Egoo00=l07ooOol0Kgoo001COol00g`0
Oomoo`1GOol00g`0Oomoo`1`Ool005=oo`03O01oogoo05Ioo`03O01oogoo075oo`00Dgoo00=l07oo
Ool0EWoo00=l07ooOol0LGoo001BOol00g`0Oomoo`1FOol00g`0Oomoo`1bOol0059oo`03O01oogoo
05Eoo`03O01oogoo07=oo`00DGoo00=l07ooOol0EWoo00=l07ooOol0Lgoo001AOol00g`0Oomoo`1E
Ool00g`0Oomoo`1dOol0055oo`03O01oogoo05Aoo`03O01oogoo07Eoo`00D7oo00=l07ooOol0E7oo
00=l07ooOol0MWoo001@Ool00g`0Oomoo`1COol00g`0Oomoo`1gOol0051oo`03O01oogoo059oo`03
O01oogoo07Qoo`00Cgoo00=l07ooOol0DWoo00=l07ooOol0NGoo001?Ool00g`0Oomoo`1AOol00g`0
Oomoo`1jOol004moo`03O01oogoo055oo`03O01oogoo07Yoo`00Cgoo00=l07ooOol0D7oo00=l07oo
Ool0Ngoo001>Ool00g`0Oomoo`1@Ool00g`0Oomoo`1lOol004ioo`03O01oogoo051oo`03O01oogoo
07aoo`00CWoo00=l07ooOol0Cgoo00=l07ooOol0OGoo001=Ool00g`0Oomoo`1?Ool00g`0Oomoo`1n
Ool004eoo`03O01oogoo04ioo`03O01oogoo07moo`00CGoo00=l07ooOol0CGoo00=l07ooOol0P7oo
001<Ool00g`0Oomoo`1=Ool00g`0Oomoo`21Ool004aoo`03O01oogoo04aoo`03O01oogoo089oo`00
C7oo00=l07ooOol0Bgoo00=l07ooOol0Pgoo001<Ool00g`0Oomoo`1:Ool00g`0Oomoo`24Ool004ao
o`03O01oogoo04Yoo`03O01oogoo08Aoo`00Bgoo00=l07ooOol0BWoo00=l07ooOol0QGoo001;Ool0
0g`0Oomoo`19Ool00g`0Oomoo`26Ool004]oo`03O01oogoo04Qoo`03O01oogoo08Moo`00Bgoo00=l
07ooOol0Agoo00=l07ooOol0R7oo001;Ool00g`0Oomoo`16Ool00g`0Oomoo`29Ool004]oo`03O01o
ogoo04Eoo`03O01oogoo08Yoo`00Bgoo00=l07ooOol0A7oo00=l07ooOol0Rgoo001;Ool00g`0Oomo
o`13Ool00g`0Oomoo`2<Ool004]oo`03O01oogoo045oo`9l08moo`00Bgoo00=l07ooOol0@7oo00=l
07ooOol0Sgoo001;Ool00g`0Oomoo`0oOol00g`0Oomoo`2@Ool004]oo`03O01oogoo03ioo`03O01o
ogoo095oo`00Bgoo00=l07ooOol0?7oo0W`0U7oo001;Ool00g`0Oomoo`0kOol00g`0Oomoo`2DOol0
04]oo`03O01oogoo03Yoo`03O01oogoo09Eoo`00Bgoo00=l07ooOol0>Goo00=l07ooOol0UWoo001;
Ool00g`0Oomoo`0gOol2O02IOol004]oo`03O01oogoo03Ioo`03O01oogoo09Uoo`00Bgoo00=l07oo
Ool0=Goo00=l07ooOol0VWoo001;Ool00g`0Oomoo`0dOol00g`0Oomoo`2KOol004]oo`03O01oogoo
03=oo`03O01oogoo09aoo`00C7oo00=l07ooOol0<Goo00=l07ooOol0WGoo001<Ool00g`0Oomoo`0`
Ool00g`0Oomoo`2NOol004aoo`03O01oogoo02ioo`9l0:5oo`00CGoo00=l07ooOol0:goo0W`0Xgoo
001=Ool00g`0Oomoo`0ZOol00g`0Oomoo`2SOol004ioo`03O01oogoo02Moo`9l0:Ioo`00Cgoo00=l
07ooOol097oo0W`0Z7oo001?Ool00g`0Oomoo`0ROol2O02ZOol0051oo`03O01oogoo01moo`9l0:ao
o`00DGoo00=l07ooOol077oo0W`0[Woo001BOol00g`0Oomoo`0IOol2O02`Ool005=oo`9l01Ioo`=l
0;9oo`00EGoo0W`04Woo0W`0]Goo001GOol3O00<Ool3O02gOol005Yoo`al0;Yoo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.5764 .56968 m
.56055 .58816 L
s
.59175 .55078 m
.5764 .56968 L
s
.60655 .53152 m
.59175 .55078 L
s
.56055 .58816 m
.54429 .60612 L
s
.62072 .512 m
.60655 .53152 L
s
.54429 .60612 m
.52769 .62348 L
s
.6342 .49231 m
.62072 .512 L
s
.52769 .62348 m
.51081 .64015 L
s
.64691 .47254 m
.6342 .49231 L
s
.51081 .64015 m
.49374 .65606 L
s
.65879 .45277 m
.64691 .47254 L
s
.49374 .65606 m
.47655 .67111 L
s
.66977 .4331 m
.65879 .45277 L
s
.47655 .67111 m
.45933 .68522 L
s
.67978 .41363 m
.66977 .4331 L
s
.45933 .68522 m
.44215 .69831 L
s
.68876 .39447 m
.67978 .41363 L
s
.44215 .69831 m
.4251 .71028 L
s
.69663 .37571 m
.68876 .39447 L
s
.4251 .71028 m
.40829 .72106 L
s
.70332 .35746 m
.69663 .37571 L
s
.40829 .72106 m
.3918 .73055 L
s
.70878 .33984 m
.70332 .35746 L
s
.3918 .73055 m
.37573 .73866 L
s
.71293 .32297 m
.70878 .33984 L
s
.37573 .73866 m
.36018 .74531 L
s
.71571 .30696 m
.71293 .32297 L
s
.36018 .74531 m
.34528 .75043 L
s
.71706 .29194 m
.71571 .30696 L
s
.34528 .75043 m
.33112 .75391 L
s
.71693 .27804 m
.71706 .29194 L
s
.33112 .75391 m
.31782 .7557 L
s
.71526 .26538 m
.71693 .27804 L
s
.31782 .7557 m
.30551 .75571 L
s
.71202 .2541 m
.71526 .26538 L
s
.30551 .75571 m
.29429 .75389 L
s
.70716 .24432 m
.71202 .2541 L
s
.29429 .75389 m
.2843 .75018 L
s
.70067 .23617 m
.70716 .24432 L
s
.2843 .75018 m
.27564 .74454 L
s
.69253 .22978 m
.70067 .23617 L
s
.27564 .74454 m
.26844 .73693 L
s
.68274 .22525 m
.69253 .22978 L
s
.26844 .73693 m
.26281 .72735 L
s
.67133 .2227 m
.68274 .22525 L
s
.26281 .72735 m
.25886 .7158 L
s
.65832 .22221 m
.67133 .2227 L
s
.25886 .7158 m
.25666 .70231 L
s
.64378 .22388 m
.65832 .22221 L
s
.25666 .70231 m
.25632 .68693 L
s
.62778 .22775 m
.64378 .22388 L
s
.25632 .68693 m
.2579 .66973 L
s
.61041 .23386 m
.62778 .22775 L
s
.2579 .66973 m
.26143 .6508 L
s
.59181 .24224 m
.61041 .23386 L
s
.26143 .6508 m
.26696 .63029 L
s
.5721 .25286 m
.59181 .24224 L
s
.26696 .63029 m
.27448 .60834 L
s
.55145 .26569 m
.5721 .25286 L
s
.27448 .60834 m
.28398 .58512 L
s
.53006 .28065 m
.55145 .26569 L
s
.28398 .58512 m
.2954 .56086 L
s
.50812 .29763 m
.53006 .28065 L
s
.2954 .56086 m
.30867 .53577 L
s
.48584 .3165 m
.50812 .29763 L
s
.30867 .53577 m
.32368 .5101 L
s
.46347 .33708 m
.48584 .3165 L
s
.32368 .5101 m
.3403 .48412 L
s
.44123 .35919 m
.46347 .33708 L
s
.3403 .48412 m
.35837 .4581 L
s
.41936 .3826 m
.44123 .35919 L
s
.35837 .4581 m
.37771 .43233 L
s
.39812 .40707 m
.41936 .3826 L
s
.37771 .43233 m
.39812 .40707 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo002kOol7O01NOol00;Moo`Al00Moo`=l05]oo`00/goo17`03Woo0W`0
FGoo002aOol2O00DOol2O01GOol00:ioo`=l01Qoo`03O01oogoo05Aoo`00Zgoo0g`06goo00=l07oo
Ool0E7oo002YOol2O00OOol00g`0Oomoo`1COol00:Moo`9l025oo`03O01oogoo05=oo`00YGoo0W`0
97oo00=l07ooOol0DWoo002TOol00g`0Oomoo`0UOol00g`0Oomoo`1AOol00:9oo`9l02Qoo`03O01o
ogoo055oo`00XGoo00=l07ooOol0:7oo00=l07ooOol0DGoo002OOol2O00/Ool00g`0Oomoo`1@Ool0
09ioo`03O01oogoo02aoo`03O01oogoo051oo`00W7oo0W`0;goo00=l07ooOol0D7oo002KOol00g`0
Oomoo`0_Ool00g`0Oomoo`1@Ool009Uoo`9l039oo`03O01oogoo051oo`00V7oo00=l07ooOol0<Woo
00=l07ooOol0D7oo002FOol2O00eOol00g`0Oomoo`1@Ool009Eoo`03O01oogoo03Eoo`03O01oogoo
051oo`00U7oo00=l07ooOol0=Woo00=l07ooOol0D7oo002BOol2O00iOol00g`0Oomoo`1@Ool0095o
o`03O01oogoo03Uoo`03O01oogoo051oo`00T7oo00=l07ooOol0>Woo00=l07ooOol0D7oo002?Ool0
0g`0Oomoo`0kOol00g`0Oomoo`1@Ool008eoo`9l03ioo`03O01oogoo051oo`00S7oo00=l07ooOol0
?Woo00=l07ooOol0D7oo002;Ool00g`0Oomoo`0nOol00g`0Oomoo`1AOol008Yoo`03O01oogoo03mo
o`03O01oogoo055oo`00RGoo00=l07ooOol0@7oo00=l07ooOol0DGoo0028Ool00g`0Oomoo`11Ool0
0g`0Oomoo`1AOol008Moo`03O01oogoo049oo`03O01oogoo055oo`00QWoo00=l07ooOol0@Woo00=l
07ooOol0DWoo0025Ool00g`0Oomoo`13Ool00g`0Oomoo`1BOol008Aoo`03O01oogoo04Aoo`03O01o
ogoo059oo`00Pgoo00=l07ooOol0AGoo00=l07ooOol0DWoo0022Ool00g`0Oomoo`15Ool00g`0Oomo
o`1COol0085oo`03O01oogoo04Ioo`03O01oogoo05=oo`00P7oo00=l07ooOol0AWoo00=l07ooOol0
E7oo001oOol00g`0Oomoo`17Ool00g`0Oomoo`1DOol007ioo`03O01oogoo04Qoo`03O01oogoo05Ao
o`00OGoo00=l07ooOol0B7oo00=l07ooOol0EGoo001lOol00g`0Oomoo`19Ool00g`0Oomoo`1EOol0
07]oo`03O01oogoo04Uoo`03O01oogoo05Ioo`00NWoo00=l07ooOol0BWoo00=l07ooOol0EWoo001i
Ool00g`0Oomoo`1;Ool00g`0Oomoo`1FOol007Qoo`03O01oogoo04]oo`03O01oogoo05Moo`00Mgoo
00=l07ooOol0C7oo00=l07ooOol0Egoo001fOol00g`0Oomoo`1=Ool00g`0Oomoo`1GOol007Eoo`03
O01oogoo04eoo`03O01oogoo05Qoo`00MGoo00=l07ooOol0CGoo00=l07ooOol0F7oo001dOol00g`0
Oomoo`1>Ool00g`0Oomoo`1HOol007=oo`03O01oogoo04ioo`03O01oogoo05Uoo`00LWoo00=l07oo
Ool0Cgoo00=l07ooOol0FGoo001aOol00g`0Oomoo`1?Ool00g`0Oomoo`1JOol0071oo`03O01oogoo
051oo`03O01oogoo05Yoo`00L7oo00=l07ooOol0Cgoo00=l07ooOol0Fgoo001_Ool00g`0Oomoo`1@
Ool00g`0Oomoo`1KOol006ioo`03O01oogoo051oo`03O01oogoo05aoo`00KGoo00=l07ooOol0DGoo
00=l07ooOol0G7oo001]Ool00g`0Oomoo`1@Ool00g`0Oomoo`1MOol006aoo`03O01oogoo055oo`03
O01oogoo05eoo`00Jgoo00=l07ooOol0DGoo00=l07ooOol0GWoo001ZOol00g`0Oomoo`1BOol00g`0
Oomoo`1NOol006Uoo`03O01oogoo059oo`03O01oogoo05moo`00JGoo00=l07ooOol0DWoo00=l07oo
Ool0Ggoo001XOol00g`0Oomoo`1BOol00g`0Oomoo`1POol006Moo`03O01oogoo059oo`03O01oogoo
065oo`00IWoo00=l07ooOol0Dgoo00=l07ooOol0HGoo001UOol00g`0Oomoo`1COol00g`0Oomoo`1R
Ool006Eoo`03O01oogoo059oo`03O01oogoo06=oo`00I7oo00=l07ooOol0Dgoo00=l07ooOol0Hgoo
001SOol00g`0Oomoo`1COol00g`0Oomoo`1TOol0069oo`03O01oogoo05=oo`03O01oogoo06Eoo`00
HWoo00=l07ooOol0Dgoo00=l07ooOol0IGoo001QOol00g`0Oomoo`1COol00g`0Oomoo`1VOol0061o
o`03O01oogoo05Aoo`03O01oogoo06Ioo`00H7oo00=l07ooOol0Dgoo00=l07ooOol0Igoo001OOol0
0g`0Oomoo`1DOol00g`0Oomoo`1WOol005ioo`03O01oogoo05Aoo`03O01oogoo06Qoo`00GWoo00=l
07ooOol0Dgoo00=l07ooOol0JGoo001MOol00g`0Oomoo`1DOol00g`0Oomoo`1YOol005eoo`03O01o
ogoo05=oo`03O01oogoo06Yoo`00G7oo00=l07ooOol0Dgoo00=l07ooOol0Jgoo001KOol00g`0Oomo
o`1COol00g`0Oomoo`1/Ool005]oo`03O01oogoo05=oo`03O01oogoo06aoo`00FWoo00=l07ooOol0
Dgoo00=l07ooOol0KGoo001JOol00g`0Oomoo`1BOol00g`0Oomoo`1^Ool005Uoo`03O01oogoo05=o
o`03O01oogoo06ioo`00FGoo00=l07ooOol0DWoo00=l07ooOol0Kgoo001HOol00g`0Oomoo`1BOol0
0g`0Oomoo`1`Ool005Moo`03O01oogoo059oo`03O01oogoo075oo`00Egoo00=l07ooOol0DGoo00=l
07ooOol0LWoo001FOol00g`0Oomoo`1BOol00g`0Oomoo`1bOol005Ioo`03O01oogoo055oo`03O01o
ogoo07=oo`00EGoo00=l07ooOol0DGoo00=l07ooOol0M7oo001EOol00g`0Oomoo`1@Ool00g`0Oomo
o`1eOol005Aoo`03O01oogoo051oo`03O01oogoo07Ioo`00E7oo00=l07ooOol0D7oo00=l07ooOol0
MWoo001COol00g`0Oomoo`1@Ool00g`0Oomoo`1gOol005=oo`03O01oogoo04moo`03O01oogoo07Qo
o`00DWoo00=l07ooOol0Cgoo00=l07ooOol0NGoo001BOol00g`0Oomoo`1>Ool00g`0Oomoo`1jOol0
055oo`03O01oogoo04ioo`03O01oogoo07]oo`00DGoo00=l07ooOol0CGoo00=l07ooOol0O7oo001A
Ool00g`0Oomoo`1<Ool00g`0Oomoo`1mOol0051oo`03O01oogoo04aoo`03O01oogoo07ioo`00D7oo
00=l07ooOol0Bgoo00=l07ooOol0Ogoo001?Ool00g`0Oomoo`1<Ool00g`0Oomoo`1oOol004moo`03
O01oogoo04]oo`03O01oogoo081oo`00CWoo00=l07ooOol0Bgoo00=l07ooOol0PGoo001>Ool00g`0
Oomoo`1:Ool00g`0Oomoo`22Ool004ioo`03O01oogoo04Uoo`03O01oogoo08=oo`00CGoo00=l07oo
Ool0BGoo00=l07ooOol0Q7oo001=Ool00g`0Oomoo`18Ool00g`0Oomoo`25Ool004eoo`03O01oogoo
04Moo`03O01oogoo08Ioo`00C7oo00=l07ooOol0Agoo00=l07ooOol0Qgoo001<Ool00g`0Oomoo`16
Ool00g`0Oomoo`28Ool004aoo`03O01oogoo04Eoo`03O01oogoo08Uoo`00C7oo00=l07ooOol0A7oo
00=l07ooOol0RWoo001;Ool00g`0Oomoo`14Ool00g`0Oomoo`2;Ool004]oo`03O01oogoo04=oo`03
O01oogoo08aoo`00Bgoo00=l07ooOol0@Woo00=l07ooOol0SGoo001;Ool00g`0Oomoo`11Ool00g`0
Oomoo`2>Ool004]oo`03O01oogoo041oo`03O01oogoo08moo`00Bgoo00=l07ooOol0?goo00=l07oo
Ool0T7oo001:Ool00g`0Oomoo`0oOol00g`0Oomoo`2AOol004Yoo`03O01oogoo03eoo`9l09Aoo`00
BWoo00=l07ooOol0?7oo00=l07ooOol0U7oo001:Ool00g`0Oomoo`0kOol00g`0Oomoo`2EOol004Yo
o`03O01oogoo03Yoo`03O01oogoo09Ioo`00BWoo00=l07ooOol0>7oo0W`0VGoo0019Ool00g`0Oomo
o`0hOol00g`0Oomoo`2IOol004Uoo`03O01oogoo03Moo`03O01oogoo09Yoo`00BGoo00=l07ooOol0
=Woo00=l07ooOol0Vgoo0019Ool00g`0Oomoo`0dOol2O02NOol004Uoo`03O01oogoo03=oo`03O01o
ogoo09ioo`00BGoo00=l07ooOol0<Woo00=l07ooOol0Wgoo0019Ool00g`0Oomoo`0aOol00g`0Oomo
o`2POol004Uoo`03O01oogoo02moo`9l0:=oo`00BGoo00=l07ooOol0;Woo00=l07ooOol0Xgoo001:
Ool00g`0Oomoo`0[Ool2O02VOol004Yoo`03O01oogoo02Uoo`9l0:Qoo`00BWoo00=l07ooOol0:7oo
00=l07ooOol0Z7oo001;Ool00g`0Oomoo`0UOol2O02[Ool004]oo`03O01oogoo02=oo`9l0:eoo`00
C7oo00=l07ooOol087oo0W`0[goo001<Ool00g`0Oomoo`0NOol2O02aOol004eoo`03O01oogoo01]o
o`9l0;=oo`00CWoo00=l07ooOol067oo0W`0]Goo001?Ool00g`0Oomoo`0EOol2O02gOol0051oo`03
O01oogoo019oo`9l0;Uoo`00DGoo0W`03goo0g`0^goo001COol?O02nOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.56299 .56205 m
.54636 .57958 L
s
.57922 .54414 m
.56299 .56205 L
s
.59498 .52592 m
.57922 .54414 L
s
.54636 .57958 m
.5294 .59664 L
s
.61021 .50747 m
.59498 .52592 L
s
.5294 .59664 m
.51219 .61317 L
s
.62481 .48888 m
.61021 .50747 L
s
.51219 .61317 m
.4948 .62907 L
s
.63873 .47022 m
.62481 .48888 L
s
.4948 .62907 m
.47731 .64428 L
s
.6519 .45158 m
.63873 .47022 L
s
.47731 .64428 m
.4598 .65872 L
s
.66423 .43306 m
.6519 .45158 L
s
.4598 .65872 m
.44236 .67229 L
s
.67566 .41473 m
.66423 .43306 L
s
.44236 .67229 m
.42506 .68493 L
s
.68611 .39669 m
.67566 .41473 L
s
.42506 .68493 m
.40799 .69655 L
s
.69551 .37905 m
.68611 .39669 L
s
.40799 .69655 m
.39125 .70707 L
s
.70377 .3619 m
.69551 .37905 L
s
.39125 .70707 m
.37494 .7164 L
s
.71083 .34535 m
.70377 .3619 L
s
.37494 .7164 m
.35915 .72447 L
s
.71662 .32952 m
.71083 .34535 L
s
.35915 .72447 m
.34399 .73118 L
s
.72105 .3145 m
.71662 .32952 L
s
.34399 .73118 m
.32957 .73645 L
s
.72405 .30043 m
.72105 .3145 L
s
.32957 .73645 m
.316 .74021 L
s
.72557 .28742 m
.72405 .30043 L
s
.316 .74021 m
.3034 .74238 L
s
.72552 .27559 m
.72557 .28742 L
s
.3034 .74238 m
.29188 .74289 L
s
.72387 .26507 m
.72552 .27559 L
s
.29188 .74289 m
.28157 .74167 L
s
.72055 .25599 m
.72387 .26507 L
s
.28157 .74167 m
.27258 .73866 L
s
.71553 .24846 m
.72055 .25599 L
s
.27258 .73866 m
.26502 .73382 L
s
.70877 .24261 m
.71553 .24846 L
s
.26502 .73382 m
.25902 .72711 L
s
.70027 .23853 m
.70877 .24261 L
s
.25902 .72711 m
.25469 .71851 L
s
.69003 .23635 m
.70027 .23853 L
s
.25469 .71851 m
.25212 .70802 L
s
.67806 .23614 m
.69003 .23635 L
s
.25212 .70802 m
.2514 .69566 L
s
.6644 .23799 m
.67806 .23614 L
s
.2514 .69566 m
.25261 .68146 L
s
.64913 .24196 m
.6644 .23799 L
s
.25261 .68146 m
.25581 .66549 L
s
.63231 .24807 m
.64913 .24196 L
s
.25581 .66549 m
.26103 .64783 L
s
.61406 .25635 m
.63231 .24807 L
s
.26103 .64783 m
.2683 .62861 L
s
.59451 .26678 m
.61406 .25635 L
s
.2683 .62861 m
.2776 .60796 L
s
.57383 .27931 m
.59451 .26678 L
s
.2776 .60796 m
.2889 .58605 L
s
.5522 .29389 m
.57383 .27931 L
s
.2889 .58605 m
.30214 .56307 L
s
.52981 .31039 m
.5522 .29389 L
s
.30214 .56307 m
.31721 .53924 L
s
.5069 .32869 m
.52981 .31039 L
s
.31721 .53924 m
.334 .51479 L
s
.4837 .34862 m
.5069 .32869 L
s
.334 .51479 m
.35235 .48999 L
s
.46045 .36998 m
.4837 .34862 L
s
.35235 .48999 m
.37207 .46509 L
s
.43741 .39255 m
.46045 .36998 L
s
.37207 .46509 m
.39298 .44037 L
s
.41484 .41611 m
.43741 .39255 L
s
.39298 .44037 m
.41484 .41611 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00<5oo`Il05Uo
o`00_Goo17`01Woo0g`0EWoo002iOol4O00=Ool2O01DOol00;Moo`9l01=oo`03O01oogoo055oo`00
]7oo0g`05Woo00=l07ooOol0D7oo002bOol2O00IOol00g`0Oomoo`1@Ool00;1oo`9l01aoo`03O01o
ogoo04moo`00[Woo0W`07Woo00=l07ooOol0Cgoo002/Ool2O00QOol00g`0Oomoo`1>Ool00:Yoo`9l
02=oo`03O01oogoo04ioo`00Z7oo0W`09Goo00=l07ooOol0CWoo002WOol00g`0Oomoo`0VOol00g`0
Oomoo`1=Ool00:Eoo`9l02Uoo`03O01oogoo04eoo`00Y7oo00=l07ooOol0:Goo00=l07ooOol0CGoo
002ROol2O00/Ool00g`0Oomoo`1=Ool00:5oo`03O01oogoo02aoo`03O01oogoo04eoo`00Wgoo0W`0
;goo00=l07ooOol0CGoo002NOol00g`0Oomoo`0^Ool00g`0Oomoo`1>Ool009eoo`03O01oogoo02mo
o`03O01oogoo04ioo`00W7oo00=l07ooOol0<7oo00=l07ooOol0CWoo002JOol2O00cOol00g`0Oomo
o`1>Ool009Uoo`03O01oogoo039oo`03O01oogoo04moo`00V7oo00=l07ooOol0<goo00=l07ooOol0
Cgoo002FOol2O00fOol00g`0Oomoo`1?Ool009Eoo`03O01oogoo03Ioo`03O01oogoo04moo`00U7oo
00=l07ooOol0=Woo00=l07ooOol0D7oo002BOol2O00iOol00g`0Oomoo`1@Ool0095oo`03O01oogoo
03Uoo`03O01oogoo051oo`00T7oo00=l07ooOol0>Woo00=l07ooOol0D7oo002?Ool00g`0Oomoo`0k
Ool00g`0Oomoo`1@Ool008eoo`9l03eoo`03O01oogoo055oo`00S7oo00=l07ooOol0?Goo00=l07oo
Ool0DGoo002;Ool00g`0Oomoo`0nOol00g`0Oomoo`1AOol008Yoo`03O01oogoo03ioo`03O01oogoo
059oo`00RGoo00=l07ooOol0?Woo00=l07ooOol0Dgoo0028Ool00g`0Oomoo`0oOol00g`0Oomoo`1C
Ool008Moo`03O01oogoo03moo`03O01oogoo05Aoo`00QWoo00=l07ooOol0@7oo00=l07ooOol0E7oo
0025Ool00g`0Oomoo`10Ool00g`0Oomoo`1EOol008Aoo`03O01oogoo045oo`03O01oogoo05Eoo`00
Pgoo00=l07ooOol0@Goo00=l07ooOol0EWoo0022Ool00g`0Oomoo`12Ool00g`0Oomoo`1FOol0081o
o`9l04Aoo`03O01oogoo05Moo`00Ogoo00=l07ooOol0A7oo00=l07ooOol0Egoo001nOol00g`0Oomo
o`14Ool00g`0Oomoo`1HOol007eoo`03O01oogoo04Eoo`03O01oogoo05Qoo`00O7oo00=l07ooOol0
AGoo00=l07ooOol0FGoo001kOol00g`0Oomoo`15Ool00g`0Oomoo`1JOol007Yoo`03O01oogoo04Io
o`03O01oogoo05Yoo`00NWoo00=l07ooOol0AGoo00=l07ooOol0Fgoo001iOol00g`0Oomoo`16Ool0
0g`0Oomoo`1KOol007Qoo`03O01oogoo04Ioo`03O01oogoo05aoo`00Mgoo00=l07ooOol0Agoo00=l
07ooOol0G7oo001fOol00g`0Oomoo`17Ool00g`0Oomoo`1MOol007Eoo`03O01oogoo04Qoo`03O01o
ogoo05eoo`00M7oo00=l07ooOol0B7oo00=l07ooOol0GWoo001cOol00g`0Oomoo`19Ool00g`0Oomo
o`1NOol0079oo`03O01oogoo04Uoo`03O01oogoo05moo`00LGoo00=l07ooOol0BGoo00=l07ooOol0
H7oo001`Ool00g`0Oomoo`1:Ool00g`0Oomoo`1POol006moo`03O01oogoo04Yoo`03O01oogoo065o
o`00KWoo00=l07ooOol0Bgoo00=l07ooOol0HGoo001]Ool00g`0Oomoo`1;Ool00g`0Oomoo`1ROol0
06eoo`03O01oogoo04Yoo`03O01oogoo06=oo`00K7oo00=l07ooOol0BWoo00=l07ooOol0I7oo001[
Ool00g`0Oomoo`1;Ool00g`0Oomoo`1TOol006Yoo`03O01oogoo04]oo`03O01oogoo06Eoo`00JGoo
00=l07ooOol0Bgoo00=l07ooOol0IWoo001YOol00g`0Oomoo`1:Ool00g`0Oomoo`1WOol006Qoo`03
O01oogoo04]oo`03O01oogoo06Moo`00Igoo00=l07ooOol0Bgoo00=l07ooOol0J7oo001VOol00g`0
Oomoo`1;Ool00g`0Oomoo`1YOol006Ioo`03O01oogoo04]oo`03O01oogoo06Uoo`00IGoo00=l07oo
Ool0Bgoo00=l07ooOol0JWoo001TOol00g`0Oomoo`1;Ool00g`0Oomoo`1[Ool006=oo`03O01oogoo
04]oo`03O01oogoo06aoo`00HWoo00=l07ooOol0C7oo00=l07ooOol0K7oo001ROol00g`0Oomoo`1;
Ool00g`0Oomoo`1]Ool0065oo`03O01oogoo04]oo`03O01oogoo06ioo`00H7oo00=l07ooOol0Bgoo
00=l07ooOol0Kgoo001OOol00g`0Oomoo`1;Ool00g`0Oomoo`1`Ool005ioo`03O01oogoo04]oo`03
O01oogoo075oo`00GWoo00=l07ooOol0BWoo00=l07ooOol0LWoo001MOol00g`0Oomoo`1:Ool00g`0
Oomoo`1cOol005eoo`03O01oogoo04Uoo`03O01oogoo07Aoo`00G7oo00=l07ooOol0BWoo00=l07oo
Ool0M7oo001LOol00g`0Oomoo`19Ool00g`0Oomoo`1eOol005]oo`03O01oogoo04Uoo`03O01oogoo
07Ioo`00FWoo00=l07ooOol0BWoo00=l07ooOol0MWoo001JOol00g`0Oomoo`19Ool00g`0Oomoo`1g
Ool005Uoo`03O01oogoo04Uoo`03O01oogoo07Qoo`00F7oo00=l07ooOol0BGoo00=l07ooOol0NGoo
001GOol00g`0Oomoo`19Ool00g`0Oomoo`1jOol005Moo`03O01oogoo04Qoo`03O01oogoo07]oo`00
EWoo00=l07ooOol0B7oo00=l07ooOol0O7oo001EOol00g`0Oomoo`18Ool00g`0Oomoo`1mOol005Eo
o`03O01oogoo04Moo`03O01oogoo07ioo`00E7oo00=l07ooOol0Agoo00=l07ooOol0Ogoo001DOol0
0g`0Oomoo`16Ool00g`0Oomoo`20Ool005=oo`03O01oogoo04Ioo`03O01oogoo085oo`00Dgoo00=l
07ooOol0AGoo00=l07ooOol0PWoo001BOol00g`0Oomoo`15Ool00g`0Oomoo`23Ool0055oo`03O01o
ogoo04Eoo`03O01oogoo08Aoo`00DGoo00=l07ooOol0A7oo00=l07ooOol0QGoo001@Ool00g`0Oomo
o`14Ool00g`0Oomoo`26Ool0051oo`03O01oogoo04=oo`03O01oogoo08Moo`00Cgoo00=l07ooOol0
@goo00=l07ooOol0R7oo001?Ool00g`0Oomoo`12Ool00g`0Oomoo`29Ool004moo`03O01oogoo045o
o`03O01oogoo08Yoo`00CWoo00=l07ooOol0@Goo00=l07ooOol0Rgoo001>Ool00g`0Oomoo`10Ool0
0g`0Oomoo`2<Ool004ioo`03O01oogoo03moo`03O01oogoo08eoo`00CGoo00=l07ooOol0?goo00=l
07ooOol0SWoo001=Ool00g`0Oomoo`0nOol00g`0Oomoo`2?Ool004aoo`03O01oogoo03eoo`9l099o
o`00C7oo00=l07ooOol0?7oo00=l07ooOol0TWoo001;Ool00g`0Oomoo`0kOol2O02EOol004]oo`03
O01oogoo03Yoo`03O01oogoo09Eoo`00BWoo00=l07ooOol0>Woo00=l07ooOol0UWoo001:Ool00g`0
Oomoo`0iOol00g`0Oomoo`2GOol004Yoo`03O01oogoo03Qoo`03O01oogoo09Qoo`00BGoo00=l07oo
Ool0>7oo00=l07ooOol0VGoo0019Ool00g`0Oomoo`0gOol00g`0Oomoo`2JOol004Uoo`03O01oogoo
03Eoo`9l09eoo`00BGoo00=l07ooOol0<goo0W`0Wgoo0019Ool00g`0Oomoo`0bOol00g`0Oomoo`2O
Ool004Qoo`03O01oogoo039oo`03O01oogoo0:1oo`00B7oo00=l07ooOol0<7oo0W`0Xgoo0018Ool0
0g`0Oomoo`0_Ool00g`0Oomoo`2SOol004Qoo`03O01oogoo02ioo`03O01oogoo0:Aoo`00B7oo00=l
07ooOol0;Goo00=l07ooOol0YGoo0018Ool00g`0Oomoo`0[Ool2O02XOol004Qoo`03O01oogoo02Yo
o`03O01oogoo0:Qoo`00B7oo00=l07ooOol0:7oo0W`0Zgoo0018Ool00g`0Oomoo`0VOol2O02]Ool0
04Qoo`03O01oogoo02Eoo`03O01oogoo0:eoo`00B7oo00=l07ooOol08goo0W`0/7oo0018Ool00g`0
Oomoo`0QOol2O02bOol004Uoo`03O01oogoo01moo`03O01oogoo0;9oo`00BGoo00=l07ooOol07Goo
0W`0]Goo0019Ool00g`0Oomoo`0JOol3O02gOol004Yoo`03O01oogoo01Moo`9l0;Yoo`00Bgoo00=l
07ooOol057oo0W`0_7oo001<Ool00g`0Oomoo`0AOol2O02nOol004eoo`9l00ioo`=l0<1oo`00Cgoo
0g`01goo17`0`goo001BOol7O037Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BFieldRHCP\  = \ 
        Show[Array[p, {Steps}], ViewPoint \[Rule] {0, 0, 2}];\)\)], "Input",
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.5 .49116 m
.5 .50884 L
s
.5 .47352 m
.5 .49116 L
s
.5 .50884 m
.5 .52648 L
s
.51541 .49343 m
.51535 .51112 L
s
.51538 .47577 m
.51541 .49343 L
s
.51535 .51112 m
.5152 .52877 L
s
.5 .45595 m
.5 .47352 L
s
.5 .52648 m
.5 .54405 L
s
.51526 .45818 m
.51538 .47577 L
s
.53071 .49579 m
.53047 .51349 L
s
.53077 .47809 m
.53071 .49579 L
s
.5152 .52877 m
.51496 .54633 L
s
.53047 .51349 m
.53006 .53116 L
s
.53066 .46046 m
.53077 .47809 L
s
.53006 .53116 m
.52947 .54874 L
s
.5 .4385 m
.5 .45595 L
s
.5 .54405 m
.5 .5615 L
s
.51505 .44071 m
.51526 .45818 L
s
.54576 .49831 m
.54522 .51606 L
s
.54603 .48056 m
.54576 .49831 L
s
.54522 .51606 m
.54443 .53375 L
s
.51496 .54633 m
.51463 .56376 L
s
.54603 .46287 m
.54603 .48056 L
s
.53036 .44294 m
.53066 .46046 L
s
.54443 .53375 m
.54336 .55135 L
s
.52947 .54874 m
.5287 .56617 L
s
.54577 .44529 m
.54603 .46287 L
s
.56039 .50108 m
.55944 .51888 L
s
.56099 .48328 m
.56039 .50108 L
s
.51475 .42342 m
.51505 .44071 L
s
.5 .42125 m
.5 .4385 L
s
.5 .5615 m
.5 .57875 L
s
.55944 .51888 m
.55815 .53661 L
s
.56123 .46552 m
.56099 .48328 L
s
.52988 .42559 m
.53036 .44294 L
s
.51463 .56376 m
.51422 .581 L
s
.54336 .55135 m
.54204 .56878 L
s
.55815 .53661 m
.5565 .55422 L
s
.56112 .44785 m
.56123 .46552 L
s
.54523 .42787 m
.54577 .44529 L
s
.5287 .56617 m
.52775 .58339 L
s
.57445 .50418 m
.57298 .52202 L
s
.57549 .48631 m
.57445 .50418 L
s
.57298 .52202 m
.57108 .53978 L
s
.57608 .46847 m
.57549 .48631 L
s
.51437 .40636 m
.51475 .42342 L
s
.5565 .55422 m
.55452 .57165 L
s
.5 .40423 m
.5 .42125 L
s
.5 .57875 m
.5 .59577 L
s
.52923 .40847 m
.52988 .42559 L
s
.56064 .43035 m
.56112 .44785 L
s
.54204 .56878 m
.54045 .586 L
s
.57108 .53978 m
.56875 .55739 L
s
.51422 .581 m
.51371 .59798 L
s
.57624 .45072 m
.57608 .46847 L
s
.54443 .41067 m
.54523 .42787 L
s
.52775 .58339 m
.52663 .60036 L
s
.58779 .50765 m
.58569 .52552 L
s
.58938 .48973 m
.58779 .50765 L
s
.58569 .52552 m
.58308 .54329 L
s
.56875 .55739 m
.566 .57481 L
s
.59044 .47182 m
.58938 .48973 L
s
.55452 .57165 m
.55218 .58885 L
s
.57594 .43311 m
.57624 .45072 L
s
.5598 .41305 m
.56064 .43035 L
s
.58308 .54329 m
.57997 .56089 L
s
.59098 .45397 m
.59044 .47182 L
s
.51389 .38959 m
.51437 .40636 L
s
.54045 .586 m
.5386 .60294 L
s
.5 .38752 m
.5 .40423 L
s
.5 .59577 m
.5 .61248 L
s
.52838 .39164 m
.52923 .40847 L
s
.51371 .59798 m
.51312 .61466 L
s
.566 .57481 m
.56282 .59197 L
s
.54334 .39376 m
.54443 .41067 L
s
.57997 .56089 m
.57636 .57826 L
s
.60028 .51153 m
.59745 .52941 L
s
.60251 .49358 m
.60028 .51153 L
s
.57519 .4157 m
.57594 .43311 L
s
.59745 .52941 m
.59404 .54715 L
s
.59098 .43625 m
.59098 .45397 L
s
.60415 .4756 m
.60251 .49358 L
s
.55218 .58885 m
.54951 .60575 L
s
.52663 .60036 m
.52533 .617 L
s
.59404 .54715 m
.59005 .5647 L
s
.55859 .39603 m
.5598 .41305 L
s
.60518 .45767 m
.60415 .4756 L
s
.57636 .57826 m
.57225 .59535 L
s
.5386 .60294 m
.5365 .61954 L
s
.59005 .5647 m
.5855 .58199 L
s
.59043 .41872 m
.59098 .43625 L
s
.51331 .37319 m
.51389 .38959 L
s
.56282 .59197 m
.55923 .60881 L
s
.52736 .37517 m
.52838 .39164 L
s
.5 .37117 m
.5 .38752 L
s
.5 .61248 m
.5 .62883 L
s
.61177 .51583 m
.60812 .53368 L
s
.61475 .49787 m
.61177 .51583 L
s
.57398 .39856 m
.57519 .4157 L
s
.60812 .53368 m
.60383 .55135 L
s
.60559 .43985 m
.60518 .45767 L
s
.54198 .37719 m
.54334 .39376 L
s
.61706 .47987 m
.61475 .49787 L
s
.51312 .61466 m
.51244 .63096 L
s
.60383 .55135 m
.59889 .5688 L
s
.54951 .60575 m
.54649 .6223 L
s
.5855 .58199 m
.58039 .59896 L
s
.61869 .46188 m
.61706 .47987 L
s
.55701 .37935 m
.55859 .39603 L
s
.57225 .59535 m
.56766 .61209 L
s
.52533 .617 m
.52385 .63325 L
s
.59889 .5688 m
.59333 .58595 L
s
.60536 .42219 m
.60559 .43985 L
s
.58934 .40144 m
.59043 .41872 L
s
.61762 .53829 m
.61236 .55584 L
s
.62216 .52053 m
.61762 .53829 L
s
.62597 .50263 m
.62216 .52053 L
s
.55923 .60881 m
.55522 .62527 L
s
.61961 .44397 m
.61869 .46188 L
s
.5365 .61954 m
.53413 .63573 L
s
.61236 .55584 m
.60642 .57312 L
s
.5723 .38175 m
.57398 .39856 L
s
.62905 .48463 m
.62597 .50263 L
s
.59333 .58595 m
.58716 .60274 L
s
.58039 .59896 m
.57473 .61555 L
s
.51265 .35721 m
.51331 .37319 L
s
.52614 .35911 m
.52736 .37517 L
s
.5 .35525 m
.5 .37117 L
s
.5 .62883 m
.5 .64475 L
s
.60642 .57312 m
.5998 .59005 L
s
.54033 .36104 m
.54198 .37719 L
s
.63137 .46662 m
.62905 .48463 L
s
.54649 .6223 m
.54314 .63841 L
s
.56766 .61209 m
.56259 .62841 L
s
.6045 .40477 m
.60536 .42219 L
s
.51244 .63096 m
.51166 .64682 L
s
.61982 .4262 m
.61961 .44397 L
s
.58768 .38448 m
.58934 .40144 L
s
.62584 .5432 m
.61959 .56054 L
s
.63134 .52559 m
.62584 .5432 L
s
.55506 .36308 m
.55701 .37935 L
s
.63606 .5078 m
.63134 .52559 L
s
.61959 .56054 m
.61259 .57757 L
s
.5998 .59005 m
.59253 .60658 L
s
.58716 .60274 m
.58039 .6191 L
s
.52385 .63325 m
.5222 .64905 L
s
.63291 .44864 m
.63137 .46662 L
s
.63998 .48987 m
.63606 .5078 L
s
.61259 .57757 m
.60488 .59421 L
s
.55522 .62527 m
.5508 .64126 L
s
.57473 .61555 m
.56853 .63168 L
s
.57015 .36534 m
.5723 .38175 L
s
.53413 .63573 m
.5315 .65145 L
s
.64308 .47188 m
.63998 .48987 L
s
.61931 .40864 m
.61982 .4262 L
s
.60488 .59421 m
.59648 .61039 L
s
.59253 .60658 m
.58461 .62265 L
s
.63275 .5483 m
.62545 .56535 L
s
.63926 .53094 m
.63275 .5483 L
s
.60299 .38766 m
.6045 .40477 L
s
.62545 .56535 m
.61738 .58203 L
s
.63366 .43078 m
.63291 .44864 L
s
.64494 .51333 m
.63926 .53094 L
s
.56259 .62841 m
.55704 .64425 L
s
.61738 .58203 m
.60857 .59828 L
s
.52474 .34355 m
.52614 .35911 L
s
.51189 .34173 m
.51265 .35721 L
s
.58039 .6191 m
.57303 .63497 L
s
.5384 .34537 m
.54033 .36104 L
s
.5 .33985 m
.5 .35525 L
s
.5 .64475 m
.5 .66015 L
s
.54314 .63841 m
.53945 .65402 L
s
.58546 .36792 m
.58768 .38448 L
s
.64976 .49555 m
.64494 .51333 L
s
.64533 .4539 m
.64308 .47188 L
s
.60857 .59828 m
.59903 .61402 L
s
.59648 .61039 m
.5874 .62606 L
s
.51166 .64682 m
.5108 .66216 L
s
.55272 .34729 m
.55506 .36308 L
s
.62995 .57014 m
.6208 .58637 L
s
.63831 .55348 m
.62995 .57014 L
s
.64585 .53646 m
.63831 .55348 L
s
.56853 .63168 m
.56181 .64728 L
s
.6208 .58637 m
.61089 .60212 L
s
.58461 .62265 m
.57606 .63817 L
s
.65371 .47766 m
.64976 .49555 L
s
.5508 .64126 m
.54597 .65673 L
s
.61805 .39137 m
.61931 .40864 L
s
.65252 .51914 m
.64585 .53646 L
s
.6336 .41311 m
.63366 .43078 L
s
.5222 .64905 m
.52037 .66431 L
s
.61089 .60212 m
.60026 .61731 L
s
.59903 .61402 m
.58882 .6292 L
s
.56752 .34941 m
.57015 .36534 L
s
.60081 .37092 m
.60299 .38766 L
s
.64672 .43599 m
.64533 .4539 L
s
.6229 .59042 m
.61193 .60556 L
s
.63312 .57474 m
.6229 .59042 L
s
.64253 .55859 m
.63312 .57474 L
s
.5874 .62606 m
.57768 .64114 L
s
.57303 .63497 m
.56509 .65026 L
s
.65831 .50159 m
.65252 .51914 L
s
.61193 .60556 m
.60023 .6201 L
s
.6511 .54202 m
.64253 .55859 L
s
.60026 .61731 m
.58894 .6319 L
s
.5315 .65145 m
.52861 .66661 L
s
.55704 .64425 m
.55102 .65951 L
s
.65676 .45973 m
.65371 .47766 L
s
.62376 .59401 m
.61178 .60843 L
s
.635 .579 m
.62376 .59401 L
s
.61178 .60843 m
.59908 .62222 L
s
.64544 .56346 m
.635 .579 L
s
.60023 .6201 m
.58786 .63399 L
s
.58882 .6292 m
.57795 .64374 L
s
.65879 .5251 m
.6511 .54202 L
s
.58266 .35182 m
.58546 .36792 L
s
.59908 .62222 m
.58574 .6353 L
s
.57606 .63817 m
.56692 .65307 L
s
.66317 .48388 m
.65831 .50159 L
s
.52315 .32856 m
.52474 .34355 L
s
.65503 .54746 m
.64544 .56346 L
s
.51104 .32683 m
.51189 .34173 L
s
.53945 .65402 m
.53542 .66905 L
s
.58894 .6319 m
.57696 .6458 L
s
.53619 .33028 m
.5384 .34537 L
s
.63271 .39569 m
.6336 .41311 L
s
.56181 .64728 m
.55456 .66228 L
s
.64721 .41823 m
.64672 .43599 L
s
.5 .32503 m
.5 .33985 L
s
.5 .66015 m
.5 .67497 L
s
.58574 .6353 m
.57178 .64763 L
s
.58786 .63399 m
.57485 .64715 L
s
.61604 .37445 m
.61805 .39137 L
s
.66556 .50789 m
.65879 .5251 L
s
.57768 .64114 m
.56734 .65556 L
s
.54999 .33207 m
.55272 .34729 L
s
.65886 .44182 m
.65676 .45973 L
s
.66373 .53105 m
.65503 .54746 L
s
.5108 .66216 m
.50984 .67689 L
s
.54597 .65673 m
.54075 .67159 L
s
.57795 .64374 m
.56645 .65757 L
s
.56509 .65026 m
.55661 .66491 L
s
.59796 .35464 m
.60081 .37092 L
s
.66707 .46608 m
.66317 .48388 L
s
.57178 .64763 m
.55727 .65915 L
s
.57696 .6458 m
.56437 .65895 L
s
.56441 .33403 m
.56752 .34941 L
s
.57485 .64715 m
.56125 .65952 L
s
.52037 .66431 m
.51836 .67894 L
s
.67137 .49046 m
.66556 .50789 L
s
.6715 .5143 m
.66373 .53105 L
s
.56692 .65307 m
.5572 .66729 L
s
.55102 .65951 m
.54455 .67413 L
s
.6468 .40069 m
.64721 .41823 L
s
.63097 .37861 m
.63271 .39569 L
s
.52861 .66661 m
.52546 .68113 L
s
.55727 .65915 m
.54225 .66979 L
s
.66001 .42402 m
.65886 .44182 L
s
.56734 .65556 m
.55642 .66925 L
s
.57928 .33628 m
.58266 .35182 L
s
.66998 .44825 m
.66707 .46608 L
s
.56125 .65952 m
.54711 .67105 L
s
.61326 .35798 m
.61604 .37445 L
s
.56645 .65757 m
.55437 .67063 L
s
.55456 .66228 m
.54682 .67659 L
s
.56437 .65895 m
.55122 .67129 L
s
.67619 .47288 m
.67137 .49046 L
s
.67829 .49727 m
.6715 .5143 L
s
.53542 .66905 m
.53107 .68342 L
s
.52137 .31423 m
.52315 .32856 L
s
.5101 .3126 m
.51104 .32683 L
s
.53368 .31584 m
.53619 .33028 L
s
.55661 .66491 m
.54758 .67884 L
s
.54225 .66979 m
.52679 .6795 L
s
.5 .31089 m
.5 .32503 L
s
.5 .67497 m
.5 .68911 L
s
.54688 .3175 m
.54999 .33207 L
s
.59443 .33891 m
.59796 .35464 L
s
.54075 .67159 m
.53513 .68574 L
s
.5572 .66729 m
.54692 .68073 L
s
.66017 .4064 m
.66001 .42402 L
s
.50984 .67689 m
.50879 .69093 L
s
.64545 .38345 m
.6468 .40069 L
s
.54711 .67105 m
.53248 .68166 L
s
.67186 .43048 m
.66998 .44825 L
s
.56081 .31931 m
.56441 .33403 L
s
.67995 .45523 m
.67619 .47288 L
s
.68404 .48003 m
.67829 .49727 L
s
.55642 .66925 m
.54493 .68212 L
s
.62838 .36194 m
.63097 .37861 L
s
.55122 .67129 m
.53753 .68273 L
s
.55437 .67063 m
.54174 .68284 L
s
.54455 .67413 m
.53763 .68802 L
s
.51836 .67894 m
.51618 .69287 L
s
.52679 .6795 m
.51093 .68821 L
s
.60969 .34204 m
.61326 .35798 L
s
.57531 .32137 m
.57928 .33628 L
s
.54682 .67659 m
.53858 .69013 L
s
.52546 .68113 m
.52206 .69492 L
s
.53248 .68166 m
.5174 .69129 L
s
.54758 .67884 m
.53805 .69194 L
s
.68871 .46265 m
.68404 .48003 L
s
.67269 .41284 m
.67186 .43048 L
s
.68264 .43757 m
.67995 .45523 L
s
.65932 .38905 m
.66017 .4064 L
s
.53107 .68342 m
.52639 .69702 L
s
.64315 .36661 m
.64545 .38345 L
s
.53753 .68273 m
.52337 .69322 L
s
.54692 .68073 m
.53612 .69332 L
s
.59021 .3238 m
.59443 .33891 L
s
.5194 .30065 m
.52137 .31423 L
s
.53088 .30214 m
.53368 .31584 L
s
.54174 .68284 m
.5286 .69411 L
s
.54493 .68212 m
.53292 .69409 L
s
.50906 .29913 m
.5101 .3126 L
s
.54337 .30367 m
.54688 .3175 L
s
.6249 .34579 m
.62838 .36194 L
s
.51093 .68821 m
.49475 .69586 L
s
.53513 .68574 m
.52912 .69911 L
s
.5 .29752 m
.5 .31089 L
s
.5 .68911 m
.5 .70248 L
s
.55671 .30533 m
.56081 .31931 L
s
.50879 .69093 m
.50766 .70419 L
s
.53763 .68802 m
.53028 .70107 L
s
.5174 .69129 m
.50195 .69987 L
s
.60534 .32672 m
.60969 .34204 L
s
.69226 .44521 m
.68871 .46265 L
s
.68421 .41999 m
.68264 .43757 L
s
.67242 .39542 m
.67269 .41284 L
s
.51618 .69287 m
.51382 .706 L
s
.57074 .30721 m
.57531 .32137 L
s
.53858 .69013 m
.52988 .7028 L
s
.65742 .37205 m
.65932 .38905 L
s
.52337 .69322 m
.50878 .70267 L
s
.63988 .35025 m
.64315 .36661 L
s
.53805 .69194 m
.52803 .70415 L
s
.49475 .69586 m
.4783 .7024 L
s
.52206 .69492 m
.51841 .70788 L
s
.5286 .69411 m
.515 .70437 L
s
.53612 .69332 m
.52482 .70496 L
s
.53292 .69409 m
.52042 .70509 L
s
.58528 .30943 m
.59021 .3238 L
s
.62053 .33024 m
.6249 .34579 L
s
.52639 .69702 m
.52139 .70977 L
s
.50195 .69987 m
.48618 .70732 L
s
.69463 .42779 m
.69226 .44521 L
s
.52779 .2893 m
.53088 .30214 L
s
.51723 .28793 m
.5194 .30065 L
s
.68461 .40258 m
.68421 .41999 L
s
.53947 .29069 m
.54337 .30367 L
s
.50792 .28652 m
.50906 .29913 L
s
.52912 .69911 m
.52275 .71158 L
s
.67103 .37832 m
.67242 .39542 L
s
.5 .28503 m
.5 .29752 L
s
.5 .70248 m
.5 .71497 L
s
.55212 .29218 m
.55671 .30533 L
s
.60018 .31212 m
.60534 .32672 L
s
.50878 .70267 m
.49382 .711 L
s
.65446 .3555 m
.65742 .37205 L
s
.53028 .70107 m
.52251 .71321 L
s
.4783 .7024 m
.46167 .70775 L
s
.50766 .70419 m
.50643 .71656 L
s
.515 .70437 m
.50099 .71353 L
s
.63561 .33446 m
.63988 .35025 L
s
.52988 .7028 m
.52074 .71451 L
s
.56557 .29388 m
.57074 .30721 L
s
.52803 .70415 m
.51754 .71535 L
s
.52042 .70509 m
.50748 .71501 L
s
.52482 .70496 m
.51307 .71557 L
s
.51382 .706 m
.51129 .71821 L
s
.69578 .41048 m
.69463 .42779 L
s
.48618 .70732 m
.47016 .71358 L
s
.61526 .31539 m
.62053 .33024 L
s
.51841 .70788 m
.51452 .7199 L
s
.68382 .38543 m
.68461 .40258 L
s
.57965 .29589 m
.58528 .30943 L
s
.66848 .36162 m
.67103 .37832 L
s
.52139 .70977 m
.51609 .72155 L
s
.49382 .711 m
.47855 .71814 L
s
.46167 .70775 m
.44492 .71185 L
s
.65041 .3395 m
.65446 .3555 L
s
.52442 .27741 m
.52779 .2893 L
s
.51488 .27617 m
.51723 .28793 L
s
.52275 .71158 m
.51602 .72306 L
s
.59421 .29833 m
.60018 .31212 L
s
.53518 .27866 m
.53947 .29069 L
s
.50099 .71353 m
.48663 .72151 L
s
.5067 .27488 m
.50792 .28652 L
s
.63034 .31936 m
.63561 .33446 L
s
.54703 .27999 m
.55212 .29218 L
s
.52251 .71321 m
.51435 .72431 L
s
.5 .27352 m
.5 .28503 L
s
.5 .71497 m
.5 .72648 L
s
.50748 .71501 m
.49416 .72377 L
s
.69566 .39336 m
.69578 .41048 L
s
.52074 .71451 m
.51118 .72515 L
s
.47016 .71358 m
.45396 .71857 L
s
.51307 .71557 m
.5009 .72504 L
s
.51754 .71535 m
.50664 .72545 L
s
.5598 .28149 m
.56557 .29388 L
s
.68179 .36863 m
.68382 .38543 L
s
.50643 .71656 m
.50512 .72792 L
s
.60907 .30135 m
.61526 .31539 L
s
.66476 .34543 m
.66848 .36162 L
s
.51129 .71821 m
.5086 .72941 L
s
.44492 .71185 m
.42816 .71464 L
s
.57332 .28329 m
.57965 .29589 L
s
.47855 .71814 m
.46305 .72401 L
s
.64525 .32416 m
.65041 .3395 L
s
.51452 .7199 m
.51039 .73088 L
s
.48663 .72151 m
.47198 .72822 L
s
.51609 .72155 m
.51049 .73226 L
s
.58743 .28549 m
.59421 .29833 L
s
.62405 .30505 m
.63034 .31936 L
s
.69423 .37655 m
.69566 .39336 L
s
.45396 .71857 m
.43767 .72221 L
s
.51602 .72306 m
.50894 .73343 L
s
.49416 .72377 m
.4805 .73127 L
s
.52075 .2666 m
.52442 .27741 L
s
.5305 .2677 m
.53518 .27866 L
s
.67848 .3523 m
.68179 .36863 L
s
.51234 .26549 m
.51488 .27617 L
s
.51435 .72431 m
.50582 .73427 L
s
.54145 .26886 m
.54703 .27999 L
s
.5009 .72504 m
.48837 .73327 L
s
.50538 .26433 m
.5067 .27488 L
s
.51118 .72515 m
.50123 .73462 L
s
.50664 .72545 m
.49535 .73434 L
s
.65982 .32986 m
.66476 .34543 L
s
.42816 .71464 m
.41146 .71606 L
s
.5 .26311 m
.5 .27352 L
s
.5 .72648 m
.5 .73689 L
s
.55342 .27017 m
.5598 .28149 L
s
.60196 .28823 m
.60907 .30135 L
s
.46305 .72401 m
.44739 .72852 L
s
.50512 .72792 m
.50373 .73817 L
s
.63897 .30958 m
.64525 .32416 L
s
.56628 .27174 m
.57332 .28329 L
s
.5086 .72941 m
.50575 .73946 L
s
.47198 .72822 m
.45711 .73357 L
s
.69144 .36015 m
.69423 .37655 L
s
.43767 .72221 m
.42138 .72445 L
s
.61672 .29165 m
.62405 .30505 L
s
.51039 .73088 m
.50604 .74069 L
s
.57984 .27369 m
.58743 .28549 L
s
.67388 .33655 m
.67848 .3523 L
s
.4805 .73127 m
.46657 .73742 L
s
.51049 .73226 m
.50462 .74177 L
s
.65366 .31502 m
.65982 .32986 L
s
.41146 .71606 m
.39492 .71603 L
s
.48837 .73327 m
.47553 .74017 L
s
.50894 .73343 m
.50155 .74258 L
s
.52544 .25792 m
.5305 .2677 L
s
.51681 .25698 m
.52075 .2666 L
s
.50582 .73427 m
.49695 .74297 L
s
.49535 .73434 m
.48373 .74191 L
s
.44739 .72852 m
.43166 .73159 L
s
.50123 .73462 m
.49094 .7428 L
s
.53538 .25891 m
.54145 .26886 L
s
.50961 .25601 m
.51234 .26549 L
s
.59393 .27616 m
.60196 .28823 L
s
.50398 .255 m
.50538 .26433 L
s
.63155 .29588 m
.63897 .30958 L
s
.54646 .26003 m
.55342 .27017 L
s
.5 .25393 m
.5 .26311 L
s
.5 .73689 m
.5 .74607 L
s
.68727 .34426 m
.69144 .36015 L
s
.45711 .73357 m
.4421 .73746 L
s
.55854 .26138 m
.56628 .27174 L
s
.42138 .72445 m
.40518 .7252 L
s
.50373 .73817 m
.50225 .74717 L
s
.66795 .32148 m
.67388 .33655 L
s
.60837 .27928 m
.61672 .29165 L
s
.50575 .73946 m
.50274 .74824 L
s
.46657 .73742 m
.45244 .74212 L
s
.57143 .26307 m
.57984 .27369 L
s
.39492 .71603 m
.37866 .71451 L
s
.64626 .30104 m
.65366 .31502 L
s
.50604 .74069 m
.50147 .74921 L
s
.47553 .74017 m
.46244 .74561 L
s
.43166 .73159 m
.41595 .73314 L
s
.50462 .74177 m
.49849 .74996 L
s
.48373 .74191 m
.47183 .74806 L
s
.50155 .74258 m
.49388 .75037 L
s
.58498 .26525 m
.59393 .27616 L
s
.62299 .28319 m
.63155 .29588 L
s
.49094 .7428 m
.48035 .74957 L
s
.49695 .74297 m
.48777 .75029 L
s
.52 .24947 m
.52544 .25792 L
s
.68167 .32902 m
.68727 .34426 L
s
.51259 .24868 m
.51681 .25698 L
s
.52883 .25028 m
.53538 .25891 L
s
.50671 .24787 m
.50961 .25601 L
s
.40518 .7252 m
.38918 .7244 L
s
.4421 .73746 m
.42703 .73982 L
s
.53892 .2512 m
.54646 .26003 L
s
.50249 .24701 m
.50398 .255 L
s
.66067 .30723 m
.66795 .32148 L
s
.55011 .25232 m
.55854 .26138 L
s
.59899 .26806 m
.60837 .27928 L
s
.5 .24611 m
.5 .25393 L
s
.5 .74607 m
.5 .75389 L
s
.37866 .71451 m
.36278 .71144 L
s
.45244 .74212 m
.43819 .74526 L
s
.6376 .28803 m
.64626 .30104 L
s
.50225 .74717 m
.5007 .75479 L
s
.56223 .25376 m
.57143 .26307 L
s
.41595 .73314 m
.40035 .73309 L
s
.50274 .74824 m
.4996 .75562 L
s
.46244 .74561 m
.44918 .74951 L
s
.50147 .74921 m
.49671 .7563 L
s
.61329 .27164 m
.62299 .28319 L
s
.67462 .31454 m
.68167 .32902 L
s
.47183 .74806 m
.45971 .75266 L
s
.57512 .25564 m
.58498 .26525 L
s
.49849 .74996 m
.49212 .7567 L
s
.38918 .7244 m
.37348 .72199 L
s
.48035 .74957 m
.46952 .75481 L
s
.49388 .75037 m
.48594 .75668 L
s
.48777 .75029 m
.47834 .7561 L
s
.42703 .73982 m
.41201 .74054 L
s
.65204 .29392 m
.66067 .30723 L
s
.51421 .24246 m
.52 .24947 L
s
.52182 .2431 m
.52883 .25028 L
s
.50811 .24184 m
.51259 .24868 L
s
.53081 .24381 m
.53892 .2512 L
s
.36278 .71144 m
.34742 .70678 L
s
.58859 .25813 m
.59899 .26806 L
s
.50364 .24119 m
.50671 .24787 L
s
.54101 .2447 m
.55011 .25232 L
s
.6277 .27614 m
.6376 .28803 L
s
.43819 .74526 m
.42392 .74675 L
s
.50092 .2405 m
.50249 .24701 L
s
.40035 .73309 m
.38499 .73137 L
s
.5 .23979 m
.5 .24611 L
s
.5 .75389 m
.5 .76021 L
s
.55226 .24587 m
.56223 .25376 L
s
.44918 .74951 m
.43582 .75174 L
s
.66611 .30096 m
.67462 .31454 L
s
.5007 .75479 m
.49908 .76089 L
s
.60247 .26137 m
.61329 .27164 L
s
.37348 .72199 m
.35822 .7179 L
s
.4996 .75562 m
.49632 .76146 L
s
.56438 .24746 m
.57512 .25564 L
s
.45971 .75266 m
.44744 .75559 L
s
.64204 .28169 m
.65204 .29392 L
s
.41201 .74054 m
.39714 .73955 L
s
.49671 .7563 m
.49178 .76182 L
s
.46952 .75481 m
.45849 .7584 L
s
.49212 .7567 m
.48555 .76184 L
s
.34742 .70678 m
.33269 .70048 L
s
.47834 .7561 m
.4687 .76028 L
s
.48594 .75668 m
.4778 .76138 L
s
.5772 .24962 m
.58859 .25813 L
s
.61656 .2655 m
.6277 .27614 L
s
.51437 .2375 m
.52182 .2431 L
s
.50807 .23705 m
.51421 .24246 L
s
.52216 .23801 m
.53081 .24381 L
s
.42392 .74675 m
.40972 .74649 L
s
.50338 .2366 m
.50811 .24184 L
s
.38499 .73137 m
.36998 .72792 L
s
.53126 .23866 m
.54101 .2447 L
s
.50042 .23613 m
.50364 .24119 L
s
.65613 .28841 m
.66611 .30096 L
s
.54153 .23956 m
.55226 .24587 L
s
.49927 .23562 m
.50092 .2405 L
s
.59054 .25249 m
.60247 .26137 L
s
.43582 .75174 m
.42246 .75221 L
s
.35822 .7179 m
.34353 .71209 L
s
.5 .23511 m
.5 .23979 L
s
.5 .76021 m
.5 .76489 L
s
.63069 .27068 m
.64204 .28169 L
s
.55279 .24085 m
.56438 .24746 L
s
.39714 .73955 m
.38253 .73677 L
s
.49908 .76089 m
.49739 .76533 L
s
.44744 .75559 m
.43511 .75676 L
s
.33269 .70048 m
.31874 .69251 L
s
.49632 .76146 m
.49293 .76562 L
s
.45849 .7584 m
.44736 .76022 L
s
.6042 .25625 m
.61656 .2655 L
s
.49178 .76182 m
.48669 .76564 L
s
.56485 .24266 m
.5772 .24962 L
s
.4687 .76028 m
.45891 .7627 L
s
.48555 .76184 m
.47882 .76526 L
s
.4778 .76138 m
.46948 .76433 L
s
.36998 .72792 m
.35544 .72268 L
s
.40972 .74649 m
.39569 .74441 L
s
.50651 .23362 m
.51437 .2375 L
s
.513 .23391 m
.52216 .23801 L
s
.64468 .27705 m
.65613 .28841 L
s
.50161 .23337 m
.50807 .23705 L
s
.52091 .23433 m
.53126 .23866 L
s
.49842 .23311 m
.50338 .2366 L
s
.57754 .24517 m
.59054 .25249 L
s
.34353 .71209 m
.32953 .70453 L
s
.5301 .23496 m
.54153 .23956 L
s
.42246 .75221 m
.40921 .75082 L
s
.49705 .23281 m
.50042 .23613 L
s
.61802 .26103 m
.63069 .27068 L
s
.38253 .73677 m
.36832 .73213 L
s
.49756 .23251 m
.49927 .23562 L
s
.31874 .69251 m
.30571 .68286 L
s
.54038 .23593 m
.55279 .24085 L
s
.43511 .75676 m
.4228 .75605 L
s
.5 .23222 m
.5 .23511 L
s
.5 .76489 m
.5 .76778 L
s
.59067 .24852 m
.6042 .25625 L
s
.49739 .76533 m
.49565 .76796 L
s
.55158 .2374 m
.56485 .24266 L
s
.35544 .72268 m
.34152 .71559 L
s
.44736 .76022 m
.43618 .76015 L
s
.49293 .76562 m
.48944 .76795 L
s
.39569 .74441 m
.38196 .74041 L
s
.6318 .267 m
.64468 .27705 L
s
.45891 .7627 m
.44904 .76323 L
s
.48669 .76564 m
.48149 .76761 L
s
.46948 .76433 m
.46106 .7654 L
s
.47882 .76526 m
.47196 .76681 L
s
.32953 .70453 m
.31637 .69519 L
s
.56352 .23952 m
.57754 .24517 L
s
.50337 .23168 m
.513 .23391 L
s
.49828 .23161 m
.50651 .23362 L
s
.51 .23184 m
.52091 .23433 L
s
.60405 .25288 m
.61802 .26103 L
s
.49487 .23156 m
.50161 .23337 L
s
.40921 .75082 m
.39616 .74747 L
s
.51801 .23219 m
.5301 .23496 L
s
.30571 .68286 m
.29374 .67153 L
s
.36832 .73213 m
.35462 .72558 L
s
.49326 .23149 m
.49842 .23311 L
s
.52722 .23285 m
.54038 .23593 L
s
.49355 .2314 m
.49705 .23281 L
s
.576 .24245 m
.59067 .24852 L
s
.4228 .75605 m
.41062 .75335 L
s
.49579 .2313 m
.49756 .23251 L
s
.34152 .71559 m
.32836 .70663 L
s
.53746 .23396 m
.55158 .2374 L
s
.6175 .25843 m
.6318 .267 L
s
.5 .23126 m
.5 .23222 L
s
.5 .76778 m
.5 .76874 L
s
.38196 .74041 m
.36866 .73443 L
s
.43618 .76015 m
.42506 .75808 L
s
.31637 .69519 m
.30421 .68405 L
s
.49565 .76796 m
.49386 .76865 L
s
.44904 .76323 m
.43916 .76175 L
s
.54854 .23568 m
.56352 .23952 L
s
.58884 .24637 m
.60405 .25288 L
s
.48944 .76795 m
.48588 .76832 L
s
.46106 .7654 m
.45258 .76447 L
s
.48149 .76761 m
.47621 .7676 L
s
.29374 .67153 m
.28299 .65853 L
s
.47196 .76681 m
.46502 .76637 L
s
.49333 .23142 m
.50337 .23168 L
s
.49859 .23133 m
.51 .23184 L
s
.35462 .72558 m
.34159 .71707 L
s
.39616 .74747 m
.38344 .7421 L
s
.48972 .23158 m
.49828 .23161 L
s
.50533 .23139 m
.51801 .23219 L
s
.48788 .23175 m
.49487 .23156 L
s
.56027 .23818 m
.576 .24245 L
s
.51338 .23172 m
.52722 .23285 L
s
.48793 .2319 m
.49326 .23149 L
s
.32836 .70663 m
.3161 .69577 L
s
.60186 .25146 m
.6175 .25843 L
s
.41062 .75335 m
.39868 .74858 L
s
.52256 .23247 m
.53746 .23396 L
s
.48995 .23202 m
.49355 .2314 L
s
.36866 .73443 m
.35593 .72642 L
s
.30421 .68405 m
.29319 .67114 L
s
.49398 .23215 m
.49579 .2313 L
s
.57247 .24164 m
.58884 .24637 L
s
.42506 .75808 m
.4141 .75391 L
s
.53269 .23378 m
.54854 .23568 L
s
.28299 .65853 m
.27361 .64389 L
s
.5 .23237 m
.5 .23126 L
s
.5 .76874 m
.5 .76763 L
s
.43916 .76175 m
.42936 .75815 L
s
.34159 .71707 m
.32937 .70657 L
s
.49386 .76865 m
.49205 .76725 L
s
.38344 .7421 m
.37118 .73462 L
s
.48588 .76832 m
.48228 .76658 L
s
.45258 .76447 m
.44412 .76141 L
s
.48674 .23291 m
.49859 .23133 L
s
.54357 .23583 m
.56027 .23818 L
s
.49213 .23267 m
.50533 .23139 L
s
.48294 .23328 m
.49333 .23142 L
s
.47621 .7676 m
.47088 .76548 L
s
.46502 .76637 m
.45807 .76381 L
s
.48088 .23368 m
.48972 .23158 L
s
.49893 .23267 m
.51338 .23172 L
s
.58494 .24623 m
.60186 .25146 L
s
.3161 .69577 m
.3049 .68304 L
s
.48069 .23408 m
.48788 .23175 L
s
.50697 .23304 m
.52256 .23247 L
s
.29319 .67114 m
.28346 .65648 L
s
.39868 .74858 m
.3871 .74167 L
s
.48247 .23445 m
.48793 .2319 L
s
.35593 .72642 m
.3439 .71634 L
s
.55502 .2388 m
.57247 .24164 L
s
.27361 .64389 m
.26573 .62768 L
s
.51606 .23393 m
.53269 .23378 L
s
.48628 .23481 m
.48995 .23202 L
s
.4141 .75391 m
.40339 .74756 L
s
.32937 .70657 m
.31811 .69409 L
s
.49213 .23519 m
.49398 .23215 L
s
.526 .23551 m
.54357 .23583 L
s
.37118 .73462 m
.35952 .72501 L
s
.42936 .75815 m
.41973 .75235 L
s
.5 .23567 m
.5 .23237 L
s
.5 .76763 m
.5 .76433 L
s
.56684 .24287 m
.58494 .24623 L
s
.3049 .68304 m
.29491 .66844 L
s
.4785 .23615 m
.49213 .23267 L
s
.47454 .2367 m
.48674 .23291 L
s
.49205 .76725 m
.49021 .76364 L
s
.48398 .2358 m
.49893 .23267 L
s
.44412 .76141 m
.43577 .75613 L
s
.47227 .23735 m
.48294 .23328 L
s
.48228 .76658 m
.47866 .76262 L
s
.28346 .65648 m
.27518 .64013 L
s
.45807 .76381 m
.45115 .75901 L
s
.47088 .76548 m
.46555 .76112 L
s
.4908 .23577 m
.50697 .23304 L
s
.47183 .23802 m
.48088 .23368 L
s
.53661 .23797 m
.55502 .2388 L
s
.26573 .62768 m
.25951 .60997 L
s
.3439 .71634 m
.33272 .70419 L
s
.3871 .74167 m
.376 .73255 L
s
.47335 .23866 m
.48069 .23408 L
s
.49877 .23622 m
.51606 .23393 L
s
.47691 .23927 m
.48247 .23445 L
s
.31811 .69409 m
.30796 .67965 L
s
.5077 .23732 m
.526 .23551 L
s
.40339 .74756 m
.39307 .73895 L
s
.5477 .2415 m
.56684 .24287 L
s
.48255 .23987 m
.48628 .23481 L
s
.29491 .66844 m
.28629 .65205 L
s
.35952 .72501 m
.3486 .71324 L
s
.49027 .24052 m
.49213 .23519 L
s
.27518 .64013 m
.26849 .62217 L
s
.41973 .75235 m
.41038 .74425 L
s
.46457 .2419 m
.4785 .23615 L
s
.46866 .24118 m
.48398 .2358 L
s
.51738 .23925 m
.53661 .23797 L
s
.4621 .24278 m
.47454 .2367 L
s
.25951 .60997 m
.25507 .59087 L
s
.47419 .24075 m
.4908 .23577 L
s
.5 .24129 m
.5 .23567 L
s
.5 .76433 m
.5 .75871 L
s
.46141 .24373 m
.47227 .23735 L
s
.43577 .75613 m
.4276 .74853 L
s
.33272 .70419 m
.32255 .68997 L
s
.49021 .76364 m
.48838 .7577 L
s
.48097 .24074 m
.49877 .23622 L
s
.45115 .75901 m
.44436 .75188 L
s
.376 .73255 m
.36553 .7212 L
s
.46265 .24468 m
.47183 .23802 L
s
.47866 .76262 m
.47506 .75632 L
s
.46555 .76112 m
.46029 .75443 L
s
.30796 .67965 m
.29908 .6633 L
s
.52764 .24221 m
.5477 .2415 L
s
.4888 .24134 m
.5077 .23732 L
s
.46593 .24559 m
.47335 .23866 L
s
.28629 .65205 m
.27917 .63394 L
s
.39307 .73895 m
.38324 .72805 L
s
.26849 .62217 m
.26352 .60272 L
s
.4713 .24646 m
.47691 .23927 L
s
.3486 .71324 m
.33857 .69932 L
s
.49749 .24271 m
.51738 .23925 L
s
.25507 .59087 m
.25253 .57052 L
s
.47881 .24733 m
.48255 .23987 L
s
.45309 .24889 m
.46866 .24118 L
s
.45727 .24802 m
.47419 .24075 L
s
.45044 .25 m
.46457 .2419 L
s
.41038 .74425 m
.40143 .73382 L
s
.44952 .25123 m
.4621 .24278 L
s
.32255 .68997 m
.31354 .67375 L
s
.4628 .24754 m
.48097 .24074 L
s
.48841 .24825 m
.49027 .24052 L
s
.50684 .24507 m
.52764 .24221 L
s
.45047 .25249 m
.46141 .24373 L
s
.29908 .6633 m
.29162 .64512 L
s
.46948 .24761 m
.4888 .24134 L
s
.36553 .7212 m
.35582 .70762 L
s
.4276 .74853 m
.41972 .73855 L
s
.5 .24932 m
.5 .24129 L
s
.5 .75871 m
.5 .75068 L
s
.27917 .63394 m
.2737 .61422 L
s
.45343 .25374 m
.46265 .24468 L
s
.48838 .7577 m
.48657 .74934 L
s
.44436 .75188 m
.43775 .74235 L
s
.26352 .60272 m
.26039 .58191 L
s
.47506 .75632 m
.47152 .7476 L
s
.46029 .75443 m
.45514 .74532 L
s
.25253 .57052 m
.25199 .54909 L
s
.47711 .24841 m
.49749 .24271 L
s
.45849 .25493 m
.46593 .24559 L
s
.33857 .69932 m
.32957 .68328 L
s
.38324 .72805 m
.37405 .71485 L
s
.44021 .25763 m
.45727 .24802 L
s
.43742 .25895 m
.45309 .24889 L
s
.44444 .25665 m
.4628 .24754 L
s
.46571 .25608 m
.4713 .24646 L
s
.48549 .25014 m
.50684 .24507 L
s
.43626 .26046 m
.45044 .25 L
s
.31354 .67375 m
.30583 .65558 L
s
.44992 .25617 m
.46948 .24761 L
s
.29162 .64512 m
.28571 .62522 L
s
.43692 .26207 m
.44952 .25123 L
s
.40143 .73382 m
.39297 .72102 L
s
.47509 .25723 m
.47881 .24733 L
s
.2737 .61422 m
.27 .59304 L
s
.26039 .58191 m
.2592 .55991 L
s
.25199 .54909 m
.25353 .52675 L
s
.35582 .70762 m
.34701 .69184 L
s
.45644 .25636 m
.47711 .24841 L
s
.43954 .26368 m
.45047 .25249 L
s
.48656 .25845 m
.48841 .24825 L
s
.41972 .73855 m
.41222 .72617 L
s
.5 .25983 m
.5 .24932 L
s
.5 .75068 m
.5 .74017 L
s
.44425 .26524 m
.45343 .25374 L
s
.4638 .25743 m
.48549 .25014 L
s
.32957 .68328 m
.32175 .66521 L
s
.43775 .74235 m
.43142 .73038 L
s
.48657 .74934 m
.48479 .7385 L
s
.42319 .26957 m
.44021 .25763 L
s
.42609 .26806 m
.44444 .25665 L
s
.45514 .74532 m
.45017 .73375 L
s
.47152 .7476 m
.46808 .73641 L
s
.37405 .71485 m
.36563 .69937 L
s
.42182 .27136 m
.43742 .25895 L
s
.43033 .267 m
.44992 .25617 L
s
.30583 .65558 m
.29957 .63559 L
s
.45112 .26674 m
.45849 .25493 L
s
.28571 .62522 m
.28148 .60376 L
s
.2592 .55991 m
.26004 .53693 L
s
.27 .59304 m
.26817 .57058 L
s
.25353 .52675 m
.2572 .50372 L
s
.42219 .27331 m
.43626 .26046 L
s
.4357 .26656 m
.45644 .25636 L
s
.4602 .26819 m
.46571 .25608 L
s
.42445 .27531 m
.43692 .26207 L
s
.39297 .72102 m
.38515 .70588 L
s
.34701 .69184 m
.33924 .67393 L
s
.442 .26694 m
.4638 .25743 L
s
.47144 .26963 m
.47509 .25723 L
s
.42876 .27729 m
.43954 .26368 L
s
.40795 .28173 m
.42609 .26806 L
s
.41093 .28006 m
.43033 .267 L
s
.32175 .66521 m
.31525 .64521 L
s
.4064 .28379 m
.42319 .26957 L
s
.2572 .50372 m
.26302 .48024 L
s
.26004 .53693 m
.26295 .51319 L
s
.41222 .72617 m
.40522 .71138 L
s
.26817 .57058 m
.2683 .54705 L
s
.41512 .27896 m
.4357 .26656 L
s
.29957 .63559 m
.29488 .61394 L
s
.48476 .27115 m
.48656 .25845 L
s
.28148 .60376 m
.27903 .58092 L
s
.40648 .28609 m
.42182 .27136 L
s
.43523 .27919 m
.44425 .26524 L
s
.36563 .69937 m
.35811 .68168 L
s
.43142 .73038 m
.42545 .71596 L
s
.5 .27285 m
.5 .25983 L
s
.5 .74017 m
.5 .72715 L
s
.42033 .27862 m
.442 .26694 L
s
.40838 .2885 m
.42219 .27331 L
s
.45017 .73375 m
.44544 .71969 L
s
.48479 .7385 m
.48308 .72515 L
s
.46808 .73641 m
.46478 .72271 L
s
.44391 .28102 m
.45112 .26674 L
s
.26302 .48024 m
.27098 .45657 L
s
.26295 .51319 m
.26796 .48894 L
s
.39193 .29527 m
.41093 .28006 L
s
.41226 .29092 m
.42445 .27531 L
s
.39023 .29757 m
.40795 .28173 L
s
.33924 .67393 m
.33266 .65399 L
s
.39494 .29348 m
.41512 .27896 L
s
.2683 .54705 m
.27043 .52267 L
s
.38515 .70588 m
.37808 .68844 L
s
.39004 .30021 m
.4064 .28379 L
s
.27903 .58092 m
.27846 .55692 L
s
.39905 .29238 m
.42033 .27862 L
s
.45483 .28278 m
.4602 .26819 L
s
.31525 .64521 m
.3102 .62344 L
s
.29488 .61394 m
.29187 .5908 L
s
.41826 .29329 m
.42876 .27729 L
s
.39157 .30305 m
.40648 .28609 L
s
.27098 .45657 m
.28103 .43297 L
s
.26796 .48894 m
.27507 .46445 L
s
.46791 .28453 m
.47144 .26963 L
s
.3754 .30999 m
.39494 .29348 L
s
.40522 .71138 m
.39881 .69424 L
s
.37358 .31251 m
.39193 .29527 L
s
.3784 .30811 m
.39905 .29238 L
s
.27043 .52267 m
.27461 .49773 L
s
.35811 .68168 m
.35161 .66186 L
s
.395 .30594 m
.40838 .2885 L
s
.37315 .31548 m
.39023 .29757 L
s
.42648 .29556 m
.43523 .27919 L
s
.48303 .28636 m
.48476 .27115 L
s
.28103 .43297 m
.29309 .40971 L
s
.27846 .55692 m
.27982 .532 L
s
.42545 .71596 m
.41993 .69913 L
s
.37432 .31873 m
.39004 .30021 L
s
.27507 .46445 m
.28422 .44 L
s
.33266 .65399 m
.32738 .63218 L
s
.35674 .32834 m
.3754 .30999 L
s
.35864 .32564 m
.3784 .30811 L
s
.5 .28837 m
.5 .27285 L
s
.5 .72715 m
.5 .71163 L
s
.29187 .5908 m
.29063 .56641 L
s
.4005 .30882 m
.41226 .29092 L
s
.3102 .62344 m
.30671 .6001 L
s
.44544 .71969 m
.44103 .70319 L
s
.3561 .33161 m
.37358 .31251 L
s
.43696 .29772 m
.44391 .28102 L
s
.48308 .72515 m
.48146 .70931 L
s
.29309 .40971 m
.30705 .38709 L
s
.46478 .72271 m
.46167 .70654 L
s
.27461 .49773 m
.28081 .47249 L
s
.37729 .32212 m
.39157 .30305 L
s
.34002 .3448 m
.35864 .32564 L
s
.37808 .68844 m
.37187 .66881 L
s
.28422 .44 m
.29533 .41587 L
s
.35692 .33527 m
.37315 .31548 L
s
.33919 .34834 m
.35674 .32834 L
s
.30705 .38709 m
.32275 .36536 L
s
.32275 .36536 m
.34002 .3448 L
s
.27982 .532 m
.28313 .50644 L
s
.40818 .3116 m
.41826 .29329 L
s
.44967 .29981 m
.45483 .28278 L
s
.33971 .35239 m
.3561 .33161 L
s
.29533 .41587 m
.3083 .39237 L
s
.32298 .36977 m
.33919 .34834 L
s
.28081 .47249 m
.28901 .44726 L
s
.38224 .32553 m
.395 .30594 L
s
.35944 .33916 m
.37432 .31873 L
s
.3083 .39237 m
.32298 .36977 L
s
.29063 .56641 m
.29123 .54102 L
s
.35161 .66186 m
.34627 .64009 L
s
.39881 .69424 m
.39311 .67483 L
s
.34177 .35677 m
.35692 .33527 L
s
.32463 .37461 m
.33971 .35239 L
s
.46454 .30188 m
.46791 .28453 L
s
.30671 .6001 m
.30487 .5754 L
s
.28901 .44726 m
.29912 .42233 L
s
.32738 .63218 m
.32352 .6087 L
s
.41812 .31425 m
.42648 .29556 L
s
.28313 .50644 m
.28841 .48053 L
s
.36383 .34314 m
.37729 .32212 L
s
.31104 .39802 m
.32463 .37461 L
s
.38933 .32888 m
.4005 .30882 L
s
.29912 .42233 m
.31104 .39802 L
s
.41993 .69913 m
.41496 .67997 L
s
.48139 .30403 m
.48303 .28636 L
s
.3456 .36131 m
.35944 .33916 L
s
.3279 .37972 m
.34177 .35677 L
s
.29123 .54102 m
.29369 .51492 L
s
.28841 .48053 m
.29561 .45459 L
s
.37187 .66881 m
.36664 .64712 L
s
.43034 .31678 m
.43696 .29772 L
s
.5 .30635 m
.5 .28837 L
s
.5 .71163 m
.5 .69365 L
s
.44103 .70319 m
.437 .68431 L
s
.37027 .34709 m
.38224 .32553 L
s
.48146 .70931 m
.47994 .69102 L
s
.46167 .70654 m
.45881 .68796 L
s
.31547 .40388 m
.3279 .37972 L
s
.39865 .33209 m
.40818 .3116 L
s
.29561 .45459 m
.30467 .42893 L
s
.30487 .5754 m
.30475 .54962 L
s
.30467 .42893 m
.31547 .40388 L
s
.34627 .64009 m
.34218 .61654 L
s
.35138 .3659 m
.36383 .34314 L
s
.333 .38495 m
.3456 .36131 L
s
.32352 .6087 m
.32117 .58377 L
s
.29369 .51492 m
.29803 .48842 L
s
.4448 .31921 m
.44967 .29981 L
s
.39311 .67483 m
.38821 .65329 L
s
.3789 .35093 m
.38933 .32888 L
s
.41027 .33515 m
.41812 .31425 L
s
.3218 .40978 m
.333 .38495 L
s
.29803 .48842 m
.3042 .46185 L
s
.30475 .54962 m
.30638 .52306 L
s
.46138 .3216 m
.46454 .30188 L
s
.35927 .3704 m
.37027 .34709 L
s
.34011 .39015 m
.35138 .3659 L
s
.31216 .43552 m
.3218 .40978 L
s
.3042 .46185 m
.31216 .43552 L
s
.41496 .67997 m
.41061 .65862 L
s
.36664 .64712 m
.3625 .62358 L
s
.32117 .58377 m
.3204 .55768 L
s
.47987 .32405 m
.48139 .30403 L
s
.34218 .61654 m
.33945 .59146 L
s
.38982 .35459 m
.39865 .33209 L
s
.42418 .33804 m
.43034 .31678 L
s
.30638 .52306 m
.30978 .49604 L
s
.437 .68431 m
.43343 .66318 L
s
.33019 .41561 m
.34011 .39015 L
s
.5 .69365 m
.5 .67333 L
s
.5 .32667 m
.5 .30635 L
s
.45881 .68796 m
.45623 .66708 L
s
.47994 .69102 m
.47857 .67042 L
s
.36939 .37475 m
.3789 .35093 L
s
.34939 .39522 m
.35927 .3704 L
s
.30978 .49604 m
.31492 .46889 L
s
.38821 .65329 m
.38421 .62981 L
s
.32175 .44197 m
.33019 .41561 L
s
.4403 .34082 m
.4448 .31921 L
s
.3204 .55768 m
.32125 .53074 L
s
.40305 .35806 m
.41027 .33515 L
s
.31492 .46889 m
.32175 .44197 L
s
.3625 .62358 m
.35954 .59842 L
s
.33945 .59146 m
.33813 .56514 L
s
.34078 .42125 m
.34939 .39522 L
s
.45848 .34354 m
.46138 .3216 L
s
.38182 .37888 m
.38982 .35459 L
s
.41061 .65862 m
.40697 .63526 L
s
.32125 .53074 m
.32375 .50326 L
s
.36093 .40008 m
.36939 .37475 L
s
.41856 .36134 m
.42418 .33804 L
s
.33357 .44816 m
.34078 .42125 L
s
.47849 .34629 m
.47987 .32405 L
s
.32375 .50326 m
.32787 .47562 L
s
.43343 .66318 m
.43038 .63999 L
s
.33813 .56514 m
.33829 .53788 L
s
.32787 .47562 m
.33357 .44816 L
s
.38421 .62981 m
.3812 .60464 L
s
.5 .67333 m
.5 .65081 L
s
.5 .34919 m
.5 .32667 L
s
.45623 .66708 m
.45399 .64408 L
s
.39658 .38276 m
.40305 .35806 L
s
.47857 .67042 m
.47735 .64765 L
s
.35954 .59842 m
.35782 .57193 L
s
.35365 .42662 m
.36093 .40008 L
s
.43624 .36446 m
.4403 .34082 L
s
.37479 .40467 m
.38182 .37888 L
s
.33829 .53788 m
.33995 .51003 L
s
.40697 .63526 m
.40412 .61013 L
s
.34768 .45403 m
.35365 .42662 L
s
.4559 .36749 m
.45848 .34354 L
s
.41358 .38642 m
.41856 .36134 L
s
.33995 .51003 m
.34309 .48196 L
s
.35782 .57193 m
.3574 .54444 L
s
.34309 .48196 m
.34768 .45403 L
s
.3812 .60464 m
.37925 .57805 L
s
.36884 .43166 m
.37479 .40467 L
s
.43038 .63999 m
.42791 .61495 L
s
.39096 .40897 m
.39658 .38276 L
s
.47727 .37053 m
.47849 .34629 L
s
.45399 .64408 m
.45213 .61919 L
s
.5 .65081 m
.5 .62632 L
s
.5 .37368 m
.5 .34919 L
s
.43269 .38988 m
.43624 .36446 L
s
.47735 .64765 m
.47632 .62294 L
s
.3574 .54444 m
.3583 .51628 L
s
.36406 .45951 m
.36884 .43166 L
s
.40412 .61013 m
.40212 .58352 L
s
.37925 .57805 m
.37839 .55039 L
s
.40932 .41299 m
.41358 .38642 L
s
.3583 .51628 m
.36053 .48785 L
s
.38629 .43637 m
.39096 .40897 L
s
.36053 .48785 m
.36406 .45951 L
s
.45368 .39321 m
.4559 .36749 L
s
.42791 .61495 m
.42607 .58837 L
s
.37839 .55039 m
.37867 .522 L
s
.47624 .3965 m
.47727 .37053 L
s
.38265 .46459 m
.38629 .43637 L
s
.42971 .41677 m
.43269 .38988 L
s
.40212 .58352 m
.40101 .55575 L
s
.45213 .61919 m
.45068 .59268 L
s
.5 .62632 m
.5 .60013 L
s
.5 .39987 m
.5 .37368 L
s
.40587 .44074 m
.40932 .41299 L
s
.47632 .62294 m
.47549 .59657 L
s
.37867 .522 m
.3801 .49327 L
s
.3801 .49327 m
.38265 .46459 L
s
.45186 .42038 m
.45368 .39321 L
s
.42607 .58837 m
.42491 .56056 L
s
.40101 .55575 m
.40083 .52719 L
s
.40327 .46928 m
.40587 .44074 L
s
.42736 .44481 m
.42971 .41677 L
s
.47543 .4239 m
.47624 .3965 L
s
.45068 .59268 m
.44969 .5649 L
s
.40083 .52719 m
.40159 .49823 L
s
.40159 .49823 m
.40327 .46928 L
s
.5 .60013 m
.5 .57255 L
s
.5 .42745 m
.5 .39987 L
s
.47549 .59657 m
.47488 .56886 L
s
.42491 .56056 m
.42445 .5319 L
s
.45048 .44866 m
.45186 .42038 L
s
.42569 .47361 m
.42736 .44481 L
s
.44969 .5649 m
.44916 .5362 L
s
.42445 .5319 m
.42471 .50278 L
s
.47483 .45237 m
.47543 .4239 L
s
.42471 .50278 m
.42569 .47361 L
s
.47488 .56886 m
.4745 .54018 L
s
.5 .45605 m
.5 .42745 L
s
.5 .57255 m
.5 .54395 L
s
.44956 .47766 m
.45048 .44866 L
s
.44916 .5362 m
.44911 .50698 L
s
.44911 .50698 m
.44956 .47766 L
s
.47448 .48151 m
.47483 .45237 L
s
.4745 .54018 m
.47437 .51092 L
s
.5 .54395 m
.5 .51472 L
s
.5 .48528 m
.5 .45605 L
s
.47437 .51092 m
.47448 .48151 L
s
.5 .51472 m
.5 .48528 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002:Ool?O027Ool008QooaMl
085oo`00QWoo27`000=oog`0O0004W`0OGoo0024OolRO01jOol008=oo`Yl009oo`Il0007Ooml07oo
Ooml07ooO0000Woo0g`00Woo1g`0MWoo0021OolAO00027ooO01oog`0Ooml07ooO002Ool00g`0Oomo
o`03O003Ool7O01dOol0081oo`Yl009oo`03O01oogoo00=l0004Ooml07ooO002Ool00g`0Ooml0002
Ool017`0Oomoogoo0g`00Woo00=l07ooO0001G`0LWoo001nOol9O0001GooO01oogooO0000goo0W`0
00Qoog`0Ooml07ooO01oog`00Woo00Al07ooOoml00=oo`06O01oog`0O01oog`00Woo00=l07ooO000
0g`0L7oo001mOol7O0001GooO01oogooO0000Woo00Al07ooOomoo`9l0006Ooml07ooO01oog`00Woo
00Al07ooOoml009oo`05O01oogooOoml0002Ool00g`0Ooml0002Ool01G`0Oomoog`0Ool00W`0KWoo
001kOol8O0001GooO01oogooO0000goo00el07ooOomoog`0Ooml07ooO01oog`0Ooml0002Ool017`0
Oomoog`00Woo00Ml07ooOomoog`0Ooml0002Ool2O0001GooO01oogooO0000Woo0W`0K7oo001jOol6
O0001GooO01oogooO0000Woo00El07ooOomoog`000=oo`07O01oog`0Ooml07ooO0000Woo00=l07oo
O0000Woo00El07ooOomoog`000=oo`03O01oog`000=oo`06O01oog`0O01oog`00Woo0g`0JWoo001i
Ool6O0000gooO01oo`02Ool017`0Oomoog`00goo00]l07ooOomoog`0Ooml07ooO01oog`0009oo`04
O01oogooO002Ool01G`0OomoogooO0000Woo00Al07ooOoml00=oo`03O01oogoo00=l00=oo`9l06Uo
o`00Mgoo1g`00Woo00Al07ooOoml00=oo`05O01oogooOoml0003Ool01G`0Ooml07ooO0000Woo00Il
07ooOoml07ooO003Ool017`0Oomoog`00goo00Al07ooOoml009oo`06O01oogooOoml07oo0W`00Woo
0g`0Igoo001fOol4O0001WooO01oog`0Ooml00=oo`04O01oogooO004Ool02G`0OomoogooO01oog`0
Ooml0002Ool017`0Oomoog`00Woo00Al07ooOoml00=oo`05O01oogooOoml0002Ool017`0Oomoog`0
0goo00Al07ooOoml009oo`03O01oog`006Ioo`00MGoo17`000Aoog`0Ooml009oo`04O01oogooO003
Ool01G`0OomoogooO00017oo00El07ooO01oog`0009oo`04O01oogooO002Ool01G`0OomoogooO000
0Woo00El07ooOomoog`000=oo`04O01oogooO002Ool01G`0OomoogooO0000Woo00=l07ooO000IGoo
001dOol4O002Ool2O003Ool017`0Oomoog`00goo00El07ooOomoog`000Aoo`03O01oog`0009oo`03
O01oog`0009oo`05O01oogooOoml0002Ool01G`0OomoogooO0000goo00Al07ooOoml00=oo`04O01o
ogooO002Ool01g`0OomoogooO01oog`006Aoo`00LWoo17`000Ioog`0Ooml07ooO002Ool01G`0Oomo
ogooO0000goo00El07ooOomoog`000Aoo`03O01oog`0009oo`04O01oogooO002Ool017`0Oomoog`0
0goo00El07ooOomoog`0009oo`05O01oogooOoml0003Ool017`0Oomoog`00Woo00Al07ooOoml009o
o`03O01oogoo065oo`00LGoo17`000Aoog`0Oomoo`9l00=oo`05O01oogooOoml0003Ool01G`0Oomo
ogooO00017oo00=l07ooO0000Woo00Al07ooOoml009oo`05O01oogooOoml0002Ool01G`0Oomoogoo
O0000goo00Al07ooOoml00Aoo`04O01oogooO002Ool017`0Oomoog`00Woo00=l07ooOol0H7oo001`
Ool4O0001gooO01oogooO01oog`0009oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool00g`0Oomo
o`02Ool01W`0Oomoog`0Ooml009oo`04O01oogooO003Ool01G`0OomoogooO0000goo00Al07ooOoml
00=oo`05O01oogooOoml0003Ool00g`0Ooml0003Ool00g`0Ooml001ROol006moo`=l0003Ooml07`0
009oo`04O01oogooO002Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00=l07ooOol00Woo00Al
07ooOoml009oo`06O01oogooO01oog`00goo00El07ooOomoog`000=oo`05O01oogooOoml0002Ool0
0g`0Oomoo`02Ool017`0Oomoog`00Woo00Al07ooOoml009oo`03O01oogoo05moo`00KWoo0g`000Ao
og`0Ooml009oo`03O01oog`000=oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool00g`0Oomoo`02
Ool017`0Oomoog`00Woo00Al07ooOoml009oo`05O01oogooOoml0002Ool01G`0OomoogooO0000goo
00El07ooOomoog`000=oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo00=l07ooOol0GWoo001/
Ool4O00017ooO01oog`00Woo00Al07ooOoml009oo`03O01oogoo009oo`05O01oogooOoml0004Ool0
0g`0Oomoo`02Ool017`0Oomoog`00Woo00Al07ooOoml009oo`05O01oogooOoml0003Ool01G`0Oomo
ogooO0000goo00Al07ooOoml00Aoo`04O01oogooO002Ool017`0Oomoog`00Woo00=l07ooOol0GWoo
001[Ool3O0001GooO01l07ooO0000goo00Al07ooOoml009oo`05O01oogooOoml0004Ool00g`0Oomo
o`02Ool00g`0Oomoo`02Ool017`0Oomoog`00Woo00Al07ooOoml009oo`05O01oogooOoml0003Ool0
1G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo
00=l07ooOol0GGoo001ZOol5O0000gooO01l0003Ool017`0Oomoog`00Woo00=l07ooOol00Woo00El
07ooOomoog`000Eoo`03O01oogoo009oo`04O01oogooO002Ool01g`0OomoogooO01oog`000=oo`05
O01oogooOoml0003Ool00g`0Oomoo`02Ool017`0Oomoog`00goo00El07ooOomoog`0009oo`04O01o
ogooO002Ool00g`0Oomoo`1MOol006Uoo`El0004Ooml07ooO002Ool01G`0OomoogooO0000Woo00El
07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo00=oo`04O01oogooO002Ool01G`0Oomoogoo
O0000Woo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00El07oo
Oomoog`0009oo`04O01oogooO002Ool00g`0Oomoo`1LOol006Qoo`Al0005Ooml07`0Ooml0003Ool0
17`0Oomoog`00goo00El07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo00=oo`04O01oogoo
O002Ool01G`0OomoogooO0000Woo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0Oomo
ogooO0000goo00El07ooOomoog`0009oo`04O01oogooO002Ool00g`0Oomoo`1LOol006Moo`Al0006
Ooml07ooO01oog`00Woo00El07ooOomoog`0009oo`03O01oogoo009oo`03O01oogoo009oo`03O01o
ogoo009oo`03O01oogoo00=oo`04O01oogooO002Ool01G`0OomoogooO0000Woo00El07ooOomoog`0
00Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000Woo00=l07ooOol00Woo00Al07ooOoml009o
o`04O01oogooO01MOol006Ioo`=l0007Ooml07`0Ooml07ooO0000goo00Al07ooOoml00=oo`03O01o
ogoo009oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`04O01oogooO003Ool017`0
Oomoog`00Woo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00El
07ooOomoog`0009oo`04O01oogooO002Ool00g`0Oomoo`1KOol006Eoo`El0003Ooml07`0009oo`04
O01oogooO003Ool01G`0OomoogooO0000goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol0
0goo00Al07ooOoml00=oo`04O01oogooO003Ool01G`0OomoogooO0000goo00El07ooOomoog`000=o
o`03O01oogoo009oo`04O01oogooO003Ool01G`0OomoogooO0000Woo00Al07ooOoml05aoo`00I7oo
1G`000Ioog`0Ooml07ooO003Ool017`0Oomoog`017oo00El07ooOomoog`000Aoo`03O01oogoo00=o
o`03O01oogoo00=oo`04O01oogooO003Ool017`0Oomoog`00goo00El07ooOomoog`000Aoo`05O01o
ogooOoml0002Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00El07ooOomoog`0009oo`04O01o
ogooO01LOol006=oo`Al0005Ooml07`0Ooml0002Ool017`0Oomoog`00goo00El07ooOomoog`000Ao
o`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`04O01oogooO003Ool017`0Oomoog`0
0goo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00El07ooOomo
og`0009oo`05O01oogooOoml0002Ool00g`0Oomoo`1IOol0069oo`Al0008Ooml07ooO01oog`0Ooml
00=oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0
Oomoo`03Ool017`0Oomoog`00goo00El07ooOomoog`0009oo`05O01oogooOoml0004Ool01G`0Oomo
ogooO0000goo00=l07ooOol00Woo00Al07ooOoml00=oo`05O01oogooOoml0002Ool017`0Oomoog`0
Fgoo001QOol3O0001gooO01l07ooO01oog`0009oo`04O01oogooO003Ool00g`0Oomoo`02Ool00g`0
Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool017`0Oomoog`00goo00El
07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00El
07ooOomoog`0009oo`05O01oogooOoml0002Ool01G`0OomoogooO000FWoo001POol2O00017ooO01l
07oo0W`00Woo00=l07ooO0000goo00El07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo009o
o`03O01oogoo00=oo`03O01oogoo00=oo`04O01oogooO003Ool01G`0OomoogooO0000goo00El07oo
Oomoog`000Aoo`04O01oogooO003Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00El07ooOomo
og`000=oo`04O01oogooO01JOol005moo`9l0007Ooml07`0Ooml07ooO0000Woo00=l07ooO0000Woo
00=l07ooOol00Woo00El07ooOomoog`000Eoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo
00=oo`04O01oogooO003Ool01G`0OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml
0003Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`05O01oogooOoml0002Ool00g`0Oomo
o`1HOol005ioo`05O01oog`0O01oo`02O0001GooO01oogooO0000Woo00Al07ooOoml00=oo`03O01o
ogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`05O01o
ogooOoml0003Ool017`0Oomoog`00goo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool01G`0
OomoogooO0000goo00El07ooOomoog`0009oo`05O01oogooOoml0003Ool00g`0Oomoo`1GOol005io
o`=l0006Ooml07ooO01oog`00Woo00=l07ooO0000goo00El07ooOomoog`000Aoo`03O01oogoo009o
o`03O01oogoo009oo`03O01oogoo00Aoo`03O01oogoo00=oo`05O01oogooOoml0003Ool01G`0Oomo
ogooO0000goo00Al07ooOoml00Aoo`05O01oogooOoml0004Ool01G`0OomoogooO0000Woo00El07oo
Oomoog`000=oo`04O01oogooO003Ool00g`0Oomoo`1GOol005eoo`9l0007Ooml07`0Ooml07ooO000
0Woo00Al07ooOoml009oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo
009oo`03O01oogoo00=oo`03O01oogoo00Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo
00El07ooOomoog`000Aoo`04O01oogooO004Ool01G`0OomoogooO0000goo00Al07ooOoml00=oo`04
O01oogooO003Ool00g`0Oomoo`1GOol005aoo`9l0003Ooml07oo009l009oo`04O01oogooO002Ool0
17`0Oomoog`00goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00goo
00=l07ooOol017oo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO00017oo
00El07ooOomoog`000=oo`05O01oogooOoml0003Ool017`0Oomoog`00goo00El07ooOomoog`0009o
o`03O01oogoo05Moo`00Fgoo00Yl07ooO01l07ooO01oog`0Ooml009oo`05O01oogooOoml0002Ool0
1G`0OomoogooO00017oo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol0
17oo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO00017oo00El07ooOomo
og`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000Woo00El07ooOomoog`0009oo`03O01o
ogoo05Moo`00Fgoo0W`000Moog`0O01oog`0Ooml0003Ool017`0Oomoog`00goo00El07ooOomoog`0
00Aoo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Aoo`05O01oogoo
Ooml0003Ool01G`0OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool00g`0
Oomoo`02Ool017`0Oomoog`00goo00El07ooOomoog`0009oo`05O01oogooOoml001HOol005Yoo`9l
0008Ooml07ooO01oog`0Ooml00=oo`04O01oogooO002Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool0
0g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool01G`0OomoogooO000
0goo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0003Ool01G`0OomoogooO000
17oo00Al07ooOoml00=oo`05O01oogooOoml0002Ool01G`0OomoogooO000F7oo001JOol3O0001Woo
O01oog`0Ooml00=oo`05O01oogooOoml0002Ool01G`0OomoogooO0001Goo00=l07ooOol00Woo00=l
07ooOol00goo00=l07ooOol00goo00=l07ooOol017oo00El07ooOomoog`000=oo`05O01oogooOoml
0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml
0002Ool01G`0OomoogooO0000goo00Al07ooOoml05Qoo`00FGoo0W`000=oog`0O0000Woo00=l07oo
O0000goo00Al07ooOoml00=oo`05O01oogooOoml0004Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool0
0g`0Oomoo`03Ool00g`0Oomoo`04Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`03O01o
ogoo009oo`05O01oogooOoml0004Ool017`0Oomoog`017oo00El07ooOomoog`000=oo`04O01oogoo
O003Ool017`0Oomoog`0F7oo001IOol02G`0Ooml07ooO01oog`0Ooml0003Ool01G`0OomoogooO000
0Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol0
0goo00=l07ooOol017oo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool0
1G`0OomoogooO00017oo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool017`0Oomoog`00goo
00Al07ooOoml05Qoo`00F7oo0W`000=oog`0O0000Woo00=l07ooO0000goo00Al07ooOoml00=oo`03
O01oogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03
O01oogoo00Aoo`05O01oogooOoml0003Ool01G`0OomoogooO00017oo00El07ooOomoog`000=oo`03
O01oogoo009oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00Al07ooOoml00=oo`04O01o
ogooO01HOol005Moo`9l0006Ooml07ooO01oog`00Woo00Al07ooOoml00=oo`05O01oogooOoml0004
Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04
Ool01G`0OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool00g`0Oomoo`02
Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`04O01oogooO003Ool017`0Oomoog`0F7oo
001GOol00g`0Oomoo`02O002Ool00g`0Ooml0003Ool017`0Oomoog`017oo00El07ooOomoog`000Eo
o`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`05O01oogooOoml
0003Ool01G`0OomoogooO00017oo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool01G`0Oomo
ogooO0000goo00El07ooOomoog`0009oo`05O01oogooOoml0002Ool00g`0Oomoo`1FOol005Ioo`9l
0006Ooml07ooO01oog`00Woo00El07ooOomoog`0009oo`05O01oogooOoml0004Ool00g`0Oomoo`02
Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool01G`0Oomoogoo
O0000goo00El07ooOomoog`000Aoo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo00El07oo
Oomoog`000=oo`05O01oogooOoml0002Ool01G`0OomoogooO0000Woo00=l07ooOol0EWoo001EOol2
O00017ooO01oog`00Woo00=l07ooO0000goo00El07ooOomoog`000=oo`03O01oogoo009oo`03O01o
ogoo009oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`05O01o
ogooOoml0003Ool01G`0OomoogooO00017oo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool0
1G`0OomoogooO0000goo00El07ooOomoog`0009oo`05O01oogooOoml0002Ool00g`0Oomoo`1FOol0
05Eoo`9l0006Ooml07ooO01oog`00Woo00El07ooOomoog`0009oo`03O01oogoo009oo`03O01oogoo
009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo
00Aoo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00=l07ooOol00Woo
00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00Al07ooOoml009o
o`03O01oogoo05Ioo`00E7oo0W`000Aoog`0Ooml009oo`04O01oogooO002Ool01G`0OomoogooO000
17oo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol0
17oo00=l07ooOol017oo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0004Ool0
1G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO000
0Woo00Al07ooOoml05Qoo`00Dgoo00Ml07ooO01oog`0Ooml0002Ool00g`0Ooml0003Ool01G`0Oomo
ogooO0000goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo00=l
07ooOol017oo00=l07ooOol017oo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml
0004Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0Oomo
ogooO0000Woo00Al07ooOoml05Qoo`00Dgoo0W`000Aoog`0Ooml009oo`04O01oogooO002Ool00g`0
Oomoo`02Ool01G`0OomoogooO00017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo
00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogoo
Ooml0004Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0
OomoogooO0000Woo00Al07ooOoml05Qoo`00DWoo00Ml07ooO01oog`0Ooml0002Ool017`0Oomoog`0
0Woo00El07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01o
ogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`05O01oogooOoml0004Ool01G`0OomoogooO000
0goo00=l07ooOol00Woo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO000
0goo00El07ooOomoog`0009oo`04O01oogooO01HOol0059oo`9l0007Ooml07ooOoml07ooO0000Woo
00El07ooOomoog`000=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo
00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`05O01oogooOoml0004Ool01G`0
OomoogooO0000goo00=l07ooOol00Woo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0
OomoogooO0000goo00Al07ooOoml00=oo`04O01oogooO01HOol0055oo`07O01oog`0Ooml07ooO000
0Woo00Al07ooOoml009oo`03O01oogoo009oo`05O01oogooOoml0005Ool00g`0Oomoo`02Ool00g`0
Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool01G`0OomoogooO00017oo
00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo
00El07ooOomoog`000=oo`04O01oogooO003Ool017`0Oomoog`0F7oo001AOol2O0001gooO01oogoo
O01oog`000=oo`04O01oogooO004Ool01G`0OomoogooO00017oo00=l07ooOol00goo00=l07ooOol0
0goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`000Aoo`05O01o
ogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01o
ogooOoml0003Ool017`0Oomoog`00Woo00El07ooOomoog`005Qoo`00D7oo00El07ooO01oog`0009o
o`03O01oog`000=oo`04O01oogooO003Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03
Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool01G`0Oomoogoo
O00017oo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0003Ool01G`0Oomoogoo
O0000goo00El07ooOomoog`000=oo`04O01oogooO002Ool01G`0OomoogooO000F7oo001@Ool2O000
1GooO01oogooO0000Woo00Al07ooOoml00=oo`05O01oogooOoml0004Ool00g`0Oomoo`02Ool00g`0
Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool01G`0
OomoogooO00017oo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0003Ool01G`0
OomoogooO0000goo00El07ooOomoog`000=oo`04O01oogooO002Ool017`0Oomoog`0FGoo001?Ool0
1G`0Ooml07ooO0000Woo00=l07ooO0000goo00Al07ooOoml00Aoo`03O01oogoo009oo`03O01oogoo
009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo
00Aoo`05O01oogooOoml0004Ool01G`0OomoogooO00017oo00El07ooOomoog`000=oo`05O01oogoo
Ooml0003Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`04O01oogooO002Ool00g`0Oomo
o`1GOol004moo`04O01oog`0O002Ool017`0Oomoog`00goo00Al07ooOoml00Aoo`05O01oogooOoml
0005Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomo
o`04Ool01G`0OomoogooO00017oo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool01G`0Oomo
ogooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo00=l07oo
Ool0Egoo001>Ool01G`0Ooml07ooO0000Woo00Al07ooOoml009oo`05O01oogooOoml0003Ool00g`0
Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0
Oomoo`04Ool00g`0Oomoo`04Ool01G`0OomoogooO00017oo00El07ooOomoog`000Aoo`05O01oogoo
Ooml0003Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0002Ool017`0
Oomoog`00Woo00=l07ooOol0Egoo001>Ool01g`0Ooml07ooO01oog`000=oo`04O01oogooO003Ool0
1G`0OomoogooO00017oo00=l07ooOol00Woo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol0
17oo00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`000Aoo`05O01oogooOoml0004Ool0
1G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool017`0Oomoog`00goo
00Al07ooOoml009oo`03O01oogoo05Moo`00CGoo00El07ooO01oog`0009oo`04O01oogooO003Ool0
1G`0OomoogooO0000goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol0
17oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`000Aoo`05O01o
ogooOoml0004Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool0
17`0Oomoog`00goo00Il07ooOoml07ooO01JOol004eoo`05O01oog`0Ooml0002Ool017`0Oomoog`0
0goo00El07ooOomoog`000=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01o
ogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`05O01oogooOoml0004Ool0
1G`0OomoogooO00017oo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO000
0goo00Al07ooOoml009oo`07O01oogooOoml07ooO000FWoo001=Ool2O002Ool00g`0Ooml0003Ool0
17`0Oomoog`00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00goo
00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`0
00Aoo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01oogoo
Ooml0003Ool017`0Oomoog`00Woo00Ml07ooOomoog`0Ooml001JOol004aoo`03O01oog`0009oo`03
O01oog`000=oo`04O01oogooO003Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool0
0g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool0
1G`0OomoogooO00017oo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool01G`0OomoogooO000
0goo00El07ooOomoog`0009oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo00=l07ooOol0F7oo
001<Ool01G`0Ooml07ooO0000Woo00Al07ooOoml00=oo`05O01oogooOoml0003Ool00g`0Oomoo`03
Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04
Ool00g`0Oomoo`04Ool01G`0OomoogooO00017oo00El07ooOomoog`000Aoo`05O01oogooOoml0003
Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`04O01oogooO003Ool017`0Oomoog`00Woo
00=l07ooOol0F7oo001<Ool2O002Ool017`0Oomoog`00Woo00El07ooOomoog`000=oo`05O01oogoo
Ooml0005Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0
Oomoo`04Ool00g`0Oomoo`04Ool01G`0OomoogooO00017oo00El07ooOomoog`000Aoo`05O01oogoo
Ooml0003Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`04O01oogooO003Ool01W`0Oomo
og`0Ooml05]oo`00Bgoo00=l07ooO0000Woo00=l07ooO0000goo00Al07ooOoml00Aoo`05O01oogoo
Ooml0004Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0
Oomoo`04Ool00g`0Oomoo`04Ool01G`0OomoogooO00017oo00El07ooOomoog`000Aoo`05O01oogoo
Ooml0003Ool01G`0OomoogooO0000goo00Al07ooOoml00=oo`04O01oogooO002Ool01g`0Oomoogoo
O01oog`005]oo`00Bgoo00El07ooO01oog`0009oo`05O01oogooOoml0002Ool00g`0Oomoo`02Ool0
1G`0OomoogooO00017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol0
17oo00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`000Aoo`05O01oogooOoml0004Ool0
1G`0OomoogooO0000goo00El07ooOomoog`000=oo`04O01oogooO003Ool017`0Oomoog`00Woo00Al
07ooOoml009oo`03O01oogoo05Uoo`00Bgoo00El07ooO01oog`0009oo`04O01oogooO003Ool01G`0
OomoogooO00017oo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol017oo
00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`000Aoo`05O01oogoo
Ooml0004Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`04O01oogooO002Ool01G`0Oomo
ogooO0000Woo00Al07ooOoml009oo`03O01oogoo05Uoo`00BWoo00=l07ooO0000Woo00Al07ooOoml
009oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0
Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool01G`0
OomoogooO00017oo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool017`0Oomoog`017oo00Al
07ooOoml009oo`05O01oogooOoml0002Ool00g`0Ooml0002Ool00g`0Oomoo`1JOol004Yoo`03O01o
og`0009oo`04O01oogooO002Ool017`0Oomoog`017oo00=l07ooOol00Woo00=l07ooOol00Woo00=l
07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol01Goo00=l07ooOol017oo00=l
07ooOol017oo00El07ooOomoog`000Aoo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo00Al
07ooOoml00=oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo00Al07ooOoml009oo`03O01oogoo
05Yoo`00BWoo00El07ooO01oog`0009oo`05O01oogooOoml0002Ool00g`0Oomoo`02Ool00g`0Oomo
o`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomo
o`04Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool01G`0OomoogooO00017oo00El07ooOomoog`000=o
o`03O01oogoo009oo`05O01oogooOoml0002Ool01G`0OomoogooO0000goo00Al07ooOoml009oo`04
O01oogooO002Ool00g`0Ooml001MOol004Yoo`05O01oog`0Ooml0002Ool01G`0OomoogooO0000Woo
00El07ooOomoog`000Aoo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo
00=oo`03O01oogoo00Aoo`03O01oogoo00Eoo`03O01oogoo00Aoo`05O01oogooOoml0004Ool01G`0
OomoogooO0000goo00El07ooOomoog`000Aoo`04O01oogooO003Ool017`0Oomoog`00goo00Il07oo
Ooml07ooO003Ool00g`0Ooml001MOol004Uoo`06O01oogooO01oog`00Woo00El07ooOomoog`0009o
o`05O01oogooOoml0004Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomo
o`03Ool00g`0Oomoo`04Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool01G`0OomoogooO00017oo00El
07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00Al07ooOoml009oo`07
O01oogooOoml07ooO0000Woo00Al07ooOoml05eoo`00BGoo00=l07ooO0000Woo00Al07ooOoml009o
o`05O01oogooOoml0003Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`04Ool00g`0Oomo
o`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool01G`0Oomo
ogooO00017oo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00Al
07ooOoml009oo`07O01oogooOoml07ooO0000Woo00=l07ooO000GWoo0019Ool00g`0Ooml0002Ool0
17`0Oomoog`00Woo00El07ooOomoog`000=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo
00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Eoo`03O01oogoo
00Aoo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01oogoo
Ooml0002Ool01G`0OomoogooO0000Woo00Al07ooOoml009oo`06O01oogooO01oog`0GWoo0019Ool0
1G`0Ooml07ooO0000goo00Al07ooOoml009oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo
009oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo
00Eoo`03O01oogoo00Aoo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo00El07ooOomoog`0
00=oo`05O01oogooOoml0002Ool01G`0OomoogooO0000Woo00Il07ooOoml07ooO003Ool2O01OOol0
04Uoo`05O01oog`0Ooml0003Ool017`0Oomoog`00Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l
07ooOol00Woo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l
07ooOol01Goo00=l07ooOol017oo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool01G`0Oomo
ogooO0000goo00El07ooOomoog`0009oo`04O01oogooO003Ool01W`0Oomoog`0Ooml009oo`03O01o
og`005moo`00B7oo00Il07ooOoml07ooO003Ool017`0Oomoog`00Woo00=l07ooOol00Woo00=l07oo
Ool00Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07oo
Ool017oo00=l07ooOol01Goo00=l07ooOol017oo00El07ooOomoog`000Aoo`05O01oogooOoml0003
Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`04O01oogooO002Ool01g`0OomoogooO01o
og`0009oo`03O01oog`005moo`00B7oo00Il07ooOoml07ooO002Ool01G`0OomoogooO0000Woo00=l
07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol017oo00=l
07ooOol00goo00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol017oo00El07ooOomoog`000Ao
o`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00Al07ooOoml00=oo`04O01oogooO002Ool0
17`0Oomoog`00Woo00El07ooO01oog`0061oo`00B7oo00Il07ooOoml07ooO002Ool01G`0Oomoogoo
O0000Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07oo
Ool017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol017oo00El07oo
Oomoog`000Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00Al07ooOoml00=oo`04O01o
ogooO002Ool01W`0Oomoog`0Ooml009oo`03O01oog`0061oo`00B7oo00=l07ooO0000Woo00Al07oo
Ooml009oo`05O01oogooOoml0004Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool0
0g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool0
1G`0OomoogooO00017oo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool017`0Oomoog`00Woo
00El07ooOomoog`0009oo`03O01oog`0009oo`05O01oog`0Ooml001QOol004Qoo`03O01oog`0009o
o`04O01oogooO002Ool01G`0OomoogooO00017oo00=l07ooOol00Woo00=l07ooOol00Woo00=l07oo
Ool00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol01Goo00=l07oo
Ool017oo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool017`0Oomoog`017oo00Al07ooOoml
009oo`04O01oogooO002Ool01W`0Oomoog`0Ooml009oo`03O01oog`0065oo`00B7oo00=l07ooO000
0Woo00Al07ooOoml009oo`05O01oogooOoml0004Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0
Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`05Ool00g`0
Oomoo`04Ool01G`0OomoogooO00017oo00El07ooOomoog`000=oo`04O01oogooO003Ool01G`0Oomo
ogooO0000Woo00Al07ooOoml009oo`0:O01oogooO01oog`0Ooml07ooO01ROol004Qoo`03O01oog`0
009oo`04O01oogooO002Ool01G`0OomoogooO00017oo00=l07ooOol00Woo00=l07ooOol00Woo00=l
07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol01Goo00=l
07ooOol017oo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool017`0Oomoog`00goo00Al07oo
Ooml00=oo`06O01oogooO01oog`00Woo00Ql07ooOoml07ooO01oog`0HWoo0018Ool00g`0Ooml0002
Ool017`0Oomoog`00Woo00El07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo009oo`03O01o
ogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Eoo`03O01o
ogoo00Aoo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00El07ooOomo
og`0009oo`05O01oogooOoml0002Ool00g`0Ooml0002Ool01g`0Ooml07ooO01oog`006=oo`00B7oo
00=l07ooO0000Woo00=l07ooO0000goo00El07ooOomoog`000=oo`03O01oogoo00=oo`03O01oogoo
009oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo
00Eoo`03O01oogoo00Aoo`05O01oogooOoml0003Ool01G`0OomoogooO00017oo00Al07ooOoml00=o
o`04O01oogooO002Ool017`0Oomoog`00Woo00=l07ooO0000Woo00El07ooO01oog`006=oo`00B7oo
00=l07ooO0000Woo00=l07ooO0000goo00El07ooOomoog`000=oo`03O01oogoo00=oo`03O01oogoo
009oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo
00Eoo`03O01oogoo00Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00El07ooOomoog`0
00=oo`04O01oogooO002Ool01W`0Oomoog`0Ooml009oo`07O01oog`0Ooml07ooO000I7oo0018Ool0
0g`0Ooml0002Ool00g`0Ooml0003Ool01G`0OomoogooO0000goo00=l07ooOol00goo00=l07ooOol0
0Woo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol01Goo00=l07ooOol0
17oo00=l07ooOol017oo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO000
0Woo00El07ooOomoog`0009oo`03O01oog`0009oo`07O01oogooO01oog`0Ool00W`0IGoo0018Ool0
0g`0Ooml0002Ool00g`0Ooml0003Ool01G`0OomoogooO0000goo00=l07ooOol00goo00=l07ooOol0
0Woo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol01Goo00=l07ooOol0
17oo00=l07ooOol017oo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO000
0Woo00El07ooOomoog`0009oo`05O01oog`0Ooml0002Ool01g`0Ooml07ooO01oog`006Eoo`00B7oo
00El07ooO01oog`0009oo`05O01oogooOoml0003Ool01G`0OomoogooO0001Goo00=l07ooOol00Woo
00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol01Goo00=l07ooOol017oo
00=l07ooOol017oo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000Woo
00Al07ooOoml009oo`06O01oogooO01oog`00Woo00Al07ooO01oo`9l06Ioo`00B7oo00El07ooO01o
og`0009oo`05O01oogooOoml0003Ool01G`0OomoogooO0001Goo00=l07ooOol00Woo00=l07ooOol0
0goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol0
17oo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000Woo00Al07ooOoml
009oo`0>O01oogooO01oog`0Ooml07ooO01oog`0Ooml06Ioo`00B7oo00El07ooO01oog`0009oo`05
O01oogooOoml0003Ool01G`0OomoogooO0001Goo00=l07ooOol00Woo00=l07ooOol00goo00=l07oo
Ool017oo00=l07ooOol00goo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol017oo00El07oo
Oomoog`000=oo`05O01oogooOoml0003Ool017`0Oomoog`00goo00Il07ooOoml07ooO002Ool00g`0
Ooml0002Ool01W`0Ooml07`0Ooml06Moo`00B7oo00El07ooO01oog`000=oo`04O01oogooO003Ool0
1G`0OomoogooO0001Goo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol0
0goo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`000=oo`05O01o
ogooOoml0003Ool017`0Oomoog`00Woo00Ml07ooOomoog`0Ooml0002Ool00g`0Ooml0002Ool2O000
17ooO01oog`0Igoo0018Ool01G`0Ooml07ooO0000goo00Al07ooOoml00=oo`03O01oogoo009oo`03
O01oogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03
O01oogoo00Eoo`03O01oogoo00Aoo`03O01oogoo00Aoo`05O01oogooOoml0003Ool01G`0Oomoogoo
O0000goo00Al07ooOoml009oo`07O01oogooOoml07ooO0000Woo0W`00Woo00Il07ooO01l07ooO01X
Ool004Qoo`05O01oog`0Ooml0003Ool017`0Oomoog`00goo00=l07ooOol00Woo00=l07ooOol00Woo
00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo
00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool017`0
Oomoog`00Woo00Al07ooOoml009oo`03O01oogoo009l009oo`=l009oo`03O01oogoo06Ioo`00B7oo
00El07ooO01oog`000=oo`04O01oogooO003Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomo
o`02Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomo
o`04Ool00g`0Oomoo`04Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`05O01oogooOoml
0002Ool01W`0Oomoog`0Ooml009oo`06O01oog`0Ooml07oo0W`000=oog`0Ool0J7oo0019Ool2O002
Ool017`0Oomoog`00Woo00El07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo009oo`03O01o
ogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01o
ogoo00Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000Woo00Al07ooOoml00=oo`06O01oogoo
O01oog`00Woo0W`00Woo0g`000=oog`0Ool0JGoo0019Ool2O002Ool017`0Oomoog`00Woo00El07oo
Oomoog`000Aoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo00Aoo`03
O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`05O01oogooOoml0003
Ool01G`0OomoogooO0000Woo00Al07ooOoml009oo`04O01oogooO002Ool027`0Ooml07ooO01oog`0
Ool3O01[Ool004Uoo`9l009oo`04O01oogooO002Ool00g`0Oomoo`02Ool01G`0OomoogooO00017oo
00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo
00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`000=oo`05O01oogooOoml0002Ool017`0
Oomoog`00Woo00Il07ooOoml07ooO002Ool2O0000gooO01oo`02O0000gooO01oo`1ZOol004Uoo`05
O01oog`0Ooml0002Ool017`0Oomoog`017oo00El07ooOomoog`000Aoo`03O01oogoo00=oo`03O01o
ogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01o
ogoo00Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000Woo00Al07ooOoml009oo`03O01oog`0
009oo`03O01oogoo009l0006Ooml07`0O01oog`0K7oo0019Ool01G`0Ooml07ooO0000Woo00Al07oo
Ooml00Aoo`05O01oogooOoml0004Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool0
0g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool01G`0OomoogooO000
0goo00Al07ooOoml009oo`05O01oogooOoml0002Ool01G`0Ooml07ooO0000Woo00Ql07ooO01l07oo
O01oog`0KGoo0019Ool01G`0Ooml07ooO0000Woo00Al07ooOoml00Aoo`05O01oogooOoml0004Ool0
0g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool0
0g`0Oomoo`04Ool00g`0Oomoo`04Ool01G`0OomoogooO0000goo00Al07ooOoml009oo`04O01oogoo
O002Ool01W`0Oomoog`0Ooml009oo`=l0004Ooml07`0O01^Ool004Yoo`9l0005Ooml07ooOoml0003
Ool01G`0OomoogooO0000goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo00=l07oo
Ool00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00El07oo
Oomoog`000=oo`04O01oogooO002Ool017`0Oomoog`00Woo00=l07ooO0000Woo00Al07ooO01oo`El
06moo`00BWoo00Ml07ooO01oog`0Ooml0003Ool01G`0OomoogooO0000goo00=l07ooOol00goo00=l
07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l
07ooOol017oo00=l07ooOol017oo00El07ooOomoog`000=oo`04O01oogooO002Ool01W`0Oomoog`0
Ooml009oo`03O01oog`0009oo`=l0003Ooml07`0071oo`00BWoo00El07ooO01oog`0009oo`04O01o
ogooO003Ool01G`0OomoogooO0001Goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo
00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`0
009oo`04O01oogooO003Ool027`0Oomoog`0Ooml07ooO002Ool017`0Ooml07oo17`0LGoo001:Ool0
1G`0Ooml07ooO0000Woo00Al07ooOoml00Aoo`04O01oogooO005Ool00g`0Oomoo`03Ool00g`0Oomo
o`02Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomo
o`04Ool01G`0OomoogooO0000Woo00Al07ooOoml009oo`0>O01oogooOoml07ooO01oog`0Ooml07oo
O01oo`9l0003Ooml07oo075oo`00Bgoo00Al07ooO01l009oo`04O01oogooO004Ool017`0Oomoog`0
1Goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol017oo00=l07ooOol0
17oo00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`0009oo`04O01oogooO002Ool017`0
Oomoog`00Woo00Il07ooO01oog`0Ool3O0000gooO01oo`1bOol004]oo`05O01oog`0Ooml0002Ool0
0g`0Ooml0004Ool01G`0OomoogooO00017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol0
0Woo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00El07ooOomo
og`0009oo`04O01oogooO002Ool01W`0Oomoog`0Ooml009oo`08O01oog`0O01oog`0Ooml07Aoo`00
C7oo0W`000Moog`0Oomoog`0Ooml0004Ool01G`0OomoogooO00017oo00=l07ooOol00goo00=l07oo
Ool00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07oo
Ool017oo00El07ooOomoog`0009oo`04O01oogooO002Ool02g`0Oomoog`0Ooml07ooO01oog`0Ool0
17`0MGoo001<Ool2O002Ool00g`0Ooml0002Ool01G`0OomoogooO0000goo00=l07ooOol00goo00=l
07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l
07ooOol017oo00=l07ooOol017oo00El07ooOomoog`0009oo`04O01oogooO002Ool02G`0Oomoog`0
Ooml07ooO01oo`06O01eOol004aoo`07O01oog`0Ooml07ooO0000Woo00El07ooOomoog`000=oo`03
O01oogoo00=oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03
O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`05O01oogooOoml0002Ool01W`0Oomoog`0
Ooml00=oo`9l009oo`9l0003Ooml07`0009l07Ioo`00CGoo0W`000Aoog`0Ooml009oo`03O01oogoo
009oo`04O01oogooO005Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomo
o`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool01G`0OomoogooO0000Woo00Il
07ooOoml07ooO002Ool01W`0Ooml07ooO01oo`El07Moo`00CGoo0W`00Woo00El07ooO01oog`000Ao
o`05O01oogooOoml0004Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomo
o`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool017`0Oomoog`00goo00Il07oo
Ooml07ooO002Ool2O002Ool2O00017ooO01l07`0N7oo001>Ool2O00017ooO01oog`00Woo00El07oo
Oomoog`000=oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`03
O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`04O01oogooO002Ool0
17`0Oomoog`00Woo00=l07ooOol00W`000=oog`0Ool017`0NGoo001?Ool01G`0Ooml07ooO0000Woo
00El07ooOomoog`000=oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo
009oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`04O01oogoo
O002Ool01W`0Oomoog`0Ooml009oo`04O01oog`0Ool5O01jOol004moo`9l0003Ooml07`0009oo`05
O01oogooOoml0004Ool01G`0OomoogooO0001Goo00=l07ooOol00goo00=l07ooOol00goo00=l07oo
Ool00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00Al07ooOoml009oo`06O01o
ogooO01oog`00Woo00Al07ooO01oo`Al07]oo`00D7oo00El07ooO01oog`0009oo`05O01oogooOoml
0003Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomo
o`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool017`0Oomoog`00Woo00]l07oo
Ooml07ooO01oog`0Ooml07oo00Al07aoo`00DGoo0W`000Eoog`0Oomoog`000=oo`05O01oogooOoml
0004Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomo
o`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool017`0Oomoog`00Woo00]l07ooOoml07ooO01oog`0
Ooml07oo00=l07eoo`00DWoo0W`000Aoog`0Ooml00Aoo`05O01oogooOoml0003Ool00g`0Oomoo`03
Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04
Ool00g`0Oomoo`03Ool017`0Oomoog`00Woo00=l07ooO0000Woo00Al07ooO01oo`Al07ioo`00DWoo
0W`000Eoog`0Oomoog`000=oo`05O01oogooOoml0003Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool0
0g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool0
17`0Oomoog`00Woo00Ql07ooO01oog`0Ooml07oo17`0Ogoo001COol2O00017ooO01oog`00goo00El
07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=o
o`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`04O01oogooO002Ool01W`0Ooml07oo
O01oo`Il07moo`00E7oo0g`00Woo00El07ooOomoog`000=oo`05O01oogooOoml0004Ool00g`0Oomo
o`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomo
o`03Ool01W`0Oomoog`0Ooml009oo`04O01oog`0Ool5O020Ool005Eoo`05O01oog`0Ooml0003Ool0
1G`0OomoogooO0000goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol0
0goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00Ql07ooOoml07ooO01oog`00Woo
1W`0PGoo001EOol3O002Ool017`0Oomoog`00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07oo
Ool00Woo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol017oo00=l07oo
Ool00goo00Ul07ooOoml07ooO01oog`0Ool01W`0PWoo001FOol3O0000gooO01oo`02Ool01G`0Oomo
ogooO0000goo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l
07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00Ml07ooOoml07ooO01oo`07O023Ool005Mo
o`=l0005Ooml07ooOoml0003Ool01G`0OomoogooO0001Goo00=l07ooOol00Woo00=l07ooOol00goo
00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00El07ooOoml07oo
00Ql08Aoo`00F7oo17`00goo00El07ooOomoog`000=oo`03O01oogoo009oo`03O01oogoo009oo`03
O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03
O01oog`000Yl08Aoo`00FGoo17`00Woo00El07ooOomoog`000=oo`03O01oogoo009oo`03O01oogoo
00=oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo
00=oo`9l0003Ooml07oo00Ml08Eoo`00FWoo17`00Woo00El07ooOomoog`000=oo`03O01oogoo009o
o`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo00=o
o`04O01oogooOol3O002Ool4O00017ooO01l07`0QWoo001KOol4O002Ool017`0Oomoog`00goo00=l
07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l
07ooOol00Woo00Al07ooO01l009oo`=l0003Ooml07`000El08Ioo`00G7oo1G`000Eoog`0Oomoog`0
00=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo
00=oo`04O01oogooOol3O002Ool3O0000gooO01l0006O027Ool005ioo`9l0003Ooml07`000=l00=o
o`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo00=o
o`04O01oog`0O002Ool3O002Ool3O0000gooO01l0003O028Ool005moo`9l009oo`04O01oog`0O003
Ool01G`0OomoogooO0001Goo00=l07ooOol00Woo00=l07ooOol00Woo00Al07ooOomoo`Al009oo`=l
00=oo`9l0003Ooml07`000Al08Uoo`00H7oo0g`000Aoog`0Oomoo`Al00Aoo`03O01oogoo009oo`03
O01oogoo00=oo`03O01oogoo00El009oo`04O01oog`0O002Ool01G`0Oomoog`0Ool027`0RGoo001R
Ool4O00017ooO01oogoo4g`00Woo00=l07ooOol00Woo0W`017oo0g`000Aoog`0O01oo`El08Yoo`00
Hgoo1W`00goo00El07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo009oo`El0003Ooml07oo
00Al0004Ooml07`0Ool7O02:Ool006Aoo`Al0003Ooml07`000Ml00=oo`03O01oog`000Ql00Aoo`=l
00=oo`9l0003Ooml07`000Il08]oo`00IGoo1g`000=oog`0Ool00Woo1W`017oo00=l07ooOol00Woo
00Ml07ooO01l07ooO01oo`06O002Ool5O02<Ool006Ioo`El0003Ooml07`0009l009oo`03O01oogoo
009oo`03O01oogoo00Ql00=oo`9l009oo`9l009oo`Ml08aoo`00J7oo17`00Woo00=l07ooO0002G`0
00=oog`0Ool017oo17`000Aoog`0O01l009oo`9l0003Ooml07`000=l08eoo`00JWoo1W`017oo00El
07ooOomoog`000=oo`Il009oo`=l00=oo`Ql08ioo`00K7oo4G`00goo17`00Woo1W`000=oog`0Ool0
0g`0SWoo001_Ool4O002Ool01G`0OomoogooO0000Woo17`00Woo00=l07ooO0001G`000Aoog`0O01o
o`=l08moo`00LGoo2g`00Woo00Al07ooOomoo`9l00=oo`03O01oogoo00Ml08moo`00Lgoo3g`000=o
og`0Ool01G`000Ioog`0Ooml07ooO02@Ool007Eoo`Il0004Ooml07ooOol>O0000gooO01l002@Ool0
07Qoo`Ml009oo`Al009oo`9l009oo`El091oo`00Ngoo37`000=oog`0O0001W`0T7oo001oOol9O000
0gooO01l0005O02@Ool008Ioo`Yl091oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {324.75, 95.375}} -> {-0.399192, \
0.415803, 0.00348777, 0.00348777}}]
}, Open  ]],

Cell[TextData[StyleBox["Figure 2 (A-C).  The field-line pattern given by Eq. \
(5) from three orthogonal perspectives (z, x, y respectively) of a RHCP \
photon-e&mvf corresponding to the first great circle magnetic field line and \
the second great circle electric field line shown with 6 degree increments of \
the angle .  (Electric field lines blue; Magnetic field lines red).",
  FontFamily->"New York"]], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig2A = Show[BFieldRHCP, \ EFieldRHCP];\)\)], "Input",
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.49116 .5 m
.50884 .5 L
s
.47352 .5 m
.49116 .5 L
s
1 0 0 r
.5 .49116 m
.5 .50884 L
s
.5 .47352 m
.5 .49116 L
s
0 0 1 r
.50884 .5 m
.52648 .5 L
s
1 0 0 r
.5 .50884 m
.5 .52648 L
s
.51541 .49343 m
.51535 .51112 L
s
.51538 .47577 m
.51541 .49343 L
s
0 0 1 r
.50657 .48459 m
.52423 .48462 L
s
.48888 .48465 m
.50657 .48459 L
s
.47123 .4848 m
.48888 .48465 L
s
1 0 0 r
.51535 .51112 m
.5152 .52877 L
s
0 0 1 r
.45595 .5 m
.47352 .5 L
s
1 0 0 r
.5 .45595 m
.5 .47352 L
s
0 0 1 r
.52648 .5 m
.54405 .5 L
s
1 0 0 r
.5 .52648 m
.5 .54405 L
s
.51526 .45818 m
.51538 .47577 L
s
0 0 1 r
.52423 .48462 m
.54182 .48474 L
s
.50421 .46929 m
.52191 .46923 L
s
.48651 .46953 m
.50421 .46929 L
s
1 0 0 r
.53071 .49579 m
.53047 .51349 L
s
.53077 .47809 m
.53071 .49579 L
s
0 0 1 r
.45367 .48504 m
.47123 .4848 L
s
1 0 0 r
.5152 .52877 m
.51496 .54633 L
s
0 0 1 r
.46884 .46994 m
.48651 .46953 L
s
1 0 0 r
.53047 .51349 m
.53006 .53116 L
s
.53066 .46046 m
.53077 .47809 L
s
0 0 1 r
.52191 .46923 m
.53954 .46934 L
s
.45126 .47053 m
.46884 .46994 L
s
1 0 0 r
.53006 .53116 m
.52947 .54874 L
s
0 0 1 r
.4385 .5 m
.45595 .5 L
s
1 0 0 r
.5 .4385 m
.5 .45595 L
s
0 0 1 r
.54405 .5 m
.5615 .5 L
s
1 0 0 r
.5 .54405 m
.5 .5615 L
s
.51505 .44071 m
.51526 .45818 L
s
0 0 1 r
.54182 .48474 m
.55929 .48495 L
s
.50169 .45424 m
.51944 .45397 L
s
.48394 .45478 m
.50169 .45424 L
s
1 0 0 r
.54576 .49831 m
.54522 .51606 L
s
.54603 .48056 m
.54576 .49831 L
s
0 0 1 r
.46625 .45557 m
.48394 .45478 L
s
1 0 0 r
.54522 .51606 m
.54443 .53375 L
s
0 0 1 r
.43624 .48537 m
.45367 .48504 L
s
1 0 0 r
.51496 .54633 m
.51463 .56376 L
s
.54603 .46287 m
.54603 .48056 L
s
0 0 1 r
.51944 .45397 m
.53713 .45397 L
s
1 0 0 r
.53036 .44294 m
.53066 .46046 L
s
0 0 1 r
.53954 .46934 m
.55706 .46964 L
s
.44865 .45664 m
.46625 .45557 L
s
1 0 0 r
.54443 .53375 m
.54336 .55135 L
s
0 0 1 r
.43383 .4713 m
.45126 .47053 L
s
1 0 0 r
.52947 .54874 m
.5287 .56617 L
s
.54577 .44529 m
.54603 .46287 L
s
0 0 1 r
.53713 .45397 m
.55471 .45423 L
s
1 0 0 r
.56039 .50108 m
.55944 .51888 L
s
.56099 .48328 m
.56039 .50108 L
s
0 0 1 r
.49892 .43961 m
.51672 .43901 L
s
.48112 .44056 m
.49892 .43961 L
s
1 0 0 r
.51475 .42342 m
.51505 .44071 L
s
0 0 1 r
.55929 .48495 m
.57658 .48525 L
s
.42125 .5 m
.4385 .5 L
s
1 0 0 r
.5 .42125 m
.5 .4385 L
s
0 0 1 r
.5615 .5 m
.57875 .5 L
s
1 0 0 r
.5 .5615 m
.5 .57875 L
s
0 0 1 r
.46339 .44185 m
.48112 .44056 L
s
1 0 0 r
.55944 .51888 m
.55815 .53661 L
s
.56123 .46552 m
.56099 .48328 L
s
0 0 1 r
.51672 .43901 m
.53448 .43877 L
s
1 0 0 r
.52988 .42559 m
.53036 .44294 L
s
0 0 1 r
.55706 .46964 m
.57441 .47012 L
s
.419 .48578 m
.43624 .48537 L
s
1 0 0 r
.51463 .56376 m
.51422 .581 L
s
0 0 1 r
.43122 .45796 m
.44865 .45664 L
s
1 0 0 r
.54336 .55135 m
.54204 .56878 L
s
0 0 1 r
.44578 .4435 m
.46339 .44185 L
s
1 0 0 r
.55815 .53661 m
.5565 .55422 L
s
.56112 .44785 m
.56123 .46552 L
s
0 0 1 r
.53448 .43877 m
.55215 .43888 L
s
1 0 0 r
.54523 .42787 m
.54577 .44529 L
s
0 0 1 r
.55471 .45423 m
.57213 .45477 L
s
.41661 .47225 m
.43383 .4713 L
s
1 0 0 r
.5287 .56617 m
.52775 .58339 L
s
0 0 1 r
.49582 .42555 m
.51369 .42451 L
s
.47798 .42702 m
.49582 .42555 L
s
1 0 0 r
.57445 .50418 m
.57298 .52202 L
s
.57549 .48631 m
.57445 .50418 L
s
0 0 1 r
.46022 .42892 m
.47798 .42702 L
s
1 0 0 r
.57298 .52202 m
.57108 .53978 L
s
.57608 .46847 m
.57549 .48631 L
s
0 0 1 r
.51369 .42451 m
.53153 .42392 L
s
1 0 0 r
.51437 .40636 m
.51475 .42342 L
s
0 0 1 r
.57658 .48525 m
.59364 .48563 L
s
.42835 .44548 m
.44578 .4435 L
s
1 0 0 r
.5565 .55422 m
.55452 .57165 L
s
0 0 1 r
.40423 .5 m
.42125 .5 L
s
1 0 0 r
.5 .40423 m
.5 .42125 L
s
0 0 1 r
.57875 .5 m
.59577 .5 L
s
1 0 0 r
.5 .57875 m
.5 .59577 L
s
.52923 .40847 m
.52988 .42559 L
s
0 0 1 r
.57441 .47012 m
.59153 .47077 L
s
1 0 0 r
.56064 .43035 m
.56112 .44785 L
s
0 0 1 r
.55215 .43888 m
.56965 .43936 L
s
.414 .45955 m
.43122 .45796 L
s
1 0 0 r
.54204 .56878 m
.54045 .586 L
s
0 0 1 r
.44261 .43125 m
.46022 .42892 L
s
1 0 0 r
.57108 .53978 m
.56875 .55739 L
s
0 0 1 r
.40202 .48629 m
.419 .48578 L
s
1 0 0 r
.51422 .581 m
.51371 .59798 L
s
.57624 .45072 m
.57608 .46847 L
s
0 0 1 r
.53153 .42392 m
.54928 .42376 L
s
1 0 0 r
.54443 .41067 m
.54523 .42787 L
s
0 0 1 r
.57213 .45477 m
.58933 .45557 L
s
.39964 .47337 m
.41661 .47225 L
s
1 0 0 r
.52775 .58339 m
.52663 .60036 L
s
0 0 1 r
.49235 .41221 m
.51027 .41062 L
s
.47448 .41431 m
.49235 .41221 L
s
1 0 0 r
.58779 .50765 m
.58569 .52552 L
s
.58938 .48973 m
.58779 .50765 L
s
0 0 1 r
.45671 .41692 m
.47448 .41431 L
s
1 0 0 r
.58569 .52552 m
.58308 .54329 L
s
0 0 1 r
.42519 .434 m
.44261 .43125 L
s
1 0 0 r
.56875 .55739 m
.566 .57481 L
s
.59044 .47182 m
.58938 .48973 L
s
0 0 1 r
.51027 .41062 m
.52818 .40956 L
s
.41115 .44782 m
.42835 .44548 L
s
1 0 0 r
.55452 .57165 m
.55218 .58885 L
s
.57594 .43311 m
.57624 .45072 L
s
0 0 1 r
.54928 .42376 m
.56689 .42406 L
s
1 0 0 r
.5598 .41305 m
.56064 .43035 L
s
0 0 1 r
.56965 .43936 m
.58695 .4402 L
s
.43911 .42003 m
.45671 .41692 L
s
1 0 0 r
.58308 .54329 m
.57997 .56089 L
s
.59098 .45397 m
.59044 .47182 L
s
0 0 1 r
.52818 .40956 m
.54603 .40902 L
s
1 0 0 r
.51389 .38959 m
.51437 .40636 L
s
0 0 1 r
.59364 .48563 m
.61041 .48611 L
s
.39706 .4614 m
.414 .45955 L
s
1 0 0 r
.54045 .586 m
.5386 .60294 L
s
0 0 1 r
.38752 .5 m
.40423 .5 L
s
1 0 0 r
.5 .38752 m
.5 .40423 L
s
0 0 1 r
.59577 .5 m
.61248 .5 L
s
1 0 0 r
.5 .59577 m
.5 .61248 L
s
.52838 .39164 m
.52923 .40847 L
s
0 0 1 r
.59153 .47077 m
.60836 .47162 L
s
.38534 .48688 m
.40202 .48629 L
s
1 0 0 r
.51371 .59798 m
.51312 .61466 L
s
0 0 1 r
.40803 .43718 m
.42519 .434 L
s
1 0 0 r
.566 .57481 m
.56282 .59197 L
s
.54334 .39376 m
.54443 .41067 L
s
0 0 1 r
.58933 .45557 m
.60624 .45666 L
s
.42174 .42364 m
.43911 .42003 L
s
1 0 0 r
.57997 .56089 m
.57636 .57826 L
s
.60028 .51153 m
.59745 .52941 L
s
.60251 .49358 m
.60028 .51153 L
s
0 0 1 r
.48847 .39972 m
.50642 .39749 L
s
.47059 .40255 m
.48847 .39972 L
s
1 0 0 r
.57519 .4157 m
.57594 .43311 L
s
0 0 1 r
.56689 .42406 m
.5843 .42481 L
s
.45285 .40596 m
.47059 .40255 L
s
1 0 0 r
.59745 .52941 m
.59404 .54715 L
s
.59098 .43625 m
.59098 .45397 L
s
0 0 1 r
.54603 .40902 m
.56375 .40902 L
s
1 0 0 r
.60415 .4756 m
.60251 .49358 L
s
0 0 1 r
.50642 .39749 m
.5244 .39585 L
s
.39425 .45049 m
.41115 .44782 L
s
1 0 0 r
.55218 .58885 m
.54951 .60575 L
s
0 0 1 r
.383 .47467 m
.39964 .47337 L
s
1 0 0 r
.52663 .60036 m
.52533 .617 L
s
0 0 1 r
.4353 .40995 m
.45285 .40596 L
s
1 0 0 r
.59404 .54715 m
.59005 .5647 L
s
.55859 .39603 m
.5598 .41305 L
s
0 0 1 r
.58695 .4402 m
.60397 .44141 L
s
1 0 0 r
.60518 .45767 m
.60415 .4756 L
s
0 0 1 r
.5244 .39585 m
.54233 .39482 L
s
.40465 .42775 m
.42174 .42364 L
s
1 0 0 r
.57636 .57826 m
.57225 .59535 L
s
0 0 1 r
.38046 .4635 m
.39706 .4614 L
s
1 0 0 r
.5386 .60294 m
.5365 .61954 L
s
0 0 1 r
.41801 .4145 m
.4353 .40995 L
s
1 0 0 r
.59005 .5647 m
.5855 .58199 L
s
.59043 .41872 m
.59098 .43625 L
s
0 0 1 r
.56375 .40902 m
.58128 .40957 L
s
1 0 0 r
.51331 .37319 m
.51389 .38959 L
s
0 0 1 r
.61041 .48611 m
.62681 .48669 L
s
.39119 .44077 m
.40803 .43718 L
s
1 0 0 r
.56282 .59197 m
.55923 .60881 L
s
.52736 .37517 m
.52838 .39164 L
s
0 0 1 r
.60836 .47162 m
.62483 .47264 L
s
.37117 .5 m
.38752 .5 L
s
1 0 0 r
.5 .37117 m
.5 .38752 L
s
0 0 1 r
.61248 .5 m
.62883 .5 L
s
1 0 0 r
.5 .61248 m
.5 .62883 L
s
.61177 .51583 m
.60812 .53368 L
s
.61475 .49787 m
.61177 .51583 L
s
0 0 1 r
.48417 .38823 m
.50213 .38525 L
s
.46632 .39188 m
.48417 .38823 L
s
1 0 0 r
.57398 .39856 m
.57519 .4157 L
s
0 0 1 r
.5843 .42481 m
.60144 .42602 L
s
.44865 .39617 m
.46632 .39188 L
s
1 0 0 r
.60812 .53368 m
.60383 .55135 L
s
.60559 .43985 m
.60518 .45767 L
s
0 0 1 r
.54233 .39482 m
.56015 .39441 L
s
1 0 0 r
.54198 .37719 m
.54334 .39376 L
s
0 0 1 r
.60624 .45666 m
.62281 .45802 L
s
1 0 0 r
.61706 .47987 m
.61475 .49787 L
s
0 0 1 r
.50213 .38525 m
.52013 .38294 L
s
.36904 .48756 m
.38534 .48688 L
s
1 0 0 r
.51312 .61466 m
.51244 .63096 L
s
0 0 1 r
.4312 .40111 m
.44865 .39617 L
s
1 0 0 r
.60383 .55135 m
.59889 .5688 L
s
0 0 1 r
.3777 .45351 m
.39425 .45049 L
s
1 0 0 r
.54951 .60575 m
.54649 .6223 L
s
0 0 1 r
.40104 .41961 m
.41801 .4145 L
s
1 0 0 r
.5855 .58199 m
.58039 .59896 L
s
.61869 .46188 m
.61706 .47987 L
s
0 0 1 r
.52013 .38294 m
.53812 .38131 L
s
1 0 0 r
.55701 .37935 m
.55859 .39603 L
s
0 0 1 r
.60397 .44141 m
.62065 .44299 L
s
.38791 .43234 m
.40465 .42775 L
s
1 0 0 r
.57225 .59535 m
.56766 .61209 L
s
0 0 1 r
.36675 .47615 m
.383 .47467 L
s
1 0 0 r
.52533 .617 m
.52385 .63325 L
s
0 0 1 r
.41405 .40667 m
.4312 .40111 L
s
1 0 0 r
.59889 .5688 m
.59333 .58595 L
s
.60536 .42219 m
.60559 .43985 L
s
0 0 1 r
.56015 .39441 m
.57781 .39464 L
s
1 0 0 r
.58934 .40144 m
.59043 .41872 L
s
0 0 1 r
.58128 .40957 m
.59856 .41066 L
s
.46171 .38238 m
.47947 .37784 L
s
.44416 .38764 m
.46171 .38238 L
s
1 0 0 r
.61762 .53829 m
.61236 .55584 L
s
.62216 .52053 m
.61762 .53829 L
s
.62597 .50263 m
.62216 .52053 L
s
0 0 1 r
.47947 .37784 m
.49737 .37403 L
s
.37473 .44478 m
.39119 .44077 L
s
1 0 0 r
.55923 .60881 m
.55522 .62527 L
s
.61961 .44397 m
.61869 .46188 L
s
0 0 1 r
.53812 .38131 m
.55603 .38039 L
s
.36427 .46587 m
.38046 .4635 L
s
1 0 0 r
.5365 .61954 m
.53413 .63573 L
s
0 0 1 r
.42688 .39358 m
.44416 .38764 L
s
1 0 0 r
.61236 .55584 m
.60642 .57312 L
s
.5723 .38175 m
.57398 .39856 L
s
0 0 1 r
.60144 .42602 m
.61825 .4277 L
s
1 0 0 r
.62905 .48463 m
.62597 .50263 L
s
0 0 1 r
.49737 .37403 m
.51537 .37095 L
s
.39726 .41284 m
.41405 .40667 L
s
1 0 0 r
.59333 .58595 m
.58716 .60274 L
s
0 0 1 r
.38445 .42527 m
.40104 .41961 L
s
1 0 0 r
.58039 .59896 m
.57473 .61555 L
s
.51265 .35721 m
.51331 .37319 L
s
0 0 1 r
.62681 .48669 m
.64279 .48735 L
s
1 0 0 r
.52614 .35911 m
.52736 .37517 L
s
0 0 1 r
.62483 .47264 m
.64089 .47386 L
s
.35525 .5 m
.37117 .5 L
s
1 0 0 r
.5 .35525 m
.5 .37117 L
s
0 0 1 r
.62883 .5 m
.64475 .5 L
s
1 0 0 r
.5 .62883 m
.5 .64475 L
s
0 0 1 r
.40995 .4002 m
.42688 .39358 L
s
1 0 0 r
.60642 .57312 m
.5998 .59005 L
s
.54033 .36104 m
.54198 .37719 L
s
0 0 1 r
.62281 .45802 m
.63896 .45967 L
s
1 0 0 r
.63137 .46662 m
.62905 .48463 L
s
0 0 1 r
.51537 .37095 m
.53338 .36863 L
s
.36159 .45686 m
.3777 .45351 L
s
1 0 0 r
.54649 .6223 m
.54314 .63841 L
s
0 0 1 r
.37159 .43741 m
.38791 .43234 L
s
1 0 0 r
.56766 .61209 m
.56259 .62841 L
s
.6045 .40477 m
.60536 .42219 L
s
0 0 1 r
.57781 .39464 m
.59523 .3955 L
s
.35318 .48834 m
.36904 .48756 L
s
1 0 0 r
.51244 .63096 m
.51166 .64682 L
s
.61982 .4262 m
.61961 .44397 L
s
0 0 1 r
.55603 .38039 m
.5738 .38018 L
s
1 0 0 r
.58768 .38448 m
.58934 .40144 L
s
0 0 1 r
.59856 .41066 m
.61552 .41232 L
s
.4568 .37416 m
.47441 .36866 L
s
.43946 .38041 m
.4568 .37416 L
s
1 0 0 r
.62584 .5432 m
.61959 .56054 L
s
.63134 .52559 m
.62584 .5432 L
s
.55506 .36308 m
.55701 .37935 L
s
0 0 1 r
.62065 .44299 m
.63692 .44494 L
s
1 0 0 r
.63606 .5078 m
.63134 .52559 L
s
0 0 1 r
.47441 .36866 m
.4922 .36394 L
s
.42243 .38741 m
.43946 .38041 L
s
1 0 0 r
.61959 .56054 m
.61259 .57757 L
s
0 0 1 r
.39342 .40747 m
.40995 .4002 L
s
1 0 0 r
.5998 .59005 m
.59253 .60658 L
s
0 0 1 r
.3809 .41961 m
.39726 .41284 L
s
1 0 0 r
.58716 .60274 m
.58039 .6191 L
s
0 0 1 r
.35095 .4778 m
.36675 .47615 L
s
1 0 0 r
.52385 .63325 m
.5222 .64905 L
s
.63291 .44864 m
.63137 .46662 L
s
0 0 1 r
.53338 .36863 m
.55136 .36709 L
s
1 0 0 r
.63998 .48987 m
.63606 .5078 L
s
0 0 1 r
.4922 .36394 m
.51013 .36002 L
s
.40579 .39512 m
.42243 .38741 L
s
1 0 0 r
.61259 .57757 m
.60488 .59421 L
s
0 0 1 r
.35874 .4492 m
.37473 .44478 L
s
1 0 0 r
.55522 .62527 m
.5508 .64126 L
s
0 0 1 r
.36832 .43147 m
.38445 .42527 L
s
1 0 0 r
.57473 .61555 m
.56853 .63168 L
s
.57015 .36534 m
.5723 .38175 L
s
0 0 1 r
.61825 .4277 m
.63466 .42985 L
s
.34855 .4685 m
.36427 .46587 L
s
1 0 0 r
.53413 .63573 m
.5315 .65145 L
s
.64308 .47188 m
.63998 .48987 L
s
0 0 1 r
.51013 .36002 m
.52812 .35692 L
s
1 0 0 r
.61931 .40864 m
.61982 .4262 L
s
0 0 1 r
.5738 .38018 m
.59136 .38069 L
s
.38961 .40352 m
.40579 .39512 L
s
1 0 0 r
.60488 .59421 m
.59648 .61039 L
s
0 0 1 r
.37735 .41539 m
.39342 .40747 L
s
1 0 0 r
.59253 .60658 m
.58461 .62265 L
s
.63275 .5483 m
.62545 .56535 L
s
.63926 .53094 m
.63275 .5483 L
s
0 0 1 r
.4517 .36725 m
.46906 .36074 L
s
.43465 .37455 m
.4517 .36725 L
s
1 0 0 r
.60299 .38766 m
.6045 .40477 L
s
0 0 1 r
.59523 .3955 m
.61234 .39701 L
s
.41797 .38262 m
.43465 .37455 L
s
1 0 0 r
.62545 .56535 m
.61738 .58203 L
s
.63366 .43078 m
.63291 .44864 L
s
0 0 1 r
.55136 .36709 m
.56922 .36634 L
s
1 0 0 r
.64494 .51333 m
.63926 .53094 L
s
0 0 1 r
.46906 .36074 m
.48667 .35506 L
s
.35575 .44296 m
.37159 .43741 L
s
1 0 0 r
.56259 .62841 m
.55704 .64425 L
s
0 0 1 r
.40172 .39143 m
.41797 .38262 L
s
1 0 0 r
.61738 .58203 m
.60857 .59828 L
s
.52474 .34355 m
.52614 .35911 L
s
0 0 1 r
.64089 .47386 m
.65645 .47526 L
s
1 0 0 r
.51189 .34173 m
.51265 .35721 L
s
0 0 1 r
.64279 .48735 m
.65827 .48811 L
s
.36503 .42697 m
.3809 .41961 L
s
1 0 0 r
.58039 .6191 m
.57303 .63497 L
s
.5384 .34537 m
.54033 .36104 L
s
0 0 1 r
.63896 .45967 m
.65463 .4616 L
s
.33985 .5 m
.35525 .5 L
s
1 0 0 r
.5 .33985 m
.5 .35525 L
s
0 0 1 r
.64475 .5 m
.66015 .5 L
s
1 0 0 r
.5 .64475 m
.5 .66015 L
s
0 0 1 r
.34598 .46055 m
.36159 .45686 L
s
1 0 0 r
.54314 .63841 m
.53945 .65402 L
s
.58546 .36792 m
.58768 .38448 L
s
0 0 1 r
.61552 .41232 m
.63208 .41454 L
s
1 0 0 r
.64976 .49555 m
.64494 .51333 L
s
0 0 1 r
.48667 .35506 m
.50445 .35024 L
s
1 0 0 r
.64533 .4539 m
.64308 .47188 L
s
0 0 1 r
.52812 .35692 m
.5461 .35467 L
s
.38598 .40097 m
.40172 .39143 L
s
1 0 0 r
.60857 .59828 m
.59903 .61402 L
s
0 0 1 r
.37394 .4126 m
.38961 .40352 L
s
1 0 0 r
.59648 .61039 m
.5874 .62606 L
s
0 0 1 r
.33784 .4892 m
.35318 .48834 L
s
1 0 0 r
.51166 .64682 m
.5108 .66216 L
s
.55272 .34729 m
.55506 .36308 L
s
0 0 1 r
.63692 .44494 m
.65271 .44728 L
s
.42986 .37005 m
.44652 .36169 L
s
.41363 .3792 m
.42986 .37005 L
s
1 0 0 r
.62995 .57014 m
.6208 .58637 L
s
.63831 .55348 m
.62995 .57014 L
s
.64585 .53646 m
.63831 .55348 L
s
0 0 1 r
.44652 .36169 m
.46354 .35415 L
s
.35272 .43819 m
.36832 .43147 L
s
1 0 0 r
.56853 .63168 m
.56181 .64728 L
s
0 0 1 r
.39788 .38911 m
.41363 .3792 L
s
1 0 0 r
.6208 .58637 m
.61089 .60212 L
s
0 0 1 r
.36183 .42394 m
.37735 .41539 L
s
1 0 0 r
.58461 .62265 m
.57606 .63817 L
s
.65371 .47766 m
.64976 .49555 L
s
0 0 1 r
.50445 .35024 m
.52234 .34629 L
s
.34327 .45403 m
.35874 .4492 L
s
1 0 0 r
.5508 .64126 m
.54597 .65673 L
s
.61805 .39137 m
.61931 .40864 L
s
0 0 1 r
.59136 .38069 m
.60863 .38195 L
s
1 0 0 r
.65252 .51914 m
.64585 .53646 L
s
0 0 1 r
.46354 .35415 m
.48086 .34748 L
s
1 0 0 r
.6336 .41311 m
.63366 .43078 L
s
0 0 1 r
.56922 .36634 m
.58689 .3664 L
s
.33569 .47963 m
.35095 .4778 L
s
1 0 0 r
.5222 .64905 m
.52037 .66431 L
s
0 0 1 r
.38269 .39974 m
.39788 .38911 L
s
1 0 0 r
.61089 .60212 m
.60026 .61731 L
s
0 0 1 r
.3708 .41118 m
.38598 .40097 L
s
1 0 0 r
.59903 .61402 m
.58882 .6292 L
s
.56752 .34941 m
.57015 .36534 L
s
0 0 1 r
.63466 .42985 m
.65059 .43248 L
s
1 0 0 r
.60081 .37092 m
.60299 .38766 L
s
0 0 1 r
.61234 .39701 m
.62908 .39919 L
s
1 0 0 r
.64672 .43599 m
.64533 .4539 L
s
0 0 1 r
.5461 .35467 m
.56401 .35328 L
s
.40958 .3771 m
.42526 .36688 L
s
.39444 .38807 m
.40958 .3771 L
s
1 0 0 r
.6229 .59042 m
.61193 .60556 L
s
.63312 .57474 m
.6229 .59042 L
s
.64253 .55859 m
.63312 .57474 L
s
0 0 1 r
.42526 .36688 m
.44141 .35747 L
s
.35886 .42232 m
.37394 .4126 L
s
1 0 0 r
.5874 .62606 m
.57768 .64114 L
s
0 0 1 r
.34974 .43491 m
.36503 .42697 L
s
1 0 0 r
.57303 .63497 m
.56509 .65026 L
s
.65831 .50159 m
.65252 .51914 L
s
0 0 1 r
.48086 .34748 m
.49841 .34169 L
s
.3799 .39977 m
.39444 .38807 L
s
1 0 0 r
.61193 .60556 m
.60023 .6201 L
s
.6511 .54202 m
.64253 .55859 L
s
0 0 1 r
.44141 .35747 m
.45798 .3489 L
s
.3681 .41106 m
.38269 .39974 L
s
1 0 0 r
.60026 .61731 m
.58894 .6319 L
s
0 0 1 r
.33339 .47139 m
.34855 .4685 L
s
1 0 0 r
.5315 .65145 m
.52861 .66661 L
s
0 0 1 r
.34049 .44898 m
.35575 .44296 L
s
1 0 0 r
.55704 .64425 m
.55102 .65951 L
s
.65676 .45973 m
.65371 .47766 L
s
0 0 1 r
.52234 .34629 m
.54027 .34324 L
s
1 0 0 r
.62376 .59401 m
.61178 .60843 L
s
.635 .579 m
.62376 .59401 L
s
0 0 1 r
.40599 .37624 m
.421 .365 L
s
.39157 .38822 m
.40599 .37624 L
s
.37778 .40092 m
.39157 .38822 L
s
1 0 0 r
.61178 .60843 m
.59908 .62222 L
s
.64544 .56346 m
.635 .579 L
s
0 0 1 r
.421 .365 m
.43654 .35456 L
s
.36601 .41214 m
.3799 .39977 L
s
1 0 0 r
.60023 .6201 m
.58786 .63399 L
s
0 0 1 r
.35626 .42205 m
.3708 .41118 L
s
1 0 0 r
.58882 .6292 m
.57795 .64374 L
s
.65879 .5251 m
.6511 .54202 L
s
0 0 1 r
.45798 .3489 m
.4749 .34121 L
s
1 0 0 r
.58266 .35182 m
.58546 .36792 L
s
0 0 1 r
.63208 .41454 m
.64818 .41734 L
s
.3647 .41426 m
.37778 .40092 L
s
1 0 0 r
.59908 .62222 m
.58574 .6353 L
s
0 0 1 r
.34693 .43308 m
.36183 .42394 L
s
1 0 0 r
.57606 .63817 m
.56692 .65307 L
s
.66317 .48388 m
.65831 .50159 L
s
0 0 1 r
.49841 .34169 m
.51612 .33683 L
s
1 0 0 r
.52315 .32856 m
.52474 .34355 L
s
0 0 1 r
.65645 .47526 m
.67144 .47685 L
s
1 0 0 r
.65503 .54746 m
.64544 .56346 L
s
0 0 1 r
.43654 .35456 m
.45254 .34497 L
s
1 0 0 r
.51104 .32683 m
.51189 .34173 L
s
0 0 1 r
.65827 .48811 m
.67317 .48896 L
s
.33095 .46458 m
.34598 .46055 L
s
1 0 0 r
.53945 .65402 m
.53542 .66905 L
s
0 0 1 r
.3542 .42304 m
.3681 .41106 L
s
1 0 0 r
.58894 .6319 m
.57696 .6458 L
s
.53619 .33028 m
.5384 .34537 L
s
0 0 1 r
.65463 .4616 m
.66972 .46381 L
s
1 0 0 r
.63271 .39569 m
.6336 .41311 L
s
0 0 1 r
.58689 .3664 m
.60431 .36729 L
s
.33772 .44544 m
.35272 .43819 L
s
1 0 0 r
.56181 .64728 m
.55456 .66228 L
s
.64721 .41823 m
.64672 .43599 L
s
0 0 1 r
.56401 .35328 m
.58177 .35279 L
s
.32503 .5 m
.33985 .5 L
s
1 0 0 r
.5 .32503 m
.5 .33985 L
s
0 0 1 r
.66015 .5 m
.67497 .5 L
s
1 0 0 r
.5 .66015 m
.5 .67497 L
s
0 0 1 r
.35237 .42822 m
.3647 .41426 L
s
1 0 0 r
.58574 .6353 m
.57178 .64763 L
s
0 0 1 r
.35285 .42515 m
.36601 .41214 L
s
1 0 0 r
.58786 .63399 m
.57485 .64715 L
s
.61604 .37445 m
.61805 .39137 L
s
0 0 1 r
.60863 .38195 m
.62555 .38396 L
s
1 0 0 r
.66556 .50789 m
.65879 .5251 L
s
0 0 1 r
.4749 .34121 m
.49211 .33444 L
s
.34444 .43266 m
.35886 .42232 L
s
1 0 0 r
.57768 .64114 m
.56734 .65556 L
s
.54999 .33207 m
.55272 .34729 L
s
0 0 1 r
.65271 .44728 m
.66793 .45001 L
s
1 0 0 r
.65886 .44182 m
.65676 .45973 L
s
0 0 1 r
.54027 .34324 m
.55818 .34114 L
s
1 0 0 r
.66373 .53105 m
.65503 .54746 L
s
0 0 1 r
.45254 .34497 m
.46895 .33627 L
s
.32311 .49016 m
.33784 .4892 L
s
1 0 0 r
.5108 .66216 m
.50984 .67689 L
s
0 0 1 r
.32841 .45925 m
.34327 .45403 L
s
1 0 0 r
.54597 .65673 m
.54075 .67159 L
s
0 0 1 r
.34243 .43355 m
.35626 .42205 L
s
1 0 0 r
.57795 .64374 m
.56645 .65757 L
s
0 0 1 r
.33509 .44339 m
.34974 .43491 L
s
1 0 0 r
.56509 .65026 m
.55661 .66491 L
s
.59796 .35464 m
.60081 .37092 L
s
0 0 1 r
.62908 .39919 m
.64536 .40204 L
s
1 0 0 r
.66707 .46608 m
.66317 .48388 L
s
0 0 1 r
.51612 .33683 m
.53392 .33293 L
s
.34085 .44273 m
.35237 .42822 L
s
1 0 0 r
.57178 .64763 m
.55727 .65915 L
s
0 0 1 r
.34105 .43563 m
.3542 .42304 L
s
1 0 0 r
.57696 .6458 m
.56437 .65895 L
s
.56441 .33403 m
.56752 .34941 L
s
0 0 1 r
.65059 .43248 m
.66597 .43559 L
s
.34048 .43875 m
.35285 .42515 L
s
1 0 0 r
.57485 .64715 m
.56125 .65952 L
s
0 0 1 r
.32106 .48164 m
.33569 .47963 L
s
1 0 0 r
.52037 .66431 m
.51836 .67894 L
s
.67137 .49046 m
.66556 .50789 L
s
0 0 1 r
.49211 .33444 m
.50954 .32863 L
s
1 0 0 r
.6715 .5143 m
.66373 .53105 L
s
0 0 1 r
.46895 .33627 m
.4857 .3285 L
s
.33271 .4428 m
.34693 .43308 L
s
1 0 0 r
.56692 .65307 m
.5572 .66729 L
s
0 0 1 r
.32587 .45545 m
.34049 .44898 L
s
1 0 0 r
.55102 .65951 m
.54455 .67413 L
s
.6468 .40069 m
.64721 .41823 L
s
0 0 1 r
.58177 .35279 m
.59931 .3532 L
s
1 0 0 r
.63097 .37861 m
.63271 .39569 L
s
0 0 1 r
.60431 .36729 m
.62139 .36903 L
s
.31887 .47454 m
.33339 .47139 L
s
1 0 0 r
.52861 .66661 m
.52546 .68113 L
s
0 0 1 r
.33021 .45775 m
.34085 .44273 L
s
1 0 0 r
.55727 .65915 m
.54225 .66979 L
s
.66001 .42402 m
.65886 .44182 L
s
0 0 1 r
.55818 .34114 m
.57598 .33999 L
s
.33075 .44358 m
.34444 .43266 L
s
1 0 0 r
.56734 .65556 m
.55642 .66925 L
s
.57928 .33628 m
.58266 .35182 L
s
0 0 1 r
.64818 .41734 m
.66372 .42072 L
s
1 0 0 r
.66998 .44825 m
.66707 .46608 L
s
0 0 1 r
.53392 .33293 m
.55175 .33002 L
s
.32895 .45289 m
.34048 .43875 L
s
1 0 0 r
.56125 .65952 m
.54711 .67105 L
s
.61326 .35798 m
.61604 .37445 L
s
0 0 1 r
.62555 .38396 m
.64202 .38674 L
s
.32937 .44563 m
.34243 .43355 L
s
1 0 0 r
.56645 .65757 m
.55437 .67063 L
s
0 0 1 r
.32341 .45318 m
.33772 .44544 L
s
1 0 0 r
.55456 .66228 m
.54682 .67659 L
s
0 0 1 r
.32871 .44878 m
.34105 .43563 L
s
1 0 0 r
.56437 .65895 m
.55122 .67129 L
s
.67619 .47288 m
.67137 .49046 L
s
0 0 1 r
.50954 .32863 m
.52712 .32381 L
s
1 0 0 r
.67829 .49727 m
.6715 .5143 L
s
0 0 1 r
.4857 .3285 m
.50273 .32171 L
s
.31658 .46893 m
.33095 .46458 L
s
1 0 0 r
.53542 .66905 m
.53107 .68342 L
s
.52137 .31423 m
.52315 .32856 L
s
0 0 1 r
.67144 .47685 m
.68577 .47863 L
s
1 0 0 r
.5101 .3126 m
.51104 .32683 L
s
0 0 1 r
.67317 .48896 m
.6874 .4899 L
s
1 0 0 r
.53368 .31584 m
.53619 .33028 L
s
0 0 1 r
.66972 .46381 m
.68416 .46632 L
s
.32116 .45242 m
.33509 .44339 L
s
1 0 0 r
.55661 .66491 m
.54758 .67884 L
s
0 0 1 r
.3205 .47321 m
.33021 .45775 L
s
1 0 0 r
.54225 .66979 m
.52679 .6795 L
s
0 0 1 r
.31089 .5 m
.32503 .5 L
s
1 0 0 r
.5 .31089 m
.5 .32503 L
s
0 0 1 r
.67497 .5 m
.68911 .5 L
s
1 0 0 r
.5 .67497 m
.5 .68911 L
s
.54688 .3175 m
.54999 .33207 L
s
0 0 1 r
.66793 .45001 m
.6825 .45312 L
s
1 0 0 r
.59443 .33891 m
.59796 .35464 L
s
0 0 1 r
.64536 .40204 m
.66109 .40557 L
s
.31426 .46487 m
.32841 .45925 L
s
1 0 0 r
.54075 .67159 m
.53513 .68574 L
s
0 0 1 r
.31927 .45308 m
.33271 .4428 L
s
1 0 0 r
.5572 .66729 m
.54692 .68073 L
s
.66017 .4064 m
.66001 .42402 L
s
0 0 1 r
.57598 .33999 m
.5936 .33983 L
s
.30907 .49121 m
.32311 .49016 L
s
1 0 0 r
.50984 .67689 m
.50879 .69093 L
s
.64545 .38345 m
.6468 .40069 L
s
0 0 1 r
.59931 .3532 m
.61655 .35455 L
s
.31834 .46752 m
.32895 .45289 L
s
1 0 0 r
.54711 .67105 m
.53248 .68166 L
s
.67186 .43048 m
.66998 .44825 L
s
0 0 1 r
.55175 .33002 m
.56952 .32814 L
s
1 0 0 r
.56081 .31931 m
.56441 .33403 L
s
0 0 1 r
.66597 .43559 m
.68069 .43919 L
s
1 0 0 r
.67995 .45523 m
.67619 .47288 L
s
0 0 1 r
.52712 .32381 m
.54477 .32005 L
s
1 0 0 r
.68404 .48003 m
.67829 .49727 L
s
0 0 1 r
.50273 .32171 m
.51997 .31596 L
s
.31788 .45507 m
.33075 .44358 L
s
1 0 0 r
.55642 .66925 m
.54493 .68212 L
s
.62838 .36194 m
.63097 .37861 L
s
0 0 1 r
.62139 .36903 m
.63806 .37162 L
s
.31727 .46247 m
.32871 .44878 L
s
1 0 0 r
.55122 .67129 m
.53753 .68273 L
s
0 0 1 r
.31716 .45826 m
.32937 .44563 L
s
1 0 0 r
.55437 .67063 m
.54174 .68284 L
s
0 0 1 r
.31198 .46237 m
.32587 .45545 L
s
1 0 0 r
.54455 .67413 m
.53763 .68802 L
s
0 0 1 r
.30713 .48382 m
.32106 .48164 L
s
1 0 0 r
.51836 .67894 m
.51618 .69287 L
s
0 0 1 r
.31179 .48907 m
.3205 .47321 L
s
1 0 0 r
.52679 .6795 m
.51093 .68821 L
s
.60969 .34204 m
.61326 .35798 L
s
0 0 1 r
.64202 .38674 m
.65796 .39031 L
s
1 0 0 r
.57531 .32137 m
.57928 .33628 L
s
0 0 1 r
.66372 .42072 m
.67863 .42469 L
s
.30987 .46142 m
.32341 .45318 L
s
1 0 0 r
.54682 .67659 m
.53858 .69013 L
s
0 0 1 r
.30508 .47794 m
.31887 .47454 L
s
1 0 0 r
.52546 .68113 m
.52206 .69492 L
s
0 0 1 r
.30871 .4826 m
.31834 .46752 L
s
1 0 0 r
.53248 .68166 m
.5174 .69129 L
s
0 0 1 r
.30806 .46195 m
.32116 .45242 L
s
1 0 0 r
.54758 .67884 m
.53805 .69194 L
s
.68871 .46265 m
.68404 .48003 L
s
0 0 1 r
.51997 .31596 m
.53735 .31129 L
s
1 0 0 r
.67269 .41284 m
.67186 .43048 L
s
0 0 1 r
.56952 .32814 m
.58716 .32731 L
s
1 0 0 r
.68264 .43757 m
.67995 .45523 L
s
0 0 1 r
.54477 .32005 m
.56243 .31736 L
s
1 0 0 r
.65932 .38905 m
.66017 .4064 L
s
0 0 1 r
.5936 .33983 m
.61095 .34068 L
s
.30298 .47361 m
.31658 .46893 L
s
1 0 0 r
.53107 .68342 m
.52639 .69702 L
s
.64315 .36661 m
.64545 .38345 L
s
0 0 1 r
.61655 .35455 m
.63339 .35685 L
s
.30678 .47663 m
.31727 .46247 L
s
1 0 0 r
.53753 .68273 m
.52337 .69322 L
s
0 0 1 r
.30668 .46388 m
.31927 .45308 L
s
1 0 0 r
.54692 .68073 m
.53612 .69332 L
s
.59021 .3238 m
.59443 .33891 L
s
0 0 1 r
.66109 .40557 m
.6762 .40979 L
s
1 0 0 r
.5194 .30065 m
.52137 .31423 L
s
0 0 1 r
.68577 .47863 m
.69935 .4806 L
s
1 0 0 r
.53088 .30214 m
.53368 .31584 L
s
0 0 1 r
.68416 .46632 m
.69786 .46912 L
s
.30589 .4714 m
.31716 .45826 L
s
1 0 0 r
.54174 .68284 m
.5286 .69411 L
s
0 0 1 r
.30591 .46708 m
.31788 .45507 L
s
1 0 0 r
.54493 .68212 m
.53292 .69409 L
s
.50906 .29913 m
.5101 .3126 L
s
0 0 1 r
.6874 .4899 m
.70087 .49094 L
s
1 0 0 r
.54337 .30367 m
.54688 .3175 L
s
0 0 1 r
.6825 .45312 m
.69633 .45663 L
s
1 0 0 r
.6249 .34579 m
.62838 .36194 L
s
0 0 1 r
.63806 .37162 m
.65421 .3751 L
s
.30414 .50525 m
.31179 .48907 L
s
1 0 0 r
.51093 .68821 m
.49475 .69586 L
s
0 0 1 r
.30089 .47088 m
.31426 .46487 L
s
1 0 0 r
.53513 .68574 m
.52912 .69911 L
s
0 0 1 r
.29752 .5 m
.31089 .5 L
s
1 0 0 r
.5 .29752 m
.5 .31089 L
s
0 0 1 r
.68911 .5 m
.70248 .5 L
s
1 0 0 r
.5 .68911 m
.5 .70248 L
s
.55671 .30533 m
.56081 .31931 L
s
0 0 1 r
.68069 .43919 m
.69467 .44329 L
s
.29581 .49234 m
.30907 .49121 L
s
1 0 0 r
.50879 .69093 m
.50766 .70419 L
s
0 0 1 r
.29893 .46972 m
.31198 .46237 L
s
1 0 0 r
.53763 .68802 m
.53028 .70107 L
s
0 0 1 r
.30013 .49805 m
.30871 .4826 L
s
1 0 0 r
.5174 .69129 m
.50195 .69987 L
s
.60534 .32672 m
.60969 .34204 L
s
0 0 1 r
.65796 .39031 m
.67328 .39466 L
s
1 0 0 r
.69226 .44521 m
.68871 .46265 L
s
0 0 1 r
.53735 .31129 m
.55479 .30774 L
s
1 0 0 r
.68421 .41999 m
.68264 .43757 L
s
0 0 1 r
.56243 .31736 m
.58001 .31579 L
s
1 0 0 r
.67242 .39542 m
.67269 .41284 L
s
0 0 1 r
.58716 .32731 m
.60458 .32758 L
s
.294 .48618 m
.30713 .48382 L
s
1 0 0 r
.51618 .69287 m
.51382 .706 L
s
.57074 .30721 m
.57531 .32137 L
s
0 0 1 r
.67863 .42469 m
.69279 .42926 L
s
.2972 .47012 m
.30987 .46142 L
s
1 0 0 r
.53858 .69013 m
.52988 .7028 L
s
.65742 .37205 m
.65932 .38905 L
s
0 0 1 r
.61095 .34068 m
.62795 .34258 L
s
.29733 .49122 m
.30678 .47663 L
s
1 0 0 r
.52337 .69322 m
.50878 .70267 L
s
.63988 .35025 m
.64315 .36661 L
s
0 0 1 r
.63339 .35685 m
.64975 .36012 L
s
.29585 .47197 m
.30806 .46195 L
s
1 0 0 r
.53805 .69194 m
.52803 .70415 L
s
0 0 1 r
.2976 .5217 m
.30414 .50525 L
s
1 0 0 r
.49475 .69586 m
.4783 .7024 L
s
0 0 1 r
.29212 .48159 m
.30508 .47794 L
s
1 0 0 r
.52206 .69492 m
.51841 .70788 L
s
0 0 1 r
.29563 .485 m
.30589 .4714 L
s
1 0 0 r
.5286 .69411 m
.515 .70437 L
s
0 0 1 r
.29504 .47518 m
.30668 .46388 L
s
1 0 0 r
.53612 .69332 m
.52482 .70496 L
s
0 0 1 r
.29491 .47958 m
.30591 .46708 L
s
1 0 0 r
.53292 .69409 m
.52042 .70509 L
s
.58528 .30943 m
.59021 .3238 L
s
0 0 1 r
.6762 .40979 m
.69057 .41472 L
s
1 0 0 r
.62053 .33024 m
.6249 .34579 L
s
0 0 1 r
.65421 .3751 m
.66976 .37947 L
s
.29023 .47861 m
.30298 .47361 L
s
1 0 0 r
.52639 .69702 m
.52139 .70977 L
s
0 0 1 r
.29268 .51382 m
.30013 .49805 L
s
1 0 0 r
.50195 .69987 m
.48618 .70732 L
s
.69463 .42779 m
.69226 .44521 L
s
0 0 1 r
.55479 .30774 m
.57221 .30537 L
s
1 0 0 r
.52779 .2893 m
.53088 .30214 L
s
0 0 1 r
.69786 .46912 m
.7107 .47221 L
s
1 0 0 r
.51723 .28793 m
.5194 .30065 L
s
0 0 1 r
.69935 .4806 m
.71207 .48277 L
s
1 0 0 r
.68461 .40258 m
.68421 .41999 L
s
0 0 1 r
.58001 .31579 m
.59742 .31539 L
s
1 0 0 r
.53947 .29069 m
.54337 .30367 L
s
0 0 1 r
.69633 .45663 m
.70931 .46053 L
s
1 0 0 r
.50792 .28652 m
.50906 .29913 L
s
0 0 1 r
.70087 .49094 m
.71348 .49208 L
s
.28842 .47725 m
.30089 .47088 L
s
1 0 0 r
.52912 .69911 m
.52275 .71158 L
s
.67103 .37832 m
.67242 .39542 L
s
0 0 1 r
.60458 .32758 m
.62168 .32897 L
s
.28503 .5 m
.29752 .5 L
s
1 0 0 r
.5 .28503 m
.5 .29752 L
s
0 0 1 r
.70248 .5 m
.71497 .5 L
s
1 0 0 r
.5 .70248 m
.5 .71497 L
s
.55212 .29218 m
.55671 .30533 L
s
0 0 1 r
.69467 .44329 m
.70782 .44788 L
s
1 0 0 r
.60018 .31212 m
.60534 .32672 L
s
0 0 1 r
.67328 .39466 m
.68788 .39982 L
s
.289 .50618 m
.29733 .49122 L
s
1 0 0 r
.50878 .70267 m
.49382 .711 L
s
.65446 .3555 m
.65742 .37205 L
s
0 0 1 r
.62795 .34258 m
.6445 .34554 L
s
.28679 .47749 m
.29893 .46972 L
s
1 0 0 r
.53028 .70107 m
.52251 .71321 L
s
0 0 1 r
.29225 .53833 m
.2976 .5217 L
s
1 0 0 r
.4783 .7024 m
.46167 .70775 L
s
0 0 1 r
.28344 .49357 m
.29581 .49234 L
s
1 0 0 r
.50766 .70419 m
.50643 .71656 L
s
0 0 1 r
.28647 .49901 m
.29563 .485 L
s
1 0 0 r
.515 .70437 m
.50099 .71353 L
s
.63561 .33446 m
.63988 .35025 L
s
0 0 1 r
.64975 .36012 m
.66554 .36439 L
s
.28549 .47926 m
.2972 .47012 L
s
1 0 0 r
.52988 .7028 m
.52074 .71451 L
s
.56557 .29388 m
.57074 .30721 L
s
0 0 1 r
.69279 .42926 m
.70612 .43443 L
s
.28465 .48246 m
.29585 .47197 L
s
1 0 0 r
.52803 .70415 m
.51754 .71535 L
s
0 0 1 r
.28499 .49252 m
.29491 .47958 L
s
1 0 0 r
.52042 .70509 m
.50748 .71501 L
s
0 0 1 r
.28443 .48693 m
.29504 .47518 L
s
1 0 0 r
.52482 .70496 m
.51307 .71557 L
s
0 0 1 r
.28179 .48871 m
.294 .48618 L
s
1 0 0 r
.51382 .706 m
.51129 .71821 L
s
.69578 .41048 m
.69463 .42779 L
s
0 0 1 r
.57221 .30537 m
.58952 .30422 L
s
.28642 .52984 m
.29268 .51382 L
s
1 0 0 r
.48618 .70732 m
.47016 .71358 L
s
.61526 .31539 m
.62053 .33024 L
s
0 0 1 r
.66976 .37947 m
.68461 .38474 L
s
.2801 .48548 m
.29212 .48159 L
s
1 0 0 r
.51841 .70788 m
.51452 .7199 L
s
.68382 .38543 m
.68461 .40258 L
s
0 0 1 r
.59742 .31539 m
.61457 .31618 L
s
1 0 0 r
.57965 .29589 m
.58528 .30943 L
s
0 0 1 r
.69057 .41472 m
.70411 .42035 L
s
1 0 0 r
.66848 .36162 m
.67103 .37832 L
s
0 0 1 r
.62168 .32897 m
.63838 .33152 L
s
.27845 .48391 m
.29023 .47861 L
s
1 0 0 r
.52139 .70977 m
.51609 .72155 L
s
0 0 1 r
.28186 .52145 m
.289 .50618 L
s
1 0 0 r
.49382 .711 m
.47855 .71814 L
s
0 0 1 r
.28815 .55508 m
.29225 .53833 L
s
1 0 0 r
.46167 .70775 m
.44492 .71185 L
s
.65041 .3395 m
.65446 .3555 L
s
0 0 1 r
.6445 .34554 m
.6605 .34959 L
s
1 0 0 r
.52442 .27741 m
.52779 .2893 L
s
0 0 1 r
.7107 .47221 m
.72259 .47558 L
s
1 0 0 r
.51488 .27617 m
.51723 .28793 L
s
0 0 1 r
.71207 .48277 m
.72383 .48512 L
s
.27694 .48398 m
.28842 .47725 L
s
1 0 0 r
.52275 .71158 m
.51602 .72306 L
s
.59421 .29833 m
.60018 .31212 L
s
0 0 1 r
.68788 .39982 m
.70167 .40579 L
s
1 0 0 r
.53518 .27866 m
.53947 .29069 L
s
0 0 1 r
.70931 .46053 m
.72134 .46482 L
s
.27849 .51337 m
.28647 .49901 L
s
1 0 0 r
.50099 .71353 m
.48663 .72151 L
s
.5067 .27488 m
.50792 .28652 L
s
0 0 1 r
.71348 .49208 m
.72512 .4933 L
s
1 0 0 r
.63034 .31936 m
.63561 .33446 L
s
0 0 1 r
.66554 .36439 m
.68064 .36966 L
s
1 0 0 r
.54703 .27999 m
.55212 .29218 L
s
0 0 1 r
.70782 .44788 m
.72001 .45297 L
s
.27569 .48565 m
.28679 .47749 L
s
1 0 0 r
.52251 .71321 m
.51435 .72431 L
s
0 0 1 r
.27352 .5 m
.28503 .5 L
s
1 0 0 r
.5 .27352 m
.5 .28503 L
s
0 0 1 r
.71497 .5 m
.72648 .5 L
s
1 0 0 r
.5 .71497 m
.5 .72648 L
s
0 0 1 r
.27623 .50584 m
.28499 .49252 L
s
1 0 0 r
.50748 .71501 m
.49416 .72377 L
s
.69566 .39336 m
.69578 .41048 L
s
0 0 1 r
.58952 .30422 m
.60664 .30434 L
s
.27485 .48882 m
.28549 .47926 L
s
1 0 0 r
.52074 .71451 m
.51118 .72515 L
s
0 0 1 r
.28143 .54604 m
.28642 .52984 L
s
1 0 0 r
.47016 .71358 m
.45396 .71857 L
s
0 0 1 r
.27496 .4991 m
.28443 .48693 L
s
1 0 0 r
.51307 .71557 m
.5009 .72504 L
s
0 0 1 r
.27455 .49336 m
.28465 .48246 L
s
1 0 0 r
.51754 .71535 m
.50664 .72545 L
s
.5598 .28149 m
.56557 .29388 L
s
0 0 1 r
.70612 .43443 m
.71851 .4402 L
s
1 0 0 r
.68179 .36863 m
.68382 .38543 L
s
0 0 1 r
.61457 .31618 m
.63137 .31821 L
s
.27208 .49488 m
.28344 .49357 L
s
1 0 0 r
.50643 .71656 m
.50512 .72792 L
s
.60907 .30135 m
.61526 .31539 L
s
0 0 1 r
.68461 .38474 m
.69865 .39093 L
s
1 0 0 r
.66476 .34543 m
.66848 .36162 L
s
0 0 1 r
.63838 .33152 m
.65457 .33524 L
s
.27059 .4914 m
.28179 .48871 L
s
1 0 0 r
.51129 .71821 m
.5086 .72941 L
s
0 0 1 r
.28536 .57184 m
.28815 .55508 L
s
1 0 0 r
.44492 .71185 m
.42816 .71464 L
s
.57332 .28329 m
.57965 .29589 L
s
0 0 1 r
.70411 .42035 m
.71671 .42668 L
s
.27599 .53695 m
.28186 .52145 L
s
1 0 0 r
.47855 .71814 m
.46305 .72401 L
s
.64525 .32416 m
.65041 .3395 L
s
0 0 1 r
.6605 .34959 m
.67584 .35475 L
s
.26912 .48961 m
.2801 .48548 L
s
1 0 0 r
.51452 .7199 m
.51039 .73088 L
s
0 0 1 r
.27178 .52802 m
.27849 .51337 L
s
1 0 0 r
.48663 .72151 m
.47198 .72822 L
s
0 0 1 r
.26774 .48951 m
.27845 .48391 L
s
1 0 0 r
.51609 .72155 m
.51049 .73226 L
s
.58743 .28549 m
.59421 .29833 L
s
0 0 1 r
.70167 .40579 m
.71451 .41257 L
s
1 0 0 r
.62405 .30505 m
.63034 .31936 L
s
0 0 1 r
.68064 .36966 m
.69495 .37595 L
s
1 0 0 r
.69423 .37655 m
.69566 .39336 L
s
0 0 1 r
.60664 .30434 m
.62345 .30577 L
s
.27779 .56233 m
.28143 .54604 L
s
1 0 0 r
.45396 .71857 m
.43767 .72221 L
s
0 0 1 r
.26657 .49106 m
.27694 .48398 L
s
1 0 0 r
.51602 .72306 m
.50894 .73343 L
s
0 0 1 r
.26873 .5195 m
.27623 .50584 L
s
1 0 0 r
.49416 .72377 m
.4805 .73127 L
s
.52075 .2666 m
.52442 .27741 L
s
0 0 1 r
.72259 .47558 m
.7334 .47925 L
s
1 0 0 r
.5305 .2677 m
.53518 .27866 L
s
0 0 1 r
.72134 .46482 m
.7323 .4695 L
s
1 0 0 r
.67848 .3523 m
.68179 .36863 L
s
0 0 1 r
.63137 .31821 m
.6477 .32152 L
s
1 0 0 r
.51234 .26549 m
.51488 .27617 L
s
0 0 1 r
.72383 .48512 m
.73451 .48766 L
s
.26573 .49418 m
.27569 .48565 L
s
1 0 0 r
.51435 .72431 m
.50582 .73427 L
s
.54145 .26886 m
.54703 .27999 L
s
0 0 1 r
.72001 .45297 m
.73114 .45855 L
s
.26673 .51163 m
.27496 .4991 L
s
1 0 0 r
.5009 .72504 m
.48837 .73327 L
s
.50538 .26433 m
.5067 .27488 L
s
0 0 1 r
.72512 .4933 m
.73567 .49462 L
s
.26538 .49877 m
.27485 .48882 L
s
1 0 0 r
.51118 .72515 m
.50123 .73462 L
s
0 0 1 r
.26566 .50465 m
.27455 .49336 L
s
1 0 0 r
.50664 .72545 m
.49535 .73434 L
s
.65982 .32986 m
.66476 .34543 L
s
0 0 1 r
.65457 .33524 m
.67014 .34018 L
s
1 0 0 r
.42816 .71464 m
.41146 .71606 L
s
0 0 1 r
.28394 .58854 m
.28536 .57184 L
s
.26311 .5 m
.27352 .5 L
s
1 0 0 r
.5 .26311 m
.5 .27352 L
s
0 0 1 r
.72648 .5 m
.73689 .5 L
s
1 0 0 r
.5 .72648 m
.5 .73689 L
s
.55342 .27017 m
.5598 .28149 L
s
0 0 1 r
.71851 .4402 m
.72983 .44658 L
s
1 0 0 r
.60196 .28823 m
.60907 .30135 L
s
0 0 1 r
.69865 .39093 m
.71177 .39804 L
s
.27148 .55261 m
.27599 .53695 L
s
1 0 0 r
.46305 .72401 m
.44739 .72852 L
s
0 0 1 r
.26183 .49627 m
.27208 .49488 L
s
1 0 0 r
.50512 .72792 m
.50373 .73817 L
s
.63897 .30958 m
.64525 .32416 L
s
0 0 1 r
.67584 .35475 m
.69042 .36103 L
s
1 0 0 r
.56628 .27174 m
.57332 .28329 L
s
0 0 1 r
.71671 .42668 m
.72826 .43372 L
s
.26054 .49425 m
.27059 .4914 L
s
1 0 0 r
.5086 .72941 m
.50575 .73946 L
s
0 0 1 r
.26643 .54289 m
.27178 .52802 L
s
1 0 0 r
.47198 .72822 m
.45711 .73357 L
s
.69144 .36015 m
.69423 .37655 L
s
0 0 1 r
.62345 .30577 m
.63985 .30856 L
s
.27555 .57862 m
.27779 .56233 L
s
1 0 0 r
.43767 .72221 m
.42138 .72445 L
s
.61672 .29165 m
.62405 .30505 L
s
0 0 1 r
.69495 .37595 m
.70835 .38328 L
s
.25931 .49396 m
.26912 .48961 L
s
1 0 0 r
.51039 .73088 m
.50604 .74069 L
s
.57984 .27369 m
.58743 .28549 L
s
0 0 1 r
.71451 .41257 m
.72631 .42016 L
s
1 0 0 r
.67388 .33655 m
.67848 .3523 L
s
0 0 1 r
.6477 .32152 m
.66345 .32612 L
s
.26258 .53343 m
.26873 .5195 L
s
1 0 0 r
.4805 .73127 m
.46657 .73742 L
s
0 0 1 r
.25823 .49538 m
.26774 .48951 L
s
1 0 0 r
.51049 .73226 m
.50462 .74177 L
s
.65366 .31502 m
.65982 .32986 L
s
0 0 1 r
.67014 .34018 m
.68498 .34634 L
s
1 0 0 r
.41146 .71606 m
.39492 .71603 L
s
0 0 1 r
.28397 .60508 m
.28394 .58854 L
s
.25983 .52447 m
.26673 .51163 L
s
1 0 0 r
.48837 .73327 m
.47553 .74017 L
s
0 0 1 r
.25742 .49845 m
.26657 .49106 L
s
1 0 0 r
.50894 .73343 m
.50155 .74258 L
s
.52544 .25792 m
.5305 .2677 L
s
0 0 1 r
.7323 .4695 m
.74208 .47456 L
s
1 0 0 r
.51681 .25698 m
.52075 .2666 L
s
0 0 1 r
.7334 .47925 m
.74302 .48319 L
s
.25703 .50305 m
.26573 .49418 L
s
1 0 0 r
.50582 .73427 m
.49695 .74297 L
s
0 0 1 r
.25809 .51627 m
.26566 .50465 L
s
1 0 0 r
.49535 .73434 m
.48373 .74191 L
s
0 0 1 r
.26841 .56834 m
.27148 .55261 L
s
1 0 0 r
.44739 .72852 m
.43166 .73159 L
s
0 0 1 r
.2572 .50906 m
.26538 .49877 L
s
1 0 0 r
.50123 .73462 m
.49094 .7428 L
s
.53538 .25891 m
.54145 .26886 L
s
0 0 1 r
.73114 .45855 m
.74109 .46462 L
s
1 0 0 r
.50961 .25601 m
.51234 .26549 L
s
0 0 1 r
.73451 .48766 m
.74399 .49039 L
s
1 0 0 r
.59393 .27616 m
.60196 .28823 L
s
0 0 1 r
.71177 .39804 m
.72384 .40607 L
s
1 0 0 r
.50398 .255 m
.50538 .26433 L
s
0 0 1 r
.73567 .49462 m
.745 .49602 L
s
1 0 0 r
.63155 .29588 m
.63897 .30958 L
s
0 0 1 r
.69042 .36103 m
.70412 .36845 L
s
1 0 0 r
.54646 .26003 m
.55342 .27017 L
s
0 0 1 r
.72983 .44658 m
.73997 .45354 L
s
.25393 .5 m
.26311 .5 L
s
1 0 0 r
.5 .25393 m
.5 .26311 L
s
0 0 1 r
.73689 .5 m
.74607 .5 L
s
1 0 0 r
.5 .73689 m
.5 .74607 L
s
.68727 .34426 m
.69144 .36015 L
s
0 0 1 r
.63985 .30856 m
.65574 .31273 L
s
.26254 .5579 m
.26643 .54289 L
s
1 0 0 r
.45711 .73357 m
.4421 .73746 L
s
.55854 .26138 m
.56628 .27174 L
s
0 0 1 r
.72826 .43372 m
.73862 .44146 L
s
1 0 0 r
.42138 .72445 m
.40518 .7252 L
s
0 0 1 r
.2748 .59482 m
.27555 .57862 L
s
.25283 .49775 m
.26183 .49627 L
s
1 0 0 r
.50373 .73817 m
.50225 .74717 L
s
.66795 .32148 m
.67388 .33655 L
s
0 0 1 r
.66345 .32612 m
.67852 .33205 L
s
1 0 0 r
.60837 .27928 m
.61672 .29165 L
s
0 0 1 r
.70835 .38328 m
.72072 .39163 L
s
.25176 .49726 m
.26054 .49425 L
s
1 0 0 r
.50575 .73946 m
.50274 .74824 L
s
0 0 1 r
.25788 .54756 m
.26258 .53343 L
s
1 0 0 r
.46657 .73742 m
.45244 .74212 L
s
.57143 .26307 m
.57984 .27369 L
s
0 0 1 r
.72631 .42016 m
.73693 .42857 L
s
1 0 0 r
.39492 .71603 m
.37866 .71451 L
s
0 0 1 r
.28549 .62134 m
.28397 .60508 L
s
1 0 0 r
.64626 .30104 m
.65366 .31502 L
s
0 0 1 r
.68498 .34634 m
.69896 .35374 L
s
.25079 .49853 m
.25931 .49396 L
s
1 0 0 r
.50604 .74069 m
.50147 .74921 L
s
0 0 1 r
.25439 .53756 m
.25983 .52447 L
s
1 0 0 r
.47553 .74017 m
.46244 .74561 L
s
0 0 1 r
.26686 .58405 m
.26841 .56834 L
s
1 0 0 r
.43166 .73159 m
.41595 .73314 L
s
0 0 1 r
.25004 .50151 m
.25823 .49538 L
s
1 0 0 r
.50462 .74177 m
.49849 .74996 L
s
0 0 1 r
.25194 .52817 m
.25809 .51627 L
s
1 0 0 r
.48373 .74191 m
.47183 .74806 L
s
0 0 1 r
.24963 .50612 m
.25742 .49845 L
s
1 0 0 r
.50155 .74258 m
.49388 .75037 L
s
.58498 .26525 m
.59393 .27616 L
s
0 0 1 r
.72384 .40607 m
.73475 .41502 L
s
1 0 0 r
.62299 .28319 m
.63155 .29588 L
s
0 0 1 r
.70412 .36845 m
.71681 .37701 L
s
.25043 .51965 m
.2572 .50906 L
s
1 0 0 r
.49094 .7428 m
.48035 .74957 L
s
0 0 1 r
.24971 .51223 m
.25703 .50305 L
s
1 0 0 r
.49695 .74297 m
.48777 .75029 L
s
.52 .24947 m
.52544 .25792 L
s
0 0 1 r
.74208 .47456 m
.75053 .48 L
s
1 0 0 r
.68167 .32902 m
.68727 .34426 L
s
0 0 1 r
.65574 .31273 m
.67098 .31833 L
s
1 0 0 r
.51259 .24868 m
.51681 .25698 L
s
0 0 1 r
.74302 .48319 m
.75132 .48741 L
s
1 0 0 r
.52883 .25028 m
.53538 .25891 L
s
0 0 1 r
.74109 .46462 m
.74972 .47117 L
s
1 0 0 r
.50671 .24787 m
.50961 .25601 L
s
0 0 1 r
.74399 .49039 m
.75213 .49329 L
s
1 0 0 r
.40518 .7252 m
.38918 .7244 L
s
0 0 1 r
.2756 .61082 m
.2748 .59482 L
s
.26018 .57297 m
.26254 .5579 L
s
1 0 0 r
.4421 .73746 m
.42703 .73982 L
s
.53892 .2512 m
.54646 .26003 L
s
0 0 1 r
.73997 .45354 m
.7488 .46108 L
s
1 0 0 r
.50249 .24701 m
.50398 .255 L
s
0 0 1 r
.745 .49602 m
.75299 .49751 L
s
1 0 0 r
.66067 .30723 m
.66795 .32148 L
s
0 0 1 r
.67852 .33205 m
.69277 .33933 L
s
1 0 0 r
.55011 .25232 m
.55854 .26138 L
s
0 0 1 r
.73862 .44146 m
.74768 .44989 L
s
1 0 0 r
.59899 .26806 m
.60837 .27928 L
s
0 0 1 r
.72072 .39163 m
.73194 .40101 L
s
.24611 .5 m
.25393 .5 L
s
1 0 0 r
.5 .24611 m
.5 .25393 L
s
0 0 1 r
.74607 .5 m
.75389 .5 L
s
1 0 0 r
.5 .74607 m
.5 .75389 L
s
.37866 .71451 m
.36278 .71144 L
s
0 0 1 r
.28856 .63722 m
.28549 .62134 L
s
.25474 .56181 m
.25788 .54756 L
s
1 0 0 r
.45244 .74212 m
.43819 .74526 L
s
.6376 .28803 m
.64626 .30104 L
s
0 0 1 r
.69896 .35374 m
.71197 .3624 L
s
.24521 .4993 m
.25283 .49775 L
s
1 0 0 r
.50225 .74717 m
.5007 .75479 L
s
.56223 .25376 m
.57143 .26307 L
s
0 0 1 r
.73693 .42857 m
.74624 .43777 L
s
1 0 0 r
.41595 .73314 m
.40035 .73309 L
s
0 0 1 r
.26691 .59965 m
.26686 .58405 L
s
.24438 .5004 m
.25176 .49726 L
s
1 0 0 r
.50274 .74824 m
.4996 .75562 L
s
0 0 1 r
.25049 .55082 m
.25439 .53756 L
s
1 0 0 r
.46244 .74561 m
.44918 .74951 L
s
0 0 1 r
.2437 .50329 m
.25079 .49853 L
s
1 0 0 r
.50147 .74921 m
.49671 .7563 L
s
.61329 .27164 m
.62299 .28319 L
s
0 0 1 r
.71681 .37701 m
.72836 .38671 L
s
1 0 0 r
.67462 .31454 m
.68167 .32902 L
s
0 0 1 r
.67098 .31833 m
.68546 .32538 L
s
.24734 .54029 m
.25194 .52817 L
s
1 0 0 r
.47183 .74806 m
.45971 .75266 L
s
.57512 .25564 m
.58498 .26525 L
s
0 0 1 r
.73475 .41502 m
.74436 .42488 L
s
.2433 .50788 m
.25004 .50151 L
s
1 0 0 r
.49849 .74996 m
.49212 .7567 L
s
.38918 .7244 m
.37348 .72199 L
s
0 0 1 r
.27801 .62652 m
.2756 .61082 L
s
.24519 .53048 m
.25043 .51965 L
s
1 0 0 r
.48035 .74957 m
.46952 .75481 L
s
0 0 1 r
.24332 .51406 m
.24963 .50612 L
s
1 0 0 r
.49388 .75037 m
.48594 .75668 L
s
0 0 1 r
.2439 .52166 m
.24971 .51223 L
s
1 0 0 r
.48777 .75029 m
.47834 .7561 L
s
0 0 1 r
.25946 .58799 m
.26018 .57297 L
s
1 0 0 r
.42703 .73982 m
.41201 .74054 L
s
.65204 .29392 m
.66067 .30723 L
s
0 0 1 r
.69277 .33933 m
.70608 .34796 L
s
1 0 0 r
.51421 .24246 m
.52 .24947 L
s
0 0 1 r
.75053 .48 m
.75754 .48579 L
s
1 0 0 r
.52182 .2431 m
.52883 .25028 L
s
0 0 1 r
.74972 .47117 m
.7569 .47818 L
s
1 0 0 r
.50811 .24184 m
.51259 .24868 L
s
0 0 1 r
.75132 .48741 m
.75816 .49189 L
s
1 0 0 r
.53081 .24381 m
.53892 .2512 L
s
0 0 1 r
.7488 .46108 m
.75619 .46919 L
s
1 0 0 r
.36278 .71144 m
.34742 .70678 L
s
0 0 1 r
.29322 .65258 m
.28856 .63722 L
s
1 0 0 r
.58859 .25813 m
.59899 .26806 L
s
0 0 1 r
.73194 .40101 m
.74187 .41141 L
s
1 0 0 r
.50364 .24119 m
.50671 .24787 L
s
0 0 1 r
.75213 .49329 m
.75881 .49636 L
s
1 0 0 r
.54101 .2447 m
.55011 .25232 L
s
0 0 1 r
.74768 .44989 m
.7553 .45899 L
s
1 0 0 r
.6277 .27614 m
.6376 .28803 L
s
0 0 1 r
.71197 .3624 m
.72386 .3723 L
s
.25325 .57608 m
.25474 .56181 L
s
1 0 0 r
.43819 .74526 m
.42392 .74675 L
s
.50092 .2405 m
.50249 .24701 L
s
0 0 1 r
.75299 .49751 m
.7595 .49908 L
s
1 0 0 r
.40035 .73309 m
.38499 .73137 L
s
0 0 1 r
.26863 .61501 m
.26691 .59965 L
s
.23979 .5 m
.24611 .5 L
s
1 0 0 r
.5 .23979 m
.5 .24611 L
s
0 0 1 r
.75389 .5 m
.76021 .5 L
s
1 0 0 r
.5 .75389 m
.5 .76021 L
s
.55226 .24587 m
.56223 .25376 L
s
0 0 1 r
.74624 .43777 m
.75413 .44774 L
s
.24826 .56418 m
.25049 .55082 L
s
1 0 0 r
.44918 .74951 m
.43582 .75174 L
s
.66611 .30096 m
.67462 .31454 L
s
0 0 1 r
.68546 .32538 m
.69904 .33389 L
s
.23911 .50092 m
.24521 .4993 L
s
1 0 0 r
.5007 .75479 m
.49908 .76089 L
s
.60247 .26137 m
.61329 .27164 L
s
0 0 1 r
.72836 .38671 m
.73863 .39753 L
s
1 0 0 r
.37348 .72199 m
.35822 .7179 L
s
0 0 1 r
.2821 .64178 m
.27801 .62652 L
s
.23854 .50368 m
.24438 .5004 L
s
1 0 0 r
.4996 .75562 m
.49632 .76146 L
s
.56438 .24746 m
.57512 .25564 L
s
0 0 1 r
.74436 .42488 m
.75254 .43562 L
s
.24441 .55256 m
.24734 .54029 L
s
1 0 0 r
.45971 .75266 m
.44744 .75559 L
s
.64204 .28169 m
.65204 .29392 L
s
0 0 1 r
.70608 .34796 m
.71831 .35796 L
s
1 0 0 r
.41201 .74054 m
.39714 .73955 L
s
0 0 1 r
.26045 .60286 m
.25946 .58799 L
s
.23818 .50822 m
.2437 .50329 L
s
1 0 0 r
.49671 .7563 m
.49178 .76182 L
s
0 0 1 r
.2416 .54151 m
.24519 .53048 L
s
1 0 0 r
.46952 .75481 m
.45849 .7584 L
s
0 0 1 r
.23816 .51445 m
.2433 .50788 L
s
1 0 0 r
.49212 .7567 m
.48555 .76184 L
s
.34742 .70678 m
.33269 .70048 L
s
0 0 1 r
.29952 .66731 m
.29322 .65258 L
s
.23972 .5313 m
.2439 .52166 L
s
1 0 0 r
.47834 .7561 m
.4687 .76028 L
s
0 0 1 r
.23862 .5222 m
.24332 .51406 L
s
1 0 0 r
.48594 .75668 m
.4778 .76138 L
s
.5772 .24962 m
.58859 .25813 L
s
0 0 1 r
.74187 .41141 m
.75038 .4228 L
s
1 0 0 r
.61656 .2655 m
.6277 .27614 L
s
0 0 1 r
.72386 .3723 m
.7345 .38344 L
s
1 0 0 r
.51437 .2375 m
.52182 .2431 L
s
0 0 1 r
.7569 .47818 m
.7625 .48563 L
s
1 0 0 r
.50807 .23705 m
.51421 .24246 L
s
0 0 1 r
.75754 .48579 m
.76295 .49193 L
s
1 0 0 r
.52216 .23801 m
.53081 .24381 L
s
0 0 1 r
.75619 .46919 m
.76199 .47784 L
s
.25351 .59028 m
.25325 .57608 L
s
1 0 0 r
.42392 .74675 m
.40972 .74649 L
s
.50338 .2366 m
.50811 .24184 L
s
0 0 1 r
.75816 .49189 m
.7634 .49662 L
s
1 0 0 r
.38499 .73137 m
.36998 .72792 L
s
0 0 1 r
.27208 .63002 m
.26863 .61501 L
s
1 0 0 r
.53126 .23866 m
.54101 .2447 L
s
0 0 1 r
.7553 .45899 m
.76134 .46874 L
s
1 0 0 r
.50042 .23613 m
.50364 .24119 L
s
0 0 1 r
.75881 .49636 m
.76387 .49958 L
s
1 0 0 r
.65613 .28841 m
.66611 .30096 L
s
0 0 1 r
.69904 .33389 m
.71159 .34387 L
s
1 0 0 r
.54153 .23956 m
.55226 .24587 L
s
0 0 1 r
.75413 .44774 m
.76044 .45847 L
s
1 0 0 r
.49927 .23562 m
.50092 .2405 L
s
0 0 1 r
.7595 .49908 m
.76438 .50073 L
s
1 0 0 r
.59054 .25249 m
.60247 .26137 L
s
0 0 1 r
.73863 .39753 m
.74751 .40946 L
s
.24779 .57754 m
.24826 .56418 L
s
1 0 0 r
.43582 .75174 m
.42246 .75221 L
s
.35822 .7179 m
.34353 .71209 L
s
0 0 1 r
.28791 .65647 m
.2821 .64178 L
s
.23511 .5 m
.23979 .5 L
s
1 0 0 r
.5 .23511 m
.5 .23979 L
s
0 0 1 r
.76021 .5 m
.76489 .5 L
s
1 0 0 r
.5 .76021 m
.5 .76489 L
s
.63069 .27068 m
.64204 .28169 L
s
0 0 1 r
.71831 .35796 m
.72932 .36931 L
s
1 0 0 r
.55279 .24085 m
.56438 .24746 L
s
0 0 1 r
.75254 .43562 m
.75915 .44721 L
s
1 0 0 r
.39714 .73955 m
.38253 .73677 L
s
0 0 1 r
.26323 .61747 m
.26045 .60286 L
s
.23467 .50261 m
.23911 .50092 L
s
1 0 0 r
.49908 .76089 m
.49739 .76533 L
s
0 0 1 r
.24324 .56489 m
.24441 .55256 L
s
1 0 0 r
.44744 .75559 m
.43511 .75676 L
s
.33269 .70048 m
.31874 .69251 L
s
0 0 1 r
.30749 .68126 m
.29952 .66731 L
s
.23438 .50707 m
.23854 .50368 L
s
1 0 0 r
.49632 .76146 m
.49293 .76562 L
s
0 0 1 r
.23978 .55264 m
.2416 .54151 L
s
1 0 0 r
.45849 .7584 m
.44736 .76022 L
s
.6042 .25625 m
.61656 .2655 L
s
0 0 1 r
.7345 .38344 m
.74375 .3958 L
s
.23436 .51331 m
.23818 .50822 L
s
1 0 0 r
.49178 .76182 m
.48669 .76564 L
s
.56485 .24266 m
.5772 .24962 L
s
0 0 1 r
.75038 .4228 m
.75734 .43515 L
s
.2373 .54109 m
.23972 .5313 L
s
1 0 0 r
.4687 .76028 m
.45891 .7627 L
s
0 0 1 r
.23474 .52118 m
.23816 .51445 L
s
1 0 0 r
.48555 .76184 m
.47882 .76526 L
s
0 0 1 r
.23567 .53052 m
.23862 .5222 L
s
1 0 0 r
.4778 .76138 m
.46948 .76433 L
s
.36998 .72792 m
.35544 .72268 L
s
0 0 1 r
.27732 .64456 m
.27208 .63002 L
s
1 0 0 r
.40972 .74649 m
.39569 .74441 L
s
0 0 1 r
.25559 .60431 m
.25351 .59028 L
s
1 0 0 r
.50651 .23362 m
.51437 .2375 L
s
0 0 1 r
.7625 .48563 m
.76638 .49349 L
s
1 0 0 r
.513 .23391 m
.52216 .23801 L
s
0 0 1 r
.76199 .47784 m
.76609 .487 L
s
1 0 0 r
.64468 .27705 m
.65613 .28841 L
s
0 0 1 r
.71159 .34387 m
.72295 .35532 L
s
1 0 0 r
.50161 .23337 m
.50807 .23705 L
s
0 0 1 r
.76295 .49193 m
.76663 .49839 L
s
1 0 0 r
.52091 .23433 m
.53126 .23866 L
s
0 0 1 r
.76134 .46874 m
.76567 .47909 L
s
1 0 0 r
.49842 .23311 m
.50338 .2366 L
s
0 0 1 r
.7634 .49662 m
.76689 .50158 L
s
1 0 0 r
.57754 .24517 m
.59054 .25249 L
s
0 0 1 r
.74751 .40946 m
.75483 .42246 L
s
1 0 0 r
.34353 .71209 m
.32953 .70453 L
s
0 0 1 r
.29547 .67047 m
.28791 .65647 L
s
1 0 0 r
.5301 .23496 m
.54153 .23956 L
s
0 0 1 r
.76044 .45847 m
.76504 .4699 L
s
.24918 .59079 m
.24779 .57754 L
s
1 0 0 r
.42246 .75221 m
.40921 .75082 L
s
.49705 .23281 m
.50042 .23613 L
s
0 0 1 r
.76387 .49958 m
.76719 .50295 L
s
1 0 0 r
.61802 .26103 m
.63069 .27068 L
s
0 0 1 r
.72932 .36931 m
.73897 .38198 L
s
1 0 0 r
.38253 .73677 m
.36832 .73213 L
s
0 0 1 r
.26787 .63168 m
.26323 .61747 L
s
1 0 0 r
.49756 .23251 m
.49927 .23562 L
s
0 0 1 r
.76438 .50073 m
.76749 .50244 L
s
1 0 0 r
.31874 .69251 m
.30571 .68286 L
s
0 0 1 r
.31714 .69429 m
.30749 .68126 L
s
1 0 0 r
.54038 .23593 m
.55279 .24085 L
s
0 0 1 r
.75915 .44721 m
.76407 .45962 L
s
.24395 .5772 m
.24324 .56489 L
s
1 0 0 r
.43511 .75676 m
.4228 .75605 L
s
0 0 1 r
.23222 .5 m
.23511 .5 L
s
1 0 0 r
.5 .23222 m
.5 .23511 L
s
0 0 1 r
.76489 .5 m
.76778 .5 L
s
1 0 0 r
.5 .76489 m
.5 .76778 L
s
.59067 .24852 m
.6042 .25625 L
s
0 0 1 r
.74375 .3958 m
.75148 .40933 L
s
.23204 .50435 m
.23467 .50261 L
s
1 0 0 r
.49739 .76533 m
.49565 .76796 L
s
.55158 .2374 m
.56485 .24266 L
s
0 0 1 r
.75734 .43515 m
.7626 .44842 L
s
1 0 0 r
.35544 .72268 m
.34152 .71559 L
s
0 0 1 r
.28441 .65848 m
.27732 .64456 L
s
.23985 .56382 m
.23978 .55264 L
s
1 0 0 r
.44736 .76022 m
.43618 .76015 L
s
0 0 1 r
.23205 .51056 m
.23438 .50707 L
s
1 0 0 r
.49293 .76562 m
.48944 .76795 L
s
.39569 .74441 m
.38196 .74041 L
s
0 0 1 r
.25959 .61804 m
.25559 .60431 L
s
1 0 0 r
.6318 .267 m
.64468 .27705 L
s
0 0 1 r
.72295 .35532 m
.733 .3682 L
s
.23677 .55096 m
.2373 .54109 L
s
1 0 0 r
.45891 .7627 m
.44904 .76323 L
s
0 0 1 r
.23239 .51851 m
.23436 .51331 L
s
1 0 0 r
.48669 .76564 m
.48149 .76761 L
s
0 0 1 r
.2346 .53894 m
.23567 .53052 L
s
1 0 0 r
.46948 .76433 m
.46106 .7654 L
s
0 0 1 r
.23319 .52804 m
.23474 .52118 L
s
1 0 0 r
.47882 .76526 m
.47196 .76681 L
s
.32953 .70453 m
.31637 .69519 L
s
0 0 1 r
.30481 .68363 m
.29547 .67047 L
s
1 0 0 r
.56352 .23952 m
.57754 .24517 L
s
0 0 1 r
.75483 .42246 m
.76048 .43648 L
s
1 0 0 r
.50337 .23168 m
.513 .23391 L
s
0 0 1 r
.76609 .487 m
.76832 .49663 L
s
1 0 0 r
.49828 .23161 m
.50651 .23362 L
s
0 0 1 r
.76638 .49349 m
.76839 .50172 L
s
1 0 0 r
.51 .23184 m
.52091 .23433 L
s
0 0 1 r
.76567 .47909 m
.76816 .49 L
s
1 0 0 r
.60405 .25288 m
.61802 .26103 L
s
0 0 1 r
.73897 .38198 m
.74712 .39595 L
s
1 0 0 r
.49487 .23156 m
.50161 .23337 L
s
0 0 1 r
.76663 .49839 m
.76844 .50513 L
s
1 0 0 r
.40921 .75082 m
.39616 .74747 L
s
0 0 1 r
.25253 .60384 m
.24918 .59079 L
s
1 0 0 r
.51801 .23219 m
.5301 .23496 L
s
0 0 1 r
.76504 .4699 m
.76781 .48199 L
s
1 0 0 r
.30571 .68286 m
.29374 .67153 L
s
0 0 1 r
.32847 .70626 m
.31714 .69429 L
s
1 0 0 r
.36832 .73213 m
.35462 .72558 L
s
0 0 1 r
.27442 .64538 m
.26787 .63168 L
s
1 0 0 r
.49326 .23149 m
.49842 .23311 L
s
0 0 1 r
.76689 .50158 m
.76851 .50674 L
s
1 0 0 r
.52722 .23285 m
.54038 .23593 L
s
0 0 1 r
.76407 .45962 m
.76715 .47278 L
s
1 0 0 r
.49355 .2314 m
.49705 .23281 L
s
0 0 1 r
.76719 .50295 m
.7686 .50645 L
s
1 0 0 r
.576 .24245 m
.59067 .24852 L
s
0 0 1 r
.75148 .40933 m
.75755 .424 L
s
.24665 .58938 m
.24395 .5772 L
s
1 0 0 r
.4228 .75605 m
.41062 .75335 L
s
.49579 .2313 m
.49756 .23251 L
s
0 0 1 r
.76749 .50244 m
.7687 .50421 L
s
1 0 0 r
.34152 .71559 m
.32836 .70663 L
s
0 0 1 r
.29337 .67164 m
.28441 .65848 L
s
1 0 0 r
.53746 .23396 m
.55158 .2374 L
s
0 0 1 r
.7626 .44842 m
.76604 .46254 L
s
1 0 0 r
.6175 .25843 m
.6318 .267 L
s
0 0 1 r
.733 .3682 m
.74157 .3825 L
s
.23126 .5 m
.23222 .5 L
s
1 0 0 r
.5 .23126 m
.5 .23222 L
s
0 0 1 r
.76778 .5 m
.76874 .5 L
s
1 0 0 r
.5 .76778 m
.5 .76874 L
s
.38196 .74041 m
.36866 .73443 L
s
0 0 1 r
.26557 .63134 m
.25959 .61804 L
s
.24192 .57494 m
.23985 .56382 L
s
1 0 0 r
.43618 .76015 m
.42506 .75808 L
s
.31637 .69519 m
.30421 .68405 L
s
0 0 1 r
.31595 .69579 m
.30481 .68363 L
s
.23135 .50614 m
.23204 .50435 L
s
1 0 0 r
.49565 .76796 m
.49386 .76865 L
s
0 0 1 r
.23825 .56084 m
.23677 .55096 L
s
1 0 0 r
.44904 .76323 m
.43916 .76175 L
s
.54854 .23568 m
.56352 .23952 L
s
0 0 1 r
.76048 .43648 m
.76432 .45146 L
s
1 0 0 r
.58884 .24637 m
.60405 .25288 L
s
0 0 1 r
.74712 .39595 m
.75363 .41116 L
s
.23168 .51412 m
.23205 .51056 L
s
1 0 0 r
.48944 .76795 m
.48588 .76832 L
s
0 0 1 r
.23553 .54742 m
.2346 .53894 L
s
1 0 0 r
.46106 .7654 m
.45258 .76447 L
s
0 0 1 r
.2324 .52379 m
.23239 .51851 L
s
1 0 0 r
.48149 .76761 m
.47621 .7676 L
s
.29374 .67153 m
.28299 .65853 L
s
0 0 1 r
.34147 .71701 m
.32847 .70626 L
s
.23363 .53498 m
.23319 .52804 L
s
1 0 0 r
.47196 .76681 m
.46502 .76637 L
s
.49333 .23142 m
.50337 .23168 L
s
0 0 1 r
.76832 .49663 m
.76858 .50667 L
s
1 0 0 r
.49859 .23133 m
.51 .23184 L
s
0 0 1 r
.76816 .49 m
.76867 .50141 L
s
1 0 0 r
.35462 .72558 m
.34159 .71707 L
s
0 0 1 r
.28293 .65841 m
.27442 .64538 L
s
1 0 0 r
.39616 .74747 m
.38344 .7421 L
s
0 0 1 r
.2579 .61656 m
.25253 .60384 L
s
1 0 0 r
.48972 .23158 m
.49828 .23161 L
s
0 0 1 r
.76839 .50172 m
.76842 .51028 L
s
1 0 0 r
.50533 .23139 m
.51801 .23219 L
s
0 0 1 r
.76781 .48199 m
.76861 .49467 L
s
1 0 0 r
.48788 .23175 m
.49487 .23156 L
s
0 0 1 r
.76844 .50513 m
.76825 .51212 L
s
1 0 0 r
.56027 .23818 m
.576 .24245 L
s
0 0 1 r
.75755 .424 m
.76182 .43973 L
s
1 0 0 r
.51338 .23172 m
.52722 .23285 L
s
0 0 1 r
.76715 .47278 m
.76828 .48662 L
s
1 0 0 r
.48793 .2319 m
.49326 .23149 L
s
0 0 1 r
.76851 .50674 m
.7681 .51207 L
s
1 0 0 r
.32836 .70663 m
.3161 .69577 L
s
0 0 1 r
.30423 .6839 m
.29337 .67164 L
s
1 0 0 r
.60186 .25146 m
.6175 .25843 L
s
0 0 1 r
.74157 .3825 m
.74854 .39814 L
s
1 0 0 r
.41062 .75335 m
.39868 .74858 L
s
0 0 1 r
.25142 .60132 m
.24665 .58938 L
s
1 0 0 r
.52256 .23247 m
.53746 .23396 L
s
0 0 1 r
.76604 .46254 m
.76753 .47744 L
s
1 0 0 r
.48995 .23202 m
.49355 .2314 L
s
0 0 1 r
.7686 .50645 m
.76798 .51005 L
s
1 0 0 r
.36866 .73443 m
.35593 .72642 L
s
0 0 1 r
.27358 .64407 m
.26557 .63134 L
s
1 0 0 r
.30421 .68405 m
.29319 .67114 L
s
0 0 1 r
.32886 .70681 m
.31595 .69579 L
s
1 0 0 r
.49398 .23215 m
.49579 .2313 L
s
0 0 1 r
.7687 .50421 m
.76785 .50602 L
s
1 0 0 r
.57247 .24164 m
.58884 .24637 L
s
0 0 1 r
.75363 .41116 m
.75836 .42753 L
s
.24609 .5859 m
.24192 .57494 L
s
1 0 0 r
.42506 .75808 m
.4141 .75391 L
s
.53269 .23378 m
.54854 .23568 L
s
0 0 1 r
.76432 .45146 m
.76622 .46731 L
s
1 0 0 r
.28299 .65853 m
.27361 .64389 L
s
0 0 1 r
.35611 .72639 m
.34147 .71701 L
s
.23237 .5 m
.23126 .5 L
s
1 0 0 r
.5 .23237 m
.5 .23126 L
s
0 0 1 r
.76874 .5 m
.76763 .5 L
s
1 0 0 r
.5 .76874 m
.5 .76763 L
s
0 0 1 r
.24185 .57064 m
.23825 .56084 L
s
1 0 0 r
.43916 .76175 m
.42936 .75815 L
s
.34159 .71707 m
.32937 .70657 L
s
0 0 1 r
.29343 .67063 m
.28293 .65841 L
s
.23275 .50795 m
.23135 .50614 L
s
1 0 0 r
.49386 .76865 m
.49205 .76725 L
s
.38344 .7421 m
.37118 .73462 L
s
0 0 1 r
.26538 .62882 m
.2579 .61656 L
s
.23342 .51772 m
.23168 .51412 L
s
1 0 0 r
.48588 .76832 m
.48228 .76658 L
s
0 0 1 r
.23859 .55588 m
.23553 .54742 L
s
1 0 0 r
.45258 .76447 m
.44412 .76141 L
s
.48674 .23291 m
.49859 .23133 L
s
0 0 1 r
.76867 .50141 m
.76709 .51326 L
s
1 0 0 r
.54357 .23583 m
.56027 .23818 L
s
0 0 1 r
.76182 .43973 m
.76417 .45643 L
s
1 0 0 r
.49213 .23267 m
.50533 .23139 L
s
0 0 1 r
.76861 .49467 m
.76733 .50787 L
s
1 0 0 r
.48294 .23328 m
.49333 .23142 L
s
0 0 1 r
.76858 .50667 m
.76672 .51706 L
s
.23452 .52912 m
.2324 .52379 L
s
1 0 0 r
.47621 .7676 m
.47088 .76548 L
s
0 0 1 r
.23619 .54193 m
.23363 .53498 L
s
1 0 0 r
.46502 .76637 m
.45807 .76381 L
s
.48088 .23368 m
.48972 .23158 L
s
0 0 1 r
.76842 .51028 m
.76632 .51912 L
s
1 0 0 r
.49893 .23267 m
.51338 .23172 L
s
0 0 1 r
.76828 .48662 m
.76733 .50107 L
s
1 0 0 r
.58494 .24623 m
.60186 .25146 L
s
0 0 1 r
.74854 .39814 m
.75377 .41506 L
s
1 0 0 r
.3161 .69577 m
.3049 .68304 L
s
0 0 1 r
.31696 .6951 m
.30423 .6839 L
s
1 0 0 r
.48069 .23408 m
.48788 .23175 L
s
0 0 1 r
.76825 .51212 m
.76592 .51931 L
s
1 0 0 r
.50697 .23304 m
.52256 .23247 L
s
0 0 1 r
.76753 .47744 m
.76696 .49303 L
s
1 0 0 r
.29319 .67114 m
.28346 .65648 L
s
0 0 1 r
.34352 .71654 m
.32886 .70681 L
s
1 0 0 r
.39868 .74858 m
.3871 .74167 L
s
0 0 1 r
.25833 .6129 m
.25142 .60132 L
s
1 0 0 r
.48247 .23445 m
.48793 .2319 L
s
0 0 1 r
.7681 .51207 m
.76555 .51753 L
s
1 0 0 r
.35593 .72642 m
.3439 .71634 L
s
0 0 1 r
.28366 .6561 m
.27358 .64407 L
s
1 0 0 r
.55502 .2388 m
.57247 .24164 L
s
0 0 1 r
.75836 .42753 m
.7612 .44498 L
s
1 0 0 r
.27361 .64389 m
.26573 .62768 L
s
0 0 1 r
.37232 .73427 m
.35611 .72639 L
s
1 0 0 r
.51606 .23393 m
.53269 .23378 L
s
0 0 1 r
.76622 .46731 m
.76607 .48394 L
s
1 0 0 r
.48628 .23481 m
.48995 .23202 L
s
0 0 1 r
.76798 .51005 m
.76519 .51372 L
s
1 0 0 r
.4141 .75391 m
.40339 .74756 L
s
0 0 1 r
.25244 .59661 m
.24609 .5859 L
s
1 0 0 r
.32937 .70657 m
.31811 .69409 L
s
0 0 1 r
.30591 .68189 m
.29343 .67063 L
s
1 0 0 r
.49213 .23519 m
.49398 .23215 L
s
0 0 1 r
.76785 .50602 m
.76481 .50787 L
s
1 0 0 r
.526 .23551 m
.54357 .23583 L
s
0 0 1 r
.76417 .45643 m
.76449 .474 L
s
1 0 0 r
.37118 .73462 m
.35952 .72501 L
s
0 0 1 r
.27499 .64048 m
.26538 .62882 L
s
.24765 .58027 m
.24185 .57064 L
s
1 0 0 r
.42936 .75815 m
.41973 .75235 L
s
0 0 1 r
.23567 .5 m
.23237 .5 L
s
1 0 0 r
.5 .23567 m
.5 .23237 L
s
0 0 1 r
.76763 .5 m
.76433 .5 L
s
1 0 0 r
.5 .76763 m
.5 .76433 L
s
.56684 .24287 m
.58494 .24623 L
s
0 0 1 r
.75377 .41506 m
.75713 .43316 L
s
1 0 0 r
.3049 .68304 m
.29491 .66844 L
s
0 0 1 r
.33156 .70509 m
.31696 .6951 L
s
1 0 0 r
.4785 .23615 m
.49213 .23267 L
s
0 0 1 r
.76733 .50787 m
.76385 .5215 L
s
1 0 0 r
.47454 .2367 m
.48674 .23291 L
s
0 0 1 r
.76709 .51326 m
.7633 .52546 L
s
.23636 .50979 m
.23275 .50795 L
s
1 0 0 r
.49205 .76725 m
.49021 .76364 L
s
.48398 .2358 m
.49893 .23267 L
s
0 0 1 r
.76733 .50107 m
.7642 .51602 L
s
.24387 .56423 m
.23859 .55588 L
s
1 0 0 r
.44412 .76141 m
.43577 .75613 L
s
.47227 .23735 m
.48294 .23328 L
s
0 0 1 r
.76672 .51706 m
.76265 .52773 L
s
.23738 .52134 m
.23342 .51772 L
s
1 0 0 r
.48228 .76658 m
.47866 .76262 L
s
.28346 .65648 m
.27518 .64013 L
s
0 0 1 r
.35987 .72482 m
.34352 .71654 L
s
.24099 .54885 m
.23619 .54193 L
s
1 0 0 r
.45807 .76381 m
.45115 .75901 L
s
0 0 1 r
.23888 .53445 m
.23452 .52912 L
s
1 0 0 r
.47088 .76548 m
.46555 .76112 L
s
.4908 .23577 m
.50697 .23304 L
s
0 0 1 r
.76696 .49303 m
.76423 .5092 L
s
1 0 0 r
.47183 .23802 m
.48088 .23368 L
s
0 0 1 r
.76632 .51912 m
.76198 .52817 L
s
1 0 0 r
.53661 .23797 m
.55502 .2388 L
s
0 0 1 r
.7612 .44498 m
.76203 .46339 L
s
1 0 0 r
.26573 .62768 m
.25951 .60997 L
s
0 0 1 r
.39003 .74049 m
.37232 .73427 L
s
1 0 0 r
.3439 .71634 m
.33272 .70419 L
s
0 0 1 r
.29581 .66728 m
.28366 .6561 L
s
1 0 0 r
.3871 .74167 m
.376 .73255 L
s
0 0 1 r
.26745 .624 m
.25833 .6129 L
s
1 0 0 r
.47335 .23866 m
.48069 .23408 L
s
0 0 1 r
.76592 .51931 m
.76134 .52665 L
s
1 0 0 r
.49877 .23622 m
.51606 .23393 L
s
0 0 1 r
.76607 .48394 m
.76378 .50123 L
s
1 0 0 r
.47691 .23927 m
.48247 .23445 L
s
0 0 1 r
.76555 .51753 m
.76073 .52309 L
s
1 0 0 r
.31811 .69409 m
.30796 .67965 L
s
0 0 1 r
.32035 .69204 m
.30591 .68189 L
s
1 0 0 r
.5077 .23732 m
.526 .23551 L
s
0 0 1 r
.76449 .474 m
.76268 .4923 L
s
1 0 0 r
.40339 .74756 m
.39307 .73895 L
s
0 0 1 r
.26105 .60693 m
.25244 .59661 L
s
1 0 0 r
.5477 .2415 m
.56684 .24287 L
s
0 0 1 r
.75713 .43316 m
.7585 .4523 L
s
1 0 0 r
.48255 .23987 m
.48628 .23481 L
s
0 0 1 r
.76519 .51372 m
.76013 .51745 L
s
1 0 0 r
.29491 .66844 m
.28629 .65205 L
s
0 0 1 r
.34795 .71371 m
.33156 .70509 L
s
1 0 0 r
.35952 .72501 m
.3486 .71324 L
s
0 0 1 r
.28676 .6514 m
.27499 .64048 L
s
1 0 0 r
.49027 .24052 m
.49213 .23519 L
s
0 0 1 r
.76481 .50787 m
.75948 .50973 L
s
1 0 0 r
.27518 .64013 m
.26849 .62217 L
s
0 0 1 r
.37783 .73151 m
.35987 .72482 L
s
1 0 0 r
.41973 .75235 m
.41038 .74425 L
s
0 0 1 r
.25575 .58962 m
.24765 .58027 L
s
1 0 0 r
.46457 .2419 m
.4785 .23615 L
s
0 0 1 r
.76385 .5215 m
.7581 .53543 L
s
1 0 0 r
.46866 .24118 m
.48398 .2358 L
s
0 0 1 r
.7642 .51602 m
.75882 .53134 L
s
1 0 0 r
.51738 .23925 m
.53661 .23797 L
s
0 0 1 r
.76203 .46339 m
.76075 .48262 L
s
1 0 0 r
.4621 .24278 m
.47454 .2367 L
s
0 0 1 r
.7633 .52546 m
.75722 .5379 L
s
1 0 0 r
.25951 .60997 m
.25507 .59087 L
s
0 0 1 r
.40913 .74493 m
.39003 .74049 L
s
1 0 0 r
.47419 .24075 m
.4908 .23577 L
s
0 0 1 r
.76423 .5092 m
.75925 .52581 L
s
.24129 .5 m
.23567 .5 L
s
1 0 0 r
.5 .24129 m
.5 .23567 L
s
0 0 1 r
.76433 .5 m
.75871 .5 L
s
1 0 0 r
.5 .76433 m
.5 .75871 L
s
.46141 .24373 m
.47227 .23735 L
s
0 0 1 r
.76265 .52773 m
.75627 .53859 L
s
.25147 .5724 m
.24387 .56423 L
s
1 0 0 r
.43577 .75613 m
.4276 .74853 L
s
.33272 .70419 m
.32255 .68997 L
s
0 0 1 r
.31003 .67745 m
.29581 .66728 L
s
.2423 .51162 m
.23636 .50979 L
s
1 0 0 r
.49021 .76364 m
.48838 .7577 L
s
.48097 .24074 m
.49877 .23622 L
s
0 0 1 r
.76378 .50123 m
.75926 .51903 L
s
.24812 .55564 m
.24099 .54885 L
s
1 0 0 r
.45115 .75901 m
.44436 .75188 L
s
.376 .73255 m
.36553 .7212 L
s
0 0 1 r
.2788 .63447 m
.26745 .624 L
s
1 0 0 r
.46265 .24468 m
.47183 .23802 L
s
0 0 1 r
.76198 .52817 m
.75532 .53735 L
s
.24368 .52494 m
.23738 .52134 L
s
1 0 0 r
.47866 .76262 m
.47506 .75632 L
s
0 0 1 r
.24557 .53971 m
.23888 .53445 L
s
1 0 0 r
.46555 .76112 m
.46029 .75443 L
s
.30796 .67965 m
.29908 .6633 L
s
0 0 1 r
.3367 .70092 m
.32035 .69204 L
s
1 0 0 r
.52764 .24221 m
.5477 .2415 L
s
0 0 1 r
.7585 .4523 m
.75779 .47236 L
s
1 0 0 r
.4888 .24134 m
.5077 .23732 L
s
0 0 1 r
.76268 .4923 m
.75866 .5112 L
s
1 0 0 r
.46593 .24559 m
.47335 .23866 L
s
0 0 1 r
.76134 .52665 m
.75441 .53407 L
s
1 0 0 r
.28629 .65205 m
.27917 .63394 L
s
0 0 1 r
.36606 .72083 m
.34795 .71371 L
s
1 0 0 r
.39307 .73895 m
.38324 .72805 L
s
0 0 1 r
.27195 .61676 m
.26105 .60693 L
s
1 0 0 r
.26849 .62217 m
.26352 .60272 L
s
0 0 1 r
.39728 .73648 m
.37783 .73151 L
s
1 0 0 r
.4713 .24646 m
.47691 .23927 L
s
0 0 1 r
.76073 .52309 m
.75354 .5287 L
s
1 0 0 r
.3486 .71324 m
.33857 .69932 L
s
0 0 1 r
.30068 .66143 m
.28676 .6514 L
s
1 0 0 r
.49749 .24271 m
.51738 .23925 L
s
0 0 1 r
.76075 .48262 m
.75729 .50251 L
s
1 0 0 r
.25507 .59087 m
.25253 .57052 L
s
0 0 1 r
.42948 .74747 m
.40913 .74493 L
s
1 0 0 r
.47881 .24733 m
.48255 .23987 L
s
0 0 1 r
.76013 .51745 m
.75267 .52119 L
s
1 0 0 r
.45309 .24889 m
.46866 .24118 L
s
0 0 1 r
.75882 .53134 m
.75111 .54691 L
s
1 0 0 r
.45727 .24802 m
.47419 .24075 L
s
0 0 1 r
.75925 .52581 m
.75198 .54273 L
s
1 0 0 r
.45044 .25 m
.46457 .2419 L
s
0 0 1 r
.7581 .53543 m
.75 .54956 L
s
1 0 0 r
.41038 .74425 m
.40143 .73382 L
s
0 0 1 r
.26618 .59857 m
.25575 .58962 L
s
1 0 0 r
.44952 .25123 m
.4621 .24278 L
s
0 0 1 r
.75722 .5379 m
.74877 .55048 L
s
1 0 0 r
.32255 .68997 m
.31354 .67375 L
s
0 0 1 r
.32625 .68646 m
.31003 .67745 L
s
1 0 0 r
.4628 .24754 m
.48097 .24074 L
s
0 0 1 r
.75926 .51903 m
.75246 .5372 L
s
1 0 0 r
.48841 .24825 m
.49027 .24052 L
s
0 0 1 r
.75948 .50973 m
.75175 .51159 L
s
1 0 0 r
.50684 .24507 m
.52764 .24221 L
s
0 0 1 r
.75779 .47236 m
.75493 .49316 L
s
1 0 0 r
.45047 .25249 m
.46141 .24373 L
s
0 0 1 r
.75627 .53859 m
.74751 .54953 L
s
1 0 0 r
.29908 .6633 m
.29162 .64512 L
s
0 0 1 r
.35488 .70838 m
.3367 .70092 L
s
1 0 0 r
.46948 .24761 m
.4888 .24134 L
s
0 0 1 r
.75866 .5112 m
.75239 .53052 L
s
1 0 0 r
.36553 .7212 m
.35582 .70762 L
s
0 0 1 r
.29238 .64418 m
.2788 .63447 L
s
1 0 0 r
.4276 .74853 m
.41972 .73855 L
s
0 0 1 r
.26145 .58028 m
.25147 .5724 L
s
.24932 .5 m
.24129 .5 L
s
1 0 0 r
.5 .24932 m
.5 .24129 L
s
0 0 1 r
.75871 .5 m
.75068 .5 L
s
1 0 0 r
.5 .75871 m
.5 .75068 L
s
.27917 .63394 m
.2737 .61422 L
s
0 0 1 r
.38578 .7263 m
.36606 .72083 L
s
1 0 0 r
.45343 .25374 m
.46265 .24468 L
s
0 0 1 r
.75532 .53735 m
.74626 .54657 L
s
.25066 .51343 m
.2423 .51162 L
s
1 0 0 r
.48838 .7577 m
.48657 .74934 L
s
0 0 1 r
.25765 .56225 m
.24812 .55564 L
s
1 0 0 r
.44436 .75188 m
.43775 .74235 L
s
.26352 .60272 m
.26039 .58191 L
s
0 0 1 r
.41809 .73961 m
.39728 .73648 L
s
.2524 .52848 m
.24368 .52494 L
s
1 0 0 r
.47506 .75632 m
.47152 .7476 L
s
0 0 1 r
.25468 .54486 m
.24557 .53971 L
s
1 0 0 r
.46029 .75443 m
.45514 .74532 L
s
.25253 .57052 m
.25199 .54909 L
s
0 0 1 r
.45091 .74801 m
.42948 .74747 L
s
1 0 0 r
.47711 .24841 m
.49749 .24271 L
s
0 0 1 r
.75729 .50251 m
.75159 .52289 L
s
1 0 0 r
.45849 .25493 m
.46593 .24559 L
s
0 0 1 r
.75441 .53407 m
.74507 .54151 L
s
1 0 0 r
.33857 .69932 m
.32957 .68328 L
s
0 0 1 r
.31672 .67043 m
.30068 .66143 L
s
1 0 0 r
.38324 .72805 m
.37405 .71485 L
s
0 0 1 r
.28515 .62595 m
.27195 .61676 L
s
1 0 0 r
.44021 .25763 m
.45727 .24802 L
s
0 0 1 r
.75198 .54273 m
.74237 .55979 L
s
1 0 0 r
.43742 .25895 m
.45309 .24889 L
s
0 0 1 r
.75111 .54691 m
.74105 .56258 L
s
1 0 0 r
.44444 .25665 m
.4628 .24754 L
s
0 0 1 r
.75246 .5372 m
.74335 .55556 L
s
1 0 0 r
.46571 .25608 m
.4713 .24646 L
s
0 0 1 r
.75354 .5287 m
.74392 .53429 L
s
1 0 0 r
.48549 .25014 m
.50684 .24507 L
s
0 0 1 r
.75493 .49316 m
.74986 .51451 L
s
1 0 0 r
.43626 .26046 m
.45044 .25 L
s
0 0 1 r
.75 .54956 m
.73954 .56374 L
s
1 0 0 r
.31354 .67375 m
.30583 .65558 L
s
0 0 1 r
.34442 .69417 m
.32625 .68646 L
s
1 0 0 r
.44992 .25617 m
.46948 .24761 L
s
0 0 1 r
.75239 .53052 m
.74383 .55008 L
s
1 0 0 r
.29162 .64512 m
.28571 .62522 L
s
0 0 1 r
.37478 .71429 m
.35488 .70838 L
s
1 0 0 r
.43692 .26207 m
.44952 .25123 L
s
0 0 1 r
.74877 .55048 m
.73793 .56308 L
s
1 0 0 r
.40143 .73382 m
.39297 .72102 L
s
0 0 1 r
.27898 .60703 m
.26618 .59857 L
s
1 0 0 r
.47509 .25723 m
.47881 .24733 L
s
0 0 1 r
.75267 .52119 m
.74277 .52491 L
s
1 0 0 r
.2737 .61422 m
.27 .59304 L
s
0 0 1 r
.40696 .73 m
.38578 .7263 L
s
1 0 0 r
.26039 .58191 m
.2592 .55991 L
s
0 0 1 r
.44009 .7408 m
.41809 .73961 L
s
.47325 .74647 m
.45091 .74801 L
s
1 0 0 r
.25199 .54909 m
.25353 .52675 L
s
.35582 .70762 m
.34701 .69184 L
s
0 0 1 r
.30816 .65299 m
.29238 .64418 L
s
1 0 0 r
.45644 .25636 m
.47711 .24841 L
s
0 0 1 r
.75159 .52289 m
.74364 .54356 L
s
1 0 0 r
.43954 .26368 m
.45047 .25249 L
s
0 0 1 r
.74751 .54953 m
.73632 .56046 L
s
1 0 0 r
.48656 .25845 m
.48841 .24825 L
s
0 0 1 r
.75175 .51159 m
.74155 .51344 L
s
1 0 0 r
.41972 .73855 m
.41222 .72617 L
s
0 0 1 r
.27383 .58778 m
.26145 .58028 L
s
.25983 .5 m
.24932 .5 L
s
1 0 0 r
.5 .25983 m
.5 .24932 L
s
0 0 1 r
.75068 .5 m
.74017 .5 L
s
1 0 0 r
.5 .75068 m
.5 .74017 L
s
.44425 .26524 m
.45343 .25374 L
s
0 0 1 r
.74626 .54657 m
.73476 .55575 L
s
1 0 0 r
.4638 .25743 m
.48549 .25014 L
s
0 0 1 r
.74986 .51451 m
.74257 .5362 L
s
1 0 0 r
.32957 .68328 m
.32175 .66521 L
s
0 0 1 r
.33479 .67825 m
.31672 .67043 L
s
1 0 0 r
.43775 .74235 m
.43142 .73038 L
s
0 0 1 r
.26962 .56858 m
.25765 .56225 L
s
.2615 .51521 m
.25066 .51343 L
s
1 0 0 r
.48657 .74934 m
.48479 .7385 L
s
.42319 .26957 m
.44021 .25763 L
s
0 0 1 r
.74237 .55979 m
.73043 .57681 L
s
1 0 0 r
.42609 .26806 m
.44444 .25665 L
s
0 0 1 r
.74335 .55556 m
.73194 .57391 L
s
.26625 .54983 m
.25468 .54486 L
s
1 0 0 r
.45514 .74532 m
.45017 .73375 L
s
0 0 1 r
.26359 .53192 m
.2524 .52848 L
s
1 0 0 r
.47152 .7476 m
.46808 .73641 L
s
.37405 .71485 m
.36563 .69937 L
s
0 0 1 r
.30063 .63437 m
.28515 .62595 L
s
1 0 0 r
.42182 .27136 m
.43742 .25895 L
s
0 0 1 r
.74105 .56258 m
.72864 .57818 L
s
1 0 0 r
.43033 .267 m
.44992 .25617 L
s
0 0 1 r
.74383 .55008 m
.733 .56967 L
s
1 0 0 r
.30583 .65558 m
.29957 .63559 L
s
0 0 1 r
.36441 .70043 m
.34442 .69417 L
s
1 0 0 r
.45112 .26674 m
.45849 .25493 L
s
0 0 1 r
.74507 .54151 m
.73326 .54888 L
s
1 0 0 r
.28571 .62522 m
.28148 .60376 L
s
0 0 1 r
.39624 .71852 m
.37478 .71429 L
s
1 0 0 r
.2592 .55991 m
.26004 .53693 L
s
0 0 1 r
.46307 .73996 m
.44009 .7408 L
s
1 0 0 r
.27 .59304 m
.26817 .57058 L
s
0 0 1 r
.42942 .73183 m
.40696 .73 L
s
.49628 .7428 m
.47325 .74647 L
s
1 0 0 r
.25353 .52675 m
.2572 .50372 L
s
.42219 .27331 m
.43626 .26046 L
s
0 0 1 r
.73954 .56374 m
.72669 .57781 L
s
1 0 0 r
.4357 .26656 m
.45644 .25636 L
s
0 0 1 r
.74364 .54356 m
.73344 .5643 L
s
1 0 0 r
.4602 .26819 m
.46571 .25608 L
s
0 0 1 r
.74392 .53429 m
.73181 .5398 L
s
1 0 0 r
.42445 .27531 m
.43692 .26207 L
s
0 0 1 r
.73793 .56308 m
.72469 .57555 L
s
1 0 0 r
.39297 .72102 m
.38515 .70588 L
s
0 0 1 r
.29412 .61485 m
.27898 .60703 L
s
1 0 0 r
.34701 .69184 m
.33924 .67393 L
s
0 0 1 r
.32607 .66076 m
.30816 .65299 L
s
1 0 0 r
.442 .26694 m
.4638 .25743 L
s
0 0 1 r
.74257 .5362 m
.73306 .558 L
s
1 0 0 r
.47144 .26963 m
.47509 .25723 L
s
0 0 1 r
.74277 .52491 m
.73037 .52856 L
s
1 0 0 r
.42876 .27729 m
.43954 .26368 L
s
0 0 1 r
.73632 .56046 m
.72271 .57124 L
s
1 0 0 r
.40795 .28173 m
.42609 .26806 L
s
0 0 1 r
.73194 .57391 m
.71827 .59205 L
s
1 0 0 r
.41093 .28006 m
.43033 .267 L
s
0 0 1 r
.733 .56967 m
.71994 .58907 L
s
1 0 0 r
.32175 .66521 m
.31525 .64521 L
s
0 0 1 r
.35479 .68475 m
.33479 .67825 L
s
1 0 0 r
.4064 .28379 m
.42319 .26957 L
s
0 0 1 r
.73043 .57681 m
.71621 .5936 L
s
.51976 .73698 m
.49628 .7428 L
s
1 0 0 r
.2572 .50372 m
.26302 .48024 L
s
0 0 1 r
.48681 .73705 m
.46307 .73996 L
s
1 0 0 r
.26004 .53693 m
.26295 .51319 L
s
.41222 .72617 m
.40522 .71138 L
s
0 0 1 r
.28862 .59478 m
.27383 .58778 L
s
1 0 0 r
.26817 .57058 m
.2683 .54705 L
s
0 0 1 r
.45295 .7317 m
.42942 .73183 L
s
1 0 0 r
.41512 .27896 m
.4357 .26656 L
s
0 0 1 r
.73344 .5643 m
.72104 .58488 L
s
1 0 0 r
.29957 .63559 m
.29488 .61394 L
s
0 0 1 r
.38606 .70512 m
.36441 .70043 L
s
1 0 0 r
.48476 .27115 m
.48656 .25845 L
s
0 0 1 r
.74155 .51344 m
.72885 .51524 L
s
1 0 0 r
.28148 .60376 m
.27903 .58092 L
s
0 0 1 r
.41908 .72097 m
.39624 .71852 L
s
1 0 0 r
.40648 .28609 m
.42182 .27136 L
s
0 0 1 r
.72864 .57818 m
.71391 .59352 L
s
1 0 0 r
.43523 .27919 m
.44425 .26524 L
s
0 0 1 r
.73476 .55575 m
.72081 .56477 L
s
1 0 0 r
.36563 .69937 m
.35811 .68168 L
s
0 0 1 r
.31832 .64189 m
.30063 .63437 L
s
1 0 0 r
.43142 .73038 m
.42545 .71596 L
s
0 0 1 r
.28404 .57455 m
.26962 .56858 L
s
.27285 .5 m
.25983 .5 L
s
1 0 0 r
.5 .27285 m
.5 .25983 L
s
0 0 1 r
.74017 .5 m
.72715 .5 L
s
1 0 0 r
.5 .74017 m
.5 .72715 L
s
.42033 .27862 m
.442 .26694 L
s
0 0 1 r
.73306 .558 m
.72138 .57967 L
s
1 0 0 r
.40838 .2885 m
.42219 .27331 L
s
0 0 1 r
.72669 .57781 m
.7115 .59162 L
s
1 0 0 r
.45017 .73375 m
.44544 .71969 L
s
0 0 1 r
.28031 .55456 m
.26625 .54983 L
s
.27485 .51692 m
.2615 .51521 L
s
1 0 0 r
.48479 .7385 m
.48308 .72515 L
s
0 0 1 r
.27729 .53522 m
.26359 .53192 L
s
1 0 0 r
.46808 .73641 m
.46478 .72271 L
s
.44391 .28102 m
.45112 .26674 L
s
0 0 1 r
.73326 .54888 m
.71898 .55609 L
s
.54343 .72902 m
.51976 .73698 L
s
1 0 0 r
.26302 .48024 m
.27098 .45657 L
s
0 0 1 r
.51106 .73204 m
.48681 .73705 L
s
1 0 0 r
.26295 .51319 m
.26796 .48894 L
s
.39193 .29527 m
.41093 .28006 L
s
0 0 1 r
.71994 .58907 m
.70473 .60807 L
s
1 0 0 r
.41226 .29092 m
.42445 .27531 L
s
0 0 1 r
.72469 .57555 m
.70908 .58774 L
s
1 0 0 r
.39023 .29757 m
.40795 .28173 L
s
0 0 1 r
.71827 .59205 m
.70243 .60977 L
s
1 0 0 r
.33924 .67393 m
.33266 .65399 L
s
0 0 1 r
.34601 .66734 m
.32607 .66076 L
s
1 0 0 r
.39494 .29348 m
.41512 .27896 L
s
0 0 1 r
.72104 .58488 m
.70652 .60506 L
s
1 0 0 r
.2683 .54705 m
.27043 .52267 L
s
0 0 1 r
.47733 .72957 m
.45295 .7317 L
s
1 0 0 r
.38515 .70588 m
.37808 .68844 L
s
0 0 1 r
.31156 .62192 m
.29412 .61485 L
s
1 0 0 r
.39004 .30021 m
.4064 .28379 L
s
0 0 1 r
.71621 .5936 m
.69979 .60996 L
s
1 0 0 r
.27903 .58092 m
.27846 .55692 L
s
0 0 1 r
.44308 .72154 m
.41908 .72097 L
s
1 0 0 r
.39905 .29238 m
.42033 .27862 L
s
0 0 1 r
.72138 .57967 m
.70762 .60095 L
s
1 0 0 r
.45483 .28278 m
.4602 .26819 L
s
0 0 1 r
.73181 .5398 m
.71722 .54517 L
s
1 0 0 r
.31525 .64521 m
.3102 .62344 L
s
0 0 1 r
.37656 .6898 m
.35479 .68475 L
s
1 0 0 r
.29488 .61394 m
.29187 .5908 L
s
0 0 1 r
.4092 .70813 m
.38606 .70512 L
s
1 0 0 r
.41826 .29329 m
.42876 .27729 L
s
0 0 1 r
.72271 .57124 m
.70671 .58174 L
s
1 0 0 r
.39157 .30305 m
.40648 .28609 L
s
0 0 1 r
.71391 .59352 m
.69695 .60843 L
s
.56703 .71897 m
.54343 .72902 L
s
1 0 0 r
.27098 .45657 m
.28103 .43297 L
s
0 0 1 r
.53555 .72493 m
.51106 .73204 L
s
1 0 0 r
.26796 .48894 m
.27507 .46445 L
s
.46791 .28453 m
.47144 .26963 L
s
0 0 1 r
.73037 .52856 m
.71547 .53209 L
s
1 0 0 r
.3754 .30999 m
.39494 .29348 L
s
0 0 1 r
.70652 .60506 m
.69001 .6246 L
s
1 0 0 r
.40522 .71138 m
.39881 .69424 L
s
0 0 1 r
.30576 .60119 m
.28862 .59478 L
s
1 0 0 r
.37358 .31251 m
.39193 .29527 L
s
0 0 1 r
.70473 .60807 m
.68749 .62642 L
s
1 0 0 r
.3784 .30811 m
.39905 .29238 L
s
0 0 1 r
.70762 .60095 m
.69189 .6216 L
s
.50227 .72539 m
.47733 .72957 L
s
1 0 0 r
.27043 .52267 m
.27461 .49773 L
s
.35811 .68168 m
.35161 .66186 L
s
0 0 1 r
.33814 .64839 m
.31832 .64189 L
s
1 0 0 r
.395 .30594 m
.40838 .2885 L
s
0 0 1 r
.7115 .59162 m
.69406 .605 L
s
1 0 0 r
.37315 .31548 m
.39023 .29757 L
s
0 0 1 r
.70243 .60977 m
.68452 .62685 L
s
1 0 0 r
.42648 .29556 m
.43523 .27919 L
s
0 0 1 r
.72081 .56477 m
.70444 .57352 L
s
1 0 0 r
.48303 .28636 m
.48476 .27115 L
s
0 0 1 r
.72885 .51524 m
.71364 .51697 L
s
.59029 .70691 m
.56703 .71897 L
s
1 0 0 r
.28103 .43297 m
.29309 .40971 L
s
.27846 .55692 m
.27982 .532 L
s
0 0 1 r
.468 .72018 m
.44308 .72154 L
s
1 0 0 r
.42545 .71596 m
.41993 .69913 L
s
0 0 1 r
.30087 .58007 m
.28404 .57455 L
s
1 0 0 r
.37432 .31873 m
.39004 .30021 L
s
0 0 1 r
.69979 .60996 m
.68127 .62568 L
s
.56 .71578 m
.53555 .72493 L
s
1 0 0 r
.27507 .46445 m
.28422 .44 L
s
.33266 .65399 m
.32738 .63218 L
s
0 0 1 r
.36782 .67262 m
.34601 .66734 L
s
1 0 0 r
.35674 .32834 m
.3754 .30999 L
s
0 0 1 r
.69001 .6246 m
.67166 .64326 L
s
1 0 0 r
.35864 .32564 m
.3784 .30811 L
s
0 0 1 r
.69189 .6216 m
.67436 .64136 L
s
.28837 .5 m
.27285 .5 L
s
1 0 0 r
.5 .28837 m
.5 .27285 L
s
0 0 1 r
.72715 .5 m
.71163 .5 L
s
1 0 0 r
.5 .72715 m
.5 .71163 L
s
.29187 .5908 m
.29063 .56641 L
s
0 0 1 r
.43359 .70937 m
.4092 .70813 L
s
1 0 0 r
.4005 .30882 m
.41226 .29092 L
s
0 0 1 r
.70908 .58774 m
.69118 .5995 L
s
1 0 0 r
.3102 .62344 m
.30671 .6001 L
s
0 0 1 r
.3999 .69329 m
.37656 .6898 L
s
1 0 0 r
.44544 .71969 m
.44103 .70319 L
s
0 0 1 r
.29681 .55897 m
.28031 .55456 L
s
1 0 0 r
.3561 .33161 m
.37358 .31251 L
s
0 0 1 r
.68749 .62642 m
.66839 .6439 L
s
1 0 0 r
.43696 .29772 m
.44391 .28102 L
s
0 0 1 r
.71898 .55609 m
.70228 .56304 L
s
.29069 .51854 m
.27485 .51692 L
s
1 0 0 r
.48308 .72515 m
.48146 .70931 L
s
0 0 1 r
.61291 .69295 m
.59029 .70691 L
s
1 0 0 r
.29309 .40971 m
.30705 .38709 L
s
.46478 .72271 m
.46167 .70654 L
s
0 0 1 r
.29346 .53833 m
.27729 .53522 L
s
.52751 .71919 m
.50227 .72539 L
s
1 0 0 r
.27461 .49773 m
.28081 .47249 L
s
.37729 .32212 m
.39157 .30305 L
s
0 0 1 r
.69695 .60843 m
.67788 .62271 L
s
1 0 0 r
.34002 .3448 m
.35864 .32564 L
s
0 0 1 r
.67436 .64136 m
.6552 .65998 L
s
1 0 0 r
.37808 .68844 m
.37187 .66881 L
s
0 0 1 r
.33119 .62813 m
.31156 .62192 L
s
.58413 .70467 m
.56 .71578 L
s
1 0 0 r
.28422 .44 m
.29533 .41587 L
s
.35692 .33527 m
.37315 .31548 L
s
0 0 1 r
.68452 .62685 m
.66473 .64308 L
s
1 0 0 r
.33919 .34834 m
.35674 .32834 L
s
0 0 1 r
.67166 .64326 m
.65166 .66081 L
s
.63464 .67725 m
.61291 .69295 L
s
1 0 0 r
.30705 .38709 m
.32275 .36536 L
s
.32275 .36536 m
.34002 .3448 L
s
0 0 1 r
.6552 .65998 m
.63464 .67725 L
s
1 0 0 r
.27982 .532 m
.28313 .50644 L
s
0 0 1 r
.49356 .71687 m
.468 .72018 L
s
1 0 0 r
.40818 .3116 m
.41826 .29329 L
s
0 0 1 r
.70671 .58174 m
.6884 .59182 L
s
1 0 0 r
.44967 .29981 m
.45483 .28278 L
s
0 0 1 r
.71722 .54517 m
.70019 .55033 L
s
1 0 0 r
.33971 .35239 m
.3561 .33161 L
s
0 0 1 r
.66839 .6439 m
.64761 .66029 L
s
.60763 .6917 m
.58413 .70467 L
s
1 0 0 r
.29533 .41587 m
.3083 .39237 L
s
.32298 .36977 m
.33919 .34834 L
s
0 0 1 r
.65166 .66081 m
.63023 .67702 L
s
.55274 .71099 m
.52751 .71919 L
s
1 0 0 r
.28081 .47249 m
.28901 .44726 L
s
.38224 .32553 m
.395 .30594 L
s
0 0 1 r
.69406 .605 m
.67447 .61776 L
s
1 0 0 r
.35944 .33916 m
.37432 .31873 L
s
0 0 1 r
.68127 .62568 m
.66084 .64056 L
s
.63023 .67702 m
.60763 .6917 L
s
1 0 0 r
.3083 .39237 m
.32298 .36977 L
s
.29063 .56641 m
.29123 .54102 L
s
0 0 1 r
.45898 .70877 m
.43359 .70937 L
s
1 0 0 r
.35161 .66186 m
.34627 .64009 L
s
0 0 1 r
.35991 .65373 m
.33814 .64839 L
s
1 0 0 r
.39881 .69424 m
.39311 .67483 L
s
0 0 1 r
.32517 .60689 m
.30576 .60119 L
s
1 0 0 r
.34177 .35677 m
.35692 .33527 L
s
0 0 1 r
.66473 .64308 m
.64323 .65823 L
s
1 0 0 r
.32463 .37461 m
.33971 .35239 L
s
0 0 1 r
.64761 .66029 m
.62539 .67537 L
s
1 0 0 r
.46454 .30188 m
.46791 .28453 L
s
0 0 1 r
.71547 .53209 m
.69812 .53546 L
s
1 0 0 r
.30671 .6001 m
.30487 .5754 L
s
0 0 1 r
.4246 .69513 m
.3999 .69329 L
s
.57767 .70088 m
.55274 .71099 L
s
1 0 0 r
.28901 .44726 m
.29912 .42233 L
s
.32738 .63218 m
.32352 .6087 L
s
0 0 1 r
.3913 .67648 m
.36782 .67262 L
s
1 0 0 r
.41812 .31425 m
.42648 .29556 L
s
0 0 1 r
.70444 .57352 m
.68575 .58188 L
s
.51947 .71159 m
.49356 .71687 L
s
1 0 0 r
.28313 .50644 m
.28841 .48053 L
s
.36383 .34314 m
.37729 .32212 L
s
0 0 1 r
.67788 .62271 m
.65686 .63617 L
s
1 0 0 r
.31104 .39802 m
.32463 .37461 L
s
0 0 1 r
.62539 .67537 m
.60198 .68896 L
s
1 0 0 r
.38933 .32888 m
.4005 .30882 L
s
0 0 1 r
.69118 .5995 m
.67112 .61067 L
s
.60198 .68896 m
.57767 .70088 L
s
1 0 0 r
.29912 .42233 m
.31104 .39802 L
s
.41993 .69913 m
.41496 .67997 L
s
0 0 1 r
.32003 .58504 m
.30087 .58007 L
s
1 0 0 r
.48139 .30403 m
.48303 .28636 L
s
0 0 1 r
.71364 .51697 m
.69597 .51861 L
s
1 0 0 r
.3456 .36131 m
.35944 .33916 L
s
0 0 1 r
.66084 .64056 m
.63869 .6544 L
s
1 0 0 r
.3279 .37972 m
.34177 .35677 L
s
0 0 1 r
.64323 .65823 m
.62028 .6721 L
s
1 0 0 r
.29123 .54102 m
.29369 .51492 L
s
0 0 1 r
.48508 .70631 m
.45898 .70877 L
s
.54541 .70439 m
.51947 .71159 L
s
1 0 0 r
.28841 .48053 m
.29561 .45459 L
s
.37187 .66881 m
.36664 .64712 L
s
0 0 1 r
.35288 .63336 m
.33119 .62813 L
s
1 0 0 r
.43034 .31678 m
.43696 .29772 L
s
0 0 1 r
.70228 .56304 m
.68322 .56966 L
s
.30635 .5 m
.28837 .5 L
s
.71163 .5 m
.69365 .5 L
s
1 0 0 r
.5 .30635 m
.5 .28837 L
s
.5 .71163 m
.5 .69365 L
s
.44103 .70319 m
.437 .68431 L
s
0 0 1 r
.31569 .563 m
.29681 .55897 L
s
1 0 0 r
.37027 .34709 m
.38224 .32553 L
s
0 0 1 r
.67447 .61776 m
.65291 .62973 L
s
1 0 0 r
.48146 .70931 m
.47994 .69102 L
s
0 0 1 r
.30898 .52006 m
.29069 .51854 L
s
1 0 0 r
.46167 .70654 m
.45881 .68796 L
s
0 0 1 r
.31204 .54119 m
.29346 .53833 L
s
1 0 0 r
.31547 .40388 m
.3279 .37972 L
s
0 0 1 r
.62028 .6721 m
.59612 .68453 L
s
1 0 0 r
.39865 .33209 m
.40818 .3116 L
s
0 0 1 r
.6884 .59182 m
.66791 .60135 L
s
1 0 0 r
.29561 .45459 m
.30467 .42893 L
s
0 0 1 r
.57107 .69533 m
.54541 .70439 L
s
1 0 0 r
.30487 .5754 m
.30475 .54962 L
s
0 0 1 r
.45038 .69525 m
.4246 .69513 L
s
.59612 .68453 m
.57107 .69533 L
s
1 0 0 r
.30467 .42893 m
.31547 .40388 L
s
.34627 .64009 m
.34218 .61654 L
s
0 0 1 r
.38346 .65782 m
.35991 .65373 L
s
1 0 0 r
.35138 .3659 m
.36383 .34314 L
s
0 0 1 r
.65686 .63617 m
.6341 .64862 L
s
1 0 0 r
.333 .38495 m
.3456 .36131 L
s
0 0 1 r
.63869 .6544 m
.61505 .667 L
s
1 0 0 r
.32352 .6087 m
.32117 .58377 L
s
0 0 1 r
.41623 .67883 m
.3913 .67648 L
s
1 0 0 r
.29369 .51492 m
.29803 .48842 L
s
0 0 1 r
.51158 .70197 m
.48508 .70631 L
s
1 0 0 r
.4448 .31921 m
.44967 .29981 L
s
0 0 1 r
.70019 .55033 m
.68079 .5552 L
s
1 0 0 r
.39311 .67483 m
.38821 .65329 L
s
0 0 1 r
.34671 .61179 m
.32517 .60689 L
s
1 0 0 r
.3789 .35093 m
.38933 .32888 L
s
0 0 1 r
.67112 .61067 m
.64907 .6211 L
s
1 0 0 r
.41027 .33515 m
.41812 .31425 L
s
0 0 1 r
.68575 .58188 m
.66485 .58973 L
s
1 0 0 r
.3218 .40978 m
.333 .38495 L
s
0 0 1 r
.61505 .667 m
.59022 .6782 L
s
.53815 .6958 m
.51158 .70197 L
s
1 0 0 r
.29803 .48842 m
.3042 .46185 L
s
.30475 .54962 m
.30638 .52306 L
s
0 0 1 r
.47694 .69362 m
.45038 .69525 L
s
1 0 0 r
.46138 .3216 m
.46454 .30188 L
s
0 0 1 r
.69812 .53546 m
.6784 .53862 L
s
1 0 0 r
.35927 .3704 m
.37027 .34709 L
s
0 0 1 r
.65291 .62973 m
.6296 .64073 L
s
1 0 0 r
.34011 .39015 m
.35138 .3659 L
s
0 0 1 r
.6341 .64862 m
.60985 .65989 L
s
1 0 0 r
.31216 .43552 m
.3218 .40978 L
s
0 0 1 r
.59022 .6782 m
.56448 .68784 L
s
.56448 .68784 m
.53815 .6958 L
s
1 0 0 r
.3042 .46185 m
.31216 .43552 L
s
.41496 .67997 m
.41061 .65862 L
s
0 0 1 r
.34138 .58939 m
.32003 .58504 L
s
1 0 0 r
.36664 .64712 m
.3625 .62358 L
s
0 0 1 r
.37642 .6375 m
.35288 .63336 L
s
1 0 0 r
.32117 .58377 m
.3204 .55768 L
s
0 0 1 r
.44232 .6796 m
.41623 .67883 L
s
.69597 .51861 m
.67595 .52013 L
s
1 0 0 r
.47987 .32405 m
.48139 .30403 L
s
.34218 .61654 m
.33945 .59146 L
s
0 0 1 r
.40854 .66055 m
.38346 .65782 L
s
1 0 0 r
.38982 .35459 m
.39865 .33209 L
s
0 0 1 r
.66791 .60135 m
.64541 .61018 L
s
1 0 0 r
.42418 .33804 m
.43034 .31678 L
s
0 0 1 r
.68322 .56966 m
.66196 .57582 L
s
.50396 .69022 m
.47694 .69362 L
s
1 0 0 r
.30638 .52306 m
.30978 .49604 L
s
.437 .68431 m
.43343 .66318 L
s
0 0 1 r
.33682 .56657 m
.31569 .563 L
s
1 0 0 r
.33019 .41561 m
.34011 .39015 L
s
0 0 1 r
.60985 .65989 m
.58439 .66981 L
s
.69365 .5 m
.67333 .5 L
s
1 0 0 r
.5 .69365 m
.5 .67333 L
s
0 0 1 r
.32667 .5 m
.30635 .5 L
s
1 0 0 r
.5 .32667 m
.5 .30635 L
s
.45881 .68796 m
.45623 .66708 L
s
0 0 1 r
.33292 .54377 m
.31204 .54119 L
s
1 0 0 r
.47994 .69102 m
.47857 .67042 L
s
0 0 1 r
.32958 .52143 m
.30898 .52006 L
s
1 0 0 r
.36939 .37475 m
.3789 .35093 L
s
0 0 1 r
.64907 .6211 m
.62525 .63061 L
s
1 0 0 r
.34939 .39522 m
.35927 .3704 L
s
0 0 1 r
.6296 .64073 m
.60478 .65061 L
s
.53111 .68508 m
.50396 .69022 L
s
1 0 0 r
.30978 .49604 m
.31492 .46889 L
s
.38821 .65329 m
.38421 .62981 L
s
0 0 1 r
.37019 .61579 m
.34671 .61179 L
s
.58439 .66981 m
.55803 .67825 L
s
1 0 0 r
.32175 .44197 m
.33019 .41561 L
s
0 0 1 r
.68079 .5552 m
.65918 .5597 L
s
1 0 0 r
.4403 .34082 m
.4448 .31921 L
s
.3204 .55768 m
.32125 .53074 L
s
0 0 1 r
.46926 .67875 m
.44232 .6796 L
s
1 0 0 r
.40305 .35806 m
.41027 .33515 L
s
0 0 1 r
.66485 .58973 m
.64194 .59695 L
s
.55803 .67825 m
.53111 .68508 L
s
1 0 0 r
.31492 .46889 m
.32175 .44197 L
s
.3625 .62358 m
.35954 .59842 L
s
0 0 1 r
.40158 .64046 m
.37642 .6375 L
s
1 0 0 r
.33945 .59146 m
.33813 .56514 L
s
0 0 1 r
.43486 .66187 m
.40854 .66055 L
s
.60478 .65061 m
.57875 .65922 L
s
1 0 0 r
.34078 .42125 m
.34939 .39522 L
s
0 0 1 r
.6784 .53862 m
.65646 .54152 L
s
1 0 0 r
.45848 .34354 m
.46138 .3216 L
s
.38182 .37888 m
.38982 .35459 L
s
0 0 1 r
.64541 .61018 m
.62112 .61818 L
s
1 0 0 r
.41061 .65862 m
.40697 .63526 L
s
0 0 1 r
.36474 .59303 m
.34138 .58939 L
s
1 0 0 r
.32125 .53074 m
.32375 .50326 L
s
0 0 1 r
.49674 .67625 m
.46926 .67875 L
s
1 0 0 r
.36093 .40008 m
.36939 .37475 L
s
0 0 1 r
.62525 .63061 m
.59992 .63907 L
s
1 0 0 r
.41856 .36134 m
.42418 .33804 L
s
0 0 1 r
.66196 .57582 m
.63866 .58144 L
s
1 0 0 r
.33357 .44816 m
.34078 .42125 L
s
0 0 1 r
.57875 .65922 m
.55184 .66643 L
s
.67595 .52013 m
.65371 .52151 L
s
1 0 0 r
.47849 .34629 m
.47987 .32405 L
s
0 0 1 r
.52438 .67213 m
.49674 .67625 L
s
1 0 0 r
.32375 .50326 m
.32787 .47562 L
s
.43343 .66318 m
.43038 .63999 L
s
0 0 1 r
.36001 .56962 m
.33682 .56657 L
s
1 0 0 r
.33813 .56514 m
.33829 .53788 L
s
0 0 1 r
.46212 .66171 m
.43486 .66187 L
s
.55184 .66643 m
.52438 .67213 L
s
1 0 0 r
.32787 .47562 m
.33357 .44816 L
s
.38421 .62981 m
.3812 .60464 L
s
0 0 1 r
.39536 .6188 m
.37019 .61579 L
s
.67333 .5 m
.65081 .5 L
s
1 0 0 r
.5 .67333 m
.5 .65081 L
s
0 0 1 r
.34919 .5 m
.32667 .5 L
s
1 0 0 r
.5 .34919 m
.5 .32667 L
s
.45623 .66708 m
.45399 .64408 L
s
0 0 1 r
.35592 .54601 m
.33292 .54377 L
s
1 0 0 r
.39658 .38276 m
.40305 .35806 L
s
0 0 1 r
.64194 .59695 m
.61724 .60342 L
s
1 0 0 r
.47857 .67042 m
.47735 .64765 L
s
0 0 1 r
.35235 .52265 m
.32958 .52143 L
s
1 0 0 r
.35954 .59842 m
.35782 .57193 L
s
0 0 1 r
.42807 .64218 m
.40158 .64046 L
s
1 0 0 r
.35365 .42662 m
.36093 .40008 L
s
0 0 1 r
.59992 .63907 m
.57338 .64635 L
s
.65918 .5597 m
.63554 .56376 L
s
1 0 0 r
.43624 .36446 m
.4403 .34082 L
s
.37479 .40467 m
.38182 .37888 L
s
0 0 1 r
.62112 .61818 m
.59533 .62521 L
s
.48997 .66005 m
.46212 .66171 L
s
1 0 0 r
.33829 .53788 m
.33995 .51003 L
s
.40697 .63526 m
.40412 .61013 L
s
0 0 1 r
.38987 .59588 m
.36474 .59303 L
s
.57338 .64635 m
.54597 .65232 L
s
1 0 0 r
.34768 .45403 m
.35365 .42662 L
s
0 0 1 r
.65646 .54152 m
.63251 .5441 L
s
1 0 0 r
.4559 .36749 m
.45848 .34354 L
s
0 0 1 r
.63866 .58144 m
.61358 .58642 L
s
1 0 0 r
.41358 .38642 m
.41856 .36134 L
s
0 0 1 r
.51804 .65691 m
.48997 .66005 L
s
1 0 0 r
.33995 .51003 m
.34309 .48196 L
s
.35782 .57193 m
.3574 .54444 L
s
0 0 1 r
.45556 .6426 m
.42807 .64218 L
s
.54597 .65232 m
.51804 .65691 L
s
1 0 0 r
.34309 .48196 m
.34768 .45403 L
s
.3812 .60464 m
.37925 .57805 L
s
0 0 1 r
.42195 .62075 m
.39536 .6188 L
s
.59533 .62521 m
.56834 .63116 L
s
1 0 0 r
.36884 .43166 m
.37479 .40467 L
s
.43038 .63999 m
.42791 .61495 L
s
0 0 1 r
.38505 .57209 m
.36001 .56962 L
s
.61724 .60342 m
.59103 .60904 L
s
1 0 0 r
.39096 .40897 m
.39658 .38276 L
s
0 0 1 r
.65371 .52151 m
.62947 .52273 L
s
1 0 0 r
.47727 .37053 m
.47849 .34629 L
s
.45399 .64408 m
.45213 .61919 L
s
0 0 1 r
.38081 .54787 m
.35592 .54601 L
s
.65081 .5 m
.62632 .5 L
s
1 0 0 r
.5 .65081 m
.5 .62632 L
s
0 0 1 r
.37368 .5 m
.34919 .5 L
s
1 0 0 r
.5 .37368 m
.5 .34919 L
s
0 0 1 r
.63554 .56376 m
.61012 .56731 L
s
1 0 0 r
.43269 .38988 m
.43624 .36446 L
s
.47735 .64765 m
.47632 .62294 L
s
0 0 1 r
.37706 .52368 m
.35235 .52265 L
s
1 0 0 r
.3574 .54444 m
.3583 .51628 L
s
0 0 1 r
.48372 .6417 m
.45556 .6426 L
s
1 0 0 r
.36406 .45951 m
.36884 .43166 L
s
0 0 1 r
.56834 .63116 m
.54049 .63594 L
s
1 0 0 r
.40412 .61013 m
.40212 .58352 L
s
0 0 1 r
.41648 .59788 m
.38987 .59588 L
s
1 0 0 r
.37925 .57805 m
.37839 .55039 L
s
0 0 1 r
.44961 .62161 m
.42195 .62075 L
s
.61358 .58642 m
.58701 .59068 L
s
1 0 0 r
.40932 .41299 m
.41358 .38642 L
s
0 0 1 r
.51215 .63947 m
.48372 .6417 L
s
1 0 0 r
.3583 .51628 m
.36053 .48785 L
s
0 0 1 r
.59103 .60904 m
.56363 .61371 L
s
1 0 0 r
.38629 .43637 m
.39096 .40897 L
s
0 0 1 r
.54049 .63594 m
.51215 .63947 L
s
1 0 0 r
.36053 .48785 m
.36406 .45951 L
s
0 0 1 r
.63251 .5441 m
.60679 .54632 L
s
1 0 0 r
.45368 .39321 m
.4559 .36749 L
s
.42791 .61495 m
.42607 .58837 L
s
0 0 1 r
.41163 .57393 m
.38505 .57209 L
s
1 0 0 r
.37839 .55039 m
.37867 .522 L
s
0 0 1 r
.478 .62133 m
.44961 .62161 L
s
.62947 .52273 m
.6035 .52376 L
s
1 0 0 r
.47624 .3965 m
.47727 .37053 L
s
0 0 1 r
.56363 .61371 m
.53541 .61735 L
s
1 0 0 r
.38265 .46459 m
.38629 .43637 L
s
0 0 1 r
.61012 .56731 m
.58323 .57029 L
s
1 0 0 r
.42971 .41677 m
.43269 .38988 L
s
.40212 .58352 m
.40101 .55575 L
s
0 0 1 r
.44425 .59899 m
.41648 .59788 L
s
1 0 0 r
.45213 .61919 m
.45068 .59268 L
s
0 0 1 r
.40732 .54932 m
.38081 .54787 L
s
.62632 .5 m
.60013 .5 L
s
1 0 0 r
.5 .62632 m
.5 .60013 L
s
0 0 1 r
.39987 .5 m
.37368 .5 L
s
1 0 0 r
.5 .39987 m
.5 .37368 L
s
0 0 1 r
.58701 .59068 m
.55926 .59413 L
s
1 0 0 r
.40587 .44074 m
.40932 .41299 L
s
.47632 .62294 m
.47549 .59657 L
s
0 0 1 r
.40343 .52451 m
.37706 .52368 L
s
.50673 .6199 m
.478 .62133 L
s
1 0 0 r
.37867 .522 m
.3801 .49327 L
s
0 0 1 r
.53541 .61735 m
.50673 .6199 L
s
1 0 0 r
.3801 .49327 m
.38265 .46459 L
s
0 0 1 r
.60679 .54632 m
.57962 .54814 L
s
1 0 0 r
.45186 .42038 m
.45368 .39321 L
s
.42607 .58837 m
.42491 .56056 L
s
0 0 1 r
.43944 .57509 m
.41163 .57393 L
s
1 0 0 r
.40101 .55575 m
.40083 .52719 L
s
0 0 1 r
.47281 .59917 m
.44425 .59899 L
s
.55926 .59413 m
.53072 .59673 L
s
1 0 0 r
.40327 .46928 m
.40587 .44074 L
s
0 0 1 r
.58323 .57029 m
.55519 .57264 L
s
1 0 0 r
.42736 .44481 m
.42971 .41677 L
s
0 0 1 r
.6035 .52376 m
.5761 .52457 L
s
1 0 0 r
.47543 .4239 m
.47624 .3965 L
s
.45068 .59268 m
.44969 .5649 L
s
0 0 1 r
.4351 .55031 m
.40732 .54932 L
s
.50177 .59841 m
.47281 .59917 L
s
1 0 0 r
.40083 .52719 m
.40159 .49823 L
s
0 0 1 r
.53072 .59673 m
.50177 .59841 L
s
1 0 0 r
.40159 .49823 m
.40327 .46928 L
s
0 0 1 r
.60013 .5 m
.57255 .5 L
s
1 0 0 r
.5 .60013 m
.5 .57255 L
s
0 0 1 r
.42745 .5 m
.39987 .5 L
s
1 0 0 r
.5 .42745 m
.5 .39987 L
s
.47549 .59657 m
.47488 .56886 L
s
0 0 1 r
.43114 .52512 m
.40343 .52451 L
s
.4681 .57555 m
.43944 .57509 L
s
1 0 0 r
.42491 .56056 m
.42445 .5319 L
s
0 0 1 r
.57962 .54814 m
.55134 .54952 L
s
1 0 0 r
.45048 .44866 m
.45186 .42038 L
s
0 0 1 r
.55519 .57264 m
.52639 .57431 L
s
1 0 0 r
.42569 .47361 m
.42736 .44481 L
s
.44969 .5649 m
.44916 .5362 L
s
0 0 1 r
.4638 .55084 m
.4351 .55031 L
s
1 0 0 r
.42445 .5319 m
.42471 .50278 L
s
0 0 1 r
.49722 .57529 m
.4681 .57555 L
s
.5761 .52457 m
.54763 .52517 L
s
1 0 0 r
.47483 .45237 m
.47543 .4239 L
s
0 0 1 r
.52639 .57431 m
.49722 .57529 L
s
1 0 0 r
.42471 .50278 m
.42569 .47361 L
s
0 0 1 r
.45982 .5255 m
.43114 .52512 L
s
1 0 0 r
.47488 .56886 m
.4745 .54018 L
s
0 0 1 r
.45605 .5 m
.42745 .5 L
s
.57255 .5 m
.54395 .5 L
s
1 0 0 r
.5 .45605 m
.5 .42745 L
s
.5 .57255 m
.5 .54395 L
s
0 0 1 r
.55134 .54952 m
.52234 .55044 L
s
1 0 0 r
.44956 .47766 m
.45048 .44866 L
s
0 0 1 r
.49302 .55089 m
.4638 .55084 L
s
1 0 0 r
.44916 .5362 m
.44911 .50698 L
s
0 0 1 r
.52234 .55044 m
.49302 .55089 L
s
1 0 0 r
.44911 .50698 m
.44956 .47766 L
s
0 0 1 r
.54763 .52517 m
.51849 .52552 L
s
1 0 0 r
.47448 .48151 m
.47483 .45237 L
s
.4745 .54018 m
.47437 .51092 L
s
0 0 1 r
.48908 .52563 m
.45982 .5255 L
s
.54395 .5 m
.51472 .5 L
s
1 0 0 r
.5 .54395 m
.5 .51472 L
s
0 0 1 r
.48528 .5 m
.45605 .5 L
s
1 0 0 r
.5 .48528 m
.5 .45605 L
s
0 0 1 r
.51849 .52552 m
.48908 .52563 L
s
1 0 0 r
.47437 .51092 m
.47448 .48151 L
s
0 0 1 r
.51472 .5 m
.48528 .5 L
s
1 0 0 r
.5 .51472 m
.5 .48528 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002:Ool?O027Ool008QooaMl
085oo`00QWoo27`000=oog`0O0004W`0OGoo0024OolRO01jOol008=oo`Yl009oo`Il0007Ooml07oo
Ooml07ooO0000Woo0g`00Woo1g`0MWoo0021OolAO00027ooO01oog`0Ooml07ooO002Ool00g`0Oomo
o`03O003Ool7O01dOol0081oo`Yl009oo`03O01oogoo00=l0004Ooml07ooO002Ool00g`0Ooml0002
Ool017`0Oomoogoo0g`00Woo00=l07ooO0001G`0LWoo001nOol9O0001GooO01oogooO0000goo0W`0
00Qoog`0Ooml07ooO01oog`00Woo00Al07ooOoml00=oo`06O01oog`0O01oog`00Woo00=l07ooO000
0g`0L7oo001mOol7O0001GooO01oogooO0000Woo00Al07ooOomoo`9l0006Ooml07ooO01oog`00Woo
00Al07ooOoml009oo`05O01oogooOoml0002Ool00g`0Ooml0002Ool01G`0Oomoog`0Ool00W`0KWoo
001kOol8O0001GooO01oogooO0000goo00el07ooOomoog`0Ooml07ooO01oog`0Ooml0002Ool017`0
Oomoog`00Woo00Ml07ooOomoog`0Ooml0002Ool2O0001GooO01oogooO0000Woo0W`0K7oo001jOol6
O0001GooO01oogooO0000Woo00El07ooOomoog`000=oo`07O01oog`0Ooml07ooO0000Woo00=l07oo
O0000Woo00El07ooOomoog`000=oo`03O01oog`000=oo`06O01oog`0O01oog`00Woo0g`0JWoo001i
Ool6O0000gooO01oo`02Ool017`0Oomoog`00goo00]l07ooOomoog`0Ooml07ooO01oog`0009oo`04
O01oogooO002Ool01G`0OomoogooO0000Woo00Al07ooOoml00=oo`03O01oogoo00=l00=oo`9l06Uo
o`00Mgoo1g`00Woo00Al07ooOoml00=oo`05O01oogooOoml0003Ool01G`0Ooml07ooO0000Woo00Il
07ooOoml07ooO003Ool017`0Oomoog`00goo00Al07ooOoml009oo`06O01oogooOoml07oo0W`00Woo
0g`0Igoo001fOol4O0001WooO01oog`0Ooml00=oo`04O01oogooO004Ool02G`0OomoogooO01oog`0
Ooml0002Ool017`0Oomoog`00Woo00Al07ooOoml00=oo`05O01oogooOoml0002Ool017`0Oomoog`0
0goo00Al07ooOoml009oo`03O01oog`006Ioo`00MGoo17`000Aoog`0Ooml009oo`04O01oogooO003
Ool01G`0OomoogooO00017oo00El07ooO01oog`0009oo`04O01oogooO002Ool01G`0OomoogooO000
0Woo00El07ooOomoog`000=oo`04O01oogooO002Ool01G`0OomoogooO0000Woo00=l07ooO000IGoo
001dOol4O002Ool2O003Ool017`0Oomoog`00goo00El07ooOomoog`000Aoo`03O01oog`0009oo`03
O01oog`0009oo`05O01oogooOoml0002Ool01G`0OomoogooO0000goo00Al07ooOoml00=oo`04O01o
ogooO002Ool01g`0OomoogooO01oog`006Aoo`00LWoo17`000Ioog`0Ooml07ooO002Ool01G`0Oomo
ogooO0000goo00El07ooOomoog`000Aoo`03O01oog`0009oo`04O01oogooO002Ool017`0Oomoog`0
0goo00El07ooOomoog`0009oo`05O01oogooOoml0003Ool017`0Oomoog`00Woo00Al07ooOoml009o
o`03O01oogoo065oo`00LGoo17`000Aoog`0Oomoo`9l00=oo`05O01oogooOoml0003Ool01G`0Oomo
ogooO00017oo00=l07ooO0000Woo00Al07ooOoml009oo`05O01oogooOoml0002Ool01G`0Oomoogoo
O0000goo00Al07ooOoml00Aoo`04O01oogooO002Ool017`0Oomoog`00Woo00=l07ooOol0H7oo001`
Ool4O0001gooO01oogooO01oog`0009oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool00g`0Oomo
o`02Ool01W`0Oomoog`0Ooml009oo`04O01oogooO003Ool01G`0OomoogooO0000goo00Al07ooOoml
00=oo`05O01oogooOoml0003Ool00g`0Ooml0003Ool00g`0Ooml001ROol006moo`=l0003Ooml07`0
009oo`04O01oogooO002Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00=l07ooOol00Woo00Al
07ooOoml009oo`06O01oogooO01oog`00goo00El07ooOomoog`000=oo`05O01oogooOoml0002Ool0
0g`0Oomoo`02Ool017`0Oomoog`00Woo00Al07ooOoml009oo`03O01oogoo05moo`00KWoo0g`000Ao
og`0Ooml009oo`03O01oog`000=oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool00g`0Oomoo`02
Ool017`0Oomoog`00Woo00Al07ooOoml009oo`05O01oogooOoml0002Ool01G`0OomoogooO0000goo
00El07ooOomoog`000=oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo00=l07ooOol0GWoo001/
Ool4O00017ooO01oog`00Woo00Al07ooOoml009oo`03O01oogoo009oo`05O01oogooOoml0004Ool0
0g`0Oomoo`02Ool017`0Oomoog`00Woo00Al07ooOoml009oo`05O01oogooOoml0002Ool00`0OO000
7`0201l00g`001l07`0901l017`001moog`00Woo00Al07ooOoml009oo`03O01oogoo05ioo`00Jgoo
0g`000Eoog`0O01oog`000=oo`04O01oogooO002Ool01G`0OomoogooO00017oo00=l07ooOol00Woo
00=l07ooOol00Woo00Al07ooOoml009oo`04O01oogooO002Ool00g`0Ool07`0401l00gooO01oo`02
Ool01G`0OomoogooO0000goo00Il07ooOomoog`0Ool501l017`0Oomoog`00Woo00=l07ooOol0GGoo
001ZOol5O0000gooO01l0003Ool017`0Oomoog`00Woo00=l07ooOol00Woo00El07ooOomoog`000Eo
o`03O01oogoo009oo`04O01oogooO002Ool01G`0Oomoo`0OO0000`0O0Woo00El07ooOomoog`000=o
o`03O01oogoo009oo`04O01oogooO003Ool01G`0OomoogooO0000Woo00Al000O01ml009oo`03O01o
ogoo05eoo`00JGoo1G`000Aoog`0Ooml009oo`05O01oogooOoml0002Ool01G`0OomoogooO00017oo
00=l07ooOol00Woo00=l07ooOol00goo00Ml07ooOoml07oo01ml000201l01GooO01oogooO0000goo
00El07ooOomoog`000/07`05O0007`0OOoml0003Ool01g`0Oomoog`0Ool07g`0009oo`03O01oogoo
05aoo`00J7oo17`000Eoog`0O01oog`000=oo`04O01oogooO003Ool01G`0OomoogooO00017oo00=l
07ooOol00Woo00=l07ooOol00goo00=l07ooOol00P0O00=oog`0Ool00Woo00Al000O01ml00<07`05
O0007`0O01ml0003Ool01G`0OomoogooO0000goo00El07ooOol07g`000807`05Ooml07ooOoml0002
Ool017`001l07g`0GWoo001WOol4O0001WooO01oog`0Ooml009oo`05O01oogooOoml0002Ool00g`0
Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool017`001l07g`00Woo00=l
000O01l00P0O0Woo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000Woo
00=l07ooOol01@0O00El07ooOoml07oo00807eeoo`00IWoo0g`000Moog`0O01oog`0Ooml0003Ool0
17`0Oomoog`00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00Al07ooOomoo`80
7`05O01oogooO01oo`0201l017`0Oomoog`00Woo00El07ooOomoog`000Aoo`03O0007`0O00<07`9o
o`05O01oogooOoml0003Ool01G`0OomoogooO0000Woo00Al000O01ml009oo`03O0007`0O05]oo`00
IGoo1G`000=oog`0O0000Woo00Al07ooOoml00=oo`05O01oogooOoml0003Ool00g`0Oomoo`03Ool0
0g`0Oomoo`02Ool017`001l07`0O0Woo00=l000O01l00P0O0Woo00Al07ooOoml009oo`0301ml000O
00807`03O0007`0O00807`=oo`03O01oo`0O00T07`05O01oogooOoml0003Ool017`0Ool07`0O0Woo
00Al07oo01l07eUoo`00I7oo1G`000Ioog`0Ooml07ooO003Ool017`0Oomoog`017oo00El07ooOomo
og`000Aoo`03O01oogoo009oo`0401ml07ooOol301l017`0Oomoog`00goo00=l000O01l00`0O00=o
og`0Ool00Woo00=l07ooOol00Woo00El07ooOomoog`0009oo`03O01oogoo009oo`05O01oogoo01ml
000201l01G`0OomoogooO0000Woo00Al000O01ml00=oo`807eMoo`00Hgoo17`000Eoog`0O01oog`0
009oo`04O01oogooO003Ool01G`0OomoogooO00017oo00=l07ooOol00Woo00=l07ooOol00P0O00Ao
og`001l07`=oo`04O01oogooO00401l2Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00El07oo
Oomoog`000=oo`05O01oogooOoml0003Ool01G`0Oomoo`0OO0000`0O0goo00Al07oo01l07`Aoo`03
01moogoo05Aoo`00HWoo17`000Qoog`0Ooml07ooO01oog`00goo00El07ooOomoog`000=oo`03O01o
ogoo009oo`03O01oogoo009oo`03O0007`0O009oo`0301ml07oo00Aoo`04O01oo`0OO003Ool01G`0
OomoogooO0000Woo00=l000O01l02P0O00El000O01l07g`000<07`05Ooml07ooOoml0003Ool017`0
Oomoogoo0`0O00Al07ooOoml00807`=oo`807eAoo`00HGoo0g`000Moog`0O01oog`0Ooml0002Ool0
17`0Oomoog`00goo00=l07ooOol00Woo00=l07ooOol00Woo00Il07ooOomoo`0OO002Ool201l00goo
O01oo`02Ool201l017`001moog`00goo00El07ooOol07g`000<07`05O01oogooOoml0003Ool01G`0
OomoogooO0000goo00Il07ooOomoo`0OO00201l01GooO01oogooO0000goo00=l07ooOol00P0O0Woo
00Al07oo01l07`=oo`0301moogoo055oo`00H7oo0W`000Aoog`0O01oo`9l009oo`03O01oog`000=o
o`05O01oogooOoml0004Ool00g`0Oomoo`02Ool01W`0Oomoo`0OOoml00807`=oo`04O0007`0O01l2
Ool017`0Oomoog`01P0O00=oog`0Ool00Woo00El07ooOomoog`000Aoo`04O01oogooO003Ool00g`0
Oomoo`02Ool01G`0Oomoo`0OO0000`0O0goo00El07ooOomoog`000807`04O01oogooOol201l2Ool0
0`0OOomoo`1@Ool005moo`9l0007Ooml07`0Ooml07ooO0000Woo00=l07ooO0000Woo00=l07ooOol0
0Woo00El07ooOomoog`000Eoo`06O0007`0OOol07g`00goo0P0O00=l07ooOol00Woo00<07g`001l0
0P0O0goo00El07ooOomoog`000=oo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo00El07oo
Oomoog`000=oo`04O01oogooOol401l3Ool00g`0Oomoo`0201l4Ool0100OOomoo`0ODGoo001NOol0
1G`0Ooml07`0Ool00W`000Eoog`0Oomoog`0009oo`04O01oogooO003Ool00g`0Oomoo`02Ool00g`0
Oomoo`02Ool00g`001moo`0201l00gooO0007`0201l2Ool00g`001l07`0201l00gooO01oo`02Ool0
1G`0OomoogooO0000Woo4@0O00El000O01l07g`000<07`05O01oogooOoml0003Ool017`0Oomoog`0
0`0O00El07ooOomoog`000807`=oo`807`03Ool07goo04moo`00GWoo0g`000Ioog`0Ooml07ooO002
Ool00g`0Ooml0003Ool01G`0OomoogooO00017oo00=l07ooOol00P0O00=l000O01l00Woo00=l000O
Ool00goo00<07g`0Ool017oo00Il07ooOomoog`0Ool501l00gooO01oo`02Ool017`0Oomoog`017oo
00El07ooOomoog`000Aoo`05O01oogoo01ml000301l3Ool01G`0OomoogooO0000Woo00El000O01mo
og`0009oo`0301moogoo009oo`0301moo`0O04moo`00GGoo0W`000Moog`0O01oog`0Ooml0002Ool0
17`0Oomoog`00Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l000O01l00Woo00=l07ooOol00P0O
00=l07ooOol00`0O00=l07ooOol017oo00=l000O01l00`0O0Woo00El07ooOomoog`000=oo`05O01o
ogooOoml0004Ool017`0Oomoog`017oo00El07ooOomoog`000=oo`D07`9oo`04O01oogooO002Ool0
0`0OO01oo`02Ool201l3Ool201m?Ool005aoo`9l0003Ooml07oo009l009oo`04O01oogooO002Ool0
17`0Oomoog`00goo00=l07ooOol00goo00=l07ooOol00P0O00=l000O01l00Woo00=l000O01l00goo
00=l07ooOol0100O00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO00017oo
00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0Oomoog`0Ool00`0O0goo00Al07ooOoml
00807`=oo`0401moogooOol201m>Ool005]oo`0:O01oog`0O01oog`0Ooml07ooO002Ool01G`0Oomo
ogooO0000Woo00El07ooOomoog`000Aoo`07O01oogoo01moo`0OO0000Woo0P0O00=l07ooOol00Woo
00@07g`001l07`Aoo`05O01oogooOoml0003OolE01l01G`001l07`0OO000100O0goo00El07ooOomo
og`0009oo`05O0007`0OOoml0002Ool00g`0Oomoo`0201l2Ool201l2Ool201m=Ool005]oo`9l0007
Ooml07`0Ooml07ooO0000goo00Al07ooOoml00=oo`05O01oogooOoml0002Ool201l00g`001l07`02
01l017ooO0007`0O0Woo00=l07ooOol00P0O00=oog`0Ool01Goo00=l07oo01l01@0O00El07ooOomo
og`000=oo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo00=l07ooOol00Woo100O0goo00Il
07ooOomoog`0Ool301l2Ool01G`0Oomoogoo01l00goo00@07gooOol07deoo`00FWoo0W`000Qoog`0
Ooml07ooO01oog`00goo00Al07ooOoml009oo`03O01oogoo009oo`06O01oo`0OOol07g`00P0O00Ao
o`0O01ml00Aoo`03O0007`0O00=oo`04O01oogooOol301l01G`001moogooO0000goo00El07ooOomo
og`000=oo`03O01oogoo009oo`05O01oogooOoml0003Ool01G`0OomoogooO00017oo00Al07ooOoml
00D07`9oo`05O01oogooO01oo`0301l4Ool01P0OOomoogoo01moo`807daoo`00FWoo0g`000Ioog`0
Ooml07ooO003Ool01G`0OomoogooO0000Woo00Ql07ooOomoog`0Ool07goo0P0O00Il07oo01l07goo
O003Ool201l00g`0Oomoo`02Ool00`0OO0007`0201l3Ool01G`0OomoogooO0000goo00El07ooOomo
og`000=oo`03O01oogoo009oo`05O01oogooOoml0003Ool01G`0OomoogooO00017oo00El07ooOomo
og`0009oo`05O01oo`0O01ml0003Ool017`0Oomoog`00P0O0goo00@07gooOol07`9oo`0301moogoo
04Yoo`00FGoo0W`000=oog`0O0000Woo00=l07ooO0000goo00Al07ooOoml00=oo`07O01oogooOoml
000OOol00P0O00=l000O01l00goo00Al000O01l07`9oo`03O0007`0O00807`03Ooml07oo00Eoo`04
O01oogooOolE01l00g`001l07`0201l017`001l07`0O17oo00El07ooOomoog`000=oo`04O01oogoo
O00201l01GooO01oogooO0000Woo0P0O0Woo0P0O00Eoo`0OOomoo`0O04]oo`00FGoo00Ul07ooO01o
og`0Ooml07ooO0000goo00El07ooOomoog`0009oo`03O01oogoo009oo`06O0007`0O01moog`017oo
00<07g`0Ool00goo00<07g`0Ool017oo00=l07ooOol00goo00<07g`001l00P0O00El07ooOomoog`0
00=oo`05O01oogooOoml0004Ool01G`0OomoogooO00017oo00Al07ooOomoo`P07`05O01oogooOoml
0002Ool00g`0Oomoo`0201l2Ool00g`0Oomoo`02Ool0100OOomoogoo0`0O00=oo`0OOol0BWoo001H
Ool2O0000gooO01l0002Ool00g`0Ooml0003Ool017`0Oomoog`00goo00Ql07ooOomoo`0OO0007goo
0P0O00=l07oo01l00P0O00=oog`001l00`0O00=oog`0Ool017oo00=l000O01l00`0O00=oog`0Ool0
0Woo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool0
1G`0OomoogooO0000goo00Al07ooOomoo`807`9oo`04O01oogooO003Ool017`001l07g`01Goo00T0
7gooOomoo`0OOol07goo01l0BWoo001GOol2O0001WooO01oog`0Ooml009oo`04O01oogooO003Ool0
1G`0OomoogooO0000Woo0P0O00=l07oo01l00Woo00=l000OOol00`0O00=l07ooOol00goo00=l000O
01l00`0O00=l07ooOol017oo00El07ooOomoog`000=oo`05O01oogooOoml0004Ool01G`0Oomoogoo
O0000goo00=l07ooOol00Woo00El07ooOomoog`000=oo`06O01oogooOoml07oo100O00=oog`0Ool0
0Woo00El07ooOoml000O00Eoo`0601moogooOol07goo0P0OBWoo001GOol00g`0Oomoo`02O002Ool0
0g`0Ooml0003Ool017`0Oomoog`017oo00El07oo01l07g`000D07`03O0007`0O00=oo`03O01oogoo
00<07`03O01oogoo00=oo`03O01oogoo00Aoo`05O01oogooOoml000701l00g`001l07`0601l00g`0
01l07`0201l00g`001l07`0601l3Ool01G`0OomoogooO0000goo00Al07oo01ml00807`06Ooml07oo
Ooml07oo0P0O17oo00@07gooOol07`9oo`807dUoo`00EWoo0W`000Ioog`0Ooml07ooO002Ool01G`0
OomoogooO0000Woo00Yl07ooOomoog`0Ool07goo01ml00807`04Ool07g`001l5Ool00g`001l07`03
Ool00g`0Oomoo`03Ool00g`0Ool07`0401l00g`001l07`0201l3Ool01G`0OomoogooO00017oo00El
07ooOomoog`000Aoo`05O01oogooOoml0003Ool00g`001l07`0301l2Ool01G`0OomoogooO0000Woo
00Ql07ooOol07g`001moog`00goo0P0O0goo0P0O00=oo`0OOol00P0OBGoo001EOol2O00017ooO01o
og`00Woo00=l07ooO0000goo00El07ooOomoog`000=oo`03O0007goo00807`06O01oo`0O01moog`0
0goo0P0O00=l000OOol017oo00=l07ooOol00`0O00=l000OOol017oo00El07ooOomoog`000=oo`05
O01oogooOoml0004Ool01G`0OomoogooO00017oo00El07ooOomoog`000=oo`06O01oogooOoml07oo
100O0Woo00Al07ooOoml00=oo`04O01oo`0OO005Ool201l3Ool0100OOol07goo0P0OB7oo001EOol2
O0001WooO01oog`0Ooml009oo`05O01oogooOoml0002Ool01g`0Oomoogoo01ml07oo00807`03Ooml
000O00=oo`04O0007`0O01l2Ool017`0Oomoogoo0P0O00Al000O01l07`=oo`03O01oogoo00Aoo`05
O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00El07oo
Oomoog`000=oo`05O01oogooOoml0003Ool00g`0Ool07`0401l01GooO01oogooO0000Woo00=l000O
01l01Goo00H07gooOomoo`0OOol301m8Ool005Aoo`9l0004Ooml07ooO002Ool017`0Oomoog`00Woo
00El07ooOomoog`0009oo`807`06O0007`0OOol07g`00goo00<07g`0Ool00goo00<07g`001l00P0O
0Woo00=l07ooOol017oo00=l07ooOol017oo00=l000O01l01@0O00=l000O01l01P0O00=l000O01l0
0P0O00=l000O01l01P0O0goo00El07ooOomoog`000=oo`05O01oogooOoml0002Ool01@0OO0007goo
O0000Woo00=l07ooOol00P0O17oo00@07gooOol07`9oo`<07dMoo`00Dgoo00Ml07ooO01oog`0Ooml
0002Ool00g`0Ooml0003Ool01W`0OomoogooO01oo`807`03O0007goo00807`03Ooml000O00807`03
Ooml07oo00<07`03Ooml07oo00Aoo`03O01oogoo009oo`807`03O0007`0O00@07`05O01oogooOoml
0003Ool00g`0Oomoo`02Ool01G`0OomoogooO00017oo00El07ooOomoog`000=oo`03O0007`0O00D0
7`05O0007`0OOoml0003Ool027`0OomoogooO01oo`0OO002Ool00g`0Oomoo`02Ool201l3Ool01@0O
Oomoo`0OOol00`0OAgoo001COol2O00017ooO01oog`00Woo00Al07ooOoml009oo`03O01oogoo009o
o`05O0007`0O01ml000201l2Ool00g`001moo`03Ool00g`001moo`03Ool00g`0Oomoo`03Ool00g`0
01l07`0201l2Ool00g`0Oomoo`04Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00El07ooOomo
og`000Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00El07ooOol07g`000807`03Ooml
07oo009oo`04O01oogooO00301l6Ool201l2Ool01@0OOomoo`0OOol00P0OAgoo001BOol01g`0Ooml
07ooO01oog`0009oo`04O01oogooO002Ool01G`0OomoogooO000100O00=l07oo01l00P0O00=l07oo
Ool00`0O00=l07ooOol00goo00=l000O01l00`0O00=l07ooOol017oo00=l07ooOol017oo00El07oo
Oomoog`000Aoo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00El07oo
Oomoog`000=oo`05O01oogooOoml0002Ool01P0OO0007`0OOoml009oo`04O01oogooO00301l5Ool0
0`0OOomoo`0201l017oo01l07`0OAgoo001BOol2O0001gooO01oogooO01oog`0009oo`05O01oogoo
Ooml0003Ool01g`001l07`0OOoml000O00=oo`03O0007`0O00=oo`03O01oo`0O00<07`03O01oogoo
00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`05O01oo`0O01ml000801l01G`001l07`0OO0002@0O
0goo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool017`0Oomoog`00P0O00Eoog`0Oomoog`0
00=oo`807`Aoo`807`9oo`0301moo`0O00807dIoo`00DGoo00Ml07ooO01oog`0Ooml0002Ool017`0
Oomoog`00Woo00Yl07ooOomoo`0OO0007goo01ml009oo`<07`06O01oogooOol07g`00P0O17oo00=l
07ooOol00goo00=l07ooOol00goo00<07g`001l01@0O00El000OOomoog`000Aoo`05O01oogooOoml
0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0001`0O00El000O01moog`000=oo`05O01oogooOoml
0002Ool00g`0Oomoo`0201l2Ool00g`0Oomoo`03Ool00`0OOomoo`03Ool00`0OOol07`02Ool201m6
Ool0055oo`9l0007Ooml07ooOoml07ooO0000goo00Al07ooOoml009oo`807`05O0007`0OOoml0002
01l2Ool00g`0Oomoo`0201l00gooO01oo`04Ool00g`0Oomoo`0401l00g`001l07`0301l00gooO01o
o`05Ool01G`0OomoogooO00017oo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml
0003Ool01G`0OomoogooO0000Woo00H07g`001l07gooO003Ool017`0Oomoog`00Woo00=l07oo01l0
0P0O1Woo0P0O17oo00@07goo01moo`807dIoo`00D7oo00El07ooO01oog`0009oo`03O01oog`000=o
o`05O01oogooO01oo`0201l00g`001moo`0201l01W`0Oomoogoo01ml00807`=oo`04O01oogooOol2
01l00g`001l07`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool01G`0OomoogooO00017oo00El07oo
Oomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00El07oo
Ool07g`000<07`04O01oogooO002Ool01G`0OomoogooO0000`0O1Goo0P0O0goo0P0O0Woo0P0OAGoo
001@Ool2O0001GooO01oogooO0000Woo00Al07ooOoml00=oo`05O0007`0O01ml000201l2Ool01W`0
01l07`0OOoml00Aoo`0301ml000O00807`9oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo
00Aoo`05O01oogoo01ml000401l01G`001l07`0OO000100O17oo00El07ooOomoog`000=oo`05O01o
ogooOoml0003Ool01G`0OomoogooO0000goo00Al000O01l07`9oo`04O01oogooO004Ool201l5Ool0
100OOomoogoo0P0O00=oo`0O01l0AGoo001?Ool01G`0Ooml07ooO0000Woo00=l07ooO0000goo00Al
07ooOoml00@07`06O01oogooOol07g`017oo00=l000O01l00P0O00=oog`0Ool017oo00=l07ooOol0
17oo00=l000O01l0100O00=l000O01l0100O00El000O01moog`000Aoo`05O01oogooOoml0004Ool<
01l01G`001l07gooO0000goo00El07ooOomoog`000=oo`04O01oogooO00401l00gooO01oo`05Ool2
01l4Ool0100OOomoogoo100OAGoo001?Ool017`0Ooml07`00Woo00Al07ooOoml00=oo`04O01oo`0O
O00201l2Ool01G`001l07`0OO0001@0O00=l07ooOol00goo00=l07ooOol00Woo00<07g`001l01@0O
00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`000Aoo`05O01oogooOoml0004Ool01G`0
OomoogooO0000goo00El07ooOomoog`0009oo`0301ml000O00807`05O0007`0O01ml0003Ool017`0
Oomoog`00Woo00Al07oo01ml00807`Ioo`807`=oo`0301moogoo00@07dEoo`00CWoo00El07ooO01o
og`0009oo`04O01oogooO002Ool01G`0Ool07`0OO0000`0O00=l07ooOol00P0O00=l07ooOol00goo
00=l07ooOol00goo00=l000O01l00P0O00=oog`0Ool01Goo00=l07ooOol017oo00=l07ooOol017oo
00El07ooOomoog`000Aoo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo00El07ooOomoog`0
00=oo`05O01oogooOoml0003Ool01G`001l07`0OO0000Woo00Al07ooOoml009oo`03O01oogoo00<0
7`Eoo`0501moogooOol07`02Ool401m4Ool004ioo`07O01oog`0Ooml07ooO0000goo00Al07ooOoml
00<07`05O0007gooOoml000201l2Ool00g`0Oomoo`02Ool00g`0Ool07`0401l00g`0Oomoo`03Ool0
0g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool01G`0OomoogooO00017oo00El07ooOomo
og`000Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`04O01o
ogooO00401l2Ool017`0Oomoog`01Goo0P0O17oo0P0O0Woo00<07gooOol00`0OA7oo001=Ool01G`0
Ooml07ooO0000Woo00Al07ooOoml00=oo`06O0007`0O01ml07oo0P0O00=l07ooOol00Woo00=l07oo
01l00P0O00=l000OOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07oo01l0100O00=l000O
01l0100O00=l000O01l01P0O00=l000O01l03P0O00El000OOomoog`000=oo`05O01oogooOoml0003
Ool017`0Oomoog`00goo00=l000O01l00P0O00=l07ooOol01Woo0P0O17oo00D07gooOol07goo00<0
7dAoo`00CGoo00El07ooO01oog`0009oo`05O01oogooO01oo`0201l01W`001l07`0OO0007`9oo`03
O01oogoo00807`03O0007goo009oo`03O01oogoo00=oo`03O0007`0O00@07`03O0007`0O00@07`03
O0007goo00Aoo`03O01oogoo00Aoo`05O01oogooOoml0004Ool01G`0OomoogooO00017oo00El07oo
Oomoog`000=oo`03O01oo`0O00D07`05O0007`0O01ml000301l017`0Oomoog`00Woo00Ml07ooOomo
og`0Ooml000301l7Ool201l3Ool00`0OOomoo`0401m4Ool004eoo`9l009oo`03O01oog`000=oo`04
O0007`0OO00301l00g`0Oomoo`0201l00g`001l07`02Ool00g`0Oomoo`02Ool00g`0Oomoo`0301l0
0g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool01G`0OomoogooO000
17oo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00El07ooOomo
og`000=oo`03O0007`0O00807`03Ooml07oo009oo`03O01oog`000=oo`@07`Eoo`807`9oo`0301mo
ogoo00<07dAoo`00C7oo00=l07ooO0000Woo00=l07ooO0000Woo00D07g`001l07g`000<07`03O000
7`0O009oo`06O01oogooOol07g`0100O00=l000O01l00goo00=l07ooOol017oo00=l07ooOol017oo
00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`000Aoo`05O01oogooOoml0004Ool01G`0
OomoogooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0002Ool027`0OomoogooO01oo`0O
O00201l017`001l07`0O1goo100O0goo00<07gooOol01@0OA7oo001<Ool01G`0Ooml07ooO0000Woo
00Al07oo01ml00<07`05O0007`0OOoml0003Ool00g`001l07`0201l00gooO01oo`03Ool00g`0Oomo
o`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`0401l00g`001l07`0401l00g`001l0
7`0C01l01G`001moogooO0000goo00El07ooOomoog`000=oo`04O01oogooO002Ool01G`0Oomoogoo
O0000Woo00Al07ooOoml00@07`Moo`807`9oo`807`9oo`@07d=oo`00C7oo0W`00Woo00Al07ooOoml
00807`06O0007`0O01ml000O0Woo00El000O01l07g`000Eoo`03O01oogoo009oo`03O01oogoo00<0
7`03O0007`0O00@07`03O0007`0O00@07`03O0007`0O00Aoo`03O01oogoo00Aoo`05O01oogooOoml
0004Ool01G`0OomoogooO00017oo00Il07ooOomoog`0Ool601l01G`001l07`0OO0000`0O00Ml000O
01ml000OOoml0003Ool01W`0Oomoog`0Ooml00Eoo`<07`Ioo`0601moogooOol07goo100O@goo001;
Ool00g`0Ooml0002Ool00g`0Ooml000301l017`0Ool07g`0100O00El07ooOomoog`000Aoo`03O000
7`0O00<07`03O0007`0O00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01o
ogoo00Aoo`05O01oogooOoml0004Ool01G`0OomoogooO00017oo00El07ooOomoog`000=oo`05O01o
ogooOoml0003Ool017`0Oomoog`00goo00Al07oo01ml00807`07O0007`0O01ml07ooO00027oo100O
0goo0P0O0Woo1@0O@goo001;Ool01G`0Ooml07ooO0000P0O00El000O01l07g`000807`03O0007goo
009oo`05O0007`0O01ml000401l00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0
Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool01G`0OomoogooO00017oo00El07ooOomoog`0
00Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00Al07ooOoml00=oo`04O01oogooO002
Ool017`0Oomoog`0200O1goo0`0O0Woo0P0O00=oo`0O01l00P0O@goo001;Ool01G`0Ooml07ooO000
0P0O00Al000O01ml00<07`06O0007`0O01ml000O0goo00=l07ooOol00Woo00=l07ooOol00goo00=l
07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00El
07ooOomoog`000Aoo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo00El07ooOomoog`000=o
o`04O01oogooO002Ool01G`0OomoogooO0000Woo00Al07ooOoml009oo`03O01oogoo00=oo`@07`Io
o`807`9oo`D07d=oo`00BWoo00=l07ooO0000P0O00Al000O01ml00807`05O0007`0OOoml0003Ool0
0g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`001l07`0301l00g`001l07`0301l00g`001l07`0401l0
0g`001l07`0401l00g`001l07`0401l00g`001l07`0401l00g`001l07`0601l01G`001l07`0OO000
300O00Al000O01ml00@07`04O0007`0OO00201l01G`001l07gooO0000Woo00=l07ooO0000Woo00=l
07ooOol027oo1P0O0Woo1`0O@goo001:Ool00g`0Ooml000201l02W`001l07g`001moog`0Ool07g`0
100O00=l000O01l00P0O00=l000O01l00P0O00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol0
0goo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`000Aoo`05O01o
ogooOoml0004Ool01G`0OomoogooO0000goo00Al07ooOoml00=oo`05O01oogooOoml0002Ool017`0
Oomoog`01@0O00Al000O01ml00L07`Uoo`807`9oo`D07d=oo`00BWoo00El000OO0007g`000807`09
O0007`0O01ml000OOoml000O00=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`03
O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Eoo`03O01oogoo00Aoo`05
O01oogooOoml0004Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00El07ooOomoog`0009oo`05
O01oogooOoml0003Ool017`0Oomoog`00Woo00Al07ooOoml009oo`03O01oog`000Qoo`T07`9oo`L0
7d=oo`00B7oo0P0O00El000OO0007g`000807`08O0007goo01ml000OOoml00=oo`03O01oogoo009o
o`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Ao
o`03O01oogoo00Eoo`03O01oogoo00Aoo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo00El
07ooOomoog`000Aoo`04O01oogooO003Ool017`0Oomoog`00goo00Il07ooOoml07ooO003Ool00g`0
Ooml000AOol901m3Ool0049oo`L07`04O0007`0OO00401l01G`001l07`0OO0001P0O00=l000O01l0
0P0O00=l000O01l00`0O00=l000O01l00`0O00=l000O01l02@0O00=l000O01l0100O00=l000O01l0
1@0O00=l000O01l0100O00=l000O01l0B`0O@goo0012Ool501l01Goo01ml07ooO0000P0O00]l000O
Ooml07oo01ml000OOol07g`000=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00Aoo`03
O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Eoo`03O01oogoo00Aoo`05
O01oogooOoml0004Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0003
Ool017`0Oomoog`00Woo00Ml07ooOomoog`0Ooml0002Ool00g`0Ooml000EOol0100OOol07goo0P0O
@goo0012Ool401l02Goo01l07g`001ml07oo01ml000201l027`001moog`001moo`0OO003Ool00g`0
Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0
Oomoo`04Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool01G`0OomoogooO00017oo00El07ooOomoog`0
00=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000Woo00El07ooOomoog`0009oo`04O01oogoo
O002Ool01W`0Oomoog`0Ooml01Eoo`0301moo`0O00<07d=oo`00@Woo1@0O00]oo`0OO01oog`001ml
000OOol07g`0009oo`04O01oo`0OO004Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03
Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`05Ool00g`0Oomoo`04
Ool01G`0OomoogooO00017oo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0Oomoogoo
O0000Woo00El07ooOomoog`0009oo`06O01oogooO01oog`00goo0W`05Goo1`0O@goo0012Ool701l0
1G`001ml000OO0000P0O00Qoog`0Oomoog`0Ool07g`017oo00=l07ooOol00Woo00=l07ooOol00Woo
00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol01Goo
00=l07ooOol017oo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo
00El07ooOomoog`0009oo`04O01oogooO003Ool01W`0Oomoog`0Ooml009oo`03O01oog`000ioo`L0
7`03Ool07`0O00@07d=oo`00@Woo0`0O00Uoo`0OOoml07oo01ml07ooO0000`0O00=l000O01l00P0O
00=oog`0Ool00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol017oo
00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol017oo00El07ooOomoog`0
00Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`04O01oogoo
O002Ool01g`0OomoogooO01oog`0009oo`03O01oog`000Aoo`X07`Qoo`H07d=oo`00@Woo0`0O00Ao
o`0O01ml00807`06O01oog`001moog`00Woo00D07g`001l07g`000@07`03O0007`0O00807`03O000
7`0O00807`03O0007`0O00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01o
ogoo00Eoo`03O01oogoo00Aoo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo00El07ooOomo
og`000=oo`04O01oogooO003Ool017`0Oomoog`00Woo00=l07ooOol03@0O4Goo1P0OA7oo0012Ool0
0`0OOol07`0301l02G`001l07g`001ml000OOoml0002Ool01@0OO0007gooO00017oo00=l07ooOol0
0Woo00=l07ooOol00Woo00=l07ooOol0400O00=l000O01l0100O00=l000O01l0=@0O00=l07ooO000
0Woo00=l07ooO00057oo200OA7oo0012Ool201l04Goo01l07`0OO0007g`0Ool07g`001moog`0Ool0
7g`001l00Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00goo00=l
07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol017oo00El
07ooOomoog`000Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00Al07ooOoml009oo`05
O01oogooOoml0002Ool00g`0Ooml0002Ool01G`0Ooml07ooO0004Goo100O0Woo1@0OAGoo0012Ool3
01l01Woo01l07g`001ml00807`08O01oo`0OO01oo`0OO0007`9oo`03O01oogoo009oo`03O01oogoo
009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo
00Aoo`03O01oogoo00Eoo`03O01oogoo00Aoo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo
00Al07ooOoml00Aoo`04O01oogooO002Ool017`0Oomoog`00Woo00Il07ooOoml07ooO002Ool00g`0
Ooml000<Ool501l5Ool601m5Ool004=oo`807`09Ool07`0OO0007g`001moog`000@07`03Ooml07oo
009oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo
00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Eoo`03O01oogoo00Aoo`05O01oogoo
Ooml0004Ool01G`0OomoogooO0000goo00Al07ooOoml00=oo`05O01oogooOoml0002Ool017`0Oomo
og`00Woo00Yl07ooOoml07ooO01oog`0Ooml00Qoo`D07`Uoo`H07dIoo`00@goo100O00Aoog`001ml
00807`04O01oo`0OO00201l01G`001l07`0OO00017oo00=l07ooOol00Woo00=l07ooOol00Woo00=l
07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol01Goo00=l
07ooOol017oo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool017`0Oomoog`00goo00Al07oo
Ooml00=oo`06O01oogooO01oog`00Woo00Ql07ooOoml07ooO01oog`00Woo1P0O2goo0`0O00=oo`0O
01l00`0OAWoo0013Ool501l02G`0Ooml07oo01ml000OOoml0002Ool01G`0OomoogooO000100O00=l
07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l
07ooOol017oo00=l07ooOol01Goo00=l07ooOol017oo00El07ooOomoog`000=oo`03O01oogoo009o
o`05O01oogooOoml0002Ool01G`0OomoogooO0000Woo00El07ooOomoog`0009oo`03O01oog`0009o
o`03O01oog`000L07`moo`807`=oo`D07dMoo`00@goo100O00Yoog`001ml07oo01ml000OO0007`9o
o`05O01oogooOoml0003Ool00g`001l07`0801l017`001l07`0O0Woo00=l07ooOol017oo00=l07oo
Ool00goo00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol017oo00El07ooOomoog`000=oo`05
O01oogooOoml0004Ool017`0Oomoog`00goo00Al07ooOoml00h07`04Ooml07ooO00>Ool401l4Ool5
01m8Ool004=oo`D07`03O01oog`000807`07O01oog`001moo`0OO0000goo00El07ooOomoog`000Eo
o`03O01oogoo009oo`04O01oogooOol201l00g`001l07`0401l00g`001l07`0301l00g`001l07`05
01l7Ool00g`0Oomoo`04Ool00g`0Oomoo`0I01l2Ool01W`0Oomoog`0Ooml009oo`07O01oog`0Ooml
07ooO0002goo100O1goo1P0OB7oo0013Ool201l027oo01l07g`0Ooml000OOol201l01G`001moo`0O
O0000goo00El07ooOomoog`000Eoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Aoo`03
O01oogoo00=oo`03O01oogoo00Eooa407`03Ooml07oo009oo`05O01oogooOoml0003Ool01G`0Oomo
ogooO0000Woo00El07ooOomoog`0009oo`03O01oog`0009oo`07O01oogooO01oog`0Ool00W`02Woo
0P0O2Goo0P0O00=oo`0O01l00P0OBGoo0013Ool201l02goo01l07g`001ml000OOoml07ooO0000`0O
00El07ooOomoog`000=oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo
00Aoo`03O01oogoo00=oo`03O01oogoo00Eoo`03O01oogoo00Aoo`03O01oogoo00Aoo`05O01oogoo
Ooml0003Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`05O01oogooOoml0002Ool01G`0
Ooml07ooO0000Woo00Ml07ooO01oog`0Ooml0006Ool401l8Ool301l2Ool401m:Ool004Aoo`807`0:
Ool07g`001ml000OO0007gooO002Ool00`0OO0007`0201l01G`0OomoogooO0001Goo00=l07ooOol0
0Woo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol01Goo00=l07ooOol0
17oo00=l07ooOol017oo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO000
0Woo00Al07ooOoml009oo`06O01oogooO01oog`00Woo00Al07ooO01oo`9l00L07`Yoo`807`Aoo`D0
7dYoo`00A7oo0P0O00Yoo`0OO0007g`001ml000OOoml009oo`0301ml07oo009oo`03O0007`0O00<0
7`Aoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo
00Eoo`03O01oogoo00Aoo`03O01oogoo00Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo
00El07ooOomoog`0009oo`04O01oogooO002Ool01g`0Oomoog`0Ooml07oo00L07`ioo`<07`Aoo`H0
7d]oo`00A7oo100O00al000O01l07g`001moog`0Ool07gooO003Ool01W`0OomoogooO01oo`@07`03
O0007`0O009oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Eoo`03
O01oogoo00Aoo`03O01oogoo00Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00Al07oo
Ooml00=oo`06O01oogooO01oog`01`0O00Il07ooO01l07ooO00=Ool201l6Ool00`0OOol07`0301m<
Ool004Aoo`807`07Ool07g`0Ooml07ooO0000`0O00Al000OOoml00=oo`05O01oogooOoml0005Ool0
0g`0Oomoo`0201l00g`001l07`0201l00gooO01oo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`05Ool0
0g`0Oomoo`04Ool00g`0Oomoo`04Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01o
ogooO01oo`0801l2Ool00g`0Ooml0002Ool2O00017ooO01oog`02Woo0`0O1Woo0P0O00=oo`0O01l0
0`0OC7oo0015Ool401l027ooO01oog`001moo`0OO00201l01G`0OomoogooO00017oo00=l07ooOol0
0Woo00=l07ooOol00Woo00=l07ooOol00Woo00<07g`001l01@0O00=l000O01l0100O1goo00=l07oo
Ool017oo00=l07ooOol017oo00Al07ooOomooa407`03Ooml07oo009oo`03O01oog`0009oo`9l009o
o`06O01oog`0O01oog`01goo100O1Woo0`0O00Aoo`0O01moo`<07deoo`00AGoo0`0O00El000OO01o
og`0009oo`0601ml000OOoml000O0Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo
00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo6@0O00El07ooOomoog`000=oo`05O01o
ogooOoml0002Ool017`0Oomoog`00Woo00Al07ooOoml009oo`9l009oo`=l009oo`04O01oogooOol4
01l7Ool301l2Ool201l2Ool301m>Ool004Eoo`<07`05O01oog`001ml0002Ool01P0OO0007gooO01o
o`@07`=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01o
ogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`05O01oogooOoml0003Ool0
1G`0OomoogooO0000Woo00El07ooOomoog`0009oo`06O01oogooO01oog`00Woo00Il07ooO01oog`0
Ool2O0000goo01l07`0301l9Ool201l4Ool0100OOomoogoo0`0OCgoo0016Ool301l2O0002Goo01ml
07oo01ml000OOoml0003Ool00g`0Ool07`0201l00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomo
o`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomo
o`04Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`04O01oogooO003Ool01W`0Oomoog`0
Ooml009oo`9l009oo`03O0007`0O00807`aoo`807`Aoo`807`9oo`D07dmoo`00AWoo0`0O0W`000Uo
o`0OO0007gooO0007gooO0000goo00=l07ooOol00Woo00Il000O01l07gooO005Ool00g`0Oomoo`02
Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04
Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`04O01oogooO002Ool017`0Oomoog`00Woo
00=l07ooO0001@0O0g`02goo0P0O17oo0P0O0goo00<07goo01l00P0OD7oo0016Ool401l017`0Ool0
7g`00P0O00Al000OOoml00Aoo`05O01oogooOoml0003Ool501l2Ool00g`0Oomoo`02Ool00g`0Oomo
o`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool01G`0Oomo
ogooO0000goo00El07ooOomoog`0009oo`04O01oogooO002Ool00g`001l07`0601l017`0Ooml07oo
0W`000=oog`0Ool01goo0`0O1Goo00<07gooOol00Woo00<07goo01l00P0ODGoo0017Ool201l027`0
01ml000OO0007gooO00301l4Ool01G`0OomoogooO00017oo00Al07ooOomoo`807`03O0007`0O0080
7`03Ooml07oo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Ao
o`05O01oogooOoml0003Ool01W`0OomoogooO01oo`P07`05Ooml07ooOoml0002Ool2O0001WooO01l
07`0Ooml00Ioo`<07`Ioo`807`=oo`807`04Ool07`0O01mBOol004Moo`807`0;O0007g`001ml000O
Ooml000OOoml000201l2Ool01G`0OomoogooO00017oo00=l07ooOol00goo00=l07ooOol00Woo00<0
7g`001l06@0O00=l000O01l0100O00=l000O01l02`0O00El07ooOomoog`0009oo`05O01oog`0Ooml
0002Ool027`0Ooml07`0Ooml07ooO004Ool301l7Ool201l4Ool00`0OOol07`0301mCOol004Qoo`0<
01ml000OO0007g`001moog`001moog`00Woo0P0O00El07ooOomoog`000Aoo`03O01oogoo00=oo`03
O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03
O01oogoo00Aoo`05O01oogooOoml0003Ool017`0Oomoog`00Woo00Al07ooOoml009oo`06O01oogoo
O01oog`00Woo0g`000Eoog`0O01l07oo00@07`Qoo`807`Eoo`0401moo`0OOol301mCOol004Qoo`80
7`9l000601ml000O01ml000O0Woo00El07ooOomoog`000<07`03O01oogoo00=oo`03O01oogoo009o
o`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Ao
o`03O01oogoo00Aoo`05O01oogooOoml0003Ool017`0Oomoog`00Woo00Al07ooOoml009oo`03O01o
og`0009oo`04O01oog`0Ool2O00501l:Ool201l5Ool201l00goo01moo`0301mDOol004Uoo`807`04
Ooml07ooO00301l2Ool01G`0OomoogooO0000goo00Al000O01l07`9oo`03O01oogoo009oo`03O01o
ogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01o
ogoo00Aoo`05O01oogooOoml0003Ool017`0Oomoog`00Woo00Il07ooOoml07ooO002Ool00g`0Ooml
000601l2O00;Ool201l5Ool201l017oo01l07goo0`0OEGoo0019Ool0200OO0007g`001ml000OOol2
01l00gooO01oo`02Ool01G`0OomoogooO0000goo0P0O00=l000O01l00P0O00=oog`0Ool00goo00=l
07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00El
07ooOomoog`0009oo`04O01oogooO003Ool01g`0Oomoog`0Ooml07oo00@07`03Ooml07oo00Al00Uo
o`<07`Eoo`807`9oo`0301moo`0O00<07eIoo`00BWoo0P0O00Yl000OO0007gooO01oo`0OO0007`=o
o`04O01oogooO005Ool00g`0Oomoo`02Ool00`0OO0007`0401l5Ool00g`0Oomoo`04Ool00g`0Oomo
o`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool01G`0OomoogooO0000Woo00Al07ooOoml009oo`03
O01oo`0O00D07`06O01oog`0Ooml07oo0W`000=oog`0Ool01Goo100O1Woo0P0O0Woo0P0O00=oo`0O
Ool00P0OEgoo001:Ool201l01WooO0007`0OOoml009oo`06O01oo`0O01moog`00Woo00=l07ooOol0
0goo00=l07ooOol00goo00=l07ooOol00goo1`0O1Goo00=l07ooOol017oo00=l07ooOol017oo00=l
07ooOol00goo400O00Yoog`0Oomoog`0Ooml07ooO01oo`=l0003Ooml07oo00=oo`<07`Qoo`807`=o
o`0301moo`0O00@07eQoo`00BWoo0P0O00=oog`0Ool00`0O00=l07ooO0000goo0`0O0Woo00=l07oo
Ool00Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00=l07oo01l04P0O00=l000O
01l00`0O00=oog`0Ool00Woo00Al07ooOoml009oo`04O01oogooO002Ool00g`0Ooml0002Ool02G`0
Ooml07`0Ooml07ooO01oo`0401l8Ool301l3Ool201l00goo01moo`0401mHOol004]oo`807`08O000
7g`0Ool07g`0Ooml00Aoo`05O01oo`0O01ml0004Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0
Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool01G`0
OomoogooO0000Woo00Al07ooOoml009oo`0;O01oogooO01oog`0Ooml07ooO01oo`02O00401l8Ool4
01l4Ool201l017oo01l07goo100OFGoo001;Ool00`0OO0007`0201l01W`001l07`0OOoml00=oo`05
O01oogooOoml000401l00gooO01oo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04
Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool01G`0OomoogooO0000Woo00Al07oo
Ooml009oo`09O01oogooO01oog`0Ooml07oo00@07`9l00Moo`<07`Eoo`<07`9oo`0301moo`0O00@0
7eYoo`00C7oo00Yl000O01l07g`0Ooml07oo01ml00=oo`05O01oogooOoml0004Ool00`0OO0007`04
01l5Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomo
o`04Ool01G`0OomoogooO0000Woo00Il07ooOoml07ooO003Ool00g`001l07`0301l00gooO01l0002
O006Ool201l6Ool201l3Ool201l00goo01moo`0301mKOol004aoo`807`05O01oo`0OOoml0002Ool0
0g`001l07`02Ool017`0Oomoog`01Goo00=l07ooOol00goo1`0O17oo00=l07ooOol017oo00=l07oo
Ool017oo00=l07ooOol017oo00=l07ooOol00goo00El07ooOomoog`0009oo`03O0007`0O00L07`04
O01oog`0Ool5O005Ool201l6Ool201l4Ool00`0OOol07`0501mLOol004eoo`9l00@07`03O01oog`0
009oo`807`05O01oogooOoml0004Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Ool07`0601l4
Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool801l2Ool00g`0Ooml0002Ool2O002
Ool2O00017ooO01l07`00goo0`0O1Goo0`0O17oo0P0O00=oo`0OOol0100OGGoo001=Ool01`0OO000
7`0OO01oo`0O009oo`05O01oogooOoml000201l00gooO01oo`03Ool00g`0Oomoo`03Ool00g`0Oomo
o`03Ool00g`0Oomoo`02Ool00g`0Oomoo`0H01l017`0Oomoog`00Woo00Al07ooOoml009oo`03O01o
ogoo009l0003Ooml07oo00Al00@07`Ioo`807`Eoo`807`04Ool07`0OOol401mNOol004ioo`0601ml
000OO01oog`00P0O00El07ooOomoog`0009oo`0301ml000O00=oo`03O01oogoo00=oo`03O01oogoo
00=oo`03O01oogoo009oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo
00=oo`04O01oogooO002Ool01W`0Oomoog`0Ooml009oo`04O01oog`0Ool2O00401l8Ool201l5Ool2
01l2Ool00`0OOol07`0401mOOol004moo`0901ml000O01ml000OOoml000O009oo`03O01oogoo009o
o`03O0007`0O00807`Eoo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo
00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`04O01oogooO002Ool01W`0Oomoog`0Ooml009oo`03
O01oo`0O00<07`9l00Moo`<07`Ioo`0301moogoo00807`03Ool07goo00<07f1oo`00D7oo00El000O
O0007g`0009oo`05O0007`0OOoml0003Ool00g`0Oomoo`02Ool701l4Ool00g`0Oomoo`03Ool00g`0
Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool017`0Oomoog`00Woo00Al
07ooOoml00H07`03Ooml07`0009l00Ioo`807`Moo`807`9oo`0301moo`0O00D07f5oo`00DGoo00L0
7g`0Ooml000OOoml0002Ool00`0OO01oo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Ool0
7`0601l3Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0
Ool07`0701l01gooO01oog`0Ooml07oo00=l00Eoo`807`Moo`807`9oo`807`05Ool07goo01moo`02
01mROol0059oo`0601ml000OO0007g`017oo00El000O01moog`000=oo`03O01oogoo00=oo`03O01o
ogoo009oo`03O01oogoo00<07`03O0007`0O00X07`03O0007`0O00`07`07Ooml07ooOoml07ooO000
0Woo00Al07ooO01oo`Al00=oo`<07`Ioo`<07`9oo`807`06Ool07`0OOol07goo0P0OHgoo001BOol2
O0001GooO01oo`0OO0000goo00=l07ooOol00`0O0Woo00=l07ooOol00goo00=l07ooOol00Woo00=l
07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00Al
07ooOoml009oo`08O01oog`0Ooml07ooO01oo`Al00@07`Moo`807`=oo`807`9oo`0301moo`0O00@0
7fAoo`00Dgoo00Ml000O01ml07ooO0007`02Ool01W`0OomoogooO01oo`<07`03O01oogoo009oo`03
O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03
O01oogoo00=oo`04O01oogooO002Ool01W`0Ooml07ooO01oo`H07`Qoo`<07`=oo`807`9oo`807`06
Ool07goo01moo`0OIGoo001DOol201l017`0Oomoog`00P0O00=oog`0Ool00Woo00Al07ooOomoo`<0
7`9oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo
00Aoo`03O01oogoo00=oo`06O01oogooO01oog`01P0O1G`01Woo0`0O17oo0P0O0goo00D07goo01l0
7goo00<07fIoo`00EGoo00El000OO01oog`0009oo`<07`9oo`05O01oogooOoml0002Ool501l3Ool0
0g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool0
0g`0Ool07`0301l017ooO01oogoo1W`00goo100O1Goo0P0O0goo0P0O00=oo`0OOol00`0OJ7oo001E
Ool3O0000`0OOoml0002Ool00g`0Ool07`0201l4Ool00g`0Oomoo`02Ool00g`0Ool07`0=01l2Ool0
0g`0Oomoo`02Ool00g`001l07`0<01l01gooO01oog`0Ooml07oo00Il0004Ool07`0O01l6Ool301l3
Ool201l01goo01l07goo01moo`0O06Uoo`00EWoo00=l000OO0000P0O0goo00Al07ooOomoo`807`9o
o`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`04O01oogooOol201l00g`001l07`03
01l00g`0Oomoo`03Ool00g`0Oomoo`03Ool01g`0Oomoog`0Ooml07oo00El00@07`Moo`807`Aoo`80
7`04Ool07`0OOol401mZOol005Moo`04O0007g`0Ool201l00gooO01oo`02Ool00g`0Ool07`0401l3
Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03
Ool00g`0Oomoo`03Ool01G`0Oomoog`0Ool00g`0100O00=l07ooOol01Woo0P0O17oo0P0O00=oo`0O
01l00Woo0`0OK7oo001HOol301l01G`0Ool07`0OO0000goo00Il07ooOomoog`0Ool301l00g`001l0
7`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomo
o`03Ool017`0Ooml07`0100O1G`01Goo0`0O17oo0P0O0Woo00<07gooOol00`0OKWoo001IOol0100O
O0007g`00Woo0P0O0Woo00El07ooOomoog`000Aoo`03O01oogoo00L07`9oo`03O01oogoo009oo`03
O01oogoo00=oo`03O01oogoo00=oo`04O01oogooOol201l01G`001l07`0OOol01g`00Woo100O17oo
0`0O0Woo0P0O0Woo0P0OL7oo001JOol0100OO0007`0O0Woo00El000O01l07g`000=oo`03O01oogoo
009oo`03O01oogoo009oo`04O01oogooOol201l00g`001l07`0B01l3O002Ool4O0000gooO01l0004
01l5Ool301l3Ool201l2Ool301maOol005]oo`807`05O0007`0OOoml0002Ool301l00gooO01oo`03
Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02
Ool017`0Ooml07`00Woo0g`000=oog`0O000100O00=l07ooOol017oo0P0O17oo0P0O0Woo0`0OLgoo
001LOol201l2O00201l01G`0Oomoog`0Ool0100O0goo00=l07ooOol00Woo00=l07ooOol00Woo00=l
07ooOol00goo00=l07ooOol00goo00Al07ooOomoo`=l009oo`9l00H07`Al00Eoo`807`Aoo`807`9o
o`@07gAoo`00GWoo0W`000Aoog`001l07`9l00=oo`03O01oo`0O00H07`03Ooml07oo00Aoo`03O01o
ogoo009oo`03O01oogoo00=oo`04O01oog`0O00201l00g`001l07`0201l3O0000gooO01l0003O003
Ool301l4Ool201l2Ool201l00goo01moo`1eOol005moo`<07`06Ooml000O01ml000O0Woo00El07oo
Oomoog`000=oo`807`03O0007`0O01407`=l00=oo`9l0003Ooml07`000Al00@07`Eoo`807`9oo`80
7`03Ool07`0O07Moo`00H7oo00D07g`001l07g`0009oo`04O0007`0OO00201l2Ool00g`0Oomoo`02
Ool00g`0Oomoo`03Ool00g`0Oomoo`05O002Ool017`0Ooml07`00Woo00El07ooOoml07oo00=l00D0
7`Ioo`<07`9oo`807`03Ool07`0O07Uoo`00HWoo0g`00P0O00=l07ooOol00g`00P0O3W`00Woo00=l
07ooOol00Woo0W`017oo200O17`00goo100O0Woo0`0O00=oo`0O01l0Ngoo001SOol201l4O00201l0
0gooO01oo`02Ool00g`001l07`0901l3Ool4O00201l00g`001l07`0201l01G`0Ooml07`0Ool01g`0
0`0O17oo0P0O0Woo0P0OOGoo001TOol01G`001ml07`0Ool00W`000<07g`0O00017`00goo00=l07oo
O00017`01`0O00Aoog`0O01l00=oo`9l0003Ooml07`000=l00@07`Eoo`807`9oo`807gmoo`00IGoo
00Al000O01l07`=l0003Ooml000O00807`Il00Aoo`03O01oogoo009oo`07O01oog`0O01oog`0Ool0
1W`00P0O00=l000O01l00W`017oo0`0O0Woo0P0OPGoo001VOol00g`001ml0002O00301l2O0000goo
01l07`0501l2Ool5O0000`0OO0007`0;01l7O00401l2Ool301n3Ool006Qoo`04O0007`0OO002Ool3
01l7O00701l2Ool4O00017ooO01l07`00Woo0W`000=oog`001l0100O0goo0`0OQWoo001ZOol6O000
0goo01l07`0201l3Ool017`0Oomoogoo1W`00Woo0g`000=oo`0O01l01@0O0g`00Woo0`0ORGoo001/
Ool3O0000`0OO0007`03O00701l00g`001l07`0901l4O00017ooO01oog`0100OS7oo001_Ool3O003
01l01G`001l07gooO0000Woo17`00Woo00=l07ooO0001G`000=oo`0O01l00`0O00=l07ooOol0SGoo
001aOol7O00201l00g`001l07`0>01l6O02?Ool007=oo`ml0003Ooml07oo00El0006Ooml07ooO01o
og`0T7oo001eOol6O00017ooO01oogoo3W`000=oog`0O000T7oo001hOol7O002Ool4O002Ool2O002
Ool5O02@Ool007]oo`al0003Ooml07`000Il091oo`00Ogoo2G`000=oog`0O0001G`0T7oo0026Ool:
O02@Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {638.438, 409.063}} -> {-0.399192, \
1.78339, 0.00348777, 0.00348777}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig2B = 
        Show[RotateShape[Fig2A, \[Pi]/2, 0, 0], \ 
          ViewPoint \[Rule] {0, 2, 0}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.5 .48233 m
.5 .5 L
s
.5 .5 m
.5 .51767 L
s
.50074 .49777 m
.49943 .51539 L
s
.50204 .48016 m
.50074 .49777 L
s
.50293 .49575 m
.50033 .51323 L
s
.50552 .47828 m
.50293 .49575 L
s
.50653 .49413 m
.50267 .51138 L
s
.51037 .4769 m
.50653 .49413 L
s
.50267 .51138 m
.49878 .52859 L
s
.50638 .51002 m
.50125 .52692 L
s
.51147 .49309 m
.50638 .51002 L
s
.50033 .51323 m
.49772 .53067 L
s
.51649 .47618 m
.51147 .49309 L
s
.51138 .50934 m
.50506 .52584 L
s
.51762 .4928 m
.51138 .50934 L
s
.49943 .51539 m
.49812 .53297 L
s
.5 .46472 m
.5 .48233 L
s
.5 .51767 m
.5 .53528 L
s
.52378 .47627 m
.51762 .4928 L
s
.51754 .50948 m
.5101 .52552 L
s
.52488 .49339 m
.51754 .50948 L
s
.50334 .4626 m
.50204 .48016 L
s
.50808 .46088 m
.50552 .47828 L
s
.51415 .45973 m
.51037 .4769 L
s
.53209 .4773 m
.52488 .49339 L
s
.50506 .52584 m
.49869 .54225 L
s
.52474 .51056 m
.51624 .52609 L
s
.53309 .49496 m
.52474 .51056 L
s
.50125 .52692 m
.49609 .54372 L
s
.5101 .52552 m
.50257 .54146 L
s
.49878 .52859 m
.49488 .54571 L
s
.52145 .45932 m
.51649 .47618 L
s
.51624 .52609 m
.50764 .5415 L
s
.49772 .53067 m
.49511 .54802 L
s
.49812 .53297 m
.49682 .55045 L
s
.54128 .47935 m
.53309 .49496 L
s
.52983 .45979 m
.52378 .47627 L
s
.53282 .51267 m
.52335 .52765 L
s
.5421 .49759 m
.53282 .51267 L
s
.5 .44721 m
.5 .46472 L
s
.5 .53528 m
.5 .55279 L
s
.52335 .52765 m
.51374 .5425 L
s
.50462 .44515 m
.50334 .4626 L
s
.53916 .46124 m
.53209 .4773 L
s
.51061 .44359 m
.50808 .46088 L
s
.50257 .54146 m
.49499 .55725 L
s
.55117 .48247 m
.5421 .49759 L
s
.50764 .5415 m
.49894 .55676 L
s
.49869 .54225 m
.49228 .55852 L
s
.51789 .44268 m
.51415 .45973 L
s
.53127 .53028 m
.52074 .54454 L
s
.54162 .51586 m
.53127 .53028 L
s
.49609 .54372 m
.49092 .56039 L
s
.55174 .50132 m
.54162 .51586 L
s
.51374 .5425 m
.504 .55717 L
s
.52631 .44258 m
.52145 .45932 L
s
.49488 .54571 m
.49098 .5627 L
s
.54928 .46375 m
.54128 .47935 L
s
.49511 .54802 m
.49251 .56523 L
s
.52074 .54454 m
.51004 .55859 L
s
.53576 .44342 m
.52983 .45979 L
s
.49682 .55045 m
.49552 .56778 L
s
.56161 .4867 m
.55174 .50132 L
s
.53985 .53401 m
.52847 .54767 L
s
.55099 .52015 m
.53985 .53401 L
s
.5 .42985 m
.5 .44721 L
s
.5 .55279 m
.5 .57015 L
s
.56001 .46735 m
.55117 .48247 L
s
.56186 .50614 m
.55099 .52015 L
s
.50589 .42787 m
.50462 .44515 L
s
.54606 .44528 m
.53916 .46124 L
s
.52847 .54767 m
.51689 .5611 L
s
.49894 .55676 m
.49018 .57181 L
s
.504 .55717 m
.49417 .57162 L
s
.51311 .42646 m
.51061 .44359 L
s
.49499 .55725 m
.48737 .57285 L
s
.49228 .55852 m
.48587 .5746 L
s
.51004 .55859 m
.49921 .5724 L
s
.52155 .42579 m
.51789 .44268 L
s
.49092 .56039 m
.48575 .57687 L
s
.55706 .44823 m
.54928 .46375 L
s
.57244 .49202 m
.56186 .50614 L
s
.54891 .53885 m
.53678 .55192 L
s
.56076 .52554 m
.54891 .53885 L
s
.5712 .47206 m
.56161 .4867 L
s
.53108 .426 m
.52631 .44258 L
s
.49098 .5627 m
.4871 .57949 L
s
.51689 .5611 m
.50515 .57424 L
s
.53678 .55192 m
.52441 .56472 L
s
.49251 .56523 m
.48993 .58224 L
s
.5723 .51204 m
.56076 .52554 L
s
.54154 .4272 m
.53576 .44342 L
s
.49552 .56778 m
.49424 .58491 L
s
.56858 .45228 m
.56001 .46735 L
s
.52441 .56472 m
.51184 .5772 L
s
.5 .41271 m
.5 .42985 L
s
.5 .57015 m
.5 .58729 L
s
.55277 .42946 m
.54606 .44528 L
s
.49417 .57162 m
.48427 .5858 L
s
.50714 .4108 m
.50589 .42787 L
s
.49921 .5724 m
.48828 .58592 L
s
.49018 .57181 m
.48137 .5866 L
s
.58267 .47783 m
.57244 .49202 L
s
.54551 .55727 m
.53243 .56946 L
s
.5583 .54476 m
.54551 .55727 L
s
.58348 .49838 m
.5723 .51204 L
s
.57078 .53197 m
.5583 .54476 L
s
.48737 .57285 m
.47973 .5882 L
s
.50515 .57424 m
.49328 .58707 L
s
.51556 .40956 m
.51311 .42646 L
s
.48587 .5746 m
.47945 .59044 L
s
.58046 .45742 m
.5712 .47206 L
s
.53243 .56946 m
.51912 .58128 L
s
.5646 .43283 m
.55706 .44823 L
s
.52513 .40913 m
.52155 .42579 L
s
.58289 .51894 m
.57078 .53197 L
s
.51184 .5772 m
.4991 .58932 L
s
.48575 .57687 m
.4806 .59311 L
s
.53572 .40965 m
.53108 .426 L
s
.4871 .57949 m
.48324 .59604 L
s
.48993 .58224 m
.48737 .59899 L
s
.51912 .58128 m
.5056 .59271 L
s
.59428 .48461 m
.58348 .49838 L
s
.57686 .4373 m
.56858 .45228 L
s
.54715 .4112 m
.54154 .4272 L
s
.5545 .56368 m
.5408 .57529 L
s
.56789 .55169 m
.5545 .56368 L
s
.59461 .50571 m
.58289 .51894 L
s
.49424 .58491 m
.49297 .60177 L
s
.5809 .53938 m
.56789 .55169 L
s
.59254 .46361 m
.58267 .47783 L
s
.5408 .57529 m
.52682 .58649 L
s
.48828 .58592 m
.47729 .59909 L
s
.48427 .5858 m
.47433 .59965 L
s
.5 .39583 m
.5 .41271 L
s
.5 .58729 m
.5 .60417 L
s
.49328 .58707 m
.48131 .59952 L
s
.55926 .41384 m
.55277 .42946 L
s
.48137 .5866 m
.47256 .60109 L
s
.4991 .58932 m
.48624 .60104 L
s
.50836 .39401 m
.50714 .4108 L
s
.59351 .52677 m
.5809 .53938 L
s
.47973 .5882 m
.47211 .60326 L
s
.52682 .58649 m
.5126 .59724 L
s
.58937 .44285 m
.58046 .45742 L
s
.51795 .39294 m
.51556 .40956 L
s
.47945 .59044 m
.47306 .60598 L
s
.5056 .59271 m
.49192 .60369 L
s
.57187 .4176 m
.5646 .43283 L
s
.52862 .39275 m
.52513 .40913 L
s
.60588 .49231 m
.59461 .50571 L
s
.4806 .59311 m
.47549 .60905 L
s
.56363 .57106 m
.54937 .58214 L
s
.57752 .55955 m
.56363 .57106 L
s
.60465 .47077 m
.59428 .48461 L
s
.54937 .58214 m
.5348 .59276 L
s
.54022 .39356 m
.53572 .40965 L
s
.60567 .51389 m
.59351 .52677 L
s
.48324 .59604 m
.47941 .61228 L
s
.591 .54765 m
.57752 .55955 L
s
.5126 .59724 m
.4982 .6075 L
s
.5348 .59276 m
.51996 .60287 L
s
.5848 .42247 m
.57686 .4373 L
s
.60198 .44941 m
.59254 .46361 L
s
.48737 .59899 m
.48484 .61543 L
s
.55257 .39546 m
.54715 .4112 L
s
.48131 .59952 m
.46928 .61156 L
s
.47729 .59909 m
.46627 .61187 L
s
.48624 .60104 m
.47329 .61231 L
s
.49297 .60177 m
.49172 .61831 L
s
.60403 .53539 m
.591 .54765 L
s
.47433 .59965 m
.46438 .61313 L
s
.49192 .60369 m
.47813 .61419 L
s
.5 .37929 m
.5 .39583 L
s
.5 .60417 m
.5 .62071 L
s
.5655 .39847 m
.55926 .41384 L
s
.47256 .60109 m
.46376 .61521 L
s
.51996 .60287 m
.5049 .61244 L
s
.59789 .42839 m
.58937 .44285 L
s
.61665 .47878 m
.60588 .49231 L
s
.50956 .37756 m
.50836 .39401 L
s
.61732 .5008 m
.60567 .51389 L
s
.47211 .60326 m
.46452 .61795 L
s
.4982 .6075 m
.48364 .61723 L
s
.52028 .37666 m
.51795 .39294 L
s
.61453 .4569 m
.60465 .47077 L
s
.57883 .4026 m
.57187 .4176 L
s
.47306 .60598 m
.46672 .62116 L
s
.61655 .52282 m
.60403 .53539 L
s
.53201 .37671 m
.52862 .39275 L
s
.47549 .60905 m
.47042 .62463 L
s
.5049 .61244 m
.48966 .62144 L
s
.54457 .37782 m
.54022 .39356 L
s
.61097 .43528 m
.60198 .44941 L
s
.47941 .61228 m
.47564 .62815 L
s
.59238 .40783 m
.5848 .42247 L
s
.47329 .61231 m
.4603 .62309 L
s
.46928 .61156 m
.45724 .62313 L
s
.47813 .61419 m
.46427 .62416 L
s
.48484 .61543 m
.48235 .6315 L
s
.46627 .61187 m
.45525 .6242 L
s
.55778 .38004 m
.55257 .39546 L
s
.62843 .48753 m
.61732 .5008 L
s
.48364 .61723 m
.46899 .6264 L
s
.62689 .46518 m
.61665 .47878 L
s
.49172 .61831 m
.4905 .63446 L
s
.46438 .61313 m
.45447 .62618 L
s
.62851 .50996 m
.61655 .52282 L
s
1 0 0 r
.5666 .40144 m
.55106 .39181 L
s
.58175 .41165 m
.5666 .40144 L
s
.55106 .39181 m
.53518 .38282 L
s
.59645 .42243 m
.58175 .41165 L
s
0 0 1 r
.5 .36315 m
.5 .37929 L
s
.5 .62071 m
.5 .63685 L
s
.46376 .61521 m
.45502 .62892 L
s
.57148 .3834 m
.5655 .39847 L
s
.60598 .41409 m
.59789 .42839 L
s
.48966 .62144 m
.4743 .62981 L
s
1 0 0 r
.53518 .38282 m
.51902 .37448 L
s
0 0 1 r
.6239 .44305 m
.61453 .4569 L
s
.51073 .36152 m
.50956 .37756 L
s
.46452 .61795 m
.45699 .63223 L
s
1 0 0 r
.61066 .43372 m
.59645 .42243 L
s
0 0 1 r
.52254 .36079 m
.52028 .37666 L
s
.58546 .38789 m
.57883 .4026 L
s
.46672 .62116 m
.46045 .63592 L
s
1 0 0 r
.51902 .37448 m
.50263 .36685 L
s
0 0 1 r
.53526 .36109 m
.53201 .37671 L
s
.47042 .62463 m
.46543 .63978 L
s
.61946 .42128 m
.61097 .43528 L
s
.63986 .49687 m
.62851 .50996 L
s
1 0 0 r
.62431 .44551 m
.61066 .43372 L
s
0 0 1 r
.63893 .47413 m
.62843 .48753 L
s
.46427 .62416 m
.45038 .63355 L
s
.4603 .62309 m
.4473 .63332 L
s
.54873 .36248 m
.54457 .37782 L
s
.46899 .6264 m
.45429 .63494 L
s
.45724 .62313 m
.44522 .63418 L
s
.47564 .62815 m
.47194 .64358 L
s
.59955 .39345 m
.59238 .40783 L
s
1 0 0 r
.55909 .38289 m
.54278 .37435 L
s
.57502 .39213 m
.55909 .38289 L
s
.59053 .40203 m
.57502 .39213 L
s
0 0 1 r
.63654 .45155 m
.62689 .46518 L
s
.45525 .6242 m
.44428 .63604 L
s
.4743 .62981 m
.45887 .63752 L
s
.48235 .6315 m
.47992 .64711 L
s
1 0 0 r
.54278 .37435 m
.52617 .36654 L
s
0 0 1 r
.56276 .36503 m
.55778 .38004 L
s
1 0 0 r
.50263 .36685 m
.48607 .35994 L
s
.60555 .41256 m
.59053 .40203 L
s
0 0 1 r
.45447 .62618 m
.44462 .63874 L
s
.4905 .63446 m
.48931 .65015 L
s
1 0 0 r
.63735 .45775 m
.62431 .44551 L
s
.52617 .36654 m
.5093 .35949 L
s
0 0 1 r
.6327 .42928 m
.6239 .44305 L
s
.61359 .40001 m
.60598 .41409 L
s
.45502 .62892 m
.44635 .64214 L
s
.57714 .36872 m
.57148 .3834 L
s
.5 .34748 m
.5 .36315 L
s
.5 .63685 m
.5 .65252 L
s
1 0 0 r
.62003 .42369 m
.60555 .41256 L
s
0 0 1 r
.51185 .34596 m
.51073 .36152 L
s
.45699 .63223 m
.44955 .64602 L
s
.65055 .48357 m
.63986 .49687 L
s
1 0 0 r
.48607 .35994 m
.4694 .35381 L
s
.5093 .35949 m
.49223 .35324 L
s
0 0 1 r
.59171 .37353 m
.58546 .38789 L
s
.5247 .34541 m
.52254 .36079 L
s
.64878 .46064 m
.63893 .47413 L
s
.46045 .63592 m
.45428 .6502 L
s
1 0 0 r
.6339 .43537 m
.62003 .42369 L
s
0 0 1 r
.45429 .63494 m
.4396 .64282 L
s
.45038 .63355 m
.43652 .64231 L
s
.62741 .40745 m
.61946 .42128 L
s
1 0 0 r
.56693 .37336 m
.55025 .36519 L
s
.58321 .3823 m
.56693 .37336 L
s
0 0 1 r
.53838 .34595 m
.53526 .36109 L
s
.4473 .63332 m
.43436 .64295 L
s
.45887 .63752 m
.44343 .64452 L
s
1 0 0 r
.64971 .4704 m
.63735 .45775 L
s
.55025 .36519 m
.53322 .35782 L
s
0 0 1 r
.46543 .63978 m
.46054 .65443 L
s
1 0 0 r
.59903 .39197 m
.58321 .3823 L
s
0 0 1 r
.64556 .43794 m
.63654 .45155 L
s
.44522 .63418 m
.43327 .64466 L
s
.60628 .37939 m
.59955 .39345 L
s
.5527 .34762 m
.54873 .36248 L
s
1 0 0 r
.53322 .35782 m
.51592 .35128 L
s
0 0 1 r
.47194 .64358 m
.46832 .65851 L
s
1 0 0 r
.61431 .40235 m
.59903 .39197 L
s
.49223 .35324 m
.47504 .34781 L
s
0 0 1 r
.44428 .63604 m
.4334 .64731 L
s
.47992 .64711 m
.47756 .6622 L
s
1 0 0 r
.64711 .44759 m
.6339 .43537 L
s
0 0 1 r
.56746 .35047 m
.56276 .36503 L
s
1 0 0 r
.4694 .35381 m
.45268 .34848 L
s
0 0 1 r
.44462 .63874 m
.43488 .65075 L
s
1 0 0 r
.51592 .35128 m
.49841 .34561 L
s
.62901 .41341 m
.61431 .40235 L
s
0 0 1 r
.64088 .41563 m
.6327 .42928 L
s
.48931 .65015 m
.48816 .66531 L
s
.62068 .38621 m
.61359 .40001 L
s
.66051 .47013 m
.65055 .48357 L
s
.44635 .64214 m
.4378 .6548 L
s
.58248 .35448 m
.57714 .36872 L
s
.5 .33236 m
.5 .34748 L
s
.5 .65252 m
.5 .66764 L
s
1 0 0 r
.66135 .48342 m
.64971 .4704 L
s
0 0 1 r
.65792 .44711 m
.64878 .46064 L
s
1 0 0 r
.47504 .34781 m
.45778 .34326 L
s
.49841 .34561 m
.48075 .34084 L
s
0 0 1 r
.44955 .64602 m
.44224 .65926 L
s
.51293 .33095 m
.51185 .34596 L
s
.4396 .64282 m
.42497 .64998 L
s
.44343 .64452 m
.42803 .65076 L
s
1 0 0 r
.64305 .42509 m
.62901 .41341 L
s
.55748 .35549 m
.5401 .34848 L
s
.5745 .36337 m
.55748 .35549 L
s
.59108 .37211 m
.5745 .36337 L
s
0 0 1 r
.43652 .64231 m
.42274 .65038 L
s
1 0 0 r
.65958 .46028 m
.64711 .44759 L
s
0 0 1 r
.59755 .35959 m
.59171 .37353 L
s
.52678 .33059 m
.5247 .34541 L
s
1 0 0 r
.5401 .34848 m
.52241 .34237 L
s
0 0 1 r
.45428 .6502 m
.44823 .6639 L
s
1 0 0 r
.60716 .38166 m
.59108 .37211 L
s
0 0 1 r
.43436 .64295 m
.42151 .65192 L
s
.63476 .39386 m
.62741 .40745 L
s
.65387 .42441 m
.64556 .43794 L
s
1 0 0 r
.45268 .34848 m
.43597 .344 L
s
0 0 1 r
.54135 .33136 m
.53838 .34595 L
s
1 0 0 r
.52241 .34237 m
.5045 .33721 L
s
0 0 1 r
.43327 .64466 m
.42144 .65449 L
s
.46054 .65443 m
.45576 .66851 L
s
1 0 0 r
.62267 .39199 m
.60716 .38166 L
s
.48075 .34084 m
.46302 .337 L
s
0 0 1 r
.61252 .36572 m
.60628 .37939 L
s
.55645 .33332 m
.5527 .34762 L
s
1 0 0 r
.65637 .43738 m
.64305 .42509 L
s
0 0 1 r
.46832 .65851 m
.4648 .67284 L
s
.4334 .64731 m
.42266 .65795 L
s
1 0 0 r
.67218 .49678 m
.66135 .48342 L
s
.45778 .34326 m
.44053 .33961 L
s
.5045 .33721 m
.48642 .33302 L
s
0 0 1 r
.66969 .45659 m
.66051 .47013 L
s
1 0 0 r
.63754 .40307 m
.62267 .39199 L
s
0 0 1 r
.47756 .6622 m
.47526 .67668 L
s
.57188 .33646 m
.56746 .35047 L
s
.64838 .40218 m
.64088 .41563 L
s
.43488 .65075 m
.42529 .66213 L
s
1 0 0 r
.67126 .47342 m
.65958 .46028 L
s
0 0 1 r
.48816 .66531 m
.48705 .67984 L
s
.6272 .37276 m
.62068 .38621 L
s
.66628 .43359 m
.65792 .44711 L
s
.4378 .6548 m
.42941 .66684 L
s
.42803 .65076 m
.41274 .6562 L
s
1 0 0 r
.46302 .337 m
.44527 .33413 L
s
0 0 1 r
.58744 .34076 m
.58248 .35448 L
s
1 0 0 r
.56443 .34543 m
.54672 .33868 L
s
.58175 .35313 m
.56443 .34543 L
s
.48642 .33302 m
.46825 .32982 L
s
0 0 1 r
.5 .31787 m
.5 .33236 L
s
.5 .66764 m
.5 .68213 L
s
.42497 .64998 m
.41046 .65636 L
s
1 0 0 r
.54672 .33868 m
.52869 .33292 L
s
.5986 .36176 m
.58175 .35313 L
s
.6517 .41486 m
.63754 .40307 L
s
.66889 .45022 m
.65637 .43738 L
s
.43597 .344 m
.41935 .34042 L
s
0 0 1 r
.42274 .65038 m
.40911 .65771 L
s
.44224 .65926 m
.43509 .67186 L
s
1 0 0 r
.52869 .33292 m
.5104 .32818 L
s
0 0 1 r
.51396 .31658 m
.51293 .33095 L
s
1 0 0 r
.6149 .37128 m
.5986 .36176 L
s
0 0 1 r
.60295 .34614 m
.59755 .35959 L
s
.42151 .65192 m
.40883 .66017 L
s
1 0 0 r
.44053 .33961 m
.42335 .3369 L
s
0 0 1 r
.66143 .41101 m
.65387 .42441 L
s
.52874 .31641 m
.52678 .33059 L
s
.64145 .38057 m
.63476 .39386 L
s
.44823 .6639 m
.44233 .67697 L
s
1 0 0 r
.5104 .32818 m
.49194 .32448 L
s
.68215 .51042 m
.67218 .49678 L
s
.6306 .38166 m
.6149 .37128 L
s
.46825 .32982 m
.45007 .32765 L
s
.68207 .48696 m
.67126 .47342 L
s
0 0 1 r
.42144 .65449 m
.40979 .66361 L
s
.54413 .31743 m
.54135 .33136 L
s
1 0 0 r
.66508 .42733 m
.6517 .41486 L
s
0 0 1 r
.45576 .66851 m
.45112 .68192 L
s
1 0 0 r
.44527 .33413 m
.4276 .33224 L
s
0 0 1 r
.67801 .443 m
.66969 .45659 L
s
.61822 .35251 m
.61252 .36572 L
s
1 0 0 r
.49194 .32448 m
.47338 .32185 L
s
0 0 1 r
.42266 .65795 m
.4121 .66789 L
s
.55994 .31965 m
.55645 .33332 L
s
1 0 0 r
.68055 .46358 m
.66889 .45022 L
s
.6456 .39288 m
.6306 .38166 L
s
0 0 1 r
.4648 .67284 m
.4614 .6865 L
s
.65514 .38898 m
.64838 .40218 L
s
.47526 .67668 m
.47306 .69048 L
s
.42529 .66213 m
.41589 .67281 L
s
.57596 .32307 m
.57188 .33646 L
s
1 0 0 r
.41935 .34042 m
.40289 .33777 L
s
0 0 1 r
.41274 .6562 m
.39763 .66079 L
s
.6738 .42015 m
.66628 .43359 L
s
1 0 0 r
.55304 .32862 m
.53468 .32311 L
s
.57105 .33519 m
.55304 .32862 L
s
.45007 .32765 m
.43196 .32653 L
s
.58864 .34281 m
.57105 .33519 L
s
0 0 1 r
.6331 .35973 m
.6272 .37276 L
s
1 0 0 r
.47338 .32185 m
.45481 .32031 L
s
0 0 1 r
.41046 .65636 m
.39615 .66193 L
s
1 0 0 r
.42335 .3369 m
.40632 .33518 L
s
.53468 .32311 m
.51606 .31869 L
s
0 0 1 r
.48705 .67984 m
.48598 .69366 L
s
1 0 0 r
.67761 .44043 m
.66508 .42733 L
s
.60572 .35143 m
.58864 .34281 L
s
.65984 .40488 m
.6456 .39288 L
s
0 0 1 r
.42941 .66684 m
.42122 .67817 L
s
.59199 .32764 m
.58744 .34076 L
s
1 0 0 r
.51606 .31869 m
.49724 .3154 L
s
0 0 1 r
.40911 .65771 m
.39568 .66424 L
s
.5 .3041 m
.5 .31787 L
s
.5 .68213 m
.5 .6959 L
s
1 0 0 r
.62222 .36103 m
.60572 .35143 L
s
.69118 .52429 m
.68215 .51042 L
s
.69194 .50086 m
.68207 .48696 L
s
.4276 .33224 m
.41008 .33139 L
s
0 0 1 r
.43509 .67186 m
.42813 .68375 L
s
.51493 .30295 m
.51396 .31658 L
s
1 0 0 r
.69128 .47742 m
.68055 .46358 L
s
0 0 1 r
.40883 .66017 m
.39637 .66763 L
s
.66816 .3978 m
.66143 .41101 L
s
1 0 0 r
.49724 .3154 m
.47833 .31325 L
s
.63806 .37158 m
.62222 .36103 L
s
0 0 1 r
.60785 .33327 m
.60295 .34614 L
s
.64744 .36766 m
.64145 .38057 L
s
1 0 0 r
.45481 .32031 m
.4363 .31989 L
s
0 0 1 r
.53057 .30298 m
.52874 .31641 L
s
1 0 0 r
.67324 .41763 m
.65984 .40488 L
s
0 0 1 r
.44233 .67697 m
.43663 .6893 L
s
1 0 0 r
.43196 .32653 m
.41399 .3265 L
s
0 0 1 r
.40979 .66361 m
.39836 .67196 L
s
.68541 .42942 m
.67801 .443 L
s
1 0 0 r
.68921 .45411 m
.67761 .44043 L
s
0 0 1 r
.54672 .30423 m
.54413 .31743 L
s
1 0 0 r
.47833 .31325 m
.45939 .31227 L
s
0 0 1 r
.45112 .68192 m
.44665 .69459 L
s
1 0 0 r
.65316 .38303 m
.63806 .37158 L
s
0 0 1 r
.62334 .33984 m
.61822 .35251 L
s
1 0 0 r
.40289 .33777 m
.38666 .33609 L
s
0 0 1 r
.4121 .66789 m
.40179 .67705 L
s
1 0 0 r
.40632 .33518 m
.38953 .33446 L
s
0 0 1 r
.56317 .30672 m
.55994 .31965 L
s
.4614 .6865 m
.45814 .69939 L
s
.39763 .66079 m
.38278 .66446 L
s
.66111 .3761 m
.65514 .38898 L
s
1 0 0 r
.55902 .31848 m
.54036 .31312 L
s
.57731 .32499 m
.55902 .31848 L
s
.4363 .31989 m
.41794 .32062 L
s
.41008 .33139 m
.39278 .3316 L
s
.54036 .31312 m
.52142 .30894 L
s
0 0 1 r
.68041 .40685 m
.6738 .42015 L
s
1 0 0 r
.59515 .33262 m
.57731 .32499 L
s
.68572 .43109 m
.67324 .41763 L
s
.70079 .51505 m
.69194 .50086 L
s
.45939 .31227 m
.44052 .31247 L
s
0 0 1 r
.41589 .67281 m
.40675 .68271 L
s
1 0 0 r
.52142 .30894 m
.50227 .30596 L
s
0 0 1 r
.39615 .66193 m
.38211 .6666 L
s
.47306 .69048 m
.47096 .70348 L
s
1 0 0 r
.61244 .34134 m
.59515 .33262 L
s
0 0 1 r
.57969 .3104 m
.57596 .32307 L
s
1 0 0 r
.70099 .49167 m
.69128 .47742 L
s
.69919 .53834 m
.69118 .52429 L
s
.66744 .39534 m
.65316 .38303 L
s
0 0 1 r
.63833 .34721 m
.6331 .35973 L
s
1 0 0 r
.41399 .3265 m
.39626 .32759 L
s
.50227 .30596 m
.48302 .3042 L
s
0 0 1 r
.48598 .69366 m
.48498 .70668 L
s
1 0 0 r
.62911 .35113 m
.61244 .34134 L
s
0 0 1 r
.39568 .66424 m
.38253 .6699 L
s
1 0 0 r
.69979 .46834 m
.68921 .45411 L
s
0 0 1 r
.42122 .67817 m
.41328 .68872 L
s
.5961 .31522 m
.59199 .32764 L
s
.5 .29116 m
.5 .3041 L
s
.5 .6959 m
.5 .70884 L
s
1 0 0 r
.48302 .3042 m
.46374 .30368 L
s
.44052 .31247 m
.4218 .31388 L
s
0 0 1 r
.67401 .38487 m
.66816 .3978 L
s
1 0 0 r
.64507 .36193 m
.62911 .35113 L
s
0 0 1 r
.39637 .66763 m
.3842 .67423 L
s
1 0 0 r
.41794 .32062 m
.39982 .32251 L
s
0 0 1 r
.42813 .68375 m
.42142 .69483 L
s
1 0 0 r
.68082 .40848 m
.66744 .39534 L
s
0 0 1 r
.51584 .29015 m
.51493 .30295 L
s
1 0 0 r
.6972 .4452 m
.68572 .43109 L
s
0 0 1 r
.65266 .3552 m
.64744 .36766 L
s
.69181 .41592 m
.68541 .42942 L
s
.6122 .32107 m
.60785 .33327 L
s
1 0 0 r
.38953 .33446 m
.37306 .33481 L
s
.38666 .33609 m
.37076 .33543 L
s
0 0 1 r
.53227 .29038 m
.53057 .30298 L
s
.43663 .6893 m
.43114 .70081 L
s
1 0 0 r
.39278 .3316 m
.37582 .33291 L
s
.46374 .30368 m
.44453 .30443 L
s
0 0 1 r
.39836 .67196 m
.38724 .67945 L
s
1 0 0 r
.66024 .37372 m
.64507 .36193 L
s
.70961 .50628 m
.70099 .49167 L
s
.39626 .32759 m
.37886 .32981 L
s
0 0 1 r
.5491 .29187 m
.54672 .30423 L
s
1 0 0 r
.70855 .52948 m
.70079 .51505 L
s
0 0 1 r
.44665 .69459 m
.44239 .70641 L
s
1 0 0 r
.4218 .31388 m
.40334 .31651 L
s
0 0 1 r
.38278 .66446 m
.36826 .66717 L
s
1 0 0 r
.54571 .30317 m
.52646 .29912 L
s
.56466 .30847 m
.54571 .30317 L
s
0 0 1 r
.62783 .3278 m
.62334 .33984 L
s
1 0 0 r
.58321 .31501 m
.56466 .30847 L
s
.70929 .48305 m
.69979 .46834 L
s
0 0 1 r
.40179 .67705 m
.39179 .68536 L
s
1 0 0 r
.52646 .29912 m
.50699 .29636 L
s
.69322 .42239 m
.68082 .40848 L
s
.60127 .32276 m
.58321 .31501 L
s
.70612 .5525 m
.69919 .53834 L
s
0 0 1 r
.68604 .39376 m
.68041 .40685 L
s
.66621 .36362 m
.66111 .3761 L
s
1 0 0 r
.44453 .30443 m
.42549 .30644 L
s
0 0 1 r
.56608 .29461 m
.56317 .30672 L
s
.45814 .69939 m
.45505 .7114 L
s
1 0 0 r
.50699 .29636 m
.48741 .2949 L
s
.39982 .32251 m
.38204 .32559 L
s
.67452 .38645 m
.66024 .37372 L
s
0 0 1 r
.38211 .6666 m
.36842 .67033 L
s
1 0 0 r
.61876 .33169 m
.60127 .32276 L
s
.7076 .45992 m
.6972 .4452 L
s
0 0 1 r
.40675 .68271 m
.3979 .69175 L
s
1 0 0 r
.48741 .2949 m
.4678 .29476 L
s
0 0 1 r
.47096 .70348 m
.46898 .71559 L
s
.58302 .29855 m
.57969 .3104 L
s
1 0 0 r
.63557 .34175 m
.61876 .33169 L
s
0 0 1 r
.64282 .33527 m
.63833 .34721 L
s
.38253 .6699 m
.36974 .67462 L
s
.48498 .70668 m
.48403 .71879 L
s
1 0 0 r
.40334 .31651 m
.38522 .32038 L
s
.42549 .30644 m
.40671 .30973 L
s
0 0 1 r
.41328 .68872 m
.40564 .69838 L
s
1 0 0 r
.4678 .29476 m
.44828 .29595 L
s
.37582 .33291 m
.35926 .33534 L
s
.68784 .40007 m
.67452 .38645 L
s
.70454 .43703 m
.69322 .42239 L
s
0 0 1 r
.59971 .30359 m
.5961 .31522 L
s
1 0 0 r
.37306 .33481 m
.357 .33624 L
s
.65163 .35292 m
.63557 .34175 L
s
0 0 1 r
.6789 .37228 m
.67401 .38487 L
s
.5 .27914 m
.5 .29116 L
s
.5 .70884 m
.5 .72086 L
s
1 0 0 r
.37886 .32981 m
.36188 .33319 L
s
0 0 1 r
.3842 .67423 m
.37239 .6799 L
s
1 0 0 r
.37076 .33543 m
.35528 .33584 L
s
0 0 1 r
.69715 .40257 m
.69181 .41592 L
s
1 0 0 r
.71706 .5212 m
.70961 .50628 L
s
.71763 .49819 m
.70929 .48305 L
s
0 0 1 r
.42142 .69483 m
.41499 .70501 L
s
.65704 .34328 m
.65266 .3552 L
s
.51667 .2783 m
.51584 .29015 L
s
1 0 0 r
.44828 .29595 m
.42892 .29848 L
s
.38204 .32559 m
.3647 .32987 L
s
.71514 .54409 m
.70855 .52948 L
s
0 0 1 r
.61597 .30962 m
.6122 .32107 L
s
1 0 0 r
.66683 .36514 m
.65163 .35292 L
s
.71685 .47518 m
.7076 .45992 L
s
.40671 .30973 m
.38829 .31432 L
s
0 0 1 r
.38724 .67945 m
.37649 .686 L
s
.53382 .27873 m
.53227 .29038 L
s
.43114 .70081 m
.42592 .71139 L
s
1 0 0 r
.55073 .29345 m
.53117 .28944 L
s
.56996 .2988 m
.55073 .29345 L
s
.71188 .56671 m
.70612 .5525 L
s
.70011 .41452 m
.68784 .40007 L
s
0 0 1 r
.36826 .66717 m
.35417 .66886 L
s
1 0 0 r
.53117 .28944 m
.5114 .2868 L
s
.58876 .30548 m
.56996 .2988 L
s
.38522 .32038 m
.36756 .32549 L
s
.5114 .2868 m
.49149 .28554 L
s
.42892 .29848 m
.40984 .30235 L
s
.60704 .31344 m
.58876 .30548 L
s
0 0 1 r
.55123 .28045 m
.5491 .29187 L
s
1 0 0 r
.71472 .45233 m
.70454 .43703 L
s
0 0 1 r
.69062 .38096 m
.68604 .39376 L
s
.44239 .70641 m
.43835 .71728 L
s
.63162 .31649 m
.62783 .3278 L
s
1 0 0 r
.68109 .37837 m
.66683 .36514 L
s
.49149 .28554 m
.47156 .28568 L
s
0 0 1 r
.39179 .68536 m
.38215 .69272 L
s
.67039 .35163 m
.66621 .36362 L
s
1 0 0 r
.62469 .32267 m
.60704 .31344 L
s
0 0 1 r
.36842 .67033 m
.35515 .67305 L
s
.56866 .28343 m
.56608 .29461 L
s
.45505 .7114 m
.45214 .72244 L
s
1 0 0 r
.47156 .28568 m
.45172 .28723 L
s
.36188 .33319 m
.34543 .33775 L
s
.35926 .33534 m
.34323 .33892 L
s
.38829 .31432 m
.37034 .32019 L
s
.64163 .33311 m
.62469 .32267 L
s
0 0 1 r
.3979 .69175 m
.38943 .69982 L
s
1 0 0 r
.40984 .30235 m
.39115 .30758 L
s
.3647 .32987 m
.34789 .33536 L
s
.357 .33624 m
.34146 .3388 L
s
.71124 .42976 m
.70011 .41452 L
s
.72471 .51369 m
.71763 .49819 L
s
0 0 1 r
.46898 .71559 m
.46714 .7267 L
s
.36974 .67462 m
.35739 .67834 L
s
.58592 .28761 m
.58302 .29855 L
s
.64651 .32401 m
.64282 .33527 L
s
1 0 0 r
.72325 .53636 m
.71706 .5212 L
s
.69432 .39256 m
.68109 .37837 L
s
.45172 .28723 m
.43206 .2902 L
s
.72484 .49093 m
.71685 .47518 L
s
.35528 .33584 m
.34031 .33735 L
s
.65776 .34472 m
.64163 .33311 L
s
.36756 .32549 m
.35044 .33185 L
s
0 0 1 r
.48403 .71879 m
.48316 .72987 L
s
1 0 0 r
.72048 .55881 m
.71514 .54409 L
s
0 0 1 r
.40564 .69838 m
.39835 .70706 L
s
.68275 .36012 m
.6789 .37228 L
s
.70134 .38945 m
.69715 .40257 L
s
1 0 0 r
.72365 .46823 m
.71472 .45233 L
s
0 0 1 r
.60279 .29286 m
.59971 .30359 L
s
1 0 0 r
.43206 .2902 m
.41269 .29457 L
s
0 0 1 r
.37239 .6799 m
.36103 .68456 L
s
.5 .26817 m
.5 .27914 L
s
.5 .72086 m
.5 .73183 L
s
1 0 0 r
.39115 .30758 m
.37294 .31414 L
s
.67297 .35747 m
.65776 .34472 L
s
.37034 .32019 m
.35296 .32736 L
s
0 0 1 r
.66053 .33199 m
.65704 .34328 L
s
.41499 .70501 m
.4089 .71419 L
s
1 0 0 r
.70643 .40764 m
.69432 .39256 L
s
.71639 .58089 m
.71188 .56671 L
s
0 0 1 r
.51742 .26749 m
.51667 .2783 L
s
1 0 0 r
.72115 .44572 m
.71124 .42976 L
s
.53558 .2801 m
.51549 .27749 L
s
.55544 .28417 m
.53558 .2801 L
s
.57494 .28967 m
.55544 .28417 L
s
0 0 1 r
.61909 .29904 m
.61597 .30962 L
s
1 0 0 r
.51549 .27749 m
.49526 .27634 L
s
0 0 1 r
.35417 .66886 m
.3406 .66946 L
s
1 0 0 r
.41269 .29457 m
.39373 .30035 L
s
0 0 1 r
.37649 .686 m
.36619 .69154 L
s
1 0 0 r
.59399 .29658 m
.57494 .28967 L
s
.49526 .27634 m
.47501 .27667 L
s
0 0 1 r
.5352 .26813 m
.53382 .27873 L
s
.42592 .71139 m
.42101 .72094 L
s
1 0 0 r
.61247 .30486 m
.59399 .29658 L
s
.34543 .33775 m
.32961 .34352 L
s
.68718 .37128 m
.67297 .35747 L
s
.34789 .33536 m
.33172 .34208 L
s
.47501 .27667 m
.45484 .27849 L
s
0 0 1 r
.69407 .36852 m
.69062 .38096 L
s
1 0 0 r
.34323 .33892 m
.32783 .34368 L
s
.7315 .50709 m
.72484 .49093 L
s
.35044 .33185 m
.33399 .33947 L
s
.73045 .52947 m
.72471 .51369 L
s
.37294 .31414 m
.35533 .32204 L
s
.63028 .31447 m
.61247 .30486 L
s
0 0 1 r
.55309 .27009 m
.55123 .28045 L
s
.35515 .67305 m
.34242 .67469 L
s
.63466 .306 m
.63162 .31649 L
s
.43835 .71728 m
.43458 .72708 L
s
.38215 .69272 m
.37296 .69905 L
s
1 0 0 r
.73127 .48466 m
.72365 .46823 L
s
0 0 1 r
.67355 .34021 m
.67039 .35163 L
s
1 0 0 r
.45484 .27849 m
.43488 .2818 L
s
.34146 .3388 m
.32655 .34252 L
s
.71732 .42355 m
.70643 .40764 L
s
.39373 .30035 m
.37529 .30752 L
s
.72811 .55168 m
.72325 .53636 L
s
.64733 .32537 m
.63028 .31447 L
s
.35296 .32736 m
.33627 .33581 L
s
.70028 .3861 m
.68718 .37128 L
s
0 0 1 r
.57088 .27331 m
.56866 .28343 L
s
.45214 .72244 m
.44945 .73239 L
s
1 0 0 r
.72974 .46232 m
.72115 .44572 L
s
.43488 .2818 m
.41523 .28658 L
s
.34031 .33735 m
.32597 .34001 L
s
.72448 .57356 m
.72048 .55881 L
s
0 0 1 r
.35739 .67834 m
.34557 .68097 L
s
.38943 .69982 m
.38139 .70684 L
s
1 0 0 r
.6635 .33752 m
.64733 .32537 L
s
0 0 1 r
.64935 .31353 m
.64651 .32401 L
s
.46714 .7267 m
.46545 .73668 L
s
.58834 .2777 m
.58592 .28761 L
s
1 0 0 r
.35533 .32204 m
.33844 .33125 L
s
.37529 .30752 m
.35746 .31607 L
s
.41523 .28658 m
.396 .29283 L
s
0 0 1 r
.70429 .37663 m
.70134 .38945 L
s
.6855 .34847 m
.68275 .36012 L
s
1 0 0 r
.72692 .44022 m
.71732 .42355 L
s
.71219 .40186 m
.70028 .3861 L
s
0 0 1 r
.48316 .72987 m
.48238 .7398 L
s
1 0 0 r
.67869 .35085 m
.6635 .33752 L
s
0 0 1 r
.39835 .70706 m
.39149 .71466 L
s
1 0 0 r
.33172 .34208 m
.31632 .35003 L
s
.33399 .33947 m
.31832 .34834 L
s
.71957 .59497 m
.71639 .58089 L
s
0 0 1 r
.36103 .68456 m
.3502 .68813 L
s
.60528 .28312 m
.60279 .29286 L
s
1 0 0 r
.32961 .34352 m
.31455 .35049 L
s
.73675 .52358 m
.7315 .50709 L
s
.73747 .50154 m
.73127 .48466 L
s
.396 .29283 m
.37732 .30053 L
s
0 0 1 r
.5 .25836 m
.5 .26817 L
s
.5 .73183 m
.5 .74164 L
s
1 0 0 r
.33627 .33581 m
.32038 .34553 L
s
.53972 .27133 m
.51931 .26864 L
s
.55988 .27555 m
.53972 .27133 L
s
.51931 .26864 m
.49875 .26751 L
s
.57965 .28129 m
.55988 .27555 L
s
.73478 .54547 m
.73045 .52947 L
s
0 0 1 r
.66304 .32143 m
.66053 .33199 L
s
1 0 0 r
.49875 .26751 m
.47816 .26794 L
s
.32783 .34368 m
.31316 .34964 L
s
0 0 1 r
.3406 .66946 m
.32767 .66893 L
s
1 0 0 r
.35746 .31607 m
.34038 .32597 L
s
0 0 1 r
.4089 .71419 m
.4032 .72224 L
s
1 0 0 r
.69281 .3653 m
.67869 .35085 L
s
.59893 .28851 m
.57965 .28129 L
s
.73693 .47949 m
.72974 .46232 L
s
.47816 .26794 m
.45767 .26994 L
s
0 0 1 r
.51808 .25786 m
.51742 .26749 L
s
1 0 0 r
.61761 .29718 m
.59893 .28851 L
s
0 0 1 r
.62152 .28943 m
.61909 .29904 L
s
1 0 0 r
.33844 .33125 m
.32236 .34176 L
s
0 0 1 r
.36619 .69154 m
.35642 .69597 L
s
1 0 0 r
.72282 .4185 m
.71219 .40186 L
s
.73154 .56708 m
.72811 .55168 L
s
.45767 .26994 m
.43738 .27349 L
s
.37732 .30053 m
.35929 .30965 L
s
.32655 .34252 m
.31237 .34744 L
s
0 0 1 r
.69631 .35655 m
.69407 .36852 L
s
1 0 0 r
.63557 .30726 m
.61761 .29718 L
s
0 0 1 r
.53638 .25872 m
.5352 .26813 L
s
.42101 .72094 m
.41645 .72934 L
s
1 0 0 r
.73513 .45757 m
.72692 .44022 L
s
.43738 .27349 m
.41743 .2786 L
s
.70576 .38081 m
.69281 .3653 L
s
0 0 1 r
.34242 .67469 m
.33032 .67519 L
s
1 0 0 r
.6527 .3187 m
.63557 .30726 L
s
0 0 1 r
.67564 .32948 m
.67355 .34021 L
s
.55466 .26091 m
.55309 .27009 L
s
.37296 .69905 m
.3643 .70424 L
s
1 0 0 r
.34038 .32597 m
.32416 .3372 L
s
0 0 1 r
.63689 .29644 m
.63466 .306 L
s
1 0 0 r
.72705 .58825 m
.72448 .57356 L
s
.41743 .2786 m
.39793 .28524 L
s
0 0 1 r
.43458 .72708 m
.43111 .7357 L
s
1 0 0 r
.32597 .34001 m
.31236 .34386 L
s
.31832 .34834 m
.30355 .35844 L
s
.35929 .30965 m
.34204 .32017 L
s
.32038 .34553 m
.3054 .3565 L
s
.66889 .33144 m
.6527 .3187 L
s
.31632 .35003 m
.3018 .3592 L
s
.73207 .43592 m
.72282 .4185 L
s
.74219 .5188 m
.73747 .50154 L
s
0 0 1 r
.57268 .26435 m
.57088 .27331 L
s
1 0 0 r
.39793 .28524 m
.37901 .29338 L
s
.71744 .3973 m
.70576 .38081 L
s
.74264 .49715 m
.73693 .47949 L
s
0 0 1 r
.44945 .73239 m
.447 .74112 L
s
1 0 0 r
.32236 .34176 m
.30723 .35354 L
s
0 0 1 r
.34557 .68097 m
.33439 .68245 L
s
1 0 0 r
.74051 .54032 m
.73675 .52358 L
s
.31455 .35049 m
.30035 .35869 L
s
0 0 1 r
.38139 .70684 m
.37386 .7127 L
s
1 0 0 r
.68403 .34541 m
.66889 .33144 L
s
0 0 1 r
.70594 .36422 m
.70429 .37663 L
s
.65126 .30393 m
.64935 .31353 L
s
1 0 0 r
.74186 .47552 m
.73513 .45757 L
s
.7376 .56159 m
.73478 .54547 L
s
0 0 1 r
.46545 .73668 m
.46393 .74542 L
s
.59024 .26894 m
.58834 .2777 L
s
1 0 0 r
.72133 .60884 m
.71957 .59497 L
s
.34204 .32017 m
.32567 .33203 L
s
.37901 .29338 m
.36077 .30299 L
s
0 0 1 r
.68706 .33745 m
.6855 .34847 L
s
1 0 0 r
.32416 .3372 m
.3089 .3497 L
s
.31316 .34964 m
.29936 .35682 L
s
.69803 .36055 m
.68403 .34541 L
s
0 0 1 r
.48238 .7398 m
.48168 .74846 L
s
1 0 0 r
.72776 .41468 m
.71744 .3973 L
s
0 0 1 r
.3502 .68813 m
.34001 .69053 L
s
.39149 .71466 m
.3851 .72106 L
s
1 0 0 r
.5229 .26047 m
.50199 .25927 L
s
.54364 .26332 m
.5229 .26047 L
s
.5641 .26778 m
.54364 .26332 L
s
.50199 .25927 m
.48106 .25971 L
s
.73986 .45404 m
.73207 .43592 L
s
.58415 .27383 m
.5641 .26778 L
s
.48106 .25971 m
.46022 .26179 L
s
.73347 .58247 m
.73154 .56708 L
s
0 0 1 r
.60713 .27452 m
.60528 .28312 L
s
1 0 0 r
.36077 .30299 m
.34335 .31404 L
s
.60366 .28145 m
.58415 .27383 L
s
0 0 1 r
.32767 .66893 m
.31547 .6672 L
s
1 0 0 r
.46022 .26179 m
.4396 .26551 L
s
0 0 1 r
.5 .24984 m
.5 .25836 L
s
.5 .74164 m
.5 .75016 L
s
1 0 0 r
.3054 .3565 m
.29146 .3687 L
s
0 0 1 r
.66452 .3117 m
.66304 .32143 L
s
1 0 0 r
.31237 .34744 m
.29905 .35356 L
s
.62252 .29059 m
.60366 .28145 L
s
.32567 .33203 m
.31032 .34519 L
s
.30723 .35354 m
.29316 .36654 L
s
.4396 .26551 m
.41934 .27085 L
s
.30355 .35844 m
.28979 .36976 L
s
.71079 .37677 m
.69803 .36055 L
s
0 0 1 r
.4032 .72224 m
.39795 .72907 L
s
1 0 0 r
.6406 .3012 m
.62252 .29059 L
s
.74679 .51519 m
.74264 .49715 L
s
0 0 1 r
.51864 .24954 m
.51808 .25786 L
s
1 0 0 r
.74533 .53632 m
.74219 .5188 L
s
.41934 .27085 m
.39955 .27779 L
s
0 0 1 r
.35642 .69597 m
.34727 .6992 L
s
1 0 0 r
.74705 .49396 m
.74186 .47552 L
s
0 0 1 r
.62319 .28091 m
.62152 .28943 L
s
1 0 0 r
.3018 .3592 m
.28829 .36959 L
s
.3089 .3497 m
.29474 .36344 L
s
0 0 1 r
.69726 .34514 m
.69631 .35655 L
s
1 0 0 r
.34335 .31404 m
.32686 .32646 L
s
.73663 .43286 m
.72776 .41468 L
s
.65779 .31322 m
.6406 .3012 L
s
.72813 .60279 m
.72705 .58825 L
s
.39955 .27779 m
.38036 .28629 L
s
.74268 .55722 m
.74051 .54032 L
s
0 0 1 r
.33032 .67519 m
.31896 .67447 L
s
.53736 .25062 m
.53638 .25872 L
s
.41645 .72934 m
.41229 .73647 L
s
1 0 0 r
.31236 .34386 m
.29961 .34893 L
s
.7222 .39399 m
.71079 .37677 L
s
.74611 .47277 m
.73986 .45404 L
s
.67397 .32659 m
.65779 .31322 L
s
.30035 .35869 m
.28714 .3681 L
s
0 0 1 r
.67658 .31952 m
.67564 .32948 L
s
1 0 0 r
.31032 .34519 m
.29608 .35959 L
s
.38036 .28629 m
.36191 .29631 L
s
.32686 .32646 m
.31141 .3402 L
s
0 0 1 r
.3643 .70424 m
.35624 .70821 L
s
.55591 .25304 m
.55466 .26091 L
s
.63824 .28793 m
.63689 .29644 L
s
1 0 0 r
.73884 .57774 m
.7376 .56159 L
s
0 0 1 r
.43111 .7357 m
.42798 .74301 L
s
1 0 0 r
.68904 .34124 m
.67397 .32659 L
s
.74397 .45175 m
.73663 .43286 L
s
.36191 .29631 m
.34431 .30781 L
s
.29316 .36654 m
.28026 .38071 L
s
.73218 .41212 m
.7222 .39399 L
s
0 0 1 r
.33439 .68245 m
.32394 .6827 L
s
1 0 0 r
.29146 .3687 m
.27868 .38207 L
s
.29936 .35682 m
.28655 .36522 L
s
.29474 .36344 m
.28177 .37835 L
s
0 0 1 r
.57405 .2567 m
.57268 .26435 L
s
1 0 0 r
.72159 .62242 m
.72133 .60884 L
s
0 0 1 r
.7062 .35232 m
.70594 .36422 L
s
1 0 0 r
.70289 .35708 m
.68904 .34124 L
s
0 0 1 r
.447 .74112 m
.44483 .74851 L
s
1 0 0 r
.7506 .5128 m
.74705 .49396 L
s
.31141 .3402 m
.29712 .35519 L
s
.7493 .53352 m
.74679 .51519 L
s
0 0 1 r
.37386 .7127 m
.36692 .71729 L
s
1 0 0 r
.28979 .36976 m
.27717 .38227 L
s
.34431 .30781 m
.32767 .32071 L
s
.29608 .35959 m
.28308 .37517 L
s
.73381 .59775 m
.73347 .58247 L
s
.75074 .49199 m
.74611 .47277 L
s
0 0 1 r
.65218 .29534 m
.65126 .30393 L
s
.68736 .32716 m
.68706 .33745 L
s
1 0 0 r
.74683 .55402 m
.74533 .53632 L
s
0 0 1 r
.46393 .74542 m
.46261 .75278 L
s
.59158 .26146 m
.59024 .26894 L
s
1 0 0 r
.71541 .37402 m
.70289 .35708 L
s
.52633 .25318 m
.50507 .25181 L
s
.54741 .25625 m
.52633 .25318 L
s
.50507 .25181 m
.48377 .25218 L
s
.74064 .43105 m
.73218 .41212 L
s
.56817 .26103 m
.54741 .25625 L
s
.48377 .25218 m
.46256 .25426 L
s
.58849 .26747 m
.56817 .26103 L
s
.46256 .25426 m
.44159 .25807 L
s
.29905 .35356 m
.28672 .36093 L
s
.28829 .36959 m
.2759 .38118 L
s
.32767 .32071 m
.31213 .33495 L
s
.7497 .47123 m
.74397 .45175 L
s
0 0 1 r
.34001 .69053 m
.33055 .69167 L
s
1 0 0 r
.60822 .27554 m
.58849 .26747 L
s
.44159 .25807 m
.42098 .26356 L
s
0 0 1 r
.31547 .6672 m
.30413 .66422 L
s
.3851 .72106 m
.37927 .72616 L
s
.48168 .74846 m
.48108 .75572 L
s
1 0 0 r
.62725 .2852 m
.60822 .27554 L
s
.29712 .35519 m
.2841 .37136 L
s
.42098 .26356 m
.40088 .27071 L
s
.7432 .57417 m
.74268 .55722 L
s
.72652 .39196 m
.71541 .37402 L
s
0 0 1 r
.6083 .26716 m
.60713 .27452 L
s
1 0 0 r
.64543 .29639 m
.62725 .2852 L
s
.40088 .27071 m
.38142 .27949 L
s
.28177 .37835 m
.27013 .39437 L
s
.28026 .38071 m
.26867 .39601 L
s
0 0 1 r
.66488 .30293 m
.66452 .3117 L
s
1 0 0 r
.31213 .33495 m
.29779 .35045 L
s
0 0 1 r
.5 .24276 m
.5 .24984 L
s
.5 .75016 m
.5 .75724 L
s
1 0 0 r
.72762 .61708 m
.72813 .60279 L
s
.66266 .30903 m
.64543 .29639 L
s
.28308 .37517 m
.27143 .39184 L
s
.7475 .45067 m
.74064 .43105 L
s
.38142 .27949 m
.36272 .28984 L
s
.28714 .3681 m
.27506 .37873 L
s
0 0 1 r
.39795 .72907 m
.39321 .73455 L
s
1 0 0 r
.27868 .38207 m
.26718 .39658 L
s
0 0 1 r
.69684 .33439 m
.69726 .34514 L
s
1 0 0 r
.6788 .32305 m
.66266 .30903 L
s
.75368 .51159 m
.75074 .49199 L
s
.75246 .53192 m
.7506 .5128 L
s
.29961 .34893 m
.28784 .35525 L
s
.73612 .4108 m
.72652 .39196 L
s
0 0 1 r
.34727 .6992 m
.33885 .70114 L
s
1 0 0 r
.36272 .28984 m
.34491 .3017 L
s
0 0 1 r
.5191 .24266 m
.51864 .24954 L
s
1 0 0 r
.73841 .59381 m
.73884 .57774 L
s
.2841 .37136 m
.27246 .38861 L
s
0 0 1 r
.62405 .27361 m
.62319 .28091 L
s
1 0 0 r
.75375 .4912 m
.7497 .47123 L
s
0 0 1 r
.31896 .67447 m
.30845 .67249 L
s
1 0 0 r
.29779 .35045 m
.28476 .36713 L
s
.7501 .55202 m
.7493 .53352 L
s
.69376 .33838 m
.6788 .32305 L
s
.34491 .3017 m
.32813 .31501 L
s
.27717 .38227 m
.26582 .39593 L
s
0 0 1 r
.53811 .24397 m
.53736 .25062 L
s
.41229 .73647 m
.40859 .7422 L
s
1 0 0 r
.70741 .35491 m
.69376 .33838 L
s
.75269 .47086 m
.7475 .45067 L
s
.74414 .43043 m
.73612 .4108 L
s
.28655 .36522 m
.27486 .37485 L
s
0 0 1 r
.67628 .31046 m
.67658 .31952 L
s
1 0 0 r
.32813 .31501 m
.31248 .32967 L
s
.7466 .57178 m
.74683 .55402 L
s
.27143 .39184 m
.26122 .40952 L
s
.28476 .36713 m
.27314 .38489 L
s
.27013 .39437 m
.25991 .41142 L
s
0 0 1 r
.35624 .70821 m
.34889 .71084 L
s
1 0 0 r
.71967 .37254 m
.70741 .35491 L
s
0 0 1 r
.63866 .28059 m
.63824 .28793 L
s
1 0 0 r
.72027 .6356 m
.72159 .62242 L
s
0 0 1 r
.55681 .24661 m
.55591 .25304 L
s
1 0 0 r
.31248 .32967 m
.29807 .34561 L
s
.27246 .38861 m
.26229 .40684 L
s
.73249 .61281 m
.73381 .59775 L
s
0 0 1 r
.42798 .74301 m
.42525 .74889 L
s
.70498 .34102 m
.7062 .35232 L
s
1 0 0 r
.26867 .39601 m
.25848 .41236 L
s
.2759 .38118 m
.26477 .39394 L
s
0 0 1 r
.32394 .6827 m
.31435 .68165 L
s
1 0 0 r
.75049 .45071 m
.74414 .43043 L
s
.75606 .51151 m
.75375 .4912 L
s
.75486 .53146 m
.75368 .51159 L
s
.73043 .39116 m
.71967 .37254 L
s
.29807 .34561 m
.28503 .36272 L
s
.74199 .59105 m
.7432 .57417 L
s
0 0 1 r
.57495 .25047 m
.57405 .2567 L
s
1 0 0 r
.75614 .49149 m
.75269 .47086 L
s
.27314 .38489 m
.26304 .40361 L
s
.75254 .5512 m
.75246 .53192 L
s
0 0 1 r
.44483 .74851 m
.44296 .75441 L
s
1 0 0 r
.28672 .36093 m
.2755 .36954 L
s
.26718 .39658 m
.25707 .41216 L
s
.50805 .24534 m
.48637 .24556 L
s
.52968 .24693 m
.50805 .24534 L
s
0 0 1 r
.36692 .71729 m
.36065 .7205 L
s
1 0 0 r
.55111 .25031 m
.52968 .24693 L
s
.48637 .24556 m
.46477 .24757 L
s
.73962 .41066 m
.73043 .39116 L
s
.57218 .25546 m
.55111 .25031 L
s
.46477 .24757 m
.44341 .25137 L
s
0 0 1 r
.68632 .3177 m
.68736 .32716 L
s
1 0 0 r
.59276 .26234 m
.57218 .25546 L
s
.44341 .25137 m
.42244 .25694 L
s
0 0 1 r
.65203 .28787 m
.65218 .29534 L
s
1 0 0 r
.28503 .36272 m
.27344 .3809 L
s
.6127 .27092 m
.59276 .26234 L
s
.42244 .25694 m
.40199 .26423 L
s
.75511 .47152 m
.75049 .45071 L
s
.63186 .28113 m
.6127 .27092 L
s
.26229 .40684 m
.2537 .42596 L
s
.40199 .26423 m
.38222 .27321 L
s
.26122 .40952 m
.25257 .42811 L
s
.74912 .57058 m
.7501 .55202 L
s
0 0 1 r
.59232 .25539 m
.59158 .26146 L
s
1 0 0 r
.65012 .29291 m
.63186 .28113 L
s
0 0 1 r
.46261 .75278 m
.4615 .75863 L
s
1 0 0 r
.27506 .37873 m
.26424 .39054 L
s
.38222 .27321 m
.36325 .2838 L
s
0 0 1 r
.30413 .66422 m
.29378 .65994 L
s
1 0 0 r
.74715 .43089 m
.73962 .41066 L
s
.66735 .30618 m
.65012 .29291 L
s
.36325 .2838 m
.34521 .29595 L
s
.26304 .40361 m
.25453 .42318 L
s
0 0 1 r
.33055 .69167 m
.32193 .69147 L
s
1 0 0 r
.25991 .41142 m
.25123 .4294 L
s
.27344 .3809 m
.2634 .40004 L
s
.72545 .63101 m
.72762 .61708 L
s
.68342 .32085 m
.66735 .30618 L
s
.34521 .29595 m
.32824 .30958 L
s
.73626 .60969 m
.73841 .59381 L
s
.26582 .39593 m
.25586 .41068 L
s
.75781 .51243 m
.75614 .49149 L
s
.75657 .53205 m
.75606 .51151 L
s
0 0 1 r
.37927 .72616 m
.37407 .72982 L
s
1 0 0 r
.69822 .33683 m
.68342 .32085 L
s
0 0 1 r
.48108 .75572 m
.4806 .76143 L
s
1 0 0 r
.32824 .30958 m
.31246 .32459 L
s
.75296 .45174 m
.74715 .43089 L
s
.75795 .49272 m
.75511 .47152 L
s
.71164 .35401 m
.69822 .33683 L
s
.31246 .32459 m
.29798 .34089 L
s
.75423 .55146 m
.75486 .53146 L
s
0 0 1 r
.60874 .26118 m
.6083 .26716 L
s
1 0 0 r
.28784 .35525 m
.2772 .36284 L
s
.7446 .58948 m
.7466 .57178 L
s
.2634 .40004 m
.25498 .41999 L
s
.25848 .41236 m
.24982 .42967 L
s
0 0 1 r
.66406 .29523 m
.66488 .30293 L
s
1 0 0 r
.72358 .37227 m
.71164 .35401 L
s
.29798 .34089 m
.2849 .35836 L
s
.2537 .42596 m
.24677 .44584 L
s
.25453 .42318 m
.2477 .44349 L
s
0 0 1 r
.69497 .32443 m
.69684 .33439 L
s
.5 .23724 m
.5 .24276 L
s
.5 .75724 m
.5 .76276 L
s
1 0 0 r
.73395 .3915 m
.72358 .37227 L
s
.757 .47306 m
.75296 .45174 L
s
.2849 .35836 m
.27333 .3769 L
s
.27486 .37485 m
.26442 .38569 L
s
.25257 .42811 m
.24557 .44749 L
s
.75081 .57051 m
.75254 .5512 L
s
0 0 1 r
.39321 .73455 m
.38904 .73854 L
s
.33885 .70114 m
.33125 .70169 L
s
1 0 0 r
.25498 .41999 m
.24828 .44064 L
s
0 0 1 r
.30845 .67249 m
.29893 .66917 L
s
1 0 0 r
.74269 .41155 m
.73395 .3915 L
s
.27333 .3769 m
.26334 .39636 L
s
.26477 .39394 m
.25504 .40783 L
s
0 0 1 r
.51943 .23737 m
.5191 .24266 L
s
1 0 0 r
.75897 .51417 m
.75795 .49272 L
s
.75764 .53354 m
.75781 .51243 L
s
0 0 1 r
.62404 .26765 m
.62405 .27361 L
s
1 0 0 r
.7497 .4323 m
.74269 .41155 L
s
.25707 .41216 m
.24849 .42874 L
s
.26334 .39636 m
.25503 .41662 L
s
.75922 .49471 m
.757 .47306 L
s
.72944 .62754 m
.73249 .61281 L
s
.2477 .44349 m
.24263 .46439 L
s
.73899 .60775 m
.74199 .59105 L
s
.75523 .55267 m
.75657 .53205 L
s
.25123 .4294 m
.24419 .44823 L
s
.24828 .44064 m
.24334 .46185 L
s
.7173 .64826 m
.72027 .6356 L
s
.75495 .45359 m
.7497 .4323 L
s
.25503 .41662 m
.24844 .43755 L
s
0 0 1 r
.67469 .30241 m
.67628 .31046 L
s
.53862 .23891 m
.53811 .24397 L
s
.40859 .7422 m
.4054 .7464 L
s
1 0 0 r
.74631 .58907 m
.74912 .57058 L
s
.24677 .44584 m
.24159 .46636 L
s
.75838 .47528 m
.75495 .45359 L
s
.24844 .43755 m
.24365 .45898 L
s
.75958 .51653 m
.75922 .49471 L
s
.75813 .53572 m
.75897 .51417 L
s
.75176 .57144 m
.75423 .55146 L
s
0 0 1 r
.34889 .71084 m
.34233 .71204 L
s
.70222 .33046 m
.70498 .34102 L
s
1 0 0 r
.24334 .46185 m
.24022 .48346 L
s
0 0 1 r
.63808 .27455 m
.63866 .28059 L
s
1 0 0 r
.75996 .49722 m
.75838 .47528 L
s
.24365 .45898 m
.24068 .48078 L
s
.2755 .36954 m
.26555 .3794 L
s
0 0 1 r
.55733 .24177 m
.55681 .24661 L
s
.31435 .68165 m
.30573 .67922 L
s
1 0 0 r
.24557 .44749 m
.2403 .46756 L
s
.7556 .55466 m
.75764 .53354 L
s
.24263 .46439 m
.23937 .48574 L
s
0 0 1 r
.42525 .74889 m
.42294 .75318 L
s
1 0 0 r
.24982 .42967 m
.2428 .44786 L
s
.26424 .39054 m
.25481 .40352 L
s
.25586 .41068 m
.24743 .42648 L
s
.75967 .51925 m
.75996 .49722 L
s
.24068 .48078 m
.23958 .50279 L
s
.75807 .53836 m
.75958 .51653 L
s
.76021 .5 m
.75927 .47793 L
s
.75927 .52207 m
.76021 .5 L
s
.75647 .54398 m
.75927 .52207 L
s
.75927 .47793 m
.75647 .45602 L
s
.75181 .56557 m
.75647 .54398 L
s
.75647 .45602 m
.75181 .43443 L
s
.74534 .58669 m
.75181 .56557 L
s
.75181 .43443 m
.74534 .41331 L
s
.73711 .60718 m
.74534 .58669 L
s
.74534 .41331 m
.73711 .39282 L
s
.72717 .6269 m
.73711 .60718 L
s
.73711 .39282 m
.72717 .3731 L
s
.71559 .64571 m
.72717 .6269 L
s
.72717 .3731 m
.71559 .35429 L
s
.70245 .66347 m
.71559 .64571 L
s
.71559 .35429 m
.70245 .33653 L
s
.68786 .68005 m
.70245 .66347 L
s
.70245 .33653 m
.68786 .31995 L
s
.67191 .69533 m
.68786 .68005 L
s
.68786 .31995 m
.67191 .30467 L
s
.65473 .70921 m
.67191 .69533 L
s
.67191 .30467 m
.65473 .29079 L
s
.63643 .72157 m
.65473 .70921 L
s
.65473 .29079 m
.63643 .27843 L
s
.61715 .73235 m
.63643 .72157 L
s
.63643 .27843 m
.61715 .26765 L
s
.59702 .74144 m
.61715 .73235 L
s
.61715 .26765 m
.59702 .25856 L
s
.57619 .7488 m
.59702 .74144 L
s
.59702 .25856 m
.57619 .2512 L
s
.55482 .75437 m
.57619 .7488 L
s
.57619 .2512 m
.55482 .24563 L
s
.53305 .7581 m
.55482 .75437 L
s
.55482 .24563 m
.53305 .2419 L
s
.51104 .75997 m
.53305 .7581 L
s
.53305 .2419 m
.51104 .24003 L
s
.48896 .75997 m
.51104 .75997 L
s
.51104 .24003 m
.48896 .24003 L
s
.46695 .7581 m
.48896 .75997 L
s
.48896 .24003 m
.46695 .2419 L
s
.44518 .75437 m
.46695 .7581 L
s
.46695 .2419 m
.44518 .24563 L
s
.42381 .7488 m
.44518 .75437 L
s
.44518 .24563 m
.42381 .2512 L
s
.40298 .74144 m
.42381 .7488 L
s
.42381 .2512 m
.40298 .25856 L
s
.38285 .73235 m
.40298 .74144 L
s
.40298 .25856 m
.38285 .26765 L
s
.36357 .72157 m
.38285 .73235 L
s
.38285 .26765 m
.36357 .27843 L
s
.34527 .70921 m
.36357 .72157 L
s
.36357 .27843 m
.34527 .29079 L
s
.32809 .69533 m
.34527 .70921 L
s
.34527 .29079 m
.32809 .30467 L
s
.31214 .68005 m
.32809 .69533 L
s
.32809 .30467 m
.31214 .31995 L
s
.29755 .66347 m
.31214 .68005 L
s
.31214 .31995 m
.29755 .33653 L
s
.28441 .64571 m
.29755 .66347 L
s
.29755 .33653 m
.28441 .35429 L
s
.27283 .6269 m
.28441 .64571 L
s
.28441 .35429 m
.27283 .3731 L
s
.26289 .60718 m
.27283 .6269 L
s
.27283 .3731 m
.26289 .39282 L
s
.25466 .58669 m
.26289 .60718 L
s
.26289 .39282 m
.25466 .41331 L
s
.24819 .56557 m
.25466 .58669 L
s
.25466 .41331 m
.24819 .43443 L
s
.24353 .54398 m
.24819 .56557 L
s
.24819 .43443 m
.24353 .45602 L
s
.24073 .52207 m
.24353 .54398 L
s
.24353 .45602 m
.24073 .47793 L
s
.23979 .5 m
.24073 .52207 L
s
.24073 .47793 m
.23979 .5 L
s
.24022 .48346 m
.23895 .50533 L
s
.75751 .5412 m
.75967 .51925 L
s
.23958 .50279 m
.24035 .52484 L
s
.74075 .60699 m
.7446 .58948 L
s
.73231 .62525 m
.73626 .60969 L
s
.74722 .58971 m
.75081 .57051 L
s
0 0 1 r
.57533 .24581 m
.57495 .25047 L
s
1 0 0 r
.7554 .55721 m
.75813 .53572 L
s
.24159 .46636 m
.23821 .48738 L
s
.75202 .57323 m
.75523 .55267 L
s
0 0 1 r
.68386 .3092 m
.68632 .3177 L
s
.44296 .75441 m
.44143 .75869 L
s
1 0 0 r
.72154 .64446 m
.72545 .63101 L
s
.75348 .56293 m
.75751 .5412 L
s
.24035 .52484 m
.24301 .54678 L
s
0 0 1 r
.36065 .7205 m
.35514 .72222 L
s
1 0 0 r
.75468 .56005 m
.75807 .53836 L
s
0 0 1 r
.29378 .65994 m
.28454 .65432 L
s
.65076 .28165 m
.65203 .28787 L
s
1 0 0 r
.24419 .44823 m
.23889 .46777 L
s
.23937 .48574 m
.23797 .50739 L
s
.23895 .50533 m
.23958 .52729 L
s
.74759 .58427 m
.75348 .56293 L
s
.24301 .54678 m
.24753 .56845 L
s
.75168 .57566 m
.7556 .55466 L
s
.24849 .42874 m
.24155 .44624 L
s
0 0 1 r
.5924 .25087 m
.59232 .25539 L
s
.4615 .75863 m
.46063 .76281 L
s
.32193 .69147 m
.31427 .68984 L
s
1 0 0 r
.7399 .60506 m
.74759 .58427 L
s
.24753 .56845 m
.2539 .58969 L
s
.2772 .36284 m
.26781 .37172 L
s
.74942 .58144 m
.75468 .56005 L
s
.74739 .59127 m
.75176 .57144 L
s
.2403 .46756 m
.23685 .48817 L
s
.25504 .40783 m
.24683 .42279 L
s
.75079 .57848 m
.7554 .55721 L
s
.26442 .38569 m
.25538 .39774 L
s
.23958 .52729 m
.2421 .5492 L
s
.73044 .62515 m
.7399 .60506 L
s
.74163 .60734 m
.74631 .58907 L
s
.2539 .58969 m
.26208 .61035 L
s
0 0 1 r
.37407 .72982 m
.36958 .73195 L
s
1 0 0 r
.23821 .48738 m
.23671 .50875 L
s
.23797 .50739 m
.23847 .5292 L
s
0 0 1 r
.4806 .76143 m
.48024 .76544 L
s
1 0 0 r
.73414 .62414 m
.73899 .60775 L
s
.71927 .64438 m
.73044 .62515 L
s
.26208 .61035 m
.27201 .63025 L
s
0 0 1 r
.69158 .31538 m
.69497 .32443 L
s
1 0 0 r
.74231 .60237 m
.74942 .58144 L
s
0 0 1 r
.66199 .28872 m
.66406 .29523 L
s
.60838 .25672 m
.60874 .26118 L
s
1 0 0 r
.2428 .44786 m
.23752 .46682 L
s
.74691 .59356 m
.75202 .57323 L
s
.72459 .64181 m
.72944 .62754 L
s
.70648 .66262 m
.71927 .64438 L
s
.2421 .5492 m
.24652 .57088 L
s
.27201 .63025 m
.28362 .64926 L
s
0 0 1 r
.5 .23343 m
.5 .23724 L
s
.5 .76276 m
.5 .76657 L
s
.29893 .66917 m
.29052 .66446 L
s
1 0 0 r
.74431 .59938 m
.75079 .57848 L
s
.74586 .59635 m
.75168 .57566 L
s
.69215 .67972 m
.70648 .66262 L
s
.28362 .64926 m
.29685 .66723 L
s
0 0 1 r
.33125 .70169 m
.32458 .70077 L
s
1 0 0 r
.74172 .60866 m
.74722 .58971 L
s
.73338 .62268 m
.74231 .60237 L
s
.24743 .42648 m
.24064 .44323 L
s
.71261 .66028 m
.7173 .64826 L
s
0 0 1 r
.38904 .73854 m
.38552 .74094 L
s
1 0 0 r
.23889 .46777 m
.23542 .48791 L
s
.67638 .69554 m
.69215 .67972 L
s
.29685 .66723 m
.31159 .68402 L
s
.23847 .5292 m
.24089 .55099 L
s
.24652 .57088 m
.25282 .59216 L
s
.65929 .70998 m
.67638 .69554 L
s
0 0 1 r
.51963 .2338 m
.51943 .23737 L
s
1 0 0 r
.31159 .68402 m
.32774 .69951 L
s
0 0 1 r
.6231 .26316 m
.62404 .26765 L
s
1 0 0 r
.23685 .48817 m
.23528 .50918 L
s
.23671 .50875 m
.23712 .53032 L
s
.73502 .62417 m
.74075 .60699 L
s
.25481 .40352 m
.2469 .41761 L
s
.64099 .7229 m
.65929 .70998 L
s
.32774 .69951 m
.34519 .71356 L
s
.26555 .3794 m
.25699 .3905 L
s
.72269 .6422 m
.73338 .62268 L
s
.74112 .61079 m
.74739 .59127 L
s
0 0 1 r
.67172 .2955 m
.67469 .30241 L
s
1 0 0 r
.73597 .61974 m
.74431 .59938 L
s
.62164 .73421 m
.64099 .7229 L
s
.34519 .71356 m
.3638 .72608 L
s
.25282 .59216 m
.26097 .6129 L
s
0 0 1 r
.69784 .32075 m
.70222 .33046 L
s
1 0 0 r
.60136 .74383 m
.62164 .73421 L
s
.72651 .64036 m
.73231 .62525 L
s
0 0 1 r
.53886 .23558 m
.53862 .23891 L
s
1 0 0 r
.3638 .72608 m
.38343 .73695 L
s
0 0 1 r
.4054 .7464 m
.40277 .74895 L
s
1 0 0 r
.24155 .44624 m
.23636 .46455 L
s
.7399 .61352 m
.74691 .59356 L
s
.58031 .75167 m
.60136 .74383 L
s
.73816 .61659 m
.74586 .59635 L
s
.38343 .73695 m
.40395 .74611 L
s
.24089 .55099 m
.24524 .5726 L
s
.55864 .75768 m
.58031 .75167 L
s
.40395 .74611 m
.42519 .75346 L
s
.7103 .66079 m
.72269 .6422 L
s
0 0 1 r
.34233 .71204 m
.33668 .7117 L
s
1 0 0 r
.53653 .76179 m
.55864 .75768 L
s
.42519 .75346 m
.447 .75897 L
s
0 0 1 r
.30573 .67922 m
.29821 .67534 L
s
1 0 0 r
.51414 .76399 m
.53653 .76179 L
s
.447 .75897 m
.4692 .76257 L
s
.26097 .6129 m
.27093 .63292 L
s
.49164 .76425 m
.51414 .76399 L
s
.4692 .76257 m
.49164 .76425 L
s
0 0 1 r
.63644 .26994 m
.63808 .27455 L
s
1 0 0 r
.73504 .62524 m
.74163 .60734 L
s
.71585 .65729 m
.72154 .64446 L
s
0 0 1 r
.55744 .23866 m
.55733 .24177 L
s
1 0 0 r
.23752 .46682 m
.23408 .48642 L
s
.72581 .63939 m
.73597 .61974 L
s
.23712 .53032 m
.23948 .55193 L
s
0 0 1 r
.42294 .75318 m
.42111 .75576 L
s
1 0 0 r
.24683 .42279 m
.24027 .43876 L
s
.69629 .67829 m
.7103 .66079 L
s
.27093 .63292 m
.28262 .65206 L
s
.23542 .48791 m
.23384 .5085 L
s
.23528 .50918 m
.23565 .53045 L
s
.24524 .5726 m
.25151 .59387 L
s
0 0 1 r
.67993 .30178 m
.68386 .3092 L
s
1 0 0 r
.7274 .64007 m
.73414 .62414 L
s
.73431 .6272 m
.74172 .60866 L
s
0 0 1 r
.28454 .65432 m
.27656 .64732 L
s
.57516 .24287 m
.57533 .24581 L
s
1 0 0 r
.25538 .39774 m
.24788 .41094 L
s
.7286 .63621 m
.73816 .61659 L
s
.68076 .69457 m
.69629 .67829 L
s
0 0 1 r
.44143 .75869 m
.44028 .76122 L
s
1 0 0 r
.26781 .37172 m
.25983 .38189 L
s
0 0 1 r
.35514 .72222 m
.35048 .72235 L
s
1 0 0 r
.28262 .65206 m
.29599 .67018 L
s
0 0 1 r
.64829 .27681 m
.65076 .28165 L
s
1 0 0 r
.73293 .62985 m
.74112 .61079 L
s
.71389 .65819 m
.72581 .63939 L
s
.731 .63294 m
.7399 .61352 L
s
.24064 .44323 m
.23561 .46085 L
s
.66383 .70947 m
.68076 .69457 L
s
0 0 1 r
.31427 .68984 m
.30768 .68671 L
s
1 0 0 r
.71789 .65549 m
.72459 .64181 L
s
.25151 .59387 m
.25968 .61462 L
s
.23948 .55193 m
.24381 .57341 L
s
.29599 .67018 m
.31093 .68711 L
s
0 0 1 r
.59179 .24802 m
.5924 .25087 L
s
.46063 .76281 m
.46001 .76519 L
s
1 0 0 r
.72737 .64087 m
.73502 .62417 L
s
.6456 .72289 m
.66383 .70947 L
s
.31093 .68711 m
.32733 .70273 L
s
.23636 .46455 m
.23302 .48357 L
s
.70028 .67596 m
.71389 .65819 L
s
0 0 1 r
.6866 .30735 m
.69158 .31538 L
s
1 0 0 r
.23565 .53045 m
.23801 .55181 L
s
0 0 1 r
.36958 .73195 m
.36588 .7324 L
s
1 0 0 r
.71722 .65505 m
.7286 .63621 L
s
.2469 .41761 m
.24066 .43277 L
s
0 0 1 r
.48024 .76544 m
.48001 .76762 L
s
1 0 0 r
.62622 .7347 m
.6456 .72289 L
s
0 0 1 r
.6586 .28353 m
.66199 .28872 L
s
1 0 0 r
.25968 .61462 m
.26971 .63468 L
s
.70614 .67153 m
.71261 .66028 L
s
.23408 .48642 m
.23256 .50654 L
s
.23384 .5085 m
.23423 .52941 L
s
.32733 .70273 m
.34508 .7169 L
s
0 0 1 r
.29052 .66446 m
.28335 .65831 L
s
1 0 0 r
.72653 .64263 m
.73504 .62524 L
s
0 0 1 r
.60719 .25391 m
.60838 .25672 L
s
1 0 0 r
.71882 .65488 m
.72651 .64036 L
s
.60583 .7448 m
.62622 .7347 L
s
.24381 .57341 m
.2501 .59459 L
s
.72024 .65165 m
.731 .63294 L
s
.34508 .7169 m
.36405 .7295 L
s
.25699 .3905 m
.24997 .40282 L
s
0 0 1 r
.5 .23149 m
.5 .23343 L
s
.5 .76657 m
.5 .76851 L
s
1 0 0 r
.68507 .69255 m
.70028 .67596 L
s
0 0 1 r
.32458 .70077 m
.31896 .69828 L
s
1 0 0 r
.72499 .64517 m
.73431 .6272 L
s
.72285 .64826 m
.73293 .62985 L
s
.58459 .75311 m
.60583 .7448 L
s
.36405 .7295 m
.38408 .74042 L
s
0 0 1 r
.38552 .74094 m
.38272 .7416 L
s
1 0 0 r
.26971 .63468 m
.28154 .6539 L
s
.24027 .43876 m
.23548 .45565 L
s
.56267 .75955 m
.58459 .75311 L
s
.70409 .67293 m
.71722 .65505 L
s
.38408 .74042 m
.40502 .74957 L
s
0 0 1 r
.51969 .2321 m
.51963 .2338 L
s
.62118 .26028 m
.6231 .26316 L
s
.69177 .31202 m
.69784 .32075 L
s
1 0 0 r
.54023 .76406 m
.56267 .75955 L
s
.40502 .74957 m
.42672 .75688 L
s
0 0 1 r
.66732 .28986 m
.67172 .2955 L
s
1 0 0 r
.23801 .55181 m
.24237 .5731 L
s
.66836 .70783 m
.68507 .69255 L
s
.71875 .6554 m
.7274 .64007 L
s
.70832 .66938 m
.71585 .65729 L
s
.51746 .7666 m
.54023 .76406 L
s
.42672 .75688 m
.44899 .76227 L
s
.49454 .76715 m
.51746 .7666 L
s
.44899 .76227 m
.47166 .7657 L
s
.2501 .59459 m
.25834 .61529 L
s
.47166 .7657 m
.49454 .76715 L
s
.28154 .6539 m
.29509 .67209 L
s
0 0 1 r
.40277 .74895 m
.40077 .7497 L
s
.53881 .23412 m
.53886 .23558 L
s
1 0 0 r
.23561 .46085 m
.23245 .47924 L
s
0 0 1 r
.29821 .67534 m
.29192 .66997 L
s
.33668 .7117 m
.33202 .70973 L
s
1 0 0 r
.23423 .52941 m
.23664 .55046 L
s
.24788 .41094 m
.24204 .42527 L
s
.70765 .66948 m
.72024 .65165 L
s
.65026 .72164 m
.66836 .70783 L
s
.7178 .65694 m
.72737 .64087 L
s
0 0 1 r
.63367 .26688 m
.63644 .26994 L
s
1 0 0 r
.23302 .48357 m
.23163 .50316 L
s
.68927 .68971 m
.70409 .67293 L
s
.23256 .50654 m
.23304 .52702 L
s
0 0 1 r
.55712 .2374 m
.55744 .23866 L
s
1 0 0 r
.29509 .67209 m
.31028 .68911 L
s
0 0 1 r
.27656 .64732 m
.26997 .63891 L
s
1 0 0 r
.25983 .38189 m
.25339 .39333 L
s
0 0 1 r
.42111 .75576 m
.41981 .7565 L
s
1 0 0 r
.71091 .66588 m
.72285 .64826 L
s
.7093 .66844 m
.71789 .65549 L
s
.7161 .65935 m
.72653 .64263 L
s
0 0 1 r
.67444 .29558 m
.67993 .30178 L
s
1 0 0 r
.25834 .61529 m
.2685 .63534 L
s
.71376 .66241 m
.72499 .64517 L
s
.63092 .73387 m
.65026 .72164 L
s
.24237 .5731 m
.24874 .59413 L
s
.31028 .68911 m
.32699 .7048 L
s
0 0 1 r
.5744 .24177 m
.57516 .24287 L
s
1 0 0 r
.24066 .43277 m
.23621 .44891 L
s
0 0 1 r
.35048 .72235 m
.34677 .72076 L
s
.44028 .76122 m
.43954 .76184 L
s
.64458 .27347 m
.64829 .27681 L
s
1 0 0 r
.67287 .70522 m
.68927 .68971 L
s
.61048 .7444 m
.63092 .73387 L
s
.69332 .68628 m
.70765 .66948 L
s
0 0 1 r
.30768 .68671 m
.3023 .68202 L
s
1 0 0 r
.70921 .66866 m
.71882 .65488 L
s
.32699 .7048 m
.3451 .71903 L
s
.23664 .55046 m
.24109 .57149 L
s
.2685 .63534 m
.28051 .65456 L
s
.69784 .68187 m
.70614 .67153 L
s
0 0 1 r
.59045 .24701 m
.59179 .24802 L
s
.46001 .76519 m
.45968 .76563 L
s
.67998 .30048 m
.6866 .30735 L
s
1 0 0 r
.23548 .45565 m
.23259 .47336 L
s
.58911 .75313 m
.61048 .7444 L
s
.24997 .40282 m
.24463 .41632 L
s
.3451 .71903 m
.36447 .73166 L
s
.24874 .59413 m
.25711 .61472 L
s
.65499 .71931 m
.67287 .70522 L
s
0 0 1 r
.28335 .65831 m
.27757 .65069 L
s
1 0 0 r
.69715 .68253 m
.71091 .66588 L
s
.70817 .66997 m
.71875 .6554 L
s
0 0 1 r
.36588 .7324 m
.36306 .73108 L
s
1 0 0 r
.23304 .52702 m
.23556 .54772 L
s
0 0 1 r
.65383 .2798 m
.6586 .28353 L
s
1 0 0 r
.56696 .75997 m
.58911 .75313 L
s
.23245 .47924 m
.23127 .49826 L
s
0 0 1 r
.48001 .76762 m
.47993 .76783 L
s
1 0 0 r
.23163 .50316 m
.23226 .52317 L
s
.36447 .73166 m
.38494 .74258 L
s
0 0 1 r
.60511 .25288 m
.60719 .25391 L
s
1 0 0 r
.28051 .65456 m
.29431 .67278 L
s
.7063 .67222 m
.7178 .65694 L
s
.54423 .76486 m
.56696 .75997 L
s
.70067 .67875 m
.71376 .66241 L
s
.67732 .70187 m
.69332 .68628 L
s
.38494 .74258 m
.40636 .75169 L
s
.69891 .68059 m
.70832 .66938 L
s
0 0 1 r
.31896 .69828 m
.31451 .69414 L
s
1 0 0 r
.70376 .67523 m
.7161 .65935 L
s
0 0 1 r
.5 .23155 m
.5 .23149 L
s
.5 .76851 m
.5 .76845 L
s
1 0 0 r
.52111 .76774 m
.54423 .76486 L
s
0 0 1 r
.68399 .3044 m
.69177 .31202 L
s
1 0 0 r
.40636 .75169 m
.42854 .7589 L
s
.63577 .73186 m
.65499 .71931 L
s
0 0 1 r
.38272 .7416 m
.3807 .74042 L
s
1 0 0 r
.24204 .42527 m
.23801 .44065 L
s
.49778 .76859 m
.52111 .76774 L
s
.42854 .7589 m
.4513 .76415 L
s
.24109 .57149 m
.24761 .59232 L
s
.47444 .76739 m
.49778 .76859 L
s
.4513 .76415 m
.47444 .76739 L
s
0 0 1 r
.61824 .25914 m
.62118 .26028 L
s
.66143 .28562 m
.66732 .28986 L
s
1 0 0 r
.25711 .61472 m
.26746 .6347 L
s
0 0 1 r
.5196 .23242 m
.51969 .2321 L
s
1 0 0 r
.29431 .67278 m
.30981 .68983 L
s
.69881 .6805 m
.7093 .66844 L
s
.68165 .69804 m
.69715 .68253 L
s
0 0 1 r
.29192 .66997 m
.28699 .66305 L
s
1 0 0 r
.61535 .74272 m
.63577 .73186 L
s
.65975 .7161 m
.67732 .70187 L
s
.25339 .39333 m
.24863 .40603 L
s
0 0 1 r
.40077 .7497 m
.39946 .74854 L
s
.53846 .23468 m
.53881 .23412 L
s
1 0 0 r
.23621 .44891 m
.23366 .46594 L
s
.23556 .54772 m
.24019 .56844 L
s
0 0 1 r
.33202 .70973 m
.32848 .70603 L
s
.26997 .63891 m
.26492 .62908 L
s
1 0 0 r
.30981 .68983 m
.32688 .70555 L
s
0 0 1 r
.62975 .26552 m
.63367 .26688 L
s
1 0 0 r
.69768 .68155 m
.70921 .66866 L
s
.23259 .47336 m
.23169 .49179 L
s
0 0 1 r
.66736 .29071 m
.67444 .29558 L
s
1 0 0 r
.68576 .69402 m
.70067 .67875 L
s
0 0 1 r
.55634 .23816 m
.55712 .2374 L
s
1 0 0 r
.23226 .52317 m
.23499 .54346 L
s
.26746 .6347 m
.27973 .65389 L
s
.5939 .75179 m
.61535 .74272 L
s
0 0 1 r
.41981 .7565 m
.41907 .75525 L
s
1 0 0 r
.23127 .49826 m
.23214 .51777 L
s
.24761 .59232 m
.25619 .61276 L
s
.69567 .68362 m
.70817 .66997 L
s
.32688 .70555 m
.3454 .71979 L
s
.68956 .6901 m
.70376 .67523 L
s
.64074 .72883 m
.65975 .7161 L
s
.69291 .68654 m
.7063 .67222 L
s
.68769 .69117 m
.69784 .68187 L
s
0 0 1 r
.57302 .24265 m
.5744 .24177 L
s
1 0 0 r
.57159 .75898 m
.5939 .75179 L
s
.24463 .41632 m
.2411 .43094 L
s
0 0 1 r
.34677 .72076 m
.3441 .71737 L
s
1 0 0 r
.66449 .71226 m
.68165 .69804 L
s
0 0 1 r
.63956 .27177 m
.64458 .27347 L
s
.43954 .76184 m
.43924 .76042 L
s
.3023 .68202 m
.29825 .67568 L
s
1 0 0 r
.3454 .71979 m
.36523 .73242 L
s
0 0 1 r
.67167 .2949 m
.67998 .30048 L
s
1 0 0 r
.27973 .65389 m
.29384 .67208 L
s
.54862 .7642 m
.57159 .75898 L
s
.24019 .56844 m
.24692 .58903 L
s
0 0 1 r
.58833 .24794 m
.59045 .24701 L
s
.45968 .76563 m
.45965 .76399 L
s
1 0 0 r
.36523 .73242 m
.38619 .7433 L
s
0 0 1 r
.27757 .65069 m
.27331 .64157 L
s
1 0 0 r
.68761 .69076 m
.69891 .68059 L
s
.62044 .73992 m
.64074 .72883 L
s
.52517 .76739 m
.54862 .7642 L
s
.23801 .44065 m
.2359 .45699 L
s
.25619 .61276 m
.26679 .63263 L
s
0 0 1 r
.64765 .27764 m
.65383 .2798 L
s
1 0 0 r
.66913 .70806 m
.68576 .69402 L
s
0 0 1 r
.36306 .73108 m
.36119 .72787 L
s
1 0 0 r
.38619 .7433 m
.4081 .75233 L
s
0 0 1 r
.47993 .76783 m
.48001 .76592 L
s
1 0 0 r
.50145 .76852 m
.52517 .76739 L
s
.23499 .54346 m
.23986 .56385 L
s
.4081 .75233 m
.43079 .75943 L
s
.29384 .67208 m
.3097 .68913 L
s
0 0 1 r
.6021 .25376 m
.60511 .25288 L
s
1 0 0 r
.64581 .72503 m
.66449 .71226 L
s
0 0 1 r
.67443 .29803 m
.68399 .3044 L
s
1 0 0 r
.68641 .69153 m
.69881 .6805 L
s
.47767 .76756 m
.50145 .76852 L
s
0 0 1 r
.31451 .69414 m
.31133 .68828 L
s
1 0 0 r
.23366 .46594 m
.23315 .48375 L
s
.43079 .75943 m
.45405 .76452 L
s
.45405 .76452 m
.47767 .76756 L
s
.67357 .70379 m
.68956 .6901 L
s
0 0 1 r
.5 .23374 m
.5 .23155 L
s
.5 .76845 m
.5 .76626 L
s
1 0 0 r
.599 .74924 m
.62044 .73992 L
s
.23214 .51777 m
.23514 .53763 L
s
.23169 .49179 m
.23289 .51078 L
s
.68425 .6934 m
.69768 .68155 L
s
0 0 1 r
.3807 .74042 m
.37954 .73727 L
s
.654 .28289 m
.66143 .28562 L
s
1 0 0 r
.24863 .40603 m
.24569 .41993 L
s
.67767 .69975 m
.69291 .68654 L
s
.68128 .6962 m
.69567 .68362 L
s
0 0 1 r
.61422 .25987 m
.61824 .25914 L
s
1 0 0 r
.3097 .68913 m
.32719 .70484 L
s
0 0 1 r
.51935 .23488 m
.5196 .23242 L
s
1 0 0 r
.26679 .63263 m
.27937 .65173 L
s
.24692 .58903 m
.25577 .60928 L
s
0 0 1 r
.28699 .66305 m
.28355 .65454 L
s
.26492 .62908 m
.26154 .61784 L
s
1 0 0 r
.5766 .75668 m
.599 .74924 L
s
.62572 .7362 m
.64581 .72503 L
s
.65088 .72071 m
.66913 .70806 L
s
0 0 1 r
.39946 .74854 m
.3989 .74533 L
s
.53778 .23738 m
.53846 .23468 L
s
.32848 .70603 m
.32615 .70052 L
s
1 0 0 r
.32719 .70484 m
.34617 .71906 L
s
0 0 1 r
.62461 .26598 m
.62975 .26552 L
s
.65865 .28732 m
.66736 .29071 L
s
1 0 0 r
.2411 .43094 m
.23952 .44662 L
s
.67568 .69928 m
.68769 .69117 L
s
.55344 .76216 m
.5766 .75668 L
s
.23986 .56385 m
.24688 .58416 L
s
0 0 1 r
.55507 .24104 m
.55634 .23816 L
s
.41907 .75525 m
.41895 .7519 L
s
1 0 0 r
.27937 .65173 m
.29385 .66987 L
s
.65587 .71616 m
.67357 .70379 L
s
.34617 .71906 m
.36649 .73165 L
s
.2359 .45699 m
.23584 .4742 L
s
.60439 .74564 m
.62572 .7362 L
s
.25577 .60928 m
.26669 .629 L
s
.67442 .69975 m
.68761 .69076 L
s
.52972 .7656 m
.55344 .76216 L
s
0 0 1 r
.29825 .67568 m
.29565 .66767 L
s
1 0 0 r
.23514 .53763 m
.24033 .55766 L
s
0 0 1 r
.63321 .27184 m
.63956 .27177 L
s
.571 .24565 m
.57302 .24265 L
s
.3441 .71737 m
.34256 .71209 L
s
.66166 .29074 m
.67167 .2949 L
s
.43924 .76042 m
.43941 .75685 L
s
1 0 0 r
.36649 .73165 m
.38797 .74248 L
s
.63113 .73181 m
.65088 .72071 L
s
.23315 .48375 m
.23475 .50221 L
s
.66065 .71167 m
.67767 .69975 L
s
.23289 .51078 m
.23625 .53019 L
s
.67212 .70138 m
.68641 .69153 L
s
0 0 1 r
.27331 .64157 m
.2707 .63094 L
s
1 0 0 r
.50566 .76696 m
.52972 .7656 L
s
.66506 .70755 m
.68128 .6962 L
s
.29385 .66987 m
.31014 .68688 L
s
.66894 .70404 m
.68425 .6934 L
s
.38797 .74248 m
.41041 .75143 L
s
0 0 1 r
.5854 .25095 m
.58833 .24794 L
s
.45965 .76399 m
.45995 .76014 L
s
1 0 0 r
.48147 .76621 m
.50566 .76696 L
s
.41041 .75143 m
.43362 .75841 L
s
0 0 1 r
.64 .27719 m
.64765 .27764 L
s
1 0 0 r
.582 .75322 m
.60439 .74564 L
s
0 0 1 r
.6631 .29303 m
.67443 .29803 L
s
1 0 0 r
.45738 .76336 m
.48147 .76621 L
s
0 0 1 r
.36119 .72787 m
.36037 .72268 L
s
1 0 0 r
.43362 .75841 m
.45738 .76336 L
s
.24688 .58416 m
.25607 .60419 L
s
0 0 1 r
.48001 .76592 m
.48024 .76177 L
s
1 0 0 r
.24569 .41993 m
.2447 .43497 L
s
.26669 .629 m
.27965 .648 L
s
0 0 1 r
.59813 .25668 m
.6021 .25376 L
s
.31133 .68828 m
.30955 .68065 L
s
1 0 0 r
.63658 .72703 m
.65587 .71616 L
s
.31014 .68688 m
.3281 .70256 L
s
.61003 .74122 m
.63113 .73181 L
s
0 0 1 r
.5 .23819 m
.5 .23374 L
s
.5 .76626 m
.5 .76181 L
s
.64502 .28182 m
.654 .28289 L
s
1 0 0 r
.55874 .75886 m
.582 .75322 L
s
0 0 1 r
.37954 .73727 m
.37932 .73205 L
s
1 0 0 r
.24033 .55766 m
.24772 .57767 L
s
0 0 1 r
.26154 .61784 m
.25997 .60521 L
s
.28355 .65454 m
.28173 .64442 L
s
.6091 .26258 m
.61422 .25987 L
s
1 0 0 r
.23952 .44662 m
.23999 .46325 L
s
0 0 1 r
.51893 .23962 m
.51935 .23488 L
s
1 0 0 r
.64195 .72216 m
.66065 .71167 L
s
.3281 .70256 m
.34758 .71675 L
s
.66182 .70605 m
.67568 .69928 L
s
.23625 .53019 m
.24183 .54985 L
s
.53483 .76247 m
.55874 .75886 L
s
.27965 .648 m
.29457 .66607 L
s
.23584 .4742 m
.23792 .49214 L
s
0 0 1 r
.32615 .70052 m
.32514 .69314 L
s
.3989 .74533 m
.39913 .73999 L
s
.64829 .28552 m
.65865 .28732 L
s
.53677 .24235 m
.53778 .23738 L
s
1 0 0 r
.23475 .50221 m
.23854 .52118 L
s
.25607 .60419 m
.26739 .62375 L
s
.65939 .70742 m
.67442 .69975 L
s
.64709 .71749 m
.66506 .70755 L
s
.58776 .74882 m
.61003 .74122 L
s
0 0 1 r
.61823 .26836 m
.62461 .26598 L
s
1 0 0 r
.34758 .71675 m
.36843 .72931 L
s
.61584 .73626 m
.63658 .72703 L
s
.656 .70989 m
.67212 .70138 L
s
.65184 .71332 m
.66894 .70404 L
s
.51048 .76399 m
.53483 .76247 L
s
0 0 1 r
.55329 .24618 m
.55507 .24104 L
s
.41895 .7519 m
.4195 .74634 L
s
.64992 .28813 m
.66166 .29074 L
s
1 0 0 r
.36843 .72931 m
.39045 .74008 L
s
0 0 1 r
.29565 .66767 m
.29461 .65796 L
s
.62549 .27377 m
.63321 .27184 L
s
1 0 0 r
.48592 .7634 m
.51048 .76399 L
s
.29457 .66607 m
.31133 .68302 L
s
0 0 1 r
.34256 .71209 m
.34225 .70483 L
s
.5683 .25086 m
.571 .24565 L
s
.2707 .63094 m
.26986 .61882 L
s
1 0 0 r
.24772 .57767 m
.25731 .59748 L
s
0 0 1 r
.43941 .75685 m
.44009 .75101 L
s
1 0 0 r
.39045 .74008 m
.41344 .74896 L
s
.56451 .7545 m
.58776 .74882 L
s
.46141 .76067 m
.48592 .7634 L
s
.62171 .73105 m
.64195 .72216 L
s
.41344 .74896 m
.43716 .75585 L
s
.43716 .75585 m
.46141 .76067 L
s
0 0 1 r
.65 .28955 m
.6631 .29303 L
s
1 0 0 r
.26739 .62375 m
.28079 .64263 L
s
.2447 .43497 m
.24576 .45107 L
s
0 0 1 r
.58164 .25614 m
.5854 .25095 L
s
.45995 .76014 m
.46059 .75398 L
s
.63088 .27856 m
.64 .27719 L
s
1 0 0 r
.59382 .74372 m
.61584 .73626 L
s
.24183 .54985 m
.24965 .56957 L
s
.31133 .68302 m
.3298 .69867 L
s
0 0 1 r
.36037 .72268 m
.36066 .71542 L
s
1 0 0 r
.23999 .46325 m
.24261 .48071 L
s
.6275 .7259 m
.64709 .71749 L
s
.5405 .75816 m
.56451 .7545 L
s
0 0 1 r
.48024 .76177 m
.48066 .75528 L
s
.30955 .68065 m
.30926 .67121 L
s
.59318 .26174 m
.59813 .25668 L
s
1 0 0 r
.23854 .52118 m
.24458 .54048 L
s
.23792 .49214 m
.24222 .51069 L
s
0 0 1 r
.25997 .60521 m
.26032 .59124 L
s
1 0 0 r
.64615 .71136 m
.66182 .70605 L
s
0 0 1 r
.63446 .28251 m
.64502 .28182 L
s
1 0 0 r
.63303 .7211 m
.65184 .71332 L
s
0 0 1 r
.5 .245 m
.5 .23819 L
s
.5 .76181 m
.5 .755 L
s
.28173 .64442 m
.28164 .63271 L
s
1 0 0 r
.3298 .69867 m
.34983 .71284 L
s
.64256 .71362 m
.65939 .70742 L
s
0 0 1 r
.37932 .73205 m
.38008 .72468 L
s
1 0 0 r
.25731 .59748 m
.26909 .61687 L
s
.28079 .64263 m
.29618 .66063 L
s
.63812 .71693 m
.656 .70989 L
s
.51594 .75975 m
.5405 .75816 L
s
0 0 1 r
.60285 .26738 m
.6091 .26258 L
s
1 0 0 r
.57071 .7493 m
.59382 .74372 L
s
.60008 .73822 m
.62171 .73105 L
s
0 0 1 r
.51833 .24672 m
.51893 .23962 L
s
.63629 .28543 m
.64829 .28552 L
s
.32514 .69314 m
.32555 .68385 L
s
1 0 0 r
.34983 .71284 m
.37123 .72536 L
s
0 0 1 r
.39913 .73999 m
.40021 .73241 L
s
.5354 .24968 m
.53677 .24235 L
s
1 0 0 r
.4911 .75922 m
.51594 .75975 L
s
0 0 1 r
.61059 .27278 m
.61823 .26836 L
s
1 0 0 r
.24965 .56957 m
.25972 .58916 L
s
.37123 .72536 m
.39379 .73611 L
s
0 0 1 r
.63648 .28719 m
.64992 .28813 L
s
1 0 0 r
.29618 .66063 m
.31346 .67754 L
s
.60641 .73262 m
.6275 .7259 L
s
.46621 .75656 m
.4911 .75922 L
s
0 0 1 r
.55099 .25365 m
.55329 .24618 L
s
.4195 .74634 m
.42074 .73848 L
s
1 0 0 r
.54671 .75289 m
.57071 .7493 L
s
0 0 1 r
.29461 .65796 m
.29524 .64653 L
s
.26986 .61882 m
.27092 .60524 L
s
1 0 0 r
.24576 .45107 m
.24899 .46811 L
s
.39379 .73611 m
.41731 .74495 L
s
.26909 .61687 m
.28298 .63564 L
s
.44153 .75179 m
.46621 .75656 L
s
0 0 1 r
.61639 .27768 m
.62549 .27377 L
s
1 0 0 r
.24458 .54048 m
.2529 .55993 L
s
.41731 .74495 m
.44153 .75179 L
s
0 0 1 r
.34225 .70483 m
.34325 .69555 L
s
.63517 .2877 m
.65 .28955 L
s
1 0 0 r
.57725 .74354 m
.60008 .73822 L
s
0 0 1 r
.56491 .25839 m
.5683 .25086 L
s
1 0 0 r
.24261 .48071 m
.24747 .49887 L
s
0 0 1 r
.44009 .75101 m
.4413 .74282 L
s
1 0 0 r
.61264 .72723 m
.63303 .7211 L
s
.24222 .51069 m
.24878 .52966 L
s
.31346 .67754 m
.33248 .69317 L
s
0 0 1 r
.62029 .28185 m
.63088 .27856 L
s
1 0 0 r
.52207 .75442 m
.54671 .75289 L
s
.61858 .72234 m
.63812 .71693 L
s
0 0 1 r
.57703 .26361 m
.58164 .25614 L
s
.46059 .75398 m
.46158 .74542 L
s
1 0 0 r
.62874 .71507 m
.64615 .71136 L
s
.62402 .71822 m
.64256 .71362 L
s
0 0 1 r
.36066 .71542 m
.36213 .70605 L
s
.26032 .59124 m
.26269 .57599 L
s
.30926 .67121 m
.31057 .65994 L
s
1 0 0 r
.25972 .58916 m
.272 .60841 L
s
0 0 1 r
.48066 .75528 m
.48125 .74636 L
s
1 0 0 r
.28298 .63564 m
.2989 .65358 L
s
0 0 1 r
.58724 .26903 m
.59318 .26174 L
s
1 0 0 r
.58401 .73754 m
.60641 .73262 L
s
0 0 1 r
.62235 .28506 m
.63446 .28251 L
s
1 0 0 r
.33248 .69317 m
.35306 .70734 L
s
0 0 1 r
.28164 .63271 m
.28339 .61942 L
s
1 0 0 r
.55341 .74692 m
.57725 .74354 L
s
.49703 .75386 m
.52207 .75442 L
s
0 0 1 r
.5 .25426 m
.5 .245 L
s
.5 .755 m
.5 .74574 L
s
.38008 .72468 m
.38189 .7151 L
s
.59547 .27435 m
.60285 .26738 L
s
1 0 0 r
.2529 .55993 m
.26348 .57933 L
s
0 0 1 r
.62267 .28715 m
.63629 .28543 L
s
1 0 0 r
.35306 .70734 m
.37501 .71988 L
s
0 0 1 r
.51756 .25627 m
.51833 .24672 L
s
1 0 0 r
.47185 .75117 m
.49703 .75386 L
s
.59084 .73159 m
.61264 .72723 L
s
0 0 1 r
.32555 .68385 m
.32745 .67261 L
s
1 0 0 r
.2989 .65358 m
.31672 .67048 L
s
.24899 .46811 m
.25443 .48595 L
s
.24878 .52966 m
.25763 .54888 L
s
0 0 1 r
.40021 .73241 m
.40219 .72254 L
s
1 0 0 r
.37501 .71988 m
.39811 .73064 L
s
0 0 1 r
.53368 .25944 m
.5354 .24968 L
s
.62138 .28802 m
.63648 .28719 L
s
1 0 0 r
.44679 .74637 m
.47185 .75117 L
s
0 0 1 r
.6017 .27932 m
.61059 .27278 L
s
1 0 0 r
.52881 .74826 m
.55341 .74692 L
s
.24747 .49887 m
.25459 .51757 L
s
.272 .60841 m
.28642 .6271 L
s
.39811 .73064 m
.42212 .73951 L
s
0 0 1 r
.27092 .60524 m
.27396 .59027 L
s
1 0 0 r
.42212 .73951 m
.44679 .74637 L
s
.59754 .72602 m
.61858 .72234 L
s
.5605 .74054 m
.58401 .73754 L
s
0 0 1 r
.29524 .64653 m
.29765 .6334 L
s
.61866 .28759 m
.63517 .2877 L
s
.54816 .26354 m
.55099 .25365 L
s
.42074 .73848 m
.4227 .72825 L
s
1 0 0 r
.60391 .72109 m
.62402 .71822 L
s
0 0 1 r
.60594 .28365 m
.61639 .27768 L
s
1 0 0 r
.6097 .71707 m
.62874 .71507 L
s
0 0 1 r
.34325 .69555 m
.34563 .68422 L
s
1 0 0 r
.31672 .67048 m
.3363 .68613 L
s
0 0 1 r
.56083 .26829 m
.56491 .25839 L
s
1 0 0 r
.5037 .74753 m
.52881 .74826 L
s
0 0 1 r
.4413 .74282 m
.44307 .7322 L
s
1 0 0 r
.26348 .57933 m
.2763 .59848 L
s
0 0 1 r
.26269 .57599 m
.26718 .55956 L
s
.60825 .28713 m
.62029 .28185 L
s
1 0 0 r
.56781 .73408 m
.59084 .73159 L
s
0 0 1 r
.57157 .27341 m
.57703 .26361 L
s
1 0 0 r
.28642 .6271 m
.30289 .64502 L
s
0 0 1 r
.46158 .74542 m
.46295 .7344 L
s
1 0 0 r
.53609 .74155 m
.5605 .74054 L
s
0 0 1 r
.31057 .65994 m
.31356 .64685 L
s
.36213 .70605 m
.36486 .69452 L
s
1 0 0 r
.3363 .68613 m
.35743 .70035 L
s
.47833 .74469 m
.5037 .74753 L
s
0 0 1 r
.28339 .61942 m
.28706 .60461 L
s
.60872 .28955 m
.62235 .28506 L
s
1 0 0 r
.25763 .54888 m
.26877 .56815 L
s
0 0 1 r
.48125 .74636 m
.48203 .73495 L
s
.5803 .2786 m
.58724 .26903 L
s
1 0 0 r
.57517 .72785 m
.59754 .72602 L
s
.25459 .51757 m
.26402 .53662 L
s
.25443 .48595 m
.26215 .50445 L
s
.35743 .70035 m
.37992 .71296 L
s
0 0 1 r
.5 .26602 m
.5 .25426 L
s
.5 .74574 m
.5 .73398 L
s
.60749 .29078 m
.62267 .28715 L
s
1 0 0 r
.45299 .73977 m
.47833 .74469 L
s
0 0 1 r
.38189 .7151 m
.38479 .70327 L
s
.58696 .28356 m
.59547 .27435 L
s
1 0 0 r
.30289 .64502 m
.32127 .66195 L
s
.37992 .71296 m
.40351 .72381 L
s
.2763 .59848 m
.29128 .61714 L
s
0 0 1 r
.5166 .26831 m
.51756 .25627 L
s
1 0 0 r
.42796 .73278 m
.45299 .73977 L
s
.58237 .72215 m
.60391 .72109 L
s
0 0 1 r
.60471 .29071 m
.62138 .28802 L
s
1 0 0 r
.51104 .74051 m
.53609 .74155 L
s
0 0 1 r
.32745 .67261 m
.33091 .65944 L
s
1 0 0 r
.40351 .72381 m
.42796 .73278 L
s
.54377 .7346 m
.56781 .73408 L
s
0 0 1 r
.27396 .59027 m
.27906 .574 L
s
.60058 .28931 m
.61866 .28759 L
s
1 0 0 r
.58917 .71725 m
.6097 .71707 L
s
0 0 1 r
.40219 .72254 m
.4051 .71034 L
s
.59157 .28802 m
.6017 .27932 L
s
.53159 .27169 m
.53368 .25944 L
s
.29765 .6334 m
.3019 .61863 L
s
.5448 .27589 m
.54816 .26354 L
s
1 0 0 r
.32127 .66195 m
.34139 .67768 L
s
.26877 .56815 m
.28214 .58724 L
s
0 0 1 r
.4227 .72825 m
.42542 .71563 L
s
.59416 .29173 m
.60594 .28365 L
s
1 0 0 r
.48563 .7374 m
.51104 .74051 L
s
0 0 1 r
.34563 .68422 m
.34945 .67085 L
s
.26718 .55956 m
.27383 .54209 L
s
1 0 0 r
.55168 .72775 m
.57517 .72785 L
s
0 0 1 r
.55606 .28062 m
.56083 .26829 L
s
1 0 0 r
.29128 .61714 m
.3083 .6351 L
s
0 0 1 r
.44307 .7322 m
.4454 .71913 L
s
.59481 .29447 m
.60825 .28713 L
s
1 0 0 r
.26402 .53662 m
.27571 .55582 L
s
.51896 .73311 m
.54377 .7346 L
s
.34139 .67768 m
.36305 .69202 L
s
.26215 .50445 m
.27214 .52341 L
s
.46013 .73221 m
.48563 .7374 L
s
0 0 1 r
.56527 .28558 m
.57157 .27341 L
s
.31356 .64685 m
.31829 .632 L
s
.46295 .7344 m
.4647 .72089 L
s
.28706 .60461 m
.29273 .58837 L
s
1 0 0 r
.5596 .72129 m
.58237 .72215 L
s
0 0 1 r
.59365 .29605 m
.60872 .28955 L
s
.36486 .69452 m
.36887 .68084 L
s
1 0 0 r
.36305 .69202 m
.38601 .70479 L
s
0 0 1 r
.48203 .73495 m
.483 .72103 L
s
1 0 0 r
.43484 .725 m
.46013 .73221 L
s
0 0 1 r
.57238 .29048 m
.5803 .2786 L
s
.59084 .29635 m
.60749 .29078 L
s
1 0 0 r
.56731 .71554 m
.58917 .71725 L
s
.28214 .58724 m
.29767 .60595 L
s
.3083 .6351 m
.32722 .65213 L
s
.38601 .70479 m
.41004 .71582 L
s
.41004 .71582 m
.43484 .725 L
s
0 0 1 r
.58657 .29532 m
.60471 .29071 L
s
.5 .2803 m
.5 .26602 L
s
.5 .73398 m
.5 .7197 L
s
1 0 0 r
.49366 .72958 m
.51896 .73311 L
s
0 0 1 r
.38479 .70327 m
.38882 .6892 L
s
1 0 0 r
.52729 .72566 m
.55168 .72775 L
s
0 0 1 r
.58106 .29293 m
.60058 .28931 L
s
.57737 .29502 m
.58696 .28356 L
s
.27906 .574 m
.28627 .55654 L
s
.33091 .65944 m
.336 .64437 L
s
.51546 .28287 m
.5166 .26831 L
s
1 0 0 r
.27571 .55582 m
.28963 .57495 L
s
0 0 1 r
.58026 .29892 m
.59157 .28802 L
s
.3019 .61863 m
.30804 .6023 L
s
.4051 .71034 m
.40895 .69582 L
s
.52915 .28642 m
.53159 .27169 L
s
1 0 0 r
.32722 .65213 m
.34785 .66802 L
s
0 0 1 r
.27383 .54209 m
.28268 .52371 L
s
1 0 0 r
.46815 .72401 m
.49366 .72958 L
s
.53583 .71848 m
.5596 .72129 L
s
.27214 .52341 m
.28438 .54263 L
s
0 0 1 r
.58112 .30195 m
.59416 .29173 L
s
.54091 .29068 m
.5448 .27589 L
s
1 0 0 r
.29767 .60595 m
.31522 .62403 L
s
0 0 1 r
.42542 .71563 m
.4289 .70062 L
s
.34945 .67085 m
.35474 .65547 L
s
1 0 0 r
.50228 .72156 m
.52729 .72566 L
s
.34785 .66802 m
.36997 .68257 L
s
0 0 1 r
.55061 .29535 m
.55606 .28062 L
s
.58006 .30388 m
.59481 .29447 L
s
1 0 0 r
.44273 .71643 m
.46815 .72401 L
s
0 0 1 r
.4454 .71913 m
.44831 .70363 L
s
1 0 0 r
.54435 .71189 m
.56731 .71554 L
s
0 0 1 r
.29273 .58837 m
.30042 .57081 L
s
.31829 .632 m
.3248 .61545 L
s
.57725 .30458 m
.59365 .29605 L
s
1 0 0 r
.36997 .68257 m
.39334 .69559 L
s
0 0 1 r
.55816 .30011 m
.56527 .28558 L
s
1 0 0 r
.41769 .70693 m
.44273 .71643 L
s
0 0 1 r
.4647 .72089 m
.46683 .70492 L
s
.36887 .68084 m
.37419 .66505 L
s
1 0 0 r
.28963 .57495 m
.30567 .59379 L
s
0 0 1 r
.57285 .30392 m
.59084 .29635 L
s
1 0 0 r
.39334 .69559 m
.41769 .70693 L
s
.31522 .62403 m
.33463 .64126 L
s
0 0 1 r
.56026 .29849 m
.58106 .29293 L
s
.56711 .30189 m
.58657 .29532 L
s
.483 .72103 m
.48415 .70462 L
s
.56354 .30466 m
.57238 .29048 L
s
1 0 0 r
.47693 .71546 m
.50228 .72156 L
s
.51131 .71369 m
.53583 .71848 L
s
0 0 1 r
.28627 .55654 m
.29559 .53806 L
s
1 0 0 r
.28438 .54263 m
.2988 .5619 L
s
0 0 1 r
.5 .29706 m
.5 .2803 L
s
.5 .7197 m
.5 .70294 L
s
.38882 .6892 m
.39399 .67293 L
s
.56674 .30872 m
.57737 .29502 L
s
.28268 .52371 m
.2937 .50462 L
s
.336 .64437 m
.34273 .6275 L
s
.51413 .29989 m
.51546 .28287 L
s
.30804 .6023 m
.3161 .58452 L
s
1 0 0 r
.33463 .64126 m
.35571 .65741 L
s
.45154 .70739 m
.47693 .71546 L
s
0 0 1 r
.56783 .312 m
.58026 .29892 L
s
1 0 0 r
.52051 .70627 m
.54435 .71189 L
s
0 0 1 r
.40895 .69582 m
.41376 .67902 L
s
1 0 0 r
.30567 .59379 m
.3237 .61209 L
s
0 0 1 r
.52636 .3036 m
.52915 .28642 L
s
.56691 .31429 m
.58112 .30195 L
s
1 0 0 r
.48631 .70691 m
.51131 .71369 L
s
.35571 .65741 m
.37821 .67228 L
s
0 0 1 r
.53652 .30788 m
.54091 .29068 L
s
1 0 0 r
.42642 .69742 m
.45154 .70739 L
s
0 0 1 r
.4289 .70062 m
.43315 .68328 L
s
.35474 .65547 m
.36152 .63817 L
s
.56412 .31537 m
.58006 .30388 L
s
.30042 .57081 m
.31013 .5521 L
s
1 0 0 r
.37821 .67228 m
.40187 .68567 L
s
0 0 1 r
.54451 .31244 m
.55061 .29535 L
s
1 0 0 r
.40187 .68567 m
.42642 .69742 L
s
.2988 .5619 m
.3153 .58096 L
s
0 0 1 r
.5384 .30601 m
.56026 .29849 L
s
.55963 .31513 m
.57725 .30458 L
s
.44831 .70363 m
.45178 .68575 L
s
.3248 .61545 m
.33309 .59733 L
s
.55368 .31348 m
.57285 .30392 L
s
.54651 .31042 m
.56711 .30189 L
s
1 0 0 r
.3237 .61209 m
.34353 .62962 L
s
0 0 1 r
.55028 .31695 m
.55816 .30011 L
s
.29559 .53806 m
.30702 .51873 L
s
.46683 .70492 m
.46933 .68654 L
s
.37419 .66505 m
.38083 .64723 L
s
1 0 0 r
.46114 .69821 m
.48631 .70691 L
s
.49608 .69871 m
.52051 .70627 L
s
0 0 1 r
.2937 .50462 m
.30685 .48503 L
s
.55382 .3211 m
.56354 .30466 L
s
.48415 .70462 m
.48549 .68581 L
s
1 0 0 r
.34353 .62962 m
.36495 .64615 L
s
0 0 1 r
.5 .31623 m
.5 .29706 L
s
.5 .70294 m
.5 .68377 L
s
.39399 .67293 m
.40029 .65455 L
s
.55516 .32461 m
.56674 .30872 L
s
.34273 .6275 m
.3511 .60893 L
s
.3161 .58452 m
.32607 .56545 L
s
1 0 0 r
.43611 .68765 m
.46114 .69821 L
s
.3153 .58096 m
.33371 .5996 L
s
0 0 1 r
.51264 .3193 m
.51413 .29989 L
s
.5544 .32721 m
.56783 .312 L
s
1 0 0 r
.36495 .64615 m
.3877 .66146 L
s
.47133 .68924 m
.49608 .69871 L
s
0 0 1 r
.41376 .67902 m
.41952 .66005 L
s
1 0 0 r
.41152 .67535 m
.43611 .68765 L
s
0 0 1 r
.52323 .32313 m
.52636 .3036 L
s
.51571 .31545 m
.5384 .30601 L
s
.55166 .3287 m
.56691 .31429 L
s
.31013 .5521 m
.32183 .53241 L
s
1 0 0 r
.3877 .66146 m
.41152 .67535 L
s
0 0 1 r
.36152 .63817 m
.36978 .61906 L
s
.53165 .3274 m
.53652 .30788 L
s
.54711 .32889 m
.56412 .31537 L
s
.52499 .32089 m
.54651 .31042 L
s
.43315 .68328 m
.43814 .66371 L
s
.54098 .32767 m
.55963 .31513 L
s
.53352 .32499 m
.55368 .31348 L
s
.30702 .51873 m
.32047 .49877 L
s
1 0 0 r
.33371 .5996 m
.35385 .61755 L
s
0 0 1 r
.30685 .48503 m
.32204 .46516 L
s
.33309 .59733 m
.34316 .5778 L
s
.53781 .33179 m
.54451 .31244 L
s
.45178 .68575 m
.4558 .66561 L
s
1 0 0 r
.44658 .67796 m
.47133 .68924 L
s
0 0 1 r
.54169 .33599 m
.55028 .31695 L
s
.38083 .64723 m
.38877 .62752 L
s
.46933 .68654 m
.47219 .66587 L
s
1 0 0 r
.35385 .61755 m
.37548 .63458 L
s
0 0 1 r
.54331 .33968 m
.55382 .3211 L
s
.48549 .68581 m
.487 .6647 L
s
.32607 .56545 m
.33789 .54529 L
s
1 0 0 r
.42214 .66498 m
.44658 .67796 L
s
0 0 1 r
.49245 .32675 m
.51571 .31545 L
s
.3511 .60893 m
.36107 .58884 L
s
.40029 .65455 m
.4077 .6342 L
s
.54273 .34258 m
.55516 .32461 L
s
.5 .33767 m
.5 .31623 L
s
.5 .68377 m
.5 .66233 L
s
1 0 0 r
.37548 .63458 m
.39834 .65046 L
s
.39834 .65046 m
.42214 .66498 L
s
0 0 1 r
.32204 .46516 m
.33912 .44526 L
s
.54007 .34445 m
.5544 .32721 L
s
.51098 .34096 m
.51264 .3193 L
s
.32183 .53241 m
.33544 .51196 L
s
.5028 .33321 m
.52499 .32089 L
s
.32047 .49877 m
.33585 .47842 L
s
.41952 .66005 m
.42618 .63903 L
s
.53551 .34509 m
.55166 .3287 L
s
.5198 .34487 m
.52323 .32313 L
s
.51259 .33837 m
.53352 .32499 L
s
.52923 .34433 m
.54711 .32889 L
s
.5215 .3421 m
.54098 .32767 L
s
.36978 .61906 m
.37947 .59833 L
s
.52634 .34908 m
.53165 .3274 L
s
.34316 .5778 m
.35493 .55705 L
s
.43814 .66371 m
.44385 .64205 L
s
.46892 .33982 m
.49245 .32675 L
s
.53057 .35325 m
.53781 .33179 L
s
.4558 .66561 m
.46035 .64335 L
s
.33912 .44526 m
.35792 .4256 L
s
.53247 .35708 m
.54169 .33599 L
s
.38877 .62752 m
.39796 .6061 L
s
.33789 .54529 m
.35149 .52425 L
s
.47219 .66587 m
.47538 .64309 L
s
.48021 .3473 m
.5028 .33321 L
s
.53211 .36025 m
.54331 .33968 L
s
.33585 .47842 m
.353 .45793 L
s
.487 .6647 m
.48868 .64149 L
s
.33544 .51196 m
.35084 .49101 L
s
.36107 .58884 m
.37259 .56742 L
s
.44541 .35451 m
.46892 .33982 L
s
.52957 .36249 m
.54273 .34258 L
s
.4077 .6342 m
.41617 .61206 L
s
.5 .3612 m
.5 .33767 L
s
.5 .66233 m
.5 .6388 L
s
.49115 .35351 m
.51259 .33837 L
s
.52502 .36357 m
.54007 .34445 L
s
.35792 .4256 m
.37822 .40644 L
s
.50918 .36468 m
.51098 .34096 L
s
.50142 .3583 m
.5215 .3421 L
s
.51865 .36331 m
.53551 .34509 L
s
.51069 .36157 m
.52923 .34433 L
s
.42618 .63903 m
.43371 .61618 L
s
.51609 .36863 m
.5198 .34487 L
s
.35493 .55705 m
.36831 .53532 L
s
.37947 .59833 m
.39052 .57618 L
s
.42226 .37065 m
.44541 .35451 L
s
.45751 .36298 m
.48021 .3473 L
s
.37822 .40644 m
.39976 .38804 L
s
.52066 .37272 m
.52634 .34908 L
s
.353 .45793 m
.37174 .43757 L
s
.44385 .64205 m
.45023 .61852 L
s
.39976 .38804 m
.42226 .37065 L
s
.35149 .52425 m
.36672 .50259 L
s
.52286 .37662 m
.53057 .35325 L
s
.35084 .49101 m
.36788 .46981 L
s
.46035 .64335 m
.46538 .6192 L
s
.39796 .6061 m
.40832 .58318 L
s
.46948 .37024 m
.49115 .35351 L
s
.52273 .38002 m
.53247 .35708 L
s
.47538 .64309 m
.47889 .61842 L
s
.37259 .56742 m
.38554 .54492 L
s
.43501 .38008 m
.45751 .36298 L
s
.52035 .38261 m
.53211 .36025 L
s
.37174 .43757 m
.39183 .41763 L
s
.48868 .64149 m
.4905 .6164 L
s
.48099 .37609 m
.50142 .3583 L
s
.51585 .38414 m
.52957 .36249 L
s
.41617 .61206 m
.42561 .58836 L
s
.4917 .38042 m
.51069 .36157 L
s
.5 .38658 m
.5 .3612 L
s
.5 .6388 m
.5 .61342 L
s
.50942 .38438 m
.52502 .36357 L
s
.50128 .38317 m
.51865 .36331 L
s
.41302 .39838 m
.43501 .38008 L
s
.36831 .53532 m
.38316 .51287 L
s
.39183 .41763 m
.41302 .39838 L
s
.50725 .3902 m
.50918 .36468 L
s
.36788 .46981 m
.38634 .44866 L
s
.43371 .61618 m
.44203 .59173 L
s
.39052 .57618 m
.40282 .55287 L
s
.36672 .50259 m
.38343 .48059 L
s
.44787 .38836 m
.46948 .37024 L
s
.51215 .39414 m
.51609 .36863 L
s
.51466 .39806 m
.52066 .37272 L
s
.45023 .61852 m
.45721 .59337 L
s
.51478 .40163 m
.52286 .37662 L
s
.4605 .39528 m
.48099 .37609 L
s
.38634 .44866 m
.40601 .42784 L
s
.46538 .6192 m
.47085 .59344 L
s
.40832 .58318 m
.41974 .55904 L
s
.42662 .40765 m
.44787 .38836 L
s
.38554 .54492 m
.39979 .52163 L
s
.51259 .40454 m
.52273 .38002 L
s
.47889 .61842 m
.48267 .59213 L
s
.47253 .40066 m
.4917 .38042 L
s
.50818 .4065 m
.52035 .38261 L
s
.40601 .42784 m
.42662 .40765 L
s
.38343 .48059 m
.40141 .45856 L
s
.38316 .51287 m
.39932 .49 L
s
.50173 .40726 m
.51585 .38414 L
s
.48363 .40445 m
.50128 .38317 L
s
.4905 .6164 m
.49244 .58972 L
s
.49347 .40662 m
.50942 .38438 L
s
.42561 .58836 m
.43594 .5634 L
s
.5 .41351 m
.5 .38658 L
s
.5 .61342 m
.5 .58649 L
s
.44021 .4156 m
.4605 .39528 L
s
.40282 .55287 m
.41623 .52869 L
s
.50522 .41723 m
.50725 .3902 L
s
.44203 .59173 m
.45104 .56599 L
s
.40141 .45856 m
.42042 .43679 L
s
.50803 .42111 m
.51215 .39414 L
s
.42042 .43679 m
.44021 .4156 L
s
.45344 .42204 m
.47253 .40066 L
s
.50842 .4248 m
.51466 .39806 L
s
.45721 .59337 m
.46472 .56692 L
s
.39979 .52163 m
.41517 .49784 L
s
.39932 .49 m
.41658 .46703 L
s
.41974 .55904 m
.4321 .53398 L
s
.50643 .42799 m
.51478 .40163 L
s
.47085 .59344 m
.47667 .56637 L
s
.46595 .42687 m
.48363 .40445 L
s
.50216 .43036 m
.51259 .40454 L
s
.49575 .43163 m
.50818 .4065 L
s
.48267 .59213 m
.48666 .56457 L
s
.47738 .43003 m
.49347 .40662 L
s
.48741 .43158 m
.50173 .40726 L
s
.4347 .44427 m
.45344 .42204 L
s
.43594 .5634 m
.44702 .53748 L
s
.49244 .58972 m
.49449 .56179 L
s
.41658 .46703 m
.4347 .44427 L
s
.41623 .52869 m
.4306 .50397 L
s
.5 .44165 m
.5 .41351 L
s
.5 .58649 m
.5 .55835 L
s
.41517 .49784 m
.43147 .47389 L
s
.50311 .44542 m
.50522 .41723 L
s
.45104 .56599 m
.46064 .53928 L
s
.44848 .45012 m
.46595 .42687 L
s
.50378 .44918 m
.50803 .42111 L
s
.4321 .53398 m
.44523 .50834 L
s
.50202 .4526 m
.50842 .4248 L
s
.46472 .56692 m
.47265 .5395 L
s
.46139 .45429 m
.47738 .43003 L
s
.43147 .47389 m
.44848 .45012 L
s
.49792 .45534 m
.50643 .42799 L
s
.47667 .56637 m
.48279 .53835 L
s
.4916 .45712 m
.50216 .43036 L
s
.47308 .45677 m
.48741 .43158 L
s
.4306 .50397 m
.44572 .47905 L
s
.48325 .45767 m
.49575 .43163 L
s
.48666 .56457 m
.49083 .53608 L
s
.44702 .53748 m
.4587 .51097 L
s
.49449 .56179 m
.49661 .53299 L
s
.44572 .47905 m
.46139 .45429 L
s
.5 .47061 m
.5 .44165 L
s
.5 .55835 m
.5 .52939 L
s
.46064 .53928 m
.47069 .51197 L
s
.44523 .50834 m
.45896 .48248 L
s
.50095 .47438 m
.50311 .44542 L
s
.49945 .47797 m
.50378 .44918 L
s
.45896 .48248 m
.47308 .45677 L
s
.47265 .5395 m
.48091 .5115 L
s
.49556 .48105 m
.50202 .4526 L
s
.47084 .48424 m
.48325 .45767 L
s
.48938 .48331 m
.49792 .45534 L
s
.48107 .48445 m
.4916 .45712 L
s
.4587 .51097 m
.47084 .48424 L
s
.48279 .53835 m
.48912 .50978 L
s
.49083 .53608 m
.49512 .50708 L
s
.49661 .53299 m
.49877 .50371 L
s
.47069 .51197 m
.48107 .48445 L
s
.5 .5 m
.5 .47061 L
s
.5 .52939 m
.5 .5 L
s
.49877 .50371 m
.50095 .47438 L
s
.48091 .5115 m
.48938 .48331 L
s
.49512 .50708 m
.49945 .47797 L
s
.48912 .50978 m
.49556 .48105 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002?Ool00`0OOomoo`03Ool0
0`0OOomoo`28Ool008moo`0301moogoo00=oo`0301moogoo009oo`0301moogoo08=oo`00RWoo1G`0
00<07g`0O0000W`00P0O17oo00<07gooOol00Woo00<07gooOol0OWoo0023Ool7O005Ool00`0OOomo
o`02Ool00`0OO01l0003O0000`0OO01oo`02Ool00`0OOomoo`02Ool201mjOol007ioo`El00Ioo`Il
000301ml07`0009l000301ml07`0009l00807`04Ooml07`001l2O002Ool00`0OOol07`03Ool00`0O
Oomoo`1dOol007]oo`=l00Eoo`Il00Ioo`0301moogoo009oo`0301moogoo009oo`807`=l000301ml
07oo009l000301moo`0O009oo`<07gEoo`00N7oo0g`00Woo4W`000<07g`0O0000W`000<07g`0O000
0W`00P0O0goo0P0O0g`000D07g`0O01l07oo00807`9oo`<07g5oo`00MGoo27`00goo0g`037oo00<0
7gooOol00Woo00<07gooOol00Woo00<07g`0O0000W`000D07g`0Oomoo`0O00=l00807`04O0007goo
01l2Ool00`0OOomoo`1_Ool0079oo`Il00Aoo`Al00Qoo`Ml000301ml07`0009l000301ml07`0009l
000701moogooOol07goo01l00W`000@07g`0O0007`=l00807`9l0003Ool07goo00<07feoo`00Kgoo
0g`000=oog`0O0000Woo1G`01Woo1W`01goo00<07gooOol00Woo00<07gooOol00Woo00T07g`0O01l
000OO0007goo01l00Woo0P0O00=l07ooOol00P0O00=l07ooO0000P0O0Woo00<07gooOol0Jgoo001]
Ool2O002Ool2O002Ool2O005Ool6O005Ool8O0000`0OO01l0002Ool0100OOomoogoo0P0O0goo0P0O
00El000OO01l07oo00807`04Ooml07`001l2Ool017`001l07goo0W`000Aoo`0O01l07fYoo`00Jgoo
0W`00Woo0W`00Woo0W`00Woo1G`01Goo1W`027oo00<07gooOol00W`000D07g`0O01l000O00=l0005
01moo`0OOol07`02Ool00g`001ml0002Ool00`0OO01l000201l017ooO01l07oo0P0O00=l07ooOol0
0P0OJ7oo001YOol2O002Ool2O002Ool2O00017ooO01l07`017oo1W`03Woo00<07gooOol00Woo00@0
7gooOomoo`807`9oo`0401ml07`001l3Ool201l01WooO0007g`0Ool07`9l0005Ool07`0O01ml0007
01mWOol006Qoo`03O01oogoo009l009oo`9l0003Ooml07`0009oo`El00Eoo`ml000501ml07`0O000
7`02O002Ool201l2Ool0100OOol07`0O0g`000D07gooOol07goo00807`9l0004Ool07`0OO00201l2
O00701mUOol006Moo`04O01oog`0O002Ool2O0000gooO01l0002Ool2O005Ool5O00?Ool0100OOomo
ogoo0P0O00=oog`001l017`000@07goo01l07`=oo`0301ml000O009l00807`9oo`0401ml000O01l2
O00201l2O0000gooO0007`0301mTOol006Eoo`9l0004Ooml07ooOol2O0000gooO01l0002Ool2O005
Ool2O00:Ool:O000100OOomoogoo0P0O0Woo0P0O0Woo00L07g`0O01l000OO01oo`0201l01Woo01mo
ogoo01ml00807`04Ool07g`0O00>01mROol006Aoo`05O01oog`0O01oo`02O002Ool00g`0Oomoo`02
O004Ool3O006Ool6O00:Ool01P0OO01l07`001ml009oo`807`9oo`0401moo`0O01l2Ool017`001ml
000O0Woo0`0O00=l000O01l04P0OHGoo001SOol3O002Ool00g`0Oomoo`02O0000gooO01l0003Ool3
O004Ool5O00@Ool0100OOomoogoo0P0O0W`000H07g`0O01l000OOol201l2Ool201l01goo01ml000O
Ool07goo00L07`03Ool07goo009oo`9l00P07f1oo`00HWoo0W`00Woo0W`000=oog`0O0000g`00Woo
0g`00Woo1G`017oo47`000=oo`0OOol00Woo0P0O0Woo0P0O0Woo00@07g`0O0007`9l00d07`9l0003
Ool07goo009l0006Ool07gooO01oog`01`0OGWoo001POol3O00017ooO01l07oo17`00goo0W`00goo
0W`017oo1G`047oo00=l000OO0000W`000/07g`0O01l000OO01oo`0OOol07goo00d07`03O01oo`0O
009oo`9l00=oo`06O0007gooOoml07oo17`000Aoo`0O01l07eeoo`00Ggoo1G`000=oog`0O0000W`0
0Woo0g`00Woo0g`000=oog`0O0000g`05Woo00D07gooOomoo`0O00=oo`807`03O0007goo00<07`03
Ool07`0O00807`03Ool07`0O00807`=oo`9l00=oo`0301ml07`0009oo`0401ml07ooOol2O0001Goo
O0007g`0Ool00`0OG7oo001NOol2O0000gooO01oo`02O00017ooO01oogoo0W`00Woo0g`00Woo0W`0
17oo5g`000D07g`0O01l000O00=oo`D07`03O0007g`000<07`03Ool07`0O00807`=l009oo`0501mo
og`0O0007`03Ool2O0001P0OOoml07`001moo`9l000501ml07`001moo`0201mKOol005eoo`9l0005
Ooml07ooO01oo`02O00017ooO01l07oo0g`00Woo0g`000=oog`0O0000g`05goo00D07gooOomoo`0O
00=l00<07`9oo`0301moo`0O00P07`=oo`=l00=oo`9l00Aoo`04O01oogooOol2O002Ool01W`0Ooml
07`001moo`807eYoo`00Fgoo0g`000Moog`0Ooml07ooO01oo`02O0000gooO01l0003Ool2O002Ool2
O009Ool@O003Ool01@0OOomoogoo01l00Woo0P0O00Al000OO01l00P07`9l000301moogoo009oo`07
01moog`0O01oo`0OOol00W`000=oo`0OOol00W`000Qoo`0OOoml07oo01ml07oo0g`00`0OFGoo001J
Ool027`0Ooml07ooO01oog`0Ool3O0000gooO01l0002OolBO00@Ool3O000100OO01oogoo1@0O00=o
o`0O01l00`0O00=l000O01l00P0O0goo0g`00Woo00@07gooOomoo`9l00=oo`03O0007goo009oo`9l
009oo`09O0007gooO01oog`0Ool07goo00807eQoo`00FGoo00Il07ooO01oog`0Ool4O00017ooO01l
07oo2W`02Woo2W`02Woo00<07goo01l00P0O0W`0100O00Eoo`0O01l07goo00<07`=oo`0401moogoo
Ool2O004Ool0100OOoml07`00Woo0W`00Woo00<07gooO0000Woo0W`000Ioog`001ml000OO00201mH
Ool005Qoo`03O01oog`0009l0004Ooml07`0Ool3O0000gooO01l0002O002Ool2O003Ool;O00:Ool5
O005Ool201l2Ool00`0OOomoo`0301l00g`001l07`0501l01GooO01l07oo01l017oo00<07g`0O000
0Woo00H07gooOomoog`001l2Ool2O0003P0OOomoog`0Ool07gooO01oog`0Ooml07ooO00201mGOol0
05Moo`04O01oog`0O002Ool00g`0Ooml0002O002Ool3O0000gooO01l0006O004Ool:O00<Ool3O003
01l3Ool701l00goo01l07`0301l4Ool3O002Ool0100OOomoogoo0W`000<07gooOol00Woo0W`00goo
00Il07ooOomoog`001l2Ool01W`0Ooml07ooO01oo`807eMoo`00Egoo0g`000Qoog`0O01oog`0Ooml
07oo0g`000=oog`0O00037`02Woo2g`00Woo0P0O0Woo00<07g`0O0000P0O00=l07oo01l00P0O00=o
o`0O01l00`0O00=l07ooOol00Woo00<07gooOol00W`000<07gooOol00Woo00<07g`0O0000goo00H0
7gooO01l000OOol2O0000goo01ml0002Ool01@0OO01oog`001l00W`000=oo`0OOol0EGoo001FOol3
O00017ooO01l07oo0g`000=oog`0O0007g`01goo0P0O0g`000=oo`0O01l00`0O00Aoo`0O01ml00H0
7`04Ool07g`0O002Ool00`0OOomoo`02Ool3O002Ool01P0OOomoog`0Ool07`Aoo`0BO01oogooOoml
000OOoml07oo01moog`0Ooml07oo01ml000OEWoo001EOol3O00017ooO01l07oo0W`000=oog`0O000
6g`01Woo1G`00P0O1Goo0P0O0W`0100O00Aoo`0O01ml00@07`04Ool07gooOol3O003Ool0100OOomo
ogoo0W`000@07gooOomoo`9l00Aoo`0301ml07oo009oo`0501ml07ooO0007`02Ool017`001ml000O
0W`000<07gooOol0Dgoo001DOol2O0001GooO01l07`0Ool02W`04Goo1G`000=oog`0O0000g`01Goo
00<07g`0O0000W`000Eoo`0O01moo`0O009oo`807`03Ool07`0O00H07`03O0007goo00=oo`0601mo
og`0O01oo`0O17oo00<07g`0O0000Woo00@07gooO01l009oo`0501moog`0O0007`02Ool017`0Ooml
07`00Woo00Al07ooO01oo`9l05Eoo`00Dgoo0W`000=oog`0O0002G`06Woo0g`00goo0g`00P0O17oo
0P0O0W`000=oo`0OOol00P0O00Ioog`001ml000OOol301l2Ool2O003Ool0100OOomoogoo0g`00goo
00<07gooOol00W`000H07gooOomoog`001l4Ool03P0OOomoogooO0007gooO0007gooO01oog`0Ool2
O01DOol005=oo`03O01oog`000Ql021oo`9l009oo`807`9oo`=l000301moogoo009oo`04O0007`0O
O00601l00g`001l07`03Ool00`0OOoml0002O004Ool00`0OOomoo`02O0000goo01moo`02Ool00`0O
O01l0003Ool2O003Ool01P0OO01oogoo01ml009oo`05O01oogooO0007`03O01DOol0059oo`Yl02Ao
o`807`9l00Aoo`0501moog`0O01oo`0301l2Ool00`0OO01l000601l017`0Oomoo`0O0goo00<07g`0
O0000Woo00<07gooOol00Woo0W`00goo00H07gooOoml07oo01l2Ool2O0000`0OOomoo`02O0002`0O
Ooml07oo01ml07ooO0007goo01l00W`0Dgoo001AOol9O00UOol00`0OOomoo`02Ool3O0000`0OOomo
o`02Ool00`0OO01l000401l017oo01l07g`00`0O0Woo0W`000D07gooOomoo`0O009oo`=l00Aoo`06
01moog`0O01oo`0O0goo0W`017oo00=l07ooOol00Woo00]l07ooOoml000OOoml000OO01oo`0O00=l
059oo`00D7oo0W`000=oog`0O00017`09Goo00<07gooOol017oo0P0O00Eoog`0O01oo`0O00=oo`03
01ml07oo00D07`03Ool07g`000=oo`0501ml07`0O0007`04Ool01P0OOoml07`0Ool07`Aoo`9l00=o
o`0801moog`0O01oo`0OOoml009oo`0601moog`0Ool07g`00Woo00D07gooO0007goo009l059oo`00
D7oo00=l07ooO00017`09Woo00<07gooOol017oo00<07gooOol00goo00@07g`0O01oo`807`04Ooml
000OO00601l2O0000goo01moo`02Ool2O003Ool01P0OOomoogooO0007`Aoo`0301moog`0009oo`06
01moogooOoml000O0Woo0W`000d07gooOoml000OOoml07oo01ml07ooO01oo`03O01AOol004moo`Ml
02Eoo`807`Ioo`0301moogoo009oo`807`=oo`0401ml000OOol201l00goo01ml000201l01Woo01mo
ogooO0007`=oo`0301moog`0009l00Aoo`0601moog`0O01oo`0O0goo0W`000H07gooOomoo`0OO004
Ool01@0OOomoogooO0000Woo00Ml000OOoml000OO01oo`02O01AOol004eoo`Ql02Eoo`0301moogoo
00Aoo`807`Aoo`0301moogoo009oo`0301moogoo00807`03Ool07`0O00@07`03Ool07goo009oo`05
01ml07`0Ool07`03Ool00`0OO01l0002Ool0100OOomoogoo0W`017oo00<07g`0O0000Woo00<07goo
O0000Woo00L07gooO01oo`0OOoml0002Ool01W`0Ooml000OO01oo`=l051oo`00C7oo00=l07ooO000
1G`09Goo00<07gooOol017oo00<07gooOol00goo00<07gooOol00Woo00T07gooOomoo`0OOoml000O
Ool0100O0W`00Woo00@07gooOomoo`9l00=oo`0301moogoo009l00Aoo`0301moog`000=oo`0601mo
ogooO01oo`0O0Woo00=l07oo01l00Woo00el000OOomoog`0Ool07g`0Ooml07ooO01oo`02O01@Ool0
04]oo`03O01oog`000El02Aoo`807`Ioo`0301moogoo00=oo`0301moogoo009oo`0301moogoo009o
o`0301moo`0O00L07`04Ooml07`0O003Ool01P0OOoml07`0Ool07`=oo`0301ml07`0009oo`0601mo
ogooO01oo`0O17oo00=l07ooOol00Woo00=l07ooOol00Woo00Ul07ooOomoog`0Ooml07ooO0000Woo
17`0Cgoo001;Ool7O00TOol00`0OOomoo`04Ool201l5Ool00`0OOomoo`02Ool00`0OOomoo`02Ool9
01l00g`001moo`02Ool01@0OO01l07oo01l00goo0W`00goo00<07gooOol00W`000@07gooOomoo`9l
00Aoo`0301ml07`0009oo`0701ml07ooOol07gooO0000Woo00Il07ooOoml000OO002Ool4O01>Ool0
04Yoo`Ml02Aoo`0301moogoo00Aoo`0301moogoo00=oo`807`Aoo`0301moogoo009oo`0401moo`0O
Ool601l00gooO01l0002Ool01@0OOomoog`001l00goo00D07gooO01l000O00Aoo`0301ml07oo009o
o`0301moog`000=oo`0501moogooO0007`02Ool2O0001`0OOomoog`0Ool07g`0009oo`04O01oog`0
Ool4O01>Ool004Uoo`Ml02=oo`807`Ioo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo009o
o`0501moo`0O01moo`0701l2Ool2O003Ool01P0OOoml07`0Ool07`=oo`03O01oogoo009oo`0301mo
og`0009oo`0301moogoo009l000301moogoo009oo`03O01oogoo009oo`0501moogooOoml0002Ool0
1g`001moog`0Ooml07oo00Al04eoo`00BGoo0W`000Aoog`0O01l02=oo`0301moogoo00Eoo`0301mo
ogoo00=oo`0301moogoo00=oo`0301moogoo009oo`0301moogoo00807`03Ool07`0O00<07`03Ool0
7goo009oo`0501ml07`0Ool07`03Ool2O003Ool01@0OO01l07oo01l00goo0W`01Goo0W`00goo00L0
7g`0Oomoo`0OOoml0002Ool02P0OO01oogooO01oog`0Ooml07oo17`0CGoo0018Ool7O00ROol00`0O
Oomoo`04Ool201l5Ool00`0OOomoo`03Ool0100OOomoogoo0P0O0Woo00<07goo01l01P0O00=oo`0O
Ool00Woo00@07gooOoml00Aoo`0501moog`0Ool07`03Ool00g`001moo`03Ool00`0OO01oo`02Ool0
1P0OOomoog`0Ool07`9oo`03O01oo`0O009oo`0=O0007gooOoml07oo01ml07ooO01oog`0Ool017`0
C7oo0018Ool6O00ROol00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`03Ool01@0OOomoogoo
01l00goo00D07gooOol07goo00@07`9oo`0501moogooOol07`02Ool01@0OO01oogoo01l00goo00=l
000OOol00goo0W`00Woo00@07gooOoml009oo`0601moogooOoml000O0goo00=l07ooOol00Woo00T0
7gooOomoog`0Ooml07ooO0000Woo00=l07ooO0000W`0C7oo0017Ool6O00QOol201l6Ool00`0OOomo
o`03Ool201l5Ool01@0OOomoogoo01l00goo00H07gooOomoo`0OOol401l2Ool0100OOomoo`0O0goo
00D07gooO01l000O00=oo`0301ml07`0009oo`0301moogoo009l000401moogooOol2O004Ool00`0O
O01oo`02Ool00`0OO01oo`02Ool01@0OO01oogooO0000Woo00=l07ooO0000Woo1G`0Bgoo0017Ool6
O00POol00`0OOomoo`05Ool00`0OOomoo`03Ool00`0OOomoo`04Ool01@0OOomoogoo01l017oo00<0
7gooOol01P0O0Woo00D07gooOomoo`0O00=oo`0501moogoo01ml0003Ool01P0OOomoog`0Ool07`=o
o`0301ml07oo00=oo`0301ml07oo009oo`0501moog`0Ool07`02Ool00g`0Ool07`02Ool017`0Ool0
7g`00Woo00Il07ooO01oog`0Ool3O01;Ool004Moo`El021oo`0301moogoo00Eoo`0301moogoo00=o
o`0301moogoo00Aoo`0301moogoo009oo`0501moogooOol07`02Ool0100OOol07goo0`0O0Woo00@0
7gooOol07`=oo`0901moogooOol07gooO01oo`0O00Aoo`05O01oogooOol07`02Ool017`0Oomoo`0O
0Woo00=l07oo01l00goo00=l000OOol00Woo00Il000OOomoog`001l2Ool00g`0Oomoo`02O002Ool4
O01;Ool004Ioo`9l0004Ooml07`0O00OOol00`0OOomoo`04Ool201l5Ool00`0OOomoo`04Ool00`0O
Oomoo`02Ool01@0OOomoogoo01l00Woo00D07goo01l07goo00<07`9oo`0401moogoo01l3Ool0100O
Oomoo`0O0goo0W`017oo00D07g`0O01oo`0O00=oo`9l00Aoo`9l00=oo`0301ml07oo009oo`0301ml
07oo009oo`0<O01oogooOoml07ooO01oog`0Ooml07oo0g`0BWoo0016Ool5O00OOol00`0OOomoo`04
Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`02Ool01@0OOomoogoo01l00goo00<07goo
01l01@0O0Woo00@07gooOol07`=oo`0401moogoo01l3Ool00`0OOoml0002Ool01@0OOomoogooO000
17oo00<07gooO0000goo00D07gooO01oo`0O009oo`9l0008Ool07gooO01oo`0OOoml009oo`03O01o
ogoo009l009oo`Al04Yoo`00AWoo1G`07Woo00<07gooOol017oo00<07gooOol017oo00<07gooOol0
17oo00<07gooOol00Woo00D07gooOomoo`0O00=oo`0401moo`0OOol501l2Ool0100OOomoo`0O0Woo
00D07gooOomoo`0O00=oo`0301moogoo009l00=oo`0301moog`000=oo`0601moogooO01oo`0O0goo
00=l000OOol00goo00Il07ooOoml07oo01l2Ool02g`0Oomoog`0Ooml07ooO01oog`0Ool00W`0BWoo
0016Ool4O00NOol00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`03Ool0
1@0OOomoogoo01l00goo00H07goo01moo`0OOol301l01Goo01moogoo01l00goo00@07gooOol07`Ao
o`0501moogooOol07`02O00017oo01moogoo0W`000<07gooOol00Woo0W`00goo00<07g`0Ool00goo
00D07g`0Oomoog`000Aoo`03O01oog`0009oo`04O01oog`0Ool4O019Ool004Eoo`El01eoo`0301mo
ogoo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00=oo`0501moogooOol07`03Ool0
0`0OOol07`02Ool01`0OOol07goo01moo`0O009oo`0401moogoo01l3Ool01@0OOomoogoo01l00goo
00D07gooOomoog`000Aoo`0301ml07oo00=oo`0301moog`0009oo`0301moog`0009oo`0301moog`0
009oo`0301ml07oo009oo`04O01oogooO002Ool2O0000gooO01l0002O019Ool004Eoo`El01aoo`03
01moogoo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00=oo`0501moogooOol07`04
Ool0100OOol07goo100O00Aoo`0OOol07`9oo`0401moogoo01l2Ool00`0OOomoo`02Ool0100OOomo
o`0O17oo00<07g`0Ool00Woo00<07gooO0000Woo00H07gooOomoog`001l3Ool00g`0Ool07`02Ool0
1G`001moogooO0000goo00Ul07ooOoml07ooO01oog`0Ool00g`0BGoo0015Ool4O00LOol00`0OOomo
o`04Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`03Ool01@0OOomoogoo01l017oo00<0
7goo01l00Woo100O00Aoo`0OOol07`9oo`0401moogoo01l2Ool01@0OOomoogoo01l00goo00<07goo
Ool00Woo00D07gooO01l000O00=oo`9l000301moogoo009oo`03O01oogoo009oo`03O01oogoo009o
o`0501moogooOoml0003Ool00g`0Ooml0002Ool2O0000gooO01l0002O018Ool004Aoo`El01]oo`03
01moogoo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo009oo`07
01moogooOol07goo01l00Woo00<07goo01l00P0O00Aoo`0OOol07`9oo`0301moo`0O009oo`0301mo
ogoo009oo`0401moogoo01l4Ool00`0OOomoo`02Ool00g`0Oomoo`02Ool00`0OO01oo`02Ool00`0O
Ooml0003Ool01`0OO01oogoo01moog`000=oo`04O01oogooO002Ool017`0Ooml07oo1G`0B7oo0014
Ool5O00JOol00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0O
Oomoo`02Ool00`0OOomoo`02Ool00`0OOol07`02Ool0200OOol07`0OOol07goo01l2Ool0100OOomo
o`0O0Woo00D07gooOomoo`0O00=oo`0301moogoo009oo`0701moogooOol07gooO0000goo00<07goo
O0000Woo00H07gooOoml07oo01l2Ool00g`0Ool07`02Ool01G`0OomoogooO0000Woo00=l07ooO000
0Woo0W`000Aoog`0O01l04Qoo`00A7oo17`06Woo00<07gooOol017oo00<07gooOol017oo00<07goo
Ool017oo00<07gooOol00goo00<07gooOol00Woo00<07gooOol00Woo00<07goo01l00Woo00<07goo
Ool00P0O00Aoo`0OOol07`9oo`0301moo`0O009oo`0501moogooOol07`03Ool00`0OOomoo`02Ool0
1@0OOomoogoo01l00goo0W`000H07gooOomoog`001l4Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool0
1g`0OomoogooO01oog`0009oo`04O01oog`0Ool5O017Ool004=oo`El01Uoo`0301moogoo00Aoo`03
01moogoo00Aoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo009oo`0301moogoo009oo`04
01moogoo01l2Ool00`0OOol07`0201l017oo01moo`0O0Woo00<07goo01l00Woo00D07gooOomoo`0O
00=oo`0301moogoo009oo`0501moogooOol07`05Ool01P0OOomoogoo01ml00Aoo`03O01oogoo009o
o`0301ml07oo00=oo`04O01oogooO002Ool00g`0Ooml0002Ool6O017Ool004=oo`El01Qoo`0301mo
ogoo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00=oo`0501mo
ogooOol07`02Ool0100OOomoo`0O0Woo0`0O00Ioo`0OOol07goo01l2Ool0100OOomoo`0O0Woo00D0
7gooOomoo`0O00Aoo`0501moogooOol07`05Ool00`0OOoml0002Ool00`0OOoml0002Ool00`0OOoml
0002Ool00`0OOoml0005Ool017`0Oomoog`00Woo00Il07ooO01oog`0Ool4O017Ool004=oo`Al01Qo
o`0301moogoo00Eoo`0301moogoo00=oo`0301moogoo00Eoo`0301moogoo00=oo`0301moogoo009o
o`0301moogoo009oo`0401moogoo01l2Ool00`0OOomoo`0301l00goo01l07`02Ool00`0OOol07`02
Ool01@0OOomoogoo01l00goo00D07gooOomoo`0O00Aoo`0301moogoo009oo`0601moogooO01oo`0O
0goo00=l000OOol00Woo00=l07oo01l00Woo00=l07ooOol00Woo00Ul07ooOomoog`0Ooml07ooO000
0Woo1W`0AWoo0013Ool4O00GOol00`0OOomoo`05Ool00`0OOomoo`03Ool00`0OOomoo`05Ool00`0O
Oomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`02Ool0100OOomoo`0O0Woo00<07gooOol01@0O00Ao
o`0OOol07`9oo`0401moogoo01l2Ool01@0OOomoogoo01l017oo00D07gooOomoo`0O00Eoo`0501mo
ogooOoml0005Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool017`0Oomoog`00Woo
00Al07ooO01oo`Il04Ioo`00@goo17`05goo00<07gooOol017oo00<07gooOol00goo00<07gooOol0
1Goo00<07gooOol00goo00<07gooOol00goo00D07gooOomoo`0O00=oo`0401moogoo01l2Ool501l0
17oo01moo`0O0Woo00<07goo01l00goo00D07gooOomoo`0O00=oo`0301moogoo009oo`0301moogoo
009oo`0701moogooOol07gooO0000goo00<07gooO0000goo00<07g`0Ool00goo00=l07ooOol00Woo
00]l07ooOoml07ooO01oog`0Ooml07oo00Al04Ioo`00@goo0g`000=oog`0Ool057oo00<07gooOol0
17oo00<07gooOol017oo00<07gooOol017oo00<07gooOol00goo00<07gooOol00goo00<07gooOol0
0Woo00@07gooOol07`=oo`0501moogoo01moo`0301l017oo01moo`0O0Woo00<07goo01l00Woo00D0
7gooOomoo`0O00=oo`0301moogoo009oo`0301moogoo009oo`0301moogoo009oo`0401moogooO002
Ool01P0OOomoog`0Ool07`9oo`05O01oogooOoml0004Ool017`0Oomoog`00Woo0W`00Woo1G`0AWoo
0012Ool4O0000gooO01oo`0COol00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0O
Oomoo`04Ool00`0OOomoo`02Ool00`0OOomoo`02Ool01@0OOomoogoo01l00Woo00<07gooOol00P0O
00aoo`0O01l07goo01moo`0OOol07goo01l3Ool01@0OOomoogoo01l00Woo00<07gooOol00goo00D0
7gooOomoo`0O00Aoo`0301moogoo009oo`03O0007goo00=oo`03O01oogoo009oo`05O01oogooOoml
0004Ool02G`0Oomoog`0Ooml07ooO01oo`05O016Ool0049oo`Al0003Ooml07oo019oo`0301moogoo
00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo009oo`0301moogoo
009oo`0501moogooOol07`03Ool00`0OOomoo`0201l00goo01l07`0201l01goo01moogoo01moo`0O
009oo`0501moogooOol07`03Ool00`0OOomoo`02Ool00`0OOomoo`02Ool01@0OOomoogoo01l01Goo
00<07g`0Ool00Woo00<07gooO00017oo00El07ooOomoog`000=oo`04O01oogooO002Ool2O002Ool4
O016Ool0049oo`Al0003Ooml07oo019oo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00Eo
o`0301moogoo00=oo`0301moogoo00=oo`0501moogooOol07`04Ool0100OOomoo`0O0Woo00@07goo
01moo`@07`06Ool07goo01moo`0O0goo00@07gooOol07`=oo`0301moogoo009oo`0301moogoo009o
o`0501moogooOol07`06Ool01@0OOoml07oo01l00goo00El07ooOomoog`000Aoo`07O01oogooOoml
07ooO0000Woo00Al07ooO01oo`Al04Ioo`00@Woo17`00Woo00=l07ooOol03goo00<07gooOol017oo
00<07gooOol00goo00<07gooOol01Goo00<07gooOol00goo00<07gooOol00goo00<07gooOol00Woo
00D07gooOomoo`0O00=oo`0301moogoo00807`03Ool07`0O00<07`06Ool07goo01moo`0O0Woo00D0
7gooOomoo`0O009oo`0301moogoo00=oo`0501moogooOol07`04Ool00`0OOomoo`03Ool01@0OOomo
ogooO0001Goo00El07ooOomoog`000=oo`05O01oogooOoml0002Ool00g`0Oomoo`02O0000gooO01l
0002O016Ool0049oo`Al009oo`03O01oogoo00ioo`0301moogoo00Aoo`0301moogoo00=oo`0301mo
ogoo00Eoo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo009oo`0301moogoo009oo`0401mo
ogoo01l3Ool201l00goo01l07`0301l01Woo01moo`0OOol07`9oo`0401moogoo01l3Ool00`0OOomo
o`02Ool01@0OOomoogoo01l017oo00<07gooOol00goo00<07gooOol00Woo00<07g`0Ool00goo00=l
07ooOol00Woo00El07ooOomoog`000=oo`03O01oog`0009oo`9l0003Ooml07`0009l04Ioo`00@Woo
17`00goo00=l07ooOol03Goo00<07gooOol00goo00<07gooOol017oo00<07gooOol017oo00<07goo
Ool017oo00<07gooOol00goo00D07gooOomoo`0O00Aoo`0501moogooOol07`02Ool0100OOol07goo
1P0O00Aoo`0OOol07`9oo`0501moogooOol07`02Ool00`0OOomoo`02Ool00`0OOomoo`02Ool01@0O
Oomoogoo01l01Goo00<07gooOol00Woo00@07gooOoml00Aoo`03O01oogoo009oo`05O01oogooOoml
0002Ool01g`0Oomoog`0Ooml07oo009l0003Ooml07`004Ioo`00@Woo1G`00Woo00=l07ooOol037oo
00<07gooOol00goo00<07gooOol017oo00<07gooOol01Goo00<07gooOol00goo00<07gooOol00goo
00<07gooOol00Woo00D07gooOomoo`0O00=oo`0801moogooOol07goo01moo`@07`06Ool07goo01mo
o`0O0Woo00@07gooOol07`=oo`0501moogooOol07`04Ool01@0OOomoogoo01l01Goo00<07gooOol0
0Woo00<07gooOol00Woo00=l07ooOol00Woo00El07ooOomoog`000=oo`07O01oogooOoml07ooO000
0Woo0W`000Aoog`0O01l04Ioo`00@Woo1G`00Woo00=l07ooOol02goo00<07gooOol00goo00<07goo
Ool017oo00<07gooOol01Goo00<07gooOol00goo00<07gooOol00goo00<07gooOol00Woo00<07goo
Ool00Woo00D07gooOomoo`0O00=oo`807`03Ool07goo00@07`04Ool07goo01l2Ool0100OOomoo`0O
0goo00<07gooOol00Woo00D07gooOomoo`0O00Aoo`0301moogoo009oo`0301moogoo009oo`0301mo
ogoo00=oo`03O01oogoo00=oo`05O01oogooOoml0003Ool017`0Oomoogoo0W`00Woo00=l07ooO000
17`0AGoo0012Ool3O0000gooO01oo`02Ool00g`0Oomoo`09Ool00`0OOomoo`04Ool00`0OOomoo`03
Ool00`0OOomoo`05Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`02Ool01@0OOomoogoo
01l00goo00P07gooOomoo`0OOol07goo1P0O00Aoo`0OOol07`9oo`0401moogoo01l2Ool00`0OOomo
o`02Ool01@0OOomoogoo01l017oo00<07gooOol00Woo00<07gooOol00goo00<07gooOol017oo00=l
07ooOol00Woo00=l07ooOol00Woo00Al07ooOoml00=oo`03O01oog`0009oo`Il04Eoo`00@Woo0g`0
0Woo00Al07ooOoml00]oo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo
00Aoo`0301moogoo00=oo`0301moogoo009oo`0301moogoo009oo`0501moogooOol07`03Ool0100O
Ool07goo1P0O00Ioo`0OOol07goo01l2Ool01@0OOomoogoo01l00goo00<07gooOol00Woo00D07goo
Oomoo`0O00Eoo`0301moogoo009oo`0301moogoo00Ioo`03O01oogoo009oo`05O01oogooOoml0003
Ool01W`0Oomoog`0Ooml009oo`Il04Eoo`00@Woo0g`00Woo00El07ooOomoog`000Uoo`0301moogoo
00=oo`0301moogoo00Aoo`0301moogoo00Eoo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo
00=oo`0501moogooOol07`03Ool01@0OOomoogoo01l00Woo00<07goo01l01P0O00Aoo`0OOol07`9o
o`0501moogooOol07`03Ool00`0OOomoo`02Ool01@0OOomoogoo01l01Goo00<07gooOol00Woo00<0
7gooOol027oo00=l07ooOol00Woo00El07ooOomoog`0009oo`08O01oogooOoml07ooO01oo`Il04Eo
o`00@Woo17`000=oog`0Ool00Woo00=l07ooOol01Woo00<07gooOol00goo00<07gooOol017oo00<0
7gooOol01Goo00<07gooOol00goo00<07gooOol017oo00<07gooOol00Woo00<07gooOol00Woo00D0
7gooOomoo`0O00=oo`0601moo`0OOol07goo100O00Ioo`0OOol07goo01l2Ool0100OOomoo`0O17oo
00D07gooOomoo`0O00Aoo`0301moogoo009oo`0301moogoo009oo`0301moogoo00Uoo`03O01oogoo
00=oo`04O01oogooO003Ool01g`0Oomoog`0Ooml07oo009l0004Ooml07`0O015Ool0049oo`Al009o
o`04O01oogooO007Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`03
Ool00`0OOomoo`04Ool00`0OOomoo`02Ool00`0OOomoo`02Ool01@0OOomoogoo01l00goo00L07goo
Ool07goo01moo`0501l017oo01moo`0O0Woo00D07gooOomoo`0O00=oo`0501moogooOol07`04Ool0
0`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`0:Ool00g`0Oomoo`02Ool01G`0OomoogooO000
0Woo00Al07ooOoml009oo`03O01oog`000Al04Eoo`00@Woo17`00Woo00El07ooOomoog`000Ioo`03
01moogoo00=oo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00=oo`03
01moogoo00=oo`0301moogoo009oo`0501moogooOol07`03Ool01`0OOomoo`0OOol07goo00D07`04
Ool07goo01l2Ool0100OOomoo`0O0goo00D07gooOomoo`0O00Aoo`0301moogoo009oo`0301moogoo
00=oo`0301moogoo00aoo`03O01oogoo009oo`04O01oogooO003Ool00g`0Ooml0002Ool00g`0Ooml
0004O015Ool0049oo`Al00=oo`04O01oogooO005Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0O
Oomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0O
Oomoo`02Ool01@0OOomoogoo01l00Woo00D07goo01l07goo00<07`04Ool07goo01l2Ool01@0OOomo
ogoo01l00Woo00D07gooOomoo`0O00Aoo`0301moogoo009oo`0301moogoo00=oo`0301moogoo00io
o`03O01oogoo009oo`04O01oogooO002Ool017`0Oomoog`00Woo1W`0AGoo0012Ool5O002Ool01G`0
OomoogooO00017oo00<07gooOol00goo00<07gooOol017oo00<07gooOol017oo00<07gooOol00goo
00<07gooOol017oo00<07gooOol00goo00<07gooOol00Woo00D07gooOomoo`0O00=oo`0701moogoo
01moo`0OOol01@0O00Ioo`0OOol07goo01l3Ool01@0OOomoogoo01l00Woo00<07gooOol00Woo00<0
7gooOol00Woo00<07gooOol00goo00<07gooOol03goo00=l07ooOol00Woo00Al07ooOoml009oo`04
O01oogooO002Ool6O015Ool0049oo`El009oo`05O01oogooOoml0003Ool00`0OOomoo`03Ool00`0O
Oomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0O
Oomoo`02Ool00`0OOomoo`02Ool01@0OOomoogoo01l00Woo00@07goo01moo`@07`04Ool07goo01l2
Ool0100OOomoo`0O0goo00@07gooOol07`Aoo`0301moogoo009oo`0301moogoo00=oo`0301moogoo
015oo`03O01oogoo009oo`04O01oogooO002Ool01G`0Oomoog`0Ool01W`0AGoo0012Ool5O003Ool0
1G`0OomoogooO0000Woo00<07gooOol00goo00<07gooOol00goo00<07gooOol017oo00<07gooOol0
17oo00<07gooOol00goo00<07gooOol017oo00<07gooOol00Woo00D07gooOomoo`0O00=oo`0401mo
ogoo01l2Ool00`0OOol07`0301l01Woo01moo`0OOol07`9oo`0501moogooOol07`02Ool00`0OOomo
o`02Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`0COol01G`0OomoogooO0000Woo00Al
07ooOoml009oo`03O01oog`000El04Eoo`00@Woo17`000Eoog`0Oomoog`000Aoo`03O0007goo00Ao
o`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00=o
o`0301moogoo00=oo`0501moogooOol07`03Ool0100OOomoo`0O0Woo0P0O00Eoo`0O01l07goo0080
7`9oo`0401moogoo01l2Ool0100OOomoo`0O17oo00<07gooOol00goo00<07gooOol00Woo00<07goo
Ool057oo00=l07ooOol00Woo00Al07ooOoml009oo`06O01oog`0Ooml07oo17`0AGoo0012Ool4O000
1GooO01oogooO00017oo00=l000OOol00goo00<07gooOol017oo00<07gooOol017oo00<07gooOol0
17oo00<07gooOol00goo00<07gooOol00goo00<07gooOol00goo00<07gooOol00Woo00D07gooOomo
o`0O009oo`0601moo`0OOol07goo100O00Aoo`0OOol07`9oo`0401moogoo01l2Ool00`0OOomoo`02
Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`0FOol01G`0OomoogooO0000Woo00Ul07oo
Ooml07ooO01oog`0Ool00g`0AWoo0012Ool4O0000gooO01oo`02Ool01W`0Oomoogoo01ml00Aoo`03
01moogoo00=oo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00=oo`03
01moogoo00=oo`0501moogooOol07`03Ool0100OOomoo`0O0Woo00@07goo01moo`807`05Ool07`0O
Ool07`02Ool0100OOomoo`0O0goo00D07gooOomoo`0O00Aoo`807`Aoo`0301moogoo01Moo`03O01o
ogoo009oo`06O01oogooO01oog`00Woo0W`000Aoog`0O01l04Ioo`00@Woo1G`000Eoog`0Oomoog`0
00=oo`0301ml07oo009oo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo
00Aoo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo009oo`0501moogooOol07`02Ool01`0O
Oomoo`0OOol07goo00<07`06Ool07goo01moo`0O0Woo00D07gooOomoo`0O00=oo`0301moogoo009o
o`0301moogoo00=oo`0301moogoo01Uoo`05O01oogooOoml0002Ool01G`0Oomoog`0Ool00W`000Ao
og`0O01l04Ioo`00@goo17`000=oog`0Ool00Woo00=l07oo01l00Woo00Al07ooOol07`Eoo`0301mo
ogoo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00=oo`0301mo
ogoo009oo`0501moogooOol07`02Ool01`0OOomoo`0OOol07goo00@07`07Ool07gooOol07goo01l0
0goo00<07gooOol00Woo00D07gooOomoo`0O00Eoo`0301moogoo01Yoo`03O01oogoo009oo`03O01o
og`0009oo`05O01oog`0O01oo`03O016Ool004=oo`Al009oo`06O01oogooOoml000O0goo00=l000O
Ool01Goo00<07gooOol00goo00<07gooOol017oo00<07gooOol017oo00<07gooOol00goo00<07goo
Ool00goo00<07gooOol00Woo00D07gooOomoo`0O009oo`0401moogoo01l2Ool00`0OOol07`0201l0
1Goo01moogoo01l00Woo00@07gooOol07`Aoo`0501moogooOol07`05Ool00`0OOomoo`0LOol01G`0
OomoogooO0000Woo00Al07ooO01oo`9l0004Ooml07`0O016Ool004=oo`=l0004Ooml07ooO003Ool0
0g`0Oomoo`02Ool00g`001moo`04Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`04Ool0
0`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`02Ool01@0OOomoogoo01l00Woo00@07gooOol0
7`9oo`H07`9oo`0401moogoo01l3Ool01@0OOomoogoo01l00goo00<07gooOol00goo00<07gooOol0
7Goo00El07ooOomoog`0009oo`06O01oog`0Ooml07oo17`0AWoo0013Ool5O002Ool01G`0Oomoo`0O
O0000goo00<07g`0Ool017oo00<07gooOol00goo00<07gooOol017oo00<07gooOol017oo00<07goo
Ool00goo00<07gooOol00goo00<07gooOol00Woo00D07gooOomoo`0O00=oo`0701moogoo01moo`0O
Ool00`0O00Aoo`0OOol07`9oo`0501moogooOol07`02Ool201l3Ool00`0OOomoo`03Ool00`0OOomo
o`0OOol017`0Oomoog`00Woo00=l07ooO0000Woo17`0Agoo0013Ool4O0001WooO01oog`0Ool07`9o
o`06O01oogoo01moog`00goo00<07gooOol00goo00<07gooOol017oo00<07gooOol017oo00<07goo
Ool017oo00<07gooOol00goo00<07gooOol00Woo00D07gooOomoo`0O00=oo`0501moogoo01moo`06
01l2Ool00`0OOol07`03Ool0100OOomoo`0O17oo00<07gooOol00Woo0P0O8Woo00Ml07ooOomoog`0
Ooml0002Ool00g`0Ooml0003O017Ool004=oo`Al0006Ooml07ooOoml000O0goo00El07oo01moog`0
00=oo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo
00=oo`0301moogoo009oo`0301moogoo009oo`0401moogoo01l2Ool00`0OOomoo`0501l2Ool0100O
Oomoo`0O0Woo00@07gooOol07`Aoo`0301moogoo009oo`0301moogoo02=oo`06O01oogooO01oog`0
0Woo00=l07ooO0000g`0Agoo0014Ool5O003Ool01W`0OomoogooO0007`=oo`03O01oo`0O00Eoo`03
01moogoo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo009oo`05
01moogooOol07`03Ool0100OOomoo`0O0Woo1@0O00Eoo`0OOomoo`0O009oo`0401moogoo01l4Ool0
0`0OOomoo`02Ool00`0OOomoo`0TOol017`0Oomoog`00Woo00Al07ooO01oo`Al04Moo`00A7oo17`0
00Eoog`0Oomoog`000Aoo`03O01oogoo009oo`03O0007goo00Aoo`0301moogoo00=oo`0301moogoo
00Aoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00=oo`0501moogooOol07`03Ool0100O
Oomoo`0O0Woo1P0O0Woo00@07gooOol07`9oo`0301moogoo009oo`0401moogooOol201lXOol00g`0
Ooml0002Ool017`0Ooml07oo17`0Agoo0014Ool4O0001WooO01oo`0OOoml009oo`0301moog`000=o
o`0301ml07oo00=oo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00Eoo`0301moogoo00=o
o`0301moogoo009oo`0301moogoo009oo`0501moogooOol07`02Ool00`0OOomoo`0801l2Ool0100O
Oomoo`0O17oo00D07gooOomoo`0O02Yoo`09O01oogooO01oog`0Ooml07oo00=l04Qoo`00A7oo1G`0
00=oog`001l00Woo00El07oo01moog`000=oo`0301moog`000=oo`0301moogoo00=oo`0301moogoo
00Aoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00=oo`0501moogooOol07`03Ool01@0O
Oomoogoo01l00Woo1P0O0Woo0P0O0Woo00<07gooOol00Woo00D07gooOomoo`0O02]oo`06O01oogoo
O01oog`00Woo17`0B7oo0015Ool4O0000gooO0007`02Ool00g`0Ool07`02Ool00g`0Ool07`03Ool0
0g`0Ool07`06Ool00`0OOomoo`03Ool00`0OOomoo`05Ool00`0OOomoo`03Ool00`0OOomoo`02Ool0
0`0OOomoo`02Ool01@0OOomoogoo01l00goo00<07goo01l01@0O0Woo00<07gooOol00P0O17oo00D0
7gooOomoo`0O02eoo`03O01oog`0009oo`03O01oog`000=l04Qoo`00AGoo17`00Woo00El07ooOomo
og`000Aoo`03O0007goo00=oo`03O0007goo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301mo
ogoo00=oo`0301moogoo00=oo`0501moogooOol07`04Ool0100OOomoo`0O0Woo1P0O00Eoo`0OOomo
o`0O00Eoo`0501moogooOol07`0^Ool00g`0Ooml0002Ool00g`0Ooml0003O018Ool004Eoo`El0003
01moog`0009oo`03O01oogoo009oo`0301ml07oo00=oo`0301ml07oo00Aoo`0301moogoo00=oo`03
01moogoo00Eoo`0301moogoo00=oo`0301moogoo009oo`0301moogoo009oo`0301moogoo009oo`05
01moogoo01moo`0801l2Ool00`0OOomoo`02Ool201l3Ool00`0OOomoo`0]Ool01g`0Oomoog`0Ooml
07oo00Al04Qoo`00AWoo17`000L07gooOoml000OOoml0003Ool00`0OO01oo`03Ool00`0OOoml0003
Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`03Ool01@0OOomoogoo
01l017oo00H07gooOomoo`0OOol501l01Goo01l07goo01l017oo00<07gooOol00Woo00<07gooOol0
;Woo00El07ooOoml07oo00El04Uoo`00AWoo1G`00Woo00El000OOomoog`0009oo`0301moog`0009o
o`0401moogooO003Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`03
Ool01@0OOomoogoo01l017oo00H07gooOomoo`0OOol501l01Goo01moogoo01l00goo00@07gooOomo
o`807c9oo`04O01oog`0Ool5O019Ool004Moo`=l000501ml07ooOoml0003Ool00g`001moo`02Ool0
0g`0Ool07`03Ool00g`0Ool07`06Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`03Ool0
0`0OOomoo`02Ool00`0OOomoo`02Ool0100OOomoogoo1@0O00Ioo`0O01l07goo01l2Ool201l3Ool0
0`0OOomoo`0bOol017`0Ooml07oo1G`0BGoo0017Ool3O0001P0OOoml000OOoml00=oo`03O01oogoo
009oo`03O01oogoo00=oo`03O0007goo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo
00=oo`0501moogooOol07`05Ool0100OOomoogoo1`0O00=oo`0O01l00Woo00<07gooOol00Woo00<0
7gooOol0<goo00Al07ooO01oo`El04Uoo`00B7oo0g`000=oog`001l00Woo00El07oo01moog`000=o
o`0301ml07oo00Aoo`03O01oogoo00=oo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00=o
o`0301moogoo009oo`0301moogoo009oo`0401moogooOol301l017oo01l07goo0`0O00=oo`0O01l0
0goo0P0O=Woo00Al07ooO01oo`Al04Yoo`00B7oo17`000Moo`0OOomoog`0Ool07`02Ool01W`0Oomo
o`0OOoml00=oo`0301moog`000=oo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00=oo`03
01moogoo009oo`0301moogoo009oo`0401moogooOol801l00goo01l07`03Ool201liOol2O0000goo
O01l0002O01:Ool004Qoo`9l000501ml07oo01ml0002Ool00g`001moo`02Ool00g`001moo`02Ool0
17`0Oomoo`0O0Woo00Al07ooOol07`Ioo`0301moogoo00Aoo`0301moogoo009oo`0301moogoo00=o
o`0301moogoo009oo`0401moogooOol401l00goo01l07`0301l2Ool201lkOol2O0000gooO01l0002
O01:Ool004Uoo`Al000601moog`0Ool07g`017oo00=l07ooOol00Woo00=l000OOol00goo0W`000<0
7gooOol017oo00<07gooOol00goo00<07gooOol00goo00<07gooOol00Woo00<07gooOol00goo00<0
7gooOol02@0O00Aoo`0O01l07ceoo`9l0004Ooml07`0O01;Ool004Uoo`9l000301ml000O009oo`03
O0007g`000=oo`0301ml07oo00Aoo`03O01oogoo00=oo`0301ml07oo00Aoo`0301moogoo00Aoo`03
01moogoo00=oo`0301moogoo009oo`0301moogoo009oo`0301moogoo00<07`04Ool07`0OOol301l0
0goo01moo`0nOol2O00017ooO01l07`0Bgoo0019Ool5O002Ool017`001moog`00Woo00<07gooO000
17oo00<07g`0Ool00goo00<07gooO00017oo00<07gooOol00goo00<07gooOol00goo00<07gooOol0
0goo00<07gooOol00Woo00<07goo01l00P0O00=oo`0O01l01`0O?goo1G`0C7oo001:Ool2O0000goo
01ml0002Ool01W`0Oomoog`0Ool07`9oo`04O01oogoo01l2Ool2O002Ool0100OOomoog`00Woo00<0
7gooOol017oo00<07gooOol00goo00<07gooOol00Woo00<07gooOol00goo00<07goo01l01P0O00Io
o`0O01l07goo01loOol5O01<Ool004Yoo`=l000601ml07`001moog`00Woo00=l07ooOol00Woo00=l
07oo01l017oo00=l000OOol00goo00=l07oo01l01Goo00<07gooOol017oo00<07gooOol00Woo00<0
7gooOol00Woo00<07goo01l02`0O00=oo`0OOol0?Woo17`0CGoo001;Ool5O0001`0OOomoog`0Ool0
7g`000Aoo`03O01oogoo00Aoo`0301moogoo00=oo`9l00Eoo`0301moogoo00Aoo`0301moogoo009o
o`0301moogoo009oo`/07`05Ool07gooOol07`0nOol5O01=Ool004]oo`9l000401ml07`001l2Ool0
1G`0Ool07gooO0000goo00<07g`0Ool00goo00<07gooO00017oo00<07gooO00017oo00<07gooOol0
0goo00<07gooOol00goo00<07gooOol00Woo1`0O00Ioo`0OOol07goo01l2Ool00`0OOomoo`0lOol5
O01=Ool004aoo`06O0007g`0O0007g`00Woo00Ml000OOomoog`0Ool07`02Ool2O002Ool0100OOomo
og`00Woo00D07gooOomoog`0009oo`0301moogoo00Aoo`0301moogoo009oo`0301moogoo009oo`L0
7`07Ool07`0OOol07goo01l00Woo00<07gooOol0?7oo17`0CWoo001=Ool3O0001P0OOoml07oo01ml
00=oo`03O0007goo00=oo`03O0007goo00=oo`9l000301moogoo009oo`9l000301moogoo00=oo`03
01moogoo00=oo`0301moogoo00T07`04Ool07`0O01l2Ool0100OOomoo`0O?Woo17`0CWoo001>Ool0
0`0OO01l0002Ool00g`001ml0003Ool00`0OO01oo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool0
0`0OO01l0004Ool00`0OOomoo`03Ool00`0OOol07`0501l01Goo01l07`0OOol00`0O0Woo00@07goo
Ool07ceoo`Al04moo`00CWoo00T07g`0O01l07ooO0007gooO0000Woo00<07gooO00017oo00<07g`0
O0000goo00<07gooO00017oo00<07gooOol00W`000=oo`0OOol017oo00<07goo01l00P0O00=oo`0O
Ool00P0O00Aoo`0OOomoo`<07`9oo`0401moogoo01lmOol4O01?Ool004moo`06O0007g`0O01oog`0
0Woo0W`000@07gooOoml009oo`0501moogooOoml0002Ool00`0OOomoo`02O002Ool00`0OOomoo`02
Ool00g`001moo`04Ool401l01Goo01moo`0OOol00`0O00=oo`0OOol00P0O0Woo00@07gooOol07cao
o`Al051oo`00D7oo17`000<07g`0Ool00Woo00Ml07ooOomoog`0Ool07`04Ool00g`001moo`04Ool2
O005Ool00`0OO01l0002Ool501l01goo01l07`0OOol07goo00807`03Ool07goo00807`03Ool07`0O
009oo`0301moogoo03Uoo`Al055oo`00DGoo0g`000<07gooO0000Woo00<07g`0O0000Woo0W`01Goo
00<07g`0Ool017oo00<07g`0O0000goo00<07goo01l00W`00`0O00Aoo`0O01moo`807`04Ool07goo
01l2Ool201l00goo01moo`0201l2Ool00`0OOomoo`0iOol4O01AOol0055oo`=l000601ml07ooO01o
o`0O0Woo00El07oo01moog`000Aoo`0401moog`0O002Ool01@0OOomoogooO0001`0O00El000OOol0
7goo00<07`05Ool07gooOol07`02Ool201l00goo01moo`0201l2Ool00`0OOomoo`0hOol4O01BOol0
059oo`9l000601ml07`001ml000O0goo00Al000OOomoo`9l0003Ool07goo00=oo`03O01oo`0O00@0
7`9l00@07`04Ool07`0OO00201l01goo01moogoo01moo`0O00=oo`807`03Ool07goo00807`9oo`03
01moogoo03Moo`El059oo`00DWoo00<07g`0O0000g`000<07g`001l00`0O00=l000OOol00Woo00=l
000O01l0100O0W`01P0O0W`000H07goo01l07goo01l2O00017oo01moo`0O0Woo00T07gooOol07goo
01moo`0OOol00P0O0Woo00<07gooOol0=Woo1G`0Dgoo001COol00`0OO01l0002O0000`0OOoml0002
Ool00`0OOoml000401l2O002Ool401l00g`001l07`0401l017ooO01l07oo0P0O00=oo`0OOol00W`0
00Eoo`0OOomoo`0O009oo`0401moo`0O01l2Ool201l2Ool00`0OOomoo`0eOol5O01DOol005Aoo`El
00807`9l00<07`03O0007`0O00<07`9l0005Ool07`0O01moo`02O0000goo01l07`02Ool01`0OOoml
000OOol07goo00807`04Ooml07`0Ool201l2Ool0100OOol07`0O0Woo00D07gooOomoo`0O03Moo`Al
05Eoo`00EGoo00D07g`0O0007g`000=oo`08O01oogooOoml07oo01moo`<07`04O0007gooOol201l0
0gooO01l0002Ool0100OOol07`0O0W`00Woo0P0O00=oo`0OOol00W`00goo0P0O00Eoo`0OOomoo`0O
00=oo`0301moogoo03Aoo`Al05Ioo`00EWoo0W`000@07g`0O01l00807`9l00807`9l000301moogoo
009oo`0401ml000OOol201l01goo01ml07`0Ool07goo00807`07Ooml07`0Ool07goo01l00Woo00P0
7g`0O0007goo01moo`0O0Woo00D07gooOomoo`0O03Eoo`Al05Moo`00Egoo00Ml000OO01l07ooO000
7`02Ool017`0Oomoo`0O0W`0100O00=oog`0O0000Woo0P0O0Woo00=l07ooOol00P0O0Woo00@07g`0
01l07`=oo`0301moogoo009l00807`=oo`0501moogooOol07`0dOol4O01HOol005Qoo`Ml009oo`9l
00<07`9l000601moo`0O01moog`00P0O0goo00@07g`0O0007`9oo`0401moogoo01l2O0000goo01l0
7`02Ool00`0OOol07`02O002Ool01@0OOomoogoo01l0<Woo1G`0FGoo001IOol4O00201l01G`001l0
7`0OO00017oo00=l000OOol00Woo00<07g`0O0000Woo00@07gooOol07`9l0005Ool07gooOol07`02
Ool2O0001@0OOomoo`0OOol00P0O00Aoog`0O0007`=oo`0301moogoo02moo`03O01oog`0009l05Yo
o`00FWoo1G`000Eoog`0Ool07goo009l00<07`9l0005Ool07goo01moo`02O003Ool00`0OOomoo`02
O0000goo01l07`03Ool0100OO01l000O0Woo0P0O0Woo00<07g`0O0000Woo00<07gooOol0;Woo00=l
07ooO0000W`0Fgoo001KOol2O0001@0OO01l07ooO0000`0O00Aoog`0Ool07`9oo`03O01oogoo0080
7`9oo`9l00807`9oo`0401moog`001l3Ool201l2Ool3O00017oo01moogoo0P0O00Aoog`0O0007bmo
o`03O01oog`0009l05aoo`00G7oo00=l000OO0001G`00goo0W`00P0O00Aoog`0O0007`Aoo`0501ml
07`0Ool07`03Ool0100OO01l07oo0P0O0Woo00<07goo01l017`00P0O0goo00<07g`0O0000W`0:Goo
1W`0GGoo001MOol00g`001ml0002O0000`0OOoml0002Ool201l2O002Ool00`0OO01l0002Ool0100O
Ool07goo0g`00Woo00<07gooOol00W`000<07goo01l00Woo00<07goo01l00Woo00<07g`0O0000Woo
00<07gooOol00Woo0g`09Goo1W`0GWoo001NOol6O00017ooO0007`0O0goo0W`000<07gooOol00W`0
0Woo00<07goo01l00Woo0W`00goo00<07gooO0000W`00Woo0P0O0goo0P0O00=oog`0O0000W`01Woo
17`087oo1W`0Ggoo001POol2O000100OO01l000O0W`00goo00<07gooO0000goo00<07g`0O0000P0O
17oo00H07g`0O01l07oo01l2Ool00`0OO01l0002O003Ool00`0OOomoo`02Ool00`0OOoml0002O007
Ool4O00HOol9O01POol0065oo`03O0007g`000=l000401ml07`001l2Ool0100OO01l000O0Woo00@0
7g`0O01l009oo`807`9oo`0601ml07`0O01oo`0O0Woo0P0O0g`000<07gooOol00Woo00<07gooOol0
0Woo17`01goo7g`0HWoo001SOol5O0000`0OOoml0002O00301l2O0000goo01l07`02Ool2O00027oo
01moogoo01moo`0OOol4O00201l3Ool4O0000goo01moo`07Ool5O00>OolBO01SOol006Aoo`=l0003
01ml07`000=oo`9l00=oo`03O0007g`000=oo`0501ml07`0Ool07`02Ool00`0OOol07`03Ool3O002
Ool0100OOomoogoo1W`02Goo3W`017oo1G`000=oog`0O00017`0IGoo001UOol7O00201l017ooO01l
07oo0P0O00Moog`0O0007goo01moo`03O00017oo01moo`0O0Woo00@07goo01moo`Al00=oo`0301mo
ogoo009ooael009oo`Ml06Ioo`00Igoo17`000<07g`0O0000goo0g`00goo0W`000D07gooOol07goo
00Al009oo`0301moo`0O00=oo`0301moog`000Al01Eoo`Ml00=oo`Ul06Moo`00J7oo17`000@07g`0
O01l00<07`06Ooml07`001moo`0O0g`00goo0P0O00=oog`0O00017`00Woo00<07gooOol00Woo00<0
7gooO00057`01Goo37`0JGoo001YOol3O000100OO01l000O0g`00goo0W`000@07gooOol07`Al0004
01moogooOol201l2Ool7O0000`0OOomoo`0BOolBO01ZOol006]oo`Ml000401ml07`0O002Ool3O003
Ool00`0OOoml0005O004Ool00`0OOomoo`02OolEO003Ool=O01/Ool006eoo`al0003Ool07g`0009l
00807`Aoo`807`Al000301ml07`0009oo`0301moogoo011ooa1l06ioo`00L7oo27`000<07g`0O000
0W`000=oo`0OO00017`00P0O17oo00<07gooOol00W`000<07g`0O00047`00Woo2g`0LGoo001cOol0
0`0OO01l0008O0000`0OO01oo`03Ool7O004Ool00`0OOomoo`0>Ool8O0000gooO01l0002O01cOol0
07Ioo`Ul000301ml07`0009l000301moogoo009oo`807`Al000301ml07`001Ul07Eoo`00N7oo00<0
7g`0O0000g`000<07g`0O0003g`01Woo4W`0N7oo001lOol8O0000`0OO01l0002O0000`0OO01l0003
O0000`0OO01l000BO01lOol0081oob1l081oo`00QGoo5G`0QWoo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {326.75, 97.375}} -> {-0.399192, \
0.424522, 0.00348777, 0.00348777}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig2C = Show[Fig2A, ViewPoint \[Rule] {0, 2, 0}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.5 .5 m
.5 .48233 L
s
.5 .51767 m
.5 .5 L
s
.49926 .49777 m
.49796 .48016 L
s
.50057 .51539 m
.49926 .49777 L
s
.49707 .49575 m
.49448 .47828 L
s
.49967 .51323 m
.49707 .49575 L
s
.49347 .49413 m
.48963 .4769 L
s
.49733 .51138 m
.49347 .49413 L
s
.50122 .52859 m
.49733 .51138 L
s
.49362 .51002 m
.48853 .49309 L
s
.49875 .52692 m
.49362 .51002 L
s
.50228 .53067 m
.49967 .51323 L
s
.48853 .49309 m
.48351 .47618 L
s
.48862 .50934 m
.48238 .4928 L
s
.49494 .52584 m
.48862 .50934 L
s
.50188 .53297 m
.50057 .51539 L
s
.5 .53528 m
.5 .51767 L
s
.5 .48233 m
.5 .46472 L
s
.48238 .4928 m
.47622 .47627 L
s
.48246 .50948 m
.47512 .49339 L
s
.4899 .52552 m
.48246 .50948 L
s
.49796 .48016 m
.49666 .4626 L
s
.49448 .47828 m
.49192 .46088 L
s
.48963 .4769 m
.48585 .45973 L
s
.47512 .49339 m
.46791 .4773 L
s
.50131 .54225 m
.49494 .52584 L
s
.47526 .51056 m
.46691 .49496 L
s
.48376 .52609 m
.47526 .51056 L
s
.50391 .54372 m
.49875 .52692 L
s
.49743 .54146 m
.4899 .52552 L
s
.50512 .54571 m
.50122 .52859 L
s
.48351 .47618 m
.47855 .45932 L
s
.49236 .5415 m
.48376 .52609 L
s
.50489 .54802 m
.50228 .53067 L
s
.50318 .55045 m
.50188 .53297 L
s
.46691 .49496 m
.45872 .47935 L
s
.47622 .47627 m
.47017 .45979 L
s
.46718 .51267 m
.4579 .49759 L
s
.47665 .52765 m
.46718 .51267 L
s
.5 .55279 m
.5 .53528 L
s
.5 .46472 m
.5 .44721 L
s
.48626 .5425 m
.47665 .52765 L
s
.49666 .4626 m
.49538 .44515 L
s
.46791 .4773 m
.46084 .46124 L
s
.49192 .46088 m
.48939 .44359 L
s
.50501 .55725 m
.49743 .54146 L
s
.4579 .49759 m
.44883 .48247 L
s
.50106 .55676 m
.49236 .5415 L
s
.50772 .55852 m
.50131 .54225 L
s
.48585 .45973 m
.48211 .44268 L
s
.46873 .53028 m
.45838 .51586 L
s
.47926 .54454 m
.46873 .53028 L
s
.50908 .56039 m
.50391 .54372 L
s
.45838 .51586 m
.44826 .50132 L
s
.496 .55717 m
.48626 .5425 L
s
.47855 .45932 m
.47369 .44258 L
s
.50902 .5627 m
.50512 .54571 L
s
.45872 .47935 m
.45072 .46375 L
s
.50749 .56523 m
.50489 .54802 L
s
.48996 .55859 m
.47926 .54454 L
s
.47017 .45979 m
.46424 .44342 L
s
.50448 .56778 m
.50318 .55045 L
s
.44826 .50132 m
.43839 .4867 L
s
.46015 .53401 m
.44901 .52015 L
s
.47153 .54767 m
.46015 .53401 L
s
.5 .57015 m
.5 .55279 L
s
.5 .44721 m
.5 .42985 L
s
.44883 .48247 m
.43999 .46735 L
s
.44901 .52015 m
.43814 .50614 L
s
.49538 .44515 m
.49411 .42787 L
s
.46084 .46124 m
.45394 .44528 L
s
.48311 .5611 m
.47153 .54767 L
s
.50982 .57181 m
.50106 .55676 L
s
.50583 .57162 m
.496 .55717 L
s
.48939 .44359 m
.48689 .42646 L
s
.51263 .57285 m
.50501 .55725 L
s
.51413 .5746 m
.50772 .55852 L
s
.50079 .5724 m
.48996 .55859 L
s
.48211 .44268 m
.47845 .42579 L
s
.51425 .57687 m
.50908 .56039 L
s
.45072 .46375 m
.44294 .44823 L
s
.43814 .50614 m
.42756 .49202 L
s
.45109 .53885 m
.43924 .52554 L
s
.46322 .55192 m
.45109 .53885 L
s
.43839 .4867 m
.4288 .47206 L
s
.47369 .44258 m
.46892 .426 L
s
.5129 .57949 m
.50902 .5627 L
s
.49485 .57424 m
.48311 .5611 L
s
.47559 .56472 m
.46322 .55192 L
s
.51007 .58224 m
.50749 .56523 L
s
.43924 .52554 m
.4277 .51204 L
s
.46424 .44342 m
.45846 .4272 L
s
.50576 .58491 m
.50448 .56778 L
s
.43999 .46735 m
.43142 .45228 L
s
.48816 .5772 m
.47559 .56472 L
s
.5 .58729 m
.5 .57015 L
s
.5 .42985 m
.5 .41271 L
s
.45394 .44528 m
.44723 .42946 L
s
.51573 .5858 m
.50583 .57162 L
s
.49411 .42787 m
.49286 .4108 L
s
.51172 .58592 m
.50079 .5724 L
s
.51863 .5866 m
.50982 .57181 L
s
.42756 .49202 m
.41733 .47783 L
s
.45449 .55727 m
.4417 .54476 L
s
.46757 .56946 m
.45449 .55727 L
s
.4277 .51204 m
.41652 .49838 L
s
.4417 .54476 m
.42922 .53197 L
s
.52027 .5882 m
.51263 .57285 L
s
.50672 .58707 m
.49485 .57424 L
s
.48689 .42646 m
.48444 .40956 L
s
.52055 .59044 m
.51413 .5746 L
s
.4288 .47206 m
.41954 .45742 L
s
.48088 .58128 m
.46757 .56946 L
s
.44294 .44823 m
.4354 .43283 L
s
.47845 .42579 m
.47487 .40913 L
s
.42922 .53197 m
.41711 .51894 L
s
.5009 .58932 m
.48816 .5772 L
s
.5194 .59311 m
.51425 .57687 L
s
.46892 .426 m
.46428 .40965 L
s
.51676 .59604 m
.5129 .57949 L
s
.51263 .59899 m
.51007 .58224 L
s
.4944 .59271 m
.48088 .58128 L
s
.41652 .49838 m
.40572 .48461 L
s
.43142 .45228 m
.42314 .4373 L
s
.45846 .4272 m
.45285 .4112 L
s
.4455 .56368 m
.43211 .55169 L
s
.4592 .57529 m
.4455 .56368 L
s
.41711 .51894 m
.40539 .50571 L
s
.50703 .60177 m
.50576 .58491 L
s
.43211 .55169 m
.4191 .53938 L
s
.41733 .47783 m
.40746 .46361 L
s
.47318 .58649 m
.4592 .57529 L
s
.52271 .59909 m
.51172 .58592 L
s
.52567 .59965 m
.51573 .5858 L
s
.5 .60417 m
.5 .58729 L
s
.5 .41271 m
.5 .39583 L
s
.51869 .59952 m
.50672 .58707 L
s
.44723 .42946 m
.44074 .41384 L
s
.52744 .60109 m
.51863 .5866 L
s
.51376 .60104 m
.5009 .58932 L
s
.49286 .4108 m
.49164 .39401 L
s
.4191 .53938 m
.40649 .52677 L
s
.52789 .60326 m
.52027 .5882 L
s
.4874 .59724 m
.47318 .58649 L
s
.41954 .45742 m
.41063 .44285 L
s
.48444 .40956 m
.48205 .39294 L
s
.52694 .60598 m
.52055 .59044 L
s
.50808 .60369 m
.4944 .59271 L
s
.4354 .43283 m
.42813 .4176 L
s
.47487 .40913 m
.47138 .39275 L
s
.40539 .50571 m
.39412 .49231 L
s
.52451 .60905 m
.5194 .59311 L
s
.43637 .57106 m
.42248 .55955 L
s
.45063 .58214 m
.43637 .57106 L
s
.40572 .48461 m
.39535 .47077 L
s
.4652 .59276 m
.45063 .58214 L
s
.46428 .40965 m
.45978 .39356 L
s
.40649 .52677 m
.39433 .51389 L
s
.52059 .61228 m
.51676 .59604 L
s
.42248 .55955 m
.409 .54765 L
s
.5018 .6075 m
.4874 .59724 L
s
.48004 .60287 m
.4652 .59276 L
s
.42314 .4373 m
.4152 .42247 L
s
.40746 .46361 m
.39802 .44941 L
s
.51516 .61543 m
.51263 .59899 L
s
.45285 .4112 m
.44743 .39546 L
s
.53072 .61156 m
.51869 .59952 L
s
.53373 .61187 m
.52271 .59909 L
s
.52671 .61231 m
.51376 .60104 L
s
.50828 .61831 m
.50703 .60177 L
s
.409 .54765 m
.39597 .53539 L
s
.53562 .61313 m
.52567 .59965 L
s
.52187 .61419 m
.50808 .60369 L
s
.5 .62071 m
.5 .60417 L
s
.5 .39583 m
.5 .37929 L
s
.44074 .41384 m
.4345 .39847 L
s
.53624 .61521 m
.52744 .60109 L
s
.4951 .61244 m
.48004 .60287 L
s
.41063 .44285 m
.40211 .42839 L
s
.39412 .49231 m
.38335 .47878 L
s
.49164 .39401 m
.49044 .37756 L
s
.39433 .51389 m
.38268 .5008 L
s
.53548 .61795 m
.52789 .60326 L
s
.51636 .61723 m
.5018 .6075 L
s
.48205 .39294 m
.47972 .37666 L
s
.39535 .47077 m
.38547 .4569 L
s
.42813 .4176 m
.42117 .4026 L
s
.53328 .62116 m
.52694 .60598 L
s
.39597 .53539 m
.38345 .52282 L
s
.47138 .39275 m
.46799 .37671 L
s
.52958 .62463 m
.52451 .60905 L
s
.51034 .62144 m
.4951 .61244 L
s
.45978 .39356 m
.45543 .37782 L
s
.39802 .44941 m
.38903 .43528 L
s
.52436 .62815 m
.52059 .61228 L
s
.4152 .42247 m
.40762 .40783 L
s
.5397 .62309 m
.52671 .61231 L
s
.54276 .62313 m
.53072 .61156 L
s
.53573 .62416 m
.52187 .61419 L
s
.51765 .6315 m
.51516 .61543 L
s
.54475 .6242 m
.53373 .61187 L
s
.44743 .39546 m
.44222 .38004 L
s
.38268 .5008 m
.37157 .48753 L
s
.53101 .6264 m
.51636 .61723 L
s
.38335 .47878 m
.37311 .46518 L
s
.5095 .63446 m
.50828 .61831 L
s
.54553 .62618 m
.53562 .61313 L
s
.38345 .52282 m
.37149 .50996 L
s
0 0 1 r
.4334 .40144 m
.41825 .41165 L
s
.44894 .39181 m
.4334 .40144 L
s
.46482 .38282 m
.44894 .39181 L
s
.41825 .41165 m
.40355 .42243 L
s
1 0 0 r
.5 .63685 m
.5 .62071 L
s
.5 .37929 m
.5 .36315 L
s
.54498 .62892 m
.53624 .61521 L
s
.4345 .39847 m
.42852 .3834 L
s
.40211 .42839 m
.39402 .41409 L
s
.5257 .62981 m
.51034 .62144 L
s
0 0 1 r
.48098 .37448 m
.46482 .38282 L
s
1 0 0 r
.38547 .4569 m
.3761 .44305 L
s
.49044 .37756 m
.48927 .36152 L
s
.54301 .63223 m
.53548 .61795 L
s
0 0 1 r
.40355 .42243 m
.38934 .43372 L
s
1 0 0 r
.47972 .37666 m
.47746 .36079 L
s
.42117 .4026 m
.41454 .38789 L
s
.53955 .63592 m
.53328 .62116 L
s
0 0 1 r
.49737 .36685 m
.48098 .37448 L
s
1 0 0 r
.46799 .37671 m
.46474 .36109 L
s
.53457 .63978 m
.52958 .62463 L
s
.38903 .43528 m
.38054 .42128 L
s
.37149 .50996 m
.36014 .49687 L
s
0 0 1 r
.38934 .43372 m
.37569 .44551 L
s
1 0 0 r
.37157 .48753 m
.36107 .47413 L
s
.54962 .63355 m
.53573 .62416 L
s
.5527 .63332 m
.5397 .62309 L
s
.45543 .37782 m
.45127 .36248 L
s
.54571 .63494 m
.53101 .6264 L
s
.55478 .63418 m
.54276 .62313 L
s
.52806 .64358 m
.52436 .62815 L
s
.40762 .40783 m
.40045 .39345 L
s
0 0 1 r
.44091 .38289 m
.42498 .39213 L
s
.45722 .37435 m
.44091 .38289 L
s
.42498 .39213 m
.40947 .40203 L
s
1 0 0 r
.37311 .46518 m
.36346 .45155 L
s
.55572 .63604 m
.54475 .6242 L
s
.54113 .63752 m
.5257 .62981 L
s
.52008 .64711 m
.51765 .6315 L
s
0 0 1 r
.47383 .36654 m
.45722 .37435 L
s
1 0 0 r
.44222 .38004 m
.43724 .36503 L
s
0 0 1 r
.51393 .35994 m
.49737 .36685 L
s
.40947 .40203 m
.39445 .41256 L
s
1 0 0 r
.55538 .63874 m
.54553 .62618 L
s
.51069 .65015 m
.5095 .63446 L
s
0 0 1 r
.37569 .44551 m
.36265 .45775 L
s
.4907 .35949 m
.47383 .36654 L
s
1 0 0 r
.3761 .44305 m
.3673 .42928 L
s
.39402 .41409 m
.38641 .40001 L
s
.55365 .64214 m
.54498 .62892 L
s
.42852 .3834 m
.42286 .36872 L
s
.5 .65252 m
.5 .63685 L
s
.5 .36315 m
.5 .34748 L
s
0 0 1 r
.39445 .41256 m
.37997 .42369 L
s
1 0 0 r
.48927 .36152 m
.48815 .34596 L
s
.55045 .64602 m
.54301 .63223 L
s
.36014 .49687 m
.34945 .48357 L
s
0 0 1 r
.5306 .35381 m
.51393 .35994 L
s
.50777 .35324 m
.4907 .35949 L
s
1 0 0 r
.41454 .38789 m
.40829 .37353 L
s
.47746 .36079 m
.4753 .34541 L
s
.36107 .47413 m
.35122 .46064 L
s
.54572 .6502 m
.53955 .63592 L
s
0 0 1 r
.37997 .42369 m
.3661 .43537 L
s
1 0 0 r
.5604 .64282 m
.54571 .63494 L
s
.56348 .64231 m
.54962 .63355 L
s
.38054 .42128 m
.37259 .40745 L
s
0 0 1 r
.43307 .37336 m
.41679 .3823 L
s
.44975 .36519 m
.43307 .37336 L
s
1 0 0 r
.46474 .36109 m
.46162 .34595 L
s
.56564 .64295 m
.5527 .63332 L
s
.55657 .64452 m
.54113 .63752 L
s
0 0 1 r
.36265 .45775 m
.35029 .4704 L
s
.46678 .35782 m
.44975 .36519 L
s
1 0 0 r
.53946 .65443 m
.53457 .63978 L
s
0 0 1 r
.41679 .3823 m
.40097 .39197 L
s
1 0 0 r
.36346 .45155 m
.35444 .43794 L
s
.56673 .64466 m
.55478 .63418 L
s
.40045 .39345 m
.39372 .37939 L
s
.45127 .36248 m
.4473 .34762 L
s
0 0 1 r
.48408 .35128 m
.46678 .35782 L
s
1 0 0 r
.53168 .65851 m
.52806 .64358 L
s
0 0 1 r
.40097 .39197 m
.38569 .40235 L
s
.52496 .34781 m
.50777 .35324 L
s
1 0 0 r
.5666 .64731 m
.55572 .63604 L
s
.52244 .6622 m
.52008 .64711 L
s
0 0 1 r
.3661 .43537 m
.35289 .44759 L
s
1 0 0 r
.43724 .36503 m
.43254 .35047 L
s
0 0 1 r
.54732 .34848 m
.5306 .35381 L
s
1 0 0 r
.56512 .65075 m
.55538 .63874 L
s
0 0 1 r
.50159 .34561 m
.48408 .35128 L
s
.38569 .40235 m
.37099 .41341 L
s
1 0 0 r
.3673 .42928 m
.35912 .41563 L
s
.51184 .66531 m
.51069 .65015 L
s
.38641 .40001 m
.37932 .38621 L
s
.34945 .48357 m
.33949 .47013 L
s
.5622 .6548 m
.55365 .64214 L
s
.42286 .36872 m
.41752 .35448 L
s
.5 .66764 m
.5 .65252 L
s
.5 .34748 m
.5 .33236 L
s
0 0 1 r
.35029 .4704 m
.33865 .48342 L
s
1 0 0 r
.35122 .46064 m
.34208 .44711 L
s
0 0 1 r
.54222 .34326 m
.52496 .34781 L
s
.51925 .34084 m
.50159 .34561 L
s
1 0 0 r
.55776 .65926 m
.55045 .64602 L
s
.48815 .34596 m
.48707 .33095 L
s
.57503 .64998 m
.5604 .64282 L
s
.57197 .65076 m
.55657 .64452 L
s
0 0 1 r
.37099 .41341 m
.35695 .42509 L
s
.44252 .35549 m
.4255 .36337 L
s
.4599 .34848 m
.44252 .35549 L
s
.4255 .36337 m
.40892 .37211 L
s
1 0 0 r
.57726 .65038 m
.56348 .64231 L
s
0 0 1 r
.35289 .44759 m
.34042 .46028 L
s
1 0 0 r
.40829 .37353 m
.40245 .35959 L
s
.4753 .34541 m
.47322 .33059 L
s
0 0 1 r
.47759 .34237 m
.4599 .34848 L
s
1 0 0 r
.55177 .6639 m
.54572 .6502 L
s
0 0 1 r
.40892 .37211 m
.39284 .38166 L
s
1 0 0 r
.57849 .65192 m
.56564 .64295 L
s
.37259 .40745 m
.36524 .39386 L
s
.35444 .43794 m
.34613 .42441 L
s
0 0 1 r
.56403 .344 m
.54732 .34848 L
s
1 0 0 r
.46162 .34595 m
.45865 .33136 L
s
0 0 1 r
.4955 .33721 m
.47759 .34237 L
s
1 0 0 r
.57856 .65449 m
.56673 .64466 L
s
.54424 .66851 m
.53946 .65443 L
s
0 0 1 r
.39284 .38166 m
.37733 .39199 L
s
.53698 .337 m
.51925 .34084 L
s
1 0 0 r
.39372 .37939 m
.38748 .36572 L
s
.4473 .34762 m
.44355 .33332 L
s
0 0 1 r
.35695 .42509 m
.34363 .43738 L
s
1 0 0 r
.5352 .67284 m
.53168 .65851 L
s
.57734 .65795 m
.5666 .64731 L
s
0 0 1 r
.33865 .48342 m
.32782 .49678 L
s
.55947 .33961 m
.54222 .34326 L
s
.51358 .33302 m
.4955 .33721 L
s
1 0 0 r
.33949 .47013 m
.33031 .45659 L
s
0 0 1 r
.37733 .39199 m
.36246 .40307 L
s
1 0 0 r
.52474 .67668 m
.52244 .6622 L
s
.43254 .35047 m
.42812 .33646 L
s
.35912 .41563 m
.35162 .40218 L
s
.57471 .66213 m
.56512 .65075 L
s
0 0 1 r
.34042 .46028 m
.32874 .47342 L
s
1 0 0 r
.51295 .67984 m
.51184 .66531 L
s
.37932 .38621 m
.3728 .37276 L
s
.34208 .44711 m
.33372 .43359 L
s
.57059 .66684 m
.5622 .6548 L
s
.58726 .6562 m
.57197 .65076 L
s
0 0 1 r
.55473 .33413 m
.53698 .337 L
s
1 0 0 r
.41752 .35448 m
.41256 .34076 L
s
0 0 1 r
.43557 .34543 m
.41825 .35313 L
s
.45328 .33868 m
.43557 .34543 L
s
.53175 .32982 m
.51358 .33302 L
s
1 0 0 r
.5 .68213 m
.5 .66764 L
s
.5 .33236 m
.5 .31787 L
s
.58954 .65636 m
.57503 .64998 L
s
0 0 1 r
.47131 .33292 m
.45328 .33868 L
s
.41825 .35313 m
.4014 .36176 L
s
.36246 .40307 m
.3483 .41486 L
s
.34363 .43738 m
.33111 .45022 L
s
.58065 .34042 m
.56403 .344 L
s
1 0 0 r
.59089 .65771 m
.57726 .65038 L
s
.56491 .67186 m
.55776 .65926 L
s
0 0 1 r
.4896 .32818 m
.47131 .33292 L
s
1 0 0 r
.48707 .33095 m
.48604 .31658 L
s
0 0 1 r
.4014 .36176 m
.3851 .37128 L
s
1 0 0 r
.40245 .35959 m
.39705 .34614 L
s
.59117 .66017 m
.57849 .65192 L
s
0 0 1 r
.57665 .3369 m
.55947 .33961 L
s
1 0 0 r
.34613 .42441 m
.33857 .41101 L
s
.47322 .33059 m
.47126 .31641 L
s
.36524 .39386 m
.35855 .38057 L
s
.55767 .67697 m
.55177 .6639 L
s
0 0 1 r
.50806 .32448 m
.4896 .32818 L
s
.32782 .49678 m
.31785 .51042 L
s
.3851 .37128 m
.3694 .38166 L
s
.54993 .32765 m
.53175 .32982 L
s
.32874 .47342 m
.31793 .48696 L
s
1 0 0 r
.59021 .66361 m
.57856 .65449 L
s
.45865 .33136 m
.45587 .31743 L
s
0 0 1 r
.3483 .41486 m
.33492 .42733 L
s
1 0 0 r
.54888 .68192 m
.54424 .66851 L
s
0 0 1 r
.5724 .33224 m
.55473 .33413 L
s
1 0 0 r
.33031 .45659 m
.32199 .443 L
s
.38748 .36572 m
.38178 .35251 L
s
0 0 1 r
.52662 .32185 m
.50806 .32448 L
s
1 0 0 r
.5879 .66789 m
.57734 .65795 L
s
.44355 .33332 m
.44006 .31965 L
s
0 0 1 r
.33111 .45022 m
.31945 .46358 L
s
.3694 .38166 m
.3544 .39288 L
s
1 0 0 r
.5386 .6865 m
.5352 .67284 L
s
.35162 .40218 m
.34486 .38898 L
s
.52694 .69048 m
.52474 .67668 L
s
.58411 .67281 m
.57471 .66213 L
s
.42812 .33646 m
.42404 .32307 L
s
0 0 1 r
.59711 .33777 m
.58065 .34042 L
s
1 0 0 r
.60237 .66079 m
.58726 .6562 L
s
.33372 .43359 m
.3262 .42015 L
s
0 0 1 r
.44696 .32862 m
.42895 .33519 L
s
.46532 .32311 m
.44696 .32862 L
s
.56804 .32653 m
.54993 .32765 L
s
.42895 .33519 m
.41136 .34281 L
s
1 0 0 r
.3728 .37276 m
.3669 .35973 L
s
0 0 1 r
.54519 .32031 m
.52662 .32185 L
s
1 0 0 r
.60385 .66193 m
.58954 .65636 L
s
0 0 1 r
.59368 .33518 m
.57665 .3369 L
s
.48394 .31869 m
.46532 .32311 L
s
1 0 0 r
.51402 .69366 m
.51295 .67984 L
s
0 0 1 r
.33492 .42733 m
.32239 .44043 L
s
.41136 .34281 m
.39428 .35143 L
s
.3544 .39288 m
.34016 .40488 L
s
1 0 0 r
.57878 .67817 m
.57059 .66684 L
s
.41256 .34076 m
.40801 .32764 L
s
0 0 1 r
.50276 .3154 m
.48394 .31869 L
s
1 0 0 r
.60432 .66424 m
.59089 .65771 L
s
.5 .6959 m
.5 .68213 L
s
.5 .31787 m
.5 .3041 L
s
0 0 1 r
.39428 .35143 m
.37778 .36103 L
s
.31785 .51042 m
.30882 .52429 L
s
.31793 .48696 m
.30806 .50086 L
s
.58992 .33139 m
.5724 .33224 L
s
1 0 0 r
.57187 .68375 m
.56491 .67186 L
s
.48604 .31658 m
.48507 .30295 L
s
0 0 1 r
.31945 .46358 m
.30872 .47742 L
s
1 0 0 r
.60363 .66763 m
.59117 .66017 L
s
.33857 .41101 m
.33184 .3978 L
s
0 0 1 r
.52167 .31325 m
.50276 .3154 L
s
.37778 .36103 m
.36194 .37158 L
s
1 0 0 r
.39705 .34614 m
.39215 .33327 L
s
.35855 .38057 m
.35256 .36766 L
s
0 0 1 r
.5637 .31989 m
.54519 .32031 L
s
1 0 0 r
.47126 .31641 m
.46943 .30298 L
s
0 0 1 r
.34016 .40488 m
.32676 .41763 L
s
1 0 0 r
.56337 .6893 m
.55767 .67697 L
s
0 0 1 r
.58601 .3265 m
.56804 .32653 L
s
1 0 0 r
.60164 .67196 m
.59021 .66361 L
s
.32199 .443 m
.31459 .42942 L
s
0 0 1 r
.32239 .44043 m
.31079 .45411 L
s
1 0 0 r
.45587 .31743 m
.45328 .30423 L
s
0 0 1 r
.54061 .31227 m
.52167 .31325 L
s
1 0 0 r
.55335 .69459 m
.54888 .68192 L
s
0 0 1 r
.36194 .37158 m
.34684 .38303 L
s
1 0 0 r
.38178 .35251 m
.37666 .33984 L
s
0 0 1 r
.61334 .33609 m
.59711 .33777 L
s
1 0 0 r
.59821 .67705 m
.5879 .66789 L
s
0 0 1 r
.61047 .33446 m
.59368 .33518 L
s
1 0 0 r
.44006 .31965 m
.43683 .30672 L
s
.54186 .69939 m
.5386 .6865 L
s
.61722 .66446 m
.60237 .66079 L
s
.34486 .38898 m
.33889 .3761 L
s
0 0 1 r
.44098 .31848 m
.42269 .32499 L
s
.45964 .31312 m
.44098 .31848 L
s
.58206 .32062 m
.5637 .31989 L
s
.60722 .3316 m
.58992 .33139 L
s
.47858 .30894 m
.45964 .31312 L
s
1 0 0 r
.3262 .42015 m
.31959 .40685 L
s
0 0 1 r
.42269 .32499 m
.40485 .33262 L
s
.32676 .41763 m
.31428 .43109 L
s
.30806 .50086 m
.29921 .51505 L
s
.55948 .31247 m
.54061 .31227 L
s
1 0 0 r
.59325 .68271 m
.58411 .67281 L
s
0 0 1 r
.49773 .30596 m
.47858 .30894 L
s
1 0 0 r
.61789 .6666 m
.60385 .66193 L
s
.52904 .70348 m
.52694 .69048 L
s
0 0 1 r
.40485 .33262 m
.38756 .34134 L
s
1 0 0 r
.42404 .32307 m
.42031 .3104 L
s
0 0 1 r
.30872 .47742 m
.29901 .49167 L
s
.30882 .52429 m
.30081 .53834 L
s
.34684 .38303 m
.33256 .39534 L
s
1 0 0 r
.3669 .35973 m
.36167 .34721 L
s
0 0 1 r
.60374 .32759 m
.58601 .3265 L
s
.51698 .3042 m
.49773 .30596 L
s
1 0 0 r
.51502 .70668 m
.51402 .69366 L
s
0 0 1 r
.38756 .34134 m
.37089 .35113 L
s
1 0 0 r
.61747 .6699 m
.60432 .66424 L
s
0 0 1 r
.31079 .45411 m
.30021 .46834 L
s
1 0 0 r
.58672 .68872 m
.57878 .67817 L
s
.40801 .32764 m
.4039 .31522 L
s
.5 .70884 m
.5 .6959 L
s
.5 .3041 m
.5 .29116 L
s
0 0 1 r
.53626 .30368 m
.51698 .3042 L
s
.5782 .31388 m
.55948 .31247 L
s
1 0 0 r
.33184 .3978 m
.32599 .38487 L
s
0 0 1 r
.37089 .35113 m
.35493 .36193 L
s
1 0 0 r
.6158 .67423 m
.60363 .66763 L
s
0 0 1 r
.60018 .32251 m
.58206 .32062 L
s
1 0 0 r
.57858 .69483 m
.57187 .68375 L
s
0 0 1 r
.33256 .39534 m
.31918 .40848 L
s
1 0 0 r
.48507 .30295 m
.48416 .29015 L
s
0 0 1 r
.31428 .43109 m
.3028 .4452 L
s
1 0 0 r
.35256 .36766 m
.34734 .3552 L
s
.31459 .42942 m
.30819 .41592 L
s
.39215 .33327 m
.3878 .32107 L
s
0 0 1 r
.62694 .33481 m
.61047 .33446 L
s
.62924 .33543 m
.61334 .33609 L
s
1 0 0 r
.46943 .30298 m
.46773 .29038 L
s
.56886 .70081 m
.56337 .6893 L
s
0 0 1 r
.62418 .33291 m
.60722 .3316 L
s
.55547 .30443 m
.53626 .30368 L
s
1 0 0 r
.61276 .67945 m
.60164 .67196 L
s
0 0 1 r
.35493 .36193 m
.33976 .37372 L
s
.29901 .49167 m
.29039 .50628 L
s
.62114 .32981 m
.60374 .32759 L
s
1 0 0 r
.45328 .30423 m
.4509 .29187 L
s
0 0 1 r
.29921 .51505 m
.29145 .52948 L
s
1 0 0 r
.55761 .70641 m
.55335 .69459 L
s
0 0 1 r
.59666 .31651 m
.5782 .31388 L
s
1 0 0 r
.63174 .66717 m
.61722 .66446 L
s
0 0 1 r
.45429 .30317 m
.43534 .30847 L
s
.47354 .29912 m
.45429 .30317 L
s
1 0 0 r
.37666 .33984 m
.37217 .3278 L
s
0 0 1 r
.43534 .30847 m
.41679 .31501 L
s
.30021 .46834 m
.29071 .48305 L
s
1 0 0 r
.60821 .68536 m
.59821 .67705 L
s
0 0 1 r
.49301 .29636 m
.47354 .29912 L
s
.31918 .40848 m
.30678 .42239 L
s
.41679 .31501 m
.39873 .32276 L
s
.30081 .53834 m
.29388 .5525 L
s
1 0 0 r
.31959 .40685 m
.31396 .39376 L
s
.33889 .3761 m
.33379 .36362 L
s
0 0 1 r
.57451 .30644 m
.55547 .30443 L
s
1 0 0 r
.43683 .30672 m
.43392 .29461 L
s
.54495 .7114 m
.54186 .69939 L
s
0 0 1 r
.51259 .2949 m
.49301 .29636 L
s
.61796 .32559 m
.60018 .32251 L
s
.33976 .37372 m
.32548 .38645 L
s
1 0 0 r
.63158 .67033 m
.61789 .6666 L
s
0 0 1 r
.39873 .32276 m
.38124 .33169 L
s
.3028 .4452 m
.2924 .45992 L
s
1 0 0 r
.6021 .69175 m
.59325 .68271 L
s
0 0 1 r
.5322 .29476 m
.51259 .2949 L
s
1 0 0 r
.53102 .71559 m
.52904 .70348 L
s
.42031 .3104 m
.41698 .29855 L
s
0 0 1 r
.38124 .33169 m
.36443 .34175 L
s
1 0 0 r
.36167 .34721 m
.35718 .33527 L
s
.63026 .67462 m
.61747 .6699 L
s
.51597 .71879 m
.51502 .70668 L
s
0 0 1 r
.61478 .32038 m
.59666 .31651 L
s
.59329 .30973 m
.57451 .30644 L
s
1 0 0 r
.59436 .69838 m
.58672 .68872 L
s
0 0 1 r
.55172 .29595 m
.5322 .29476 L
s
.64074 .33534 m
.62418 .33291 L
s
.32548 .38645 m
.31216 .40007 L
s
.30678 .42239 m
.29546 .43703 L
s
1 0 0 r
.4039 .31522 m
.40029 .30359 L
s
0 0 1 r
.643 .33624 m
.62694 .33481 L
s
.36443 .34175 m
.34837 .35292 L
s
1 0 0 r
.32599 .38487 m
.3211 .37228 L
s
.5 .72086 m
.5 .70884 L
s
.5 .29116 m
.5 .27914 L
s
0 0 1 r
.63812 .33319 m
.62114 .32981 L
s
1 0 0 r
.62761 .6799 m
.6158 .67423 L
s
0 0 1 r
.64472 .33584 m
.62924 .33543 L
s
1 0 0 r
.30819 .41592 m
.30285 .40257 L
s
0 0 1 r
.29039 .50628 m
.28294 .5212 L
s
.29071 .48305 m
.28237 .49819 L
s
1 0 0 r
.58501 .70501 m
.57858 .69483 L
s
.34734 .3552 m
.34296 .34328 L
s
.48416 .29015 m
.48333 .2783 L
s
0 0 1 r
.57108 .29848 m
.55172 .29595 L
s
.6353 .32987 m
.61796 .32559 L
s
.29145 .52948 m
.28486 .54409 L
s
1 0 0 r
.3878 .32107 m
.38403 .30962 L
s
0 0 1 r
.34837 .35292 m
.33317 .36514 L
s
.2924 .45992 m
.28315 .47518 L
s
.61171 .31432 m
.59329 .30973 L
s
1 0 0 r
.62351 .686 m
.61276 .67945 L
s
.46773 .29038 m
.46618 .27873 L
s
.57408 .71139 m
.56886 .70081 L
s
0 0 1 r
.44927 .29345 m
.43004 .2988 L
s
.46883 .28944 m
.44927 .29345 L
s
.29388 .5525 m
.28812 .56671 L
s
.31216 .40007 m
.29989 .41452 L
s
1 0 0 r
.64583 .66886 m
.63174 .66717 L
s
0 0 1 r
.4886 .2868 m
.46883 .28944 L
s
.43004 .2988 m
.41124 .30548 L
s
.63244 .32549 m
.61478 .32038 L
s
.50851 .28554 m
.4886 .2868 L
s
.59016 .30235 m
.57108 .29848 L
s
.41124 .30548 m
.39296 .31344 L
s
1 0 0 r
.4509 .29187 m
.44877 .28045 L
s
0 0 1 r
.29546 .43703 m
.28528 .45233 L
s
1 0 0 r
.31396 .39376 m
.30938 .38096 L
s
.56165 .71728 m
.55761 .70641 L
s
.37217 .3278 m
.36838 .31649 L
s
0 0 1 r
.33317 .36514 m
.31891 .37837 L
s
.52844 .28568 m
.50851 .28554 L
s
1 0 0 r
.61785 .69272 m
.60821 .68536 L
s
.33379 .36362 m
.32961 .35163 L
s
0 0 1 r
.39296 .31344 m
.37531 .32267 L
s
1 0 0 r
.64485 .67305 m
.63158 .67033 L
s
.43392 .29461 m
.43134 .28343 L
s
.54786 .72244 m
.54495 .7114 L
s
0 0 1 r
.54828 .28723 m
.52844 .28568 L
s
.65457 .33775 m
.63812 .33319 L
s
.65677 .33892 m
.64074 .33534 L
s
.62966 .32019 m
.61171 .31432 L
s
.37531 .32267 m
.35837 .33311 L
s
1 0 0 r
.61057 .69982 m
.6021 .69175 L
s
0 0 1 r
.60885 .30758 m
.59016 .30235 L
s
.65211 .33536 m
.6353 .32987 L
s
.65854 .3388 m
.643 .33624 L
s
.29989 .41452 m
.28876 .42976 L
s
.28237 .49819 m
.27529 .51369 L
s
1 0 0 r
.53286 .7267 m
.53102 .71559 L
s
.64261 .67834 m
.63026 .67462 L
s
.41698 .29855 m
.41408 .28761 L
s
.35718 .33527 m
.35349 .32401 L
s
0 0 1 r
.28294 .5212 m
.27675 .53636 L
s
.31891 .37837 m
.30568 .39256 L
s
.56794 .2902 m
.54828 .28723 L
s
.28315 .47518 m
.27516 .49093 L
s
.65969 .33735 m
.64472 .33584 L
s
.35837 .33311 m
.34224 .34472 L
s
.64956 .33185 m
.63244 .32549 L
s
1 0 0 r
.51684 .72987 m
.51597 .71879 L
s
0 0 1 r
.28486 .54409 m
.27952 .55881 L
s
1 0 0 r
.60165 .70706 m
.59436 .69838 L
s
.3211 .37228 m
.31725 .36012 L
s
.30285 .40257 m
.29866 .38945 L
s
0 0 1 r
.28528 .45233 m
.27635 .46823 L
s
1 0 0 r
.40029 .30359 m
.39721 .29286 L
s
0 0 1 r
.58731 .29457 m
.56794 .2902 L
s
1 0 0 r
.63897 .68456 m
.62761 .6799 L
s
.5 .73183 m
.5 .72086 L
s
.5 .27914 m
.5 .26817 L
s
0 0 1 r
.62706 .31414 m
.60885 .30758 L
s
.34224 .34472 m
.32703 .35747 L
s
.64704 .32736 m
.62966 .32019 L
s
1 0 0 r
.34296 .34328 m
.33947 .33199 L
s
.5911 .71419 m
.58501 .70501 L
s
0 0 1 r
.30568 .39256 m
.29357 .40764 L
s
.28812 .56671 m
.28361 .58089 L
s
1 0 0 r
.48333 .2783 m
.48258 .26749 L
s
0 0 1 r
.28876 .42976 m
.27885 .44572 L
s
.46442 .2801 m
.44456 .28417 L
s
.48451 .27749 m
.46442 .2801 L
s
.44456 .28417 m
.42506 .28967 L
s
1 0 0 r
.38403 .30962 m
.38091 .29904 L
s
0 0 1 r
.50474 .27634 m
.48451 .27749 L
s
1 0 0 r
.6594 .66946 m
.64583 .66886 L
s
0 0 1 r
.60627 .30035 m
.58731 .29457 L
s
1 0 0 r
.63381 .69154 m
.62351 .686 L
s
0 0 1 r
.42506 .28967 m
.40601 .29658 L
s
.52499 .27667 m
.50474 .27634 L
s
1 0 0 r
.46618 .27873 m
.4648 .26813 L
s
.57899 .72094 m
.57408 .71139 L
s
0 0 1 r
.40601 .29658 m
.38753 .30486 L
s
.67039 .34352 m
.65457 .33775 L
s
.32703 .35747 m
.31282 .37128 L
s
.66828 .34208 m
.65211 .33536 L
s
.54516 .27849 m
.52499 .27667 L
s
1 0 0 r
.30938 .38096 m
.30593 .36852 L
s
0 0 1 r
.67217 .34368 m
.65677 .33892 L
s
.27516 .49093 m
.2685 .50709 L
s
.66601 .33947 m
.64956 .33185 L
s
.27529 .51369 m
.26955 .52947 L
s
.64467 .32204 m
.62706 .31414 L
s
.38753 .30486 m
.36972 .31447 L
s
1 0 0 r
.44877 .28045 m
.44691 .27009 L
s
.65758 .67469 m
.64485 .67305 L
s
.36838 .31649 m
.36534 .306 L
s
.56542 .72708 m
.56165 .71728 L
s
.62704 .69905 m
.61785 .69272 L
s
0 0 1 r
.27635 .46823 m
.26873 .48466 L
s
1 0 0 r
.32961 .35163 m
.32645 .34021 L
s
0 0 1 r
.56512 .2818 m
.54516 .27849 L
s
.67345 .34252 m
.65854 .3388 L
s
.29357 .40764 m
.28268 .42355 L
s
.62471 .30752 m
.60627 .30035 L
s
.27675 .53636 m
.27189 .55168 L
s
.36972 .31447 m
.35267 .32537 L
s
.66373 .33581 m
.64704 .32736 L
s
.31282 .37128 m
.29972 .3861 L
s
1 0 0 r
.43134 .28343 m
.42912 .27331 L
s
.55055 .73239 m
.54786 .72244 L
s
0 0 1 r
.27885 .44572 m
.27026 .46232 L
s
.58477 .28658 m
.56512 .2818 L
s
.67403 .34001 m
.65969 .33735 L
s
.27952 .55881 m
.27552 .57356 L
s
1 0 0 r
.65443 .68097 m
.64261 .67834 L
s
.61861 .70684 m
.61057 .69982 L
s
0 0 1 r
.35267 .32537 m
.3365 .33752 L
s
1 0 0 r
.35349 .32401 m
.35065 .31353 L
s
.53455 .73668 m
.53286 .7267 L
s
.41408 .28761 m
.41166 .2777 L
s
0 0 1 r
.66156 .33125 m
.64467 .32204 L
s
.64254 .31607 m
.62471 .30752 L
s
.604 .29283 m
.58477 .28658 L
s
1 0 0 r
.29866 .38945 m
.29571 .37663 L
s
.31725 .36012 m
.3145 .34847 L
s
0 0 1 r
.28268 .42355 m
.27308 .44022 L
s
.29972 .3861 m
.28781 .40186 L
s
1 0 0 r
.51762 .7398 m
.51684 .72987 L
s
0 0 1 r
.3365 .33752 m
.32131 .35085 L
s
1 0 0 r
.60851 .71466 m
.60165 .70706 L
s
0 0 1 r
.68368 .35003 m
.66828 .34208 L
s
.68168 .34834 m
.66601 .33947 L
s
.28361 .58089 m
.28043 .59497 L
s
1 0 0 r
.6498 .68813 m
.63897 .68456 L
s
.39721 .29286 m
.39472 .28312 L
s
0 0 1 r
.68545 .35049 m
.67039 .34352 L
s
.2685 .50709 m
.26325 .52358 L
s
.26873 .48466 m
.26253 .50154 L
s
.62268 .30053 m
.604 .29283 L
s
1 0 0 r
.5 .74164 m
.5 .73183 L
s
.5 .26817 m
.5 .25836 L
s
0 0 1 r
.67962 .34553 m
.66373 .33581 L
s
.46028 .27133 m
.44012 .27555 L
s
.48069 .26864 m
.46028 .27133 L
s
.50125 .26751 m
.48069 .26864 L
s
.44012 .27555 m
.42035 .28129 L
s
.26955 .52947 m
.26522 .54547 L
s
1 0 0 r
.33947 .33199 m
.33696 .32143 L
s
0 0 1 r
.52184 .26794 m
.50125 .26751 L
s
.68684 .34964 m
.67217 .34368 L
s
1 0 0 r
.67233 .66893 m
.6594 .66946 L
s
0 0 1 r
.65962 .32597 m
.64254 .31607 L
s
1 0 0 r
.5968 .72224 m
.5911 .71419 L
s
0 0 1 r
.32131 .35085 m
.30719 .3653 L
s
.42035 .28129 m
.40107 .28851 L
s
.27026 .46232 m
.26307 .47949 L
s
.54233 .26994 m
.52184 .26794 L
s
1 0 0 r
.48258 .26749 m
.48192 .25786 L
s
0 0 1 r
.40107 .28851 m
.38239 .29718 L
s
1 0 0 r
.38091 .29904 m
.37848 .28943 L
s
0 0 1 r
.67764 .34176 m
.66156 .33125 L
s
1 0 0 r
.64358 .69597 m
.63381 .69154 L
s
0 0 1 r
.28781 .40186 m
.27718 .4185 L
s
.27189 .55168 m
.26846 .56708 L
s
.56262 .27349 m
.54233 .26994 L
s
.64071 .30965 m
.62268 .30053 L
s
.68763 .34744 m
.67345 .34252 L
s
1 0 0 r
.30593 .36852 m
.30369 .35655 L
s
0 0 1 r
.38239 .29718 m
.36443 .30726 L
s
1 0 0 r
.4648 .26813 m
.46362 .25872 L
s
.58355 .72934 m
.57899 .72094 L
s
0 0 1 r
.27308 .44022 m
.26487 .45757 L
s
.58257 .2786 m
.56262 .27349 L
s
.30719 .3653 m
.29424 .38081 L
s
1 0 0 r
.66968 .67519 m
.65758 .67469 L
s
0 0 1 r
.36443 .30726 m
.3473 .3187 L
s
1 0 0 r
.32645 .34021 m
.32436 .32948 L
s
.44691 .27009 m
.44534 .26091 L
s
.6357 .70424 m
.62704 .69905 L
s
0 0 1 r
.67584 .3372 m
.65962 .32597 L
s
1 0 0 r
.36534 .306 m
.36311 .29644 L
s
0 0 1 r
.27552 .57356 m
.27295 .58825 L
s
.60207 .28524 m
.58257 .2786 L
s
1 0 0 r
.56889 .7357 m
.56542 .72708 L
s
0 0 1 r
.68764 .34386 m
.67403 .34001 L
s
.69645 .35844 m
.68168 .34834 L
s
.65796 .32017 m
.64071 .30965 L
s
.6946 .3565 m
.67962 .34553 L
s
.3473 .3187 m
.33111 .33144 L
s
.6982 .3592 m
.68368 .35003 L
s
.27718 .4185 m
.26793 .43592 L
s
.26253 .50154 m
.25781 .5188 L
s
1 0 0 r
.42912 .27331 m
.42732 .26435 L
s
0 0 1 r
.62099 .29338 m
.60207 .28524 L
s
.29424 .38081 m
.28256 .3973 L
s
.26307 .47949 m
.25736 .49715 L
s
1 0 0 r
.553 .74112 m
.55055 .73239 L
s
0 0 1 r
.69277 .35354 m
.67764 .34176 L
s
1 0 0 r
.66561 .68245 m
.65443 .68097 L
s
0 0 1 r
.26325 .52358 m
.25949 .54032 L
s
.69965 .35869 m
.68545 .35049 L
s
1 0 0 r
.62614 .7127 m
.61861 .70684 L
s
0 0 1 r
.33111 .33144 m
.31597 .34541 L
s
1 0 0 r
.29571 .37663 m
.29406 .36422 L
s
.35065 .31353 m
.34874 .30393 L
s
0 0 1 r
.26487 .45757 m
.25814 .47552 L
s
.26522 .54547 m
.2624 .56159 L
s
1 0 0 r
.53607 .74542 m
.53455 .73668 L
s
.41166 .2777 m
.40976 .26894 L
s
0 0 1 r
.28043 .59497 m
.27867 .60884 L
s
.67433 .33203 m
.65796 .32017 L
s
.63923 .30299 m
.62099 .29338 L
s
1 0 0 r
.3145 .34847 m
.31294 .33745 L
s
0 0 1 r
.6911 .3497 m
.67584 .3372 L
s
.70064 .35682 m
.68684 .34964 L
s
.31597 .34541 m
.30197 .36055 L
s
1 0 0 r
.51832 .74846 m
.51762 .7398 L
s
0 0 1 r
.28256 .3973 m
.27224 .41468 L
s
1 0 0 r
.65999 .69053 m
.6498 .68813 L
s
.6149 .72106 m
.60851 .71466 L
s
0 0 1 r
.4771 .26047 m
.45636 .26332 L
s
.49801 .25927 m
.4771 .26047 L
s
.45636 .26332 m
.4359 .26778 L
s
.51894 .25971 m
.49801 .25927 L
s
.26793 .43592 m
.26014 .45404 L
s
.4359 .26778 m
.41585 .27383 L
s
.53978 .26179 m
.51894 .25971 L
s
.26846 .56708 m
.26653 .58247 L
s
1 0 0 r
.39472 .28312 m
.39287 .27452 L
s
0 0 1 r
.65665 .31404 m
.63923 .30299 L
s
.41585 .27383 m
.39634 .28145 L
s
1 0 0 r
.68453 .6672 m
.67233 .66893 L
s
0 0 1 r
.5604 .26551 m
.53978 .26179 L
s
1 0 0 r
.5 .75016 m
.5 .74164 L
s
.5 .25836 m
.5 .24984 L
s
0 0 1 r
.70854 .3687 m
.6946 .3565 L
s
1 0 0 r
.33696 .32143 m
.33548 .3117 L
s
0 0 1 r
.70095 .35356 m
.68763 .34744 L
s
.39634 .28145 m
.37748 .29059 L
s
.68968 .34519 m
.67433 .33203 L
s
.70684 .36654 m
.69277 .35354 L
s
.58066 .27085 m
.5604 .26551 L
s
.71021 .36976 m
.69645 .35844 L
s
.30197 .36055 m
.28921 .37677 L
s
1 0 0 r
.60205 .72907 m
.5968 .72224 L
s
0 0 1 r
.37748 .29059 m
.3594 .3012 L
s
.25736 .49715 m
.25321 .51519 L
s
1 0 0 r
.48192 .25786 m
.48136 .24954 L
s
0 0 1 r
.25781 .5188 m
.25467 .53632 L
s
.60045 .27779 m
.58066 .27085 L
s
1 0 0 r
.65273 .6992 m
.64358 .69597 L
s
0 0 1 r
.25814 .47552 m
.25295 .49396 L
s
1 0 0 r
.37848 .28943 m
.37681 .28091 L
s
0 0 1 r
.71171 .36959 m
.6982 .3592 L
s
.70526 .36344 m
.6911 .3497 L
s
1 0 0 r
.30369 .35655 m
.30274 .34514 L
s
0 0 1 r
.67314 .32646 m
.65665 .31404 L
s
.27224 .41468 m
.26337 .43286 L
s
.3594 .3012 m
.34221 .31322 L
s
.27295 .58825 m
.27187 .60279 L
s
.61964 .28629 m
.60045 .27779 L
s
.25949 .54032 m
.25732 .55722 L
s
1 0 0 r
.68104 .67447 m
.66968 .67519 L
s
.46362 .25872 m
.46264 .25062 L
s
.58771 .73647 m
.58355 .72934 L
s
0 0 1 r
.70039 .34893 m
.68764 .34386 L
s
.28921 .37677 m
.2778 .39399 L
s
.26014 .45404 m
.25389 .47277 L
s
.34221 .31322 m
.32603 .32659 L
s
.71286 .3681 m
.69965 .35869 L
s
1 0 0 r
.32436 .32948 m
.32342 .31952 L
s
0 0 1 r
.70392 .35959 m
.68968 .34519 L
s
.63809 .29631 m
.61964 .28629 L
s
.68859 .3402 m
.67314 .32646 L
s
1 0 0 r
.64376 .70821 m
.6357 .70424 L
s
.44534 .26091 m
.44409 .25304 L
s
.36311 .29644 m
.36176 .28793 L
s
0 0 1 r
.2624 .56159 m
.26116 .57774 L
s
1 0 0 r
.57202 .74301 m
.56889 .7357 L
s
0 0 1 r
.32603 .32659 m
.31096 .34124 L
s
.26337 .43286 m
.25603 .45175 L
s
.65569 .30781 m
.63809 .29631 L
s
.71974 .38071 m
.70684 .36654 L
s
.2778 .39399 m
.26782 .41212 L
s
1 0 0 r
.67606 .6827 m
.66561 .68245 L
s
0 0 1 r
.72132 .38207 m
.70854 .3687 L
s
.71345 .36522 m
.70064 .35682 L
s
.71823 .37835 m
.70526 .36344 L
s
1 0 0 r
.42732 .26435 m
.42595 .2567 L
s
0 0 1 r
.27867 .60884 m
.27841 .62242 L
s
1 0 0 r
.29406 .36422 m
.2938 .35232 L
s
0 0 1 r
.31096 .34124 m
.29711 .35708 L
s
1 0 0 r
.55517 .74851 m
.553 .74112 L
s
0 0 1 r
.25295 .49396 m
.2494 .5128 L
s
.70288 .35519 m
.68859 .3402 L
s
.25321 .51519 m
.2507 .53352 L
s
1 0 0 r
.63308 .71729 m
.62614 .7127 L
s
0 0 1 r
.72283 .38227 m
.71021 .36976 L
s
.67233 .32071 m
.65569 .30781 L
s
.71692 .37517 m
.70392 .35959 L
s
.26653 .58247 m
.26619 .59775 L
s
.25389 .47277 m
.24926 .49199 L
s
1 0 0 r
.34874 .30393 m
.34782 .29534 L
s
.31294 .33745 m
.31264 .32716 L
s
0 0 1 r
.25467 .53632 m
.25317 .55402 L
s
1 0 0 r
.53739 .75278 m
.53607 .74542 L
s
.40976 .26894 m
.40842 .26146 L
s
0 0 1 r
.29711 .35708 m
.28459 .37402 L
s
.47367 .25318 m
.45259 .25625 L
s
.49493 .25181 m
.47367 .25318 L
s
.51623 .25218 m
.49493 .25181 L
s
.26782 .41212 m
.25936 .43105 L
s
.45259 .25625 m
.43183 .26103 L
s
.53744 .25426 m
.51623 .25218 L
s
.43183 .26103 m
.41151 .26747 L
s
.55841 .25807 m
.53744 .25426 L
s
.71328 .36093 m
.70095 .35356 L
s
.7241 .38118 m
.71171 .36959 L
s
.68787 .33495 m
.67233 .32071 L
s
.25603 .45175 m
.2503 .47123 L
s
1 0 0 r
.66945 .69167 m
.65999 .69053 L
s
0 0 1 r
.41151 .26747 m
.39178 .27554 L
s
.57902 .26356 m
.55841 .25807 L
s
1 0 0 r
.69587 .66422 m
.68453 .6672 L
s
.62073 .72616 m
.6149 .72106 L
s
.51892 .75572 m
.51832 .74846 L
s
0 0 1 r
.39178 .27554 m
.37275 .2852 L
s
.7159 .37136 m
.70288 .35519 L
s
.59912 .27071 m
.57902 .26356 L
s
.25732 .55722 m
.2568 .57417 L
s
.28459 .37402 m
.27348 .39196 L
s
1 0 0 r
.39287 .27452 m
.3917 .26716 L
s
0 0 1 r
.37275 .2852 m
.35457 .29639 L
s
.61858 .27949 m
.59912 .27071 L
s
.72987 .39437 m
.71823 .37835 L
s
.73133 .39601 m
.71974 .38071 L
s
1 0 0 r
.33548 .3117 m
.33512 .30293 L
s
0 0 1 r
.70221 .35045 m
.68787 .33495 L
s
1 0 0 r
.5 .75724 m
.5 .75016 L
s
.5 .24984 m
.5 .24276 L
s
0 0 1 r
.27187 .60279 m
.27238 .61708 L
s
.35457 .29639 m
.33734 .30903 L
s
.72857 .39184 m
.71692 .37517 L
s
.25936 .43105 m
.2525 .45067 L
s
.63728 .28984 m
.61858 .27949 L
s
.72494 .37873 m
.71286 .3681 L
s
1 0 0 r
.60679 .73455 m
.60205 .72907 L
s
0 0 1 r
.73282 .39658 m
.72132 .38207 L
s
1 0 0 r
.30274 .34514 m
.30316 .33439 L
s
0 0 1 r
.33734 .30903 m
.3212 .32305 L
s
.24926 .49199 m
.24632 .51159 L
s
.2494 .5128 m
.24754 .53192 L
s
.71216 .35525 m
.70039 .34893 L
s
.27348 .39196 m
.26388 .4108 L
s
1 0 0 r
.66115 .70114 m
.65273 .6992 L
s
0 0 1 r
.65509 .3017 m
.63728 .28984 L
s
1 0 0 r
.48136 .24954 m
.4809 .24266 L
s
0 0 1 r
.26116 .57774 m
.26159 .59381 L
s
.72754 .38861 m
.7159 .37136 L
s
1 0 0 r
.37681 .28091 m
.37595 .27361 L
s
0 0 1 r
.2503 .47123 m
.24625 .4912 L
s
1 0 0 r
.69155 .67249 m
.68104 .67447 L
s
0 0 1 r
.71524 .36713 m
.70221 .35045 L
s
.2507 .53352 m
.2499 .55202 L
s
.3212 .32305 m
.30624 .33838 L
s
.67187 .31501 m
.65509 .3017 L
s
.73418 .39593 m
.72283 .38227 L
s
1 0 0 r
.46264 .25062 m
.46189 .24397 L
s
.59141 .7422 m
.58771 .73647 L
s
0 0 1 r
.30624 .33838 m
.29259 .35491 L
s
.2525 .45067 m
.24731 .47086 L
s
.26388 .4108 m
.25586 .43043 L
s
.72514 .37485 m
.71345 .36522 L
s
1 0 0 r
.32342 .31952 m
.32372 .31046 L
s
0 0 1 r
.68752 .32967 m
.67187 .31501 L
s
.25317 .55402 m
.2534 .57178 L
s
.73878 .40952 m
.72857 .39184 L
s
.72686 .38489 m
.71524 .36713 L
s
.74009 .41142 m
.72987 .39437 L
s
1 0 0 r
.65111 .71084 m
.64376 .70821 L
s
0 0 1 r
.29259 .35491 m
.28033 .37254 L
s
1 0 0 r
.36176 .28793 m
.36134 .28059 L
s
0 0 1 r
.27841 .62242 m
.27973 .6356 L
s
1 0 0 r
.44409 .25304 m
.44319 .24661 L
s
0 0 1 r
.70193 .34561 m
.68752 .32967 L
s
.73771 .40684 m
.72754 .38861 L
s
.26619 .59775 m
.26751 .61281 L
s
1 0 0 r
.57475 .74889 m
.57202 .74301 L
s
.2938 .35232 m
.29502 .34102 L
s
0 0 1 r
.74152 .41236 m
.73133 .39601 L
s
.73523 .39394 m
.7241 .38118 L
s
1 0 0 r
.68565 .68165 m
.67606 .6827 L
s
0 0 1 r
.25586 .43043 m
.24951 .45071 L
s
.24625 .4912 m
.24394 .51151 L
s
.24632 .51159 m
.24514 .53146 L
s
.28033 .37254 m
.26957 .39116 L
s
.71497 .36272 m
.70193 .34561 L
s
.2568 .57417 m
.25801 .59105 L
s
1 0 0 r
.42595 .2567 m
.42505 .25047 L
s
0 0 1 r
.24731 .47086 m
.24386 .49149 L
s
.73696 .40361 m
.72686 .38489 L
s
.24754 .53192 m
.24746 .5512 L
s
1 0 0 r
.55704 .75441 m
.55517 .74851 L
s
0 0 1 r
.7245 .36954 m
.71328 .36093 L
s
.74293 .41216 m
.73282 .39658 L
s
.49195 .24534 m
.47032 .24693 L
s
.51363 .24556 m
.49195 .24534 L
s
1 0 0 r
.63935 .7205 m
.63308 .71729 L
s
0 0 1 r
.47032 .24693 m
.44889 .25031 L
s
.53523 .24757 m
.51363 .24556 L
s
.26957 .39116 m
.26038 .41066 L
s
.44889 .25031 m
.42782 .25546 L
s
.55659 .25137 m
.53523 .24757 L
s
1 0 0 r
.31264 .32716 m
.31368 .3177 L
s
0 0 1 r
.42782 .25546 m
.40724 .26234 L
s
.57756 .25694 m
.55659 .25137 L
s
1 0 0 r
.34782 .29534 m
.34797 .28787 L
s
0 0 1 r
.72656 .3809 m
.71497 .36272 L
s
.40724 .26234 m
.3873 .27092 L
s
.59801 .26423 m
.57756 .25694 L
s
.24951 .45071 m
.24489 .47152 L
s
.3873 .27092 m
.36814 .28113 L
s
.7463 .42596 m
.73771 .40684 L
s
.61778 .27321 m
.59801 .26423 L
s
.74743 .42811 m
.73878 .40952 L
s
.2499 .55202 m
.25088 .57058 L
s
1 0 0 r
.40842 .26146 m
.40768 .25539 L
s
0 0 1 r
.36814 .28113 m
.34988 .29291 L
s
1 0 0 r
.5385 .75863 m
.53739 .75278 L
s
0 0 1 r
.73576 .39054 m
.72494 .37873 L
s
.63675 .2838 m
.61778 .27321 L
s
1 0 0 r
.70622 .65994 m
.69587 .66422 L
s
0 0 1 r
.26038 .41066 m
.25285 .43089 L
s
.34988 .29291 m
.33265 .30618 L
s
.65479 .29595 m
.63675 .2838 L
s
.74547 .42318 m
.73696 .40361 L
s
1 0 0 r
.67807 .69147 m
.66945 .69167 L
s
0 0 1 r
.74877 .4294 m
.74009 .41142 L
s
.7366 .40004 m
.72656 .3809 L
s
.27238 .61708 m
.27455 .63101 L
s
.33265 .30618 m
.31658 .32085 L
s
.67176 .30958 m
.65479 .29595 L
s
.26159 .59381 m
.26374 .60969 L
s
.74414 .41068 m
.73418 .39593 L
s
.24386 .49149 m
.24219 .51243 L
s
.24394 .51151 m
.24343 .53205 L
s
1 0 0 r
.62593 .72982 m
.62073 .72616 L
s
0 0 1 r
.31658 .32085 m
.30178 .33683 L
s
1 0 0 r
.5194 .76143 m
.51892 .75572 L
s
0 0 1 r
.68754 .32459 m
.67176 .30958 L
s
.25285 .43089 m
.24704 .45174 L
s
.24489 .47152 m
.24205 .49272 L
s
.30178 .33683 m
.28836 .35401 L
s
.70202 .34089 m
.68754 .32459 L
s
.24514 .53146 m
.24577 .55146 L
s
1 0 0 r
.3917 .26716 m
.39126 .26118 L
s
0 0 1 r
.7228 .36284 m
.71216 .35525 L
s
.2534 .57178 m
.2554 .58948 L
s
.74502 .41999 m
.7366 .40004 L
s
.75018 .42967 m
.74152 .41236 L
s
1 0 0 r
.33512 .30293 m
.33594 .29523 L
s
0 0 1 r
.28836 .35401 m
.27642 .37227 L
s
.7151 .35836 m
.70202 .34089 L
s
.75323 .44584 m
.7463 .42596 L
s
.7523 .44349 m
.74547 .42318 L
s
1 0 0 r
.30316 .33439 m
.30503 .32443 L
s
.5 .76276 m
.5 .75724 L
s
.5 .24276 m
.5 .23724 L
s
0 0 1 r
.27642 .37227 m
.26605 .3915 L
s
.24704 .45174 m
.243 .47306 L
s
.72667 .3769 m
.7151 .35836 L
s
.73558 .38569 m
.72514 .37485 L
s
.75443 .44749 m
.74743 .42811 L
s
.24746 .5512 m
.24919 .57051 L
s
1 0 0 r
.61096 .73854 m
.60679 .73455 L
s
.66875 .70169 m
.66115 .70114 L
s
0 0 1 r
.75172 .44064 m
.74502 .41999 L
s
1 0 0 r
.70107 .66917 m
.69155 .67249 L
s
0 0 1 r
.26605 .3915 m
.25731 .41155 L
s
.73666 .39636 m
.72667 .3769 L
s
.74496 .40783 m
.73523 .39394 L
s
1 0 0 r
.4809 .24266 m
.48057 .23737 L
s
0 0 1 r
.24205 .49272 m
.24103 .51417 L
s
.24219 .51243 m
.24236 .53354 L
s
1 0 0 r
.37595 .27361 m
.37596 .26765 L
s
0 0 1 r
.25731 .41155 m
.2503 .4323 L
s
.75151 .42874 m
.74293 .41216 L
s
.74497 .41662 m
.73666 .39636 L
s
.243 .47306 m
.24078 .49471 L
s
.26751 .61281 m
.27056 .62754 L
s
.75737 .46439 m
.7523 .44349 L
s
.25801 .59105 m
.26101 .60775 L
s
.24343 .53205 m
.24477 .55267 L
s
.75581 .44823 m
.74877 .4294 L
s
.75666 .46185 m
.75172 .44064 L
s
.27973 .6356 m
.2827 .64826 L
s
.2503 .4323 m
.24505 .45359 L
s
.75156 .43755 m
.74497 .41662 L
s
1 0 0 r
.32372 .31046 m
.32531 .30241 L
s
.46189 .24397 m
.46138 .23891 L
s
.5946 .7464 m
.59141 .7422 L
s
0 0 1 r
.25088 .57058 m
.25369 .58907 L
s
.75841 .46636 m
.75323 .44584 L
s
.24505 .45359 m
.24162 .47528 L
s
.75635 .45898 m
.75156 .43755 L
s
.24078 .49471 m
.24042 .51653 L
s
.24103 .51417 m
.24187 .53572 L
s
.24577 .55146 m
.24824 .57144 L
s
1 0 0 r
.65767 .71204 m
.65111 .71084 L
s
.29502 .34102 m
.29778 .33046 L
s
0 0 1 r
.75978 .48346 m
.75666 .46185 L
s
1 0 0 r
.36134 .28059 m
.36192 .27455 L
s
0 0 1 r
.24162 .47528 m
.24004 .49722 L
s
.75932 .48078 m
.75635 .45898 L
s
.73445 .3794 m
.7245 .36954 L
s
1 0 0 r
.44319 .24661 m
.44267 .24177 L
s
.69427 .67922 m
.68565 .68165 L
s
0 0 1 r
.7597 .46756 m
.75443 .44749 L
s
.24236 .53354 m
.2444 .55466 L
s
.76063 .48574 m
.75737 .46439 L
s
1 0 0 r
.57706 .75318 m
.57475 .74889 L
s
0 0 1 r
.7572 .44786 m
.75018 .42967 L
s
.74519 .40352 m
.73576 .39054 L
s
.75257 .42648 m
.74414 .41068 L
s
.24004 .49722 m
.24033 .51925 L
s
.76042 .50279 m
.75932 .48078 L
s
.24042 .51653 m
.24193 .53836 L
s
.24073 .47793 m
.23979 .5 L
s
.24353 .45602 m
.24073 .47793 L
s
.24819 .43443 m
.24353 .45602 L
s
.25466 .41331 m
.24819 .43443 L
s
.26289 .39282 m
.25466 .41331 L
s
.27283 .3731 m
.26289 .39282 L
s
.28441 .35429 m
.27283 .3731 L
s
.29755 .33653 m
.28441 .35429 L
s
.31214 .31995 m
.29755 .33653 L
s
.32809 .30467 m
.31214 .31995 L
s
.34527 .29079 m
.32809 .30467 L
s
.36357 .27843 m
.34527 .29079 L
s
.38285 .26765 m
.36357 .27843 L
s
.40298 .25856 m
.38285 .26765 L
s
.42381 .2512 m
.40298 .25856 L
s
.44518 .24563 m
.42381 .2512 L
s
.46695 .2419 m
.44518 .24563 L
s
.48896 .24003 m
.46695 .2419 L
s
.51104 .24003 m
.48896 .24003 L
s
.53305 .2419 m
.51104 .24003 L
s
.55482 .24563 m
.53305 .2419 L
s
.57619 .2512 m
.55482 .24563 L
s
.59702 .25856 m
.57619 .2512 L
s
.61715 .26765 m
.59702 .25856 L
s
.63643 .27843 m
.61715 .26765 L
s
.65473 .29079 m
.63643 .27843 L
s
.67191 .30467 m
.65473 .29079 L
s
.68786 .31995 m
.67191 .30467 L
s
.70245 .33653 m
.68786 .31995 L
s
.71559 .35429 m
.70245 .33653 L
s
.72717 .3731 m
.71559 .35429 L
s
.73711 .39282 m
.72717 .3731 L
s
.74534 .41331 m
.73711 .39282 L
s
.75181 .43443 m
.74534 .41331 L
s
.75647 .45602 m
.75181 .43443 L
s
.75927 .47793 m
.75647 .45602 L
s
.76021 .5 m
.75927 .47793 L
s
.75927 .52207 m
.76021 .5 L
s
.75647 .54398 m
.75927 .52207 L
s
.75181 .56557 m
.75647 .54398 L
s
.74534 .58669 m
.75181 .56557 L
s
.73711 .60718 m
.74534 .58669 L
s
.72717 .6269 m
.73711 .60718 L
s
.71559 .64571 m
.72717 .6269 L
s
.70245 .66347 m
.71559 .64571 L
s
.68786 .68005 m
.70245 .66347 L
s
.67191 .69533 m
.68786 .68005 L
s
.65473 .70921 m
.67191 .69533 L
s
.63643 .72157 m
.65473 .70921 L
s
.61715 .73235 m
.63643 .72157 L
s
.59702 .74144 m
.61715 .73235 L
s
.57619 .7488 m
.59702 .74144 L
s
.55482 .75437 m
.57619 .7488 L
s
.53305 .7581 m
.55482 .75437 L
s
.51104 .75997 m
.53305 .7581 L
s
.48896 .75997 m
.51104 .75997 L
s
.46695 .7581 m
.48896 .75997 L
s
.44518 .75437 m
.46695 .7581 L
s
.42381 .7488 m
.44518 .75437 L
s
.40298 .74144 m
.42381 .7488 L
s
.38285 .73235 m
.40298 .74144 L
s
.36357 .72157 m
.38285 .73235 L
s
.34527 .70921 m
.36357 .72157 L
s
.32809 .69533 m
.34527 .70921 L
s
.31214 .68005 m
.32809 .69533 L
s
.29755 .66347 m
.31214 .68005 L
s
.28441 .64571 m
.29755 .66347 L
s
.27283 .6269 m
.28441 .64571 L
s
.26289 .60718 m
.27283 .6269 L
s
.25466 .58669 m
.26289 .60718 L
s
.24819 .56557 m
.25466 .58669 L
s
.24353 .54398 m
.24819 .56557 L
s
.24073 .52207 m
.24353 .54398 L
s
.23979 .5 m
.24073 .52207 L
s
.76105 .50533 m
.75978 .48346 L
s
.24033 .51925 m
.24249 .5412 L
s
.75965 .52484 m
.76042 .50279 L
s
.2554 .58948 m
.25925 .60699 L
s
.26374 .60969 m
.26769 .62525 L
s
.24919 .57051 m
.25278 .58971 L
s
1 0 0 r
.42505 .25047 m
.42467 .24581 L
s
0 0 1 r
.24187 .53572 m
.2446 .55721 L
s
.76179 .48738 m
.75841 .46636 L
s
.24477 .55267 m
.24798 .57323 L
s
1 0 0 r
.31368 .3177 m
.31614 .3092 L
s
.55857 .75869 m
.55704 .75441 L
s
0 0 1 r
.27455 .63101 m
.27846 .64446 L
s
.24249 .5412 m
.24652 .56293 L
s
.75699 .54678 m
.75965 .52484 L
s
1 0 0 r
.64486 .72222 m
.63935 .7205 L
s
0 0 1 r
.24193 .53836 m
.24532 .56005 L
s
1 0 0 r
.71546 .65432 m
.70622 .65994 L
s
.34797 .28787 m
.34924 .28165 L
s
0 0 1 r
.76111 .46777 m
.75581 .44823 L
s
.76203 .50739 m
.76063 .48574 L
s
.76042 .52729 m
.76105 .50533 L
s
.24652 .56293 m
.25241 .58427 L
s
.75247 .56845 m
.75699 .54678 L
s
.2444 .55466 m
.24832 .57566 L
s
.75845 .44624 m
.75151 .42874 L
s
1 0 0 r
.40768 .25539 m
.4076 .25087 L
s
.53937 .76281 m
.5385 .75863 L
s
.68573 .68984 m
.67807 .69147 L
s
0 0 1 r
.25241 .58427 m
.2601 .60506 L
s
.7461 .58969 m
.75247 .56845 L
s
.73219 .37172 m
.7228 .36284 L
s
.24532 .56005 m
.25058 .58144 L
s
.24824 .57144 m
.25261 .59127 L
s
.76315 .48817 m
.7597 .46756 L
s
.75317 .42279 m
.74496 .40783 L
s
.2446 .55721 m
.24921 .57848 L
s
.74462 .39774 m
.73558 .38569 L
s
.7579 .5492 m
.76042 .52729 L
s
.2601 .60506 m
.26956 .62515 L
s
.25369 .58907 m
.25837 .60734 L
s
.73792 .61035 m
.7461 .58969 L
s
1 0 0 r
.63042 .73195 m
.62593 .72982 L
s
0 0 1 r
.76329 .50875 m
.76179 .48738 L
s
.76153 .5292 m
.76203 .50739 L
s
1 0 0 r
.51976 .76544 m
.5194 .76143 L
s
0 0 1 r
.26101 .60775 m
.26586 .62414 L
s
.26956 .62515 m
.28073 .64438 L
s
.72799 .63025 m
.73792 .61035 L
s
1 0 0 r
.30503 .32443 m
.30842 .31538 L
s
0 0 1 r
.25058 .58144 m
.25769 .60237 L
s
1 0 0 r
.33594 .29523 m
.33801 .28872 L
s
.39126 .26118 m
.39162 .25672 L
s
0 0 1 r
.76248 .46682 m
.7572 .44786 L
s
.24798 .57323 m
.25309 .59356 L
s
.27056 .62754 m
.27541 .64181 L
s
.28073 .64438 m
.29352 .66262 L
s
.75348 .57088 m
.7579 .5492 L
s
.71638 .64926 m
.72799 .63025 L
s
1 0 0 r
.5 .76657 m
.5 .76276 L
s
.5 .23724 m
.5 .23343 L
s
.70948 .66446 m
.70107 .66917 L
s
0 0 1 r
.24921 .57848 m
.25569 .59938 L
s
.24832 .57566 m
.25414 .59635 L
s
.29352 .66262 m
.30785 .67972 L
s
.70315 .66723 m
.71638 .64926 L
s
1 0 0 r
.67542 .70077 m
.66875 .70169 L
s
0 0 1 r
.25278 .58971 m
.25828 .60866 L
s
.25769 .60237 m
.26662 .62268 L
s
.75936 .44323 m
.75257 .42648 L
s
.2827 .64826 m
.28739 .66028 L
s
1 0 0 r
.61448 .74094 m
.61096 .73854 L
s
0 0 1 r
.76458 .48791 m
.76111 .46777 L
s
.30785 .67972 m
.32362 .69554 L
s
.68841 .68402 m
.70315 .66723 L
s
.75911 .55099 m
.76153 .5292 L
s
.74718 .59216 m
.75348 .57088 L
s
.32362 .69554 m
.34071 .70998 L
s
1 0 0 r
.48057 .23737 m
.48037 .2338 L
s
0 0 1 r
.67226 .69951 m
.68841 .68402 L
s
1 0 0 r
.37596 .26765 m
.3769 .26316 L
s
0 0 1 r
.76472 .50918 m
.76315 .48817 L
s
.76288 .53032 m
.76329 .50875 L
s
.25925 .60699 m
.26498 .62417 L
s
.7531 .41761 m
.74519 .40352 L
s
.34071 .70998 m
.35901 .7229 L
s
.65481 .71356 m
.67226 .69951 L
s
.74301 .3905 m
.73445 .3794 L
s
.26662 .62268 m
.27731 .6422 L
s
.25261 .59127 m
.25888 .61079 L
s
1 0 0 r
.32531 .30241 m
.32828 .2955 L
s
0 0 1 r
.25569 .59938 m
.26403 .61974 L
s
.35901 .7229 m
.37836 .73421 L
s
.6362 .72608 m
.65481 .71356 L
s
.73903 .6129 m
.74718 .59216 L
s
1 0 0 r
.29778 .33046 m
.30216 .32075 L
s
0 0 1 r
.37836 .73421 m
.39864 .74383 L
s
.26769 .62525 m
.27349 .64036 L
s
1 0 0 r
.46138 .23891 m
.46114 .23558 L
s
0 0 1 r
.61657 .73695 m
.6362 .72608 L
s
1 0 0 r
.59723 .74895 m
.5946 .7464 L
s
0 0 1 r
.76364 .46455 m
.75845 .44624 L
s
.25309 .59356 m
.2601 .61352 L
s
.39864 .74383 m
.41969 .75167 L
s
.25414 .59635 m
.26184 .61659 L
s
.59605 .74611 m
.61657 .73695 L
s
.75476 .5726 m
.75911 .55099 L
s
.41969 .75167 m
.44136 .75768 L
s
.57481 .75346 m
.59605 .74611 L
s
.27731 .6422 m
.2897 .66079 L
s
1 0 0 r
.66332 .7117 m
.65767 .71204 L
s
0 0 1 r
.44136 .75768 m
.46347 .76179 L
s
.553 .75897 m
.57481 .75346 L
s
1 0 0 r
.70179 .67534 m
.69427 .67922 L
s
0 0 1 r
.46347 .76179 m
.48586 .76399 L
s
.5308 .76257 m
.553 .75897 L
s
.72907 .63292 m
.73903 .6129 L
s
.48586 .76399 m
.50836 .76425 L
s
.50836 .76425 m
.5308 .76257 L
s
1 0 0 r
.36192 .27455 m
.36356 .26994 L
s
0 0 1 r
.25837 .60734 m
.26496 .62524 L
s
.27846 .64446 m
.28415 .65729 L
s
1 0 0 r
.44267 .24177 m
.44256 .23866 L
s
0 0 1 r
.76592 .48642 m
.76248 .46682 L
s
.26403 .61974 m
.27419 .63939 L
s
.76052 .55193 m
.76288 .53032 L
s
1 0 0 r
.57889 .75576 m
.57706 .75318 L
s
0 0 1 r
.75973 .43876 m
.75317 .42279 L
s
.2897 .66079 m
.30371 .67829 L
s
.71738 .65206 m
.72907 .63292 L
s
.76616 .5085 m
.76458 .48791 L
s
.76435 .53045 m
.76472 .50918 L
s
.74849 .59387 m
.75476 .5726 L
s
1 0 0 r
.31614 .3092 m
.32007 .30178 L
s
0 0 1 r
.26586 .62414 m
.2726 .64007 L
s
.25828 .60866 m
.26569 .6272 L
s
1 0 0 r
.72344 .64732 m
.71546 .65432 L
s
.42467 .24581 m
.42484 .24287 L
s
0 0 1 r
.75212 .41094 m
.74462 .39774 L
s
.26184 .61659 m
.2714 .63621 L
s
.30371 .67829 m
.31924 .69457 L
s
1 0 0 r
.55972 .76122 m
.55857 .75869 L
s
0 0 1 r
.74017 .38189 m
.73219 .37172 L
s
1 0 0 r
.64952 .72235 m
.64486 .72222 L
s
0 0 1 r
.70401 .67018 m
.71738 .65206 L
s
1 0 0 r
.34924 .28165 m
.35171 .27681 L
s
0 0 1 r
.25888 .61079 m
.26707 .62985 L
s
.27419 .63939 m
.28611 .65819 L
s
.2601 .61352 m
.269 .63294 L
s
.76439 .46085 m
.75936 .44323 L
s
.31924 .69457 m
.33617 .70947 L
s
1 0 0 r
.69232 .68671 m
.68573 .68984 L
s
0 0 1 r
.27541 .64181 m
.28211 .65549 L
s
.74032 .61462 m
.74849 .59387 L
s
.75619 .57341 m
.76052 .55193 L
s
.68907 .68711 m
.70401 .67018 L
s
1 0 0 r
.4076 .25087 m
.40821 .24802 L
s
.53999 .76519 m
.53937 .76281 L
s
0 0 1 r
.26498 .62417 m
.27263 .64087 L
s
.33617 .70947 m
.3544 .72289 L
s
.67267 .70273 m
.68907 .68711 L
s
.76698 .48357 m
.76364 .46455 L
s
.28611 .65819 m
.29972 .67596 L
s
1 0 0 r
.30842 .31538 m
.3134 .30735 L
s
0 0 1 r
.76199 .55181 m
.76435 .53045 L
s
1 0 0 r
.63412 .7324 m
.63042 .73195 L
s
0 0 1 r
.2714 .63621 m
.28278 .65505 L
s
.75934 .43277 m
.7531 .41761 L
s
1 0 0 r
.51999 .76762 m
.51976 .76544 L
s
0 0 1 r
.3544 .72289 m
.37378 .7347 L
s
1 0 0 r
.33801 .28872 m
.3414 .28353 L
s
0 0 1 r
.73029 .63468 m
.74032 .61462 L
s
.28739 .66028 m
.29386 .67153 L
s
.76744 .50654 m
.76592 .48642 L
s
.76577 .52941 m
.76616 .5085 L
s
.65492 .7169 m
.67267 .70273 L
s
1 0 0 r
.71665 .65831 m
.70948 .66446 L
s
0 0 1 r
.26496 .62524 m
.27347 .64263 L
s
1 0 0 r
.39162 .25672 m
.39281 .25391 L
s
0 0 1 r
.27349 .64036 m
.28118 .65488 L
s
.37378 .7347 m
.39417 .7448 L
s
.7499 .59459 m
.75619 .57341 L
s
.269 .63294 m
.27976 .65165 L
s
.63595 .7295 m
.65492 .7169 L
s
.75003 .40282 m
.74301 .3905 L
s
1 0 0 r
.5 .76851 m
.5 .76657 L
s
.5 .23343 m
.5 .23149 L
s
0 0 1 r
.29972 .67596 m
.31493 .69255 L
s
1 0 0 r
.68104 .69828 m
.67542 .70077 L
s
0 0 1 r
.26569 .6272 m
.27501 .64517 L
s
.26707 .62985 m
.27715 .64826 L
s
.39417 .7448 m
.41541 .75311 L
s
.61592 .74042 m
.63595 .7295 L
s
1 0 0 r
.61728 .7416 m
.61448 .74094 L
s
0 0 1 r
.71846 .6539 m
.73029 .63468 L
s
.76452 .45565 m
.75973 .43876 L
s
.41541 .75311 m
.43733 .75955 L
s
.28278 .65505 m
.29591 .67293 L
s
.59498 .74957 m
.61592 .74042 L
s
1 0 0 r
.48037 .2338 m
.48031 .2321 L
s
.3769 .26316 m
.37882 .26028 L
s
.30216 .32075 m
.30823 .31202 L
s
0 0 1 r
.43733 .75955 m
.45977 .76406 L
s
.57328 .75688 m
.59498 .74957 L
s
1 0 0 r
.32828 .2955 m
.33268 .28986 L
s
0 0 1 r
.75763 .5731 m
.76199 .55181 L
s
.31493 .69255 m
.33164 .70783 L
s
.2726 .64007 m
.28125 .6554 L
s
.28415 .65729 m
.29168 .66938 L
s
.45977 .76406 m
.48254 .7666 L
s
.55101 .76227 m
.57328 .75688 L
s
.48254 .7666 m
.50546 .76715 L
s
.52834 .7657 m
.55101 .76227 L
s
.74166 .61529 m
.7499 .59459 L
s
.50546 .76715 m
.52834 .7657 L
s
.70491 .67209 m
.71846 .6539 L
s
1 0 0 r
.59923 .7497 m
.59723 .74895 L
s
.46114 .23558 m
.46119 .23412 L
s
0 0 1 r
.76755 .47924 m
.76439 .46085 L
s
1 0 0 r
.70808 .66997 m
.70179 .67534 L
s
.66798 .70973 m
.66332 .7117 L
s
0 0 1 r
.76336 .55046 m
.76577 .52941 L
s
.75796 .42527 m
.75212 .41094 L
s
.27976 .65165 m
.29235 .66948 L
s
.33164 .70783 m
.34974 .72164 L
s
.27263 .64087 m
.2822 .65694 L
s
1 0 0 r
.36356 .26994 m
.36633 .26688 L
s
0 0 1 r
.76837 .50316 m
.76698 .48357 L
s
.29591 .67293 m
.31073 .68971 L
s
.76696 .52702 m
.76744 .50654 L
s
1 0 0 r
.44256 .23866 m
.44288 .2374 L
s
0 0 1 r
.68972 .68911 m
.70491 .67209 L
s
1 0 0 r
.73003 .63891 m
.72344 .64732 L
s
0 0 1 r
.74661 .39333 m
.74017 .38189 L
s
1 0 0 r
.58019 .7565 m
.57889 .75576 L
s
0 0 1 r
.27715 .64826 m
.28909 .66588 L
s
.28211 .65549 m
.2907 .66844 L
s
.27347 .64263 m
.2839 .65935 L
s
1 0 0 r
.32007 .30178 m
.32556 .29558 L
s
0 0 1 r
.7315 .63534 m
.74166 .61529 L
s
.27501 .64517 m
.28624 .66241 L
s
.34974 .72164 m
.36908 .73387 L
s
.75126 .59413 m
.75763 .5731 L
s
.67301 .7048 m
.68972 .68911 L
s
1 0 0 r
.42484 .24287 m
.4256 .24177 L
s
0 0 1 r
.76379 .44891 m
.75934 .43277 L
s
1 0 0 r
.65323 .72076 m
.64952 .72235 L
s
.56046 .76184 m
.55972 .76122 L
s
.35171 .27681 m
.35542 .27347 L
s
0 0 1 r
.31073 .68971 m
.32713 .70522 L
s
.36908 .73387 m
.38952 .7444 L
s
.29235 .66948 m
.30668 .68628 L
s
1 0 0 r
.6977 .68202 m
.69232 .68671 L
s
0 0 1 r
.28118 .65488 m
.29079 .66866 L
s
.6549 .71903 m
.67301 .7048 L
s
.75891 .57149 m
.76336 .55046 L
s
.71949 .65456 m
.7315 .63534 L
s
.29386 .67153 m
.30216 .68187 L
s
1 0 0 r
.40821 .24802 m
.40955 .24701 L
s
.54032 .76563 m
.53999 .76519 L
s
.3134 .30735 m
.32002 .30048 L
s
0 0 1 r
.76741 .47336 m
.76452 .45565 L
s
.38952 .7444 m
.41089 .75313 L
s
.75537 .41632 m
.75003 .40282 L
s
.63553 .73166 m
.6549 .71903 L
s
.74289 .61472 m
.75126 .59413 L
s
.32713 .70522 m
.34501 .71931 L
s
1 0 0 r
.72243 .65069 m
.71665 .65831 L
s
0 0 1 r
.28909 .66588 m
.30285 .68253 L
s
.28125 .6554 m
.29183 .66997 L
s
1 0 0 r
.63694 .73108 m
.63412 .7324 L
s
0 0 1 r
.76444 .54772 m
.76696 .52702 L
s
1 0 0 r
.3414 .28353 m
.34617 .2798 L
s
0 0 1 r
.41089 .75313 m
.43304 .75997 L
s
.76873 .49826 m
.76755 .47924 L
s
1 0 0 r
.52007 .76783 m
.51999 .76762 L
s
0 0 1 r
.76774 .52317 m
.76837 .50316 L
s
.61506 .74258 m
.63553 .73166 L
s
1 0 0 r
.39281 .25391 m
.39489 .25288 L
s
0 0 1 r
.70569 .67278 m
.71949 .65456 L
s
.2822 .65694 m
.2937 .67222 L
s
.43304 .75997 m
.45577 .76486 L
s
.28624 .66241 m
.29933 .67875 L
s
.30668 .68628 m
.32268 .70187 L
s
.59364 .75169 m
.61506 .74258 L
s
.29168 .66938 m
.30109 .68059 L
s
1 0 0 r
.68549 .69414 m
.68104 .69828 L
s
0 0 1 r
.2839 .65935 m
.29624 .67523 L
s
1 0 0 r
.5 .76845 m
.5 .76851 L
s
.5 .23149 m
.5 .23155 L
s
0 0 1 r
.45577 .76486 m
.47889 .76774 L
s
1 0 0 r
.30823 .31202 m
.31601 .3044 L
s
0 0 1 r
.57146 .7589 m
.59364 .75169 L
s
.34501 .71931 m
.36423 .73186 L
s
1 0 0 r
.6193 .74042 m
.61728 .7416 L
s
0 0 1 r
.76199 .44065 m
.75796 .42527 L
s
.47889 .76774 m
.50222 .76859 L
s
.5487 .76415 m
.57146 .7589 L
s
.75239 .59232 m
.75891 .57149 L
s
.50222 .76859 m
.52556 .76739 L
s
.52556 .76739 m
.5487 .76415 L
s
1 0 0 r
.37882 .26028 m
.38176 .25914 L
s
.33268 .28986 m
.33857 .28562 L
s
0 0 1 r
.73254 .6347 m
.74289 .61472 L
s
1 0 0 r
.48031 .2321 m
.4804 .23242 L
s
0 0 1 r
.69019 .68983 m
.70569 .67278 L
s
.2907 .66844 m
.30119 .6805 L
s
.30285 .68253 m
.31835 .69804 L
s
1 0 0 r
.71301 .66305 m
.70808 .66997 L
s
0 0 1 r
.36423 .73186 m
.38465 .74272 L
s
.32268 .70187 m
.34025 .7161 L
s
.75137 .40603 m
.74661 .39333 L
s
1 0 0 r
.60054 .74854 m
.59923 .7497 L
s
.46119 .23412 m
.46154 .23468 L
s
0 0 1 r
.76634 .46594 m
.76379 .44891 L
s
.75981 .56844 m
.76444 .54772 L
s
1 0 0 r
.67152 .70603 m
.66798 .70973 L
s
.73508 .62908 m
.73003 .63891 L
s
0 0 1 r
.67312 .70555 m
.69019 .68983 L
s
1 0 0 r
.36633 .26688 m
.37025 .26552 L
s
0 0 1 r
.29079 .66866 m
.30232 .68155 L
s
.76831 .49179 m
.76741 .47336 L
s
1 0 0 r
.32556 .29558 m
.33264 .29071 L
s
0 0 1 r
.29933 .67875 m
.31424 .69402 L
s
1 0 0 r
.44288 .2374 m
.44366 .23816 L
s
0 0 1 r
.76501 .54346 m
.76774 .52317 L
s
.72027 .65389 m
.73254 .6347 L
s
.38465 .74272 m
.4061 .75179 L
s
1 0 0 r
.58093 .75525 m
.58019 .7565 L
s
0 0 1 r
.76786 .51777 m
.76873 .49826 L
s
.74381 .61276 m
.75239 .59232 L
s
.29183 .66997 m
.30433 .68362 L
s
.6546 .71979 m
.67312 .70555 L
s
.29624 .67523 m
.31044 .6901 L
s
.34025 .7161 m
.35926 .72883 L
s
.2937 .67222 m
.30709 .68654 L
s
.30216 .68187 m
.31231 .69117 L
s
1 0 0 r
.4256 .24177 m
.42698 .24265 L
s
0 0 1 r
.4061 .75179 m
.42841 .75898 L
s
.7589 .43094 m
.75537 .41632 L
s
1 0 0 r
.6559 .71737 m
.65323 .72076 L
s
0 0 1 r
.31835 .69804 m
.33551 .71226 L
s
1 0 0 r
.35542 .27347 m
.36044 .27177 L
s
.56076 .76042 m
.56046 .76184 L
s
.70175 .67568 m
.6977 .68202 L
s
0 0 1 r
.63477 .73242 m
.6546 .71979 L
s
1 0 0 r
.32002 .30048 m
.32833 .2949 L
s
0 0 1 r
.70616 .67208 m
.72027 .65389 L
s
.42841 .75898 m
.45138 .7642 L
s
.75308 .58903 m
.75981 .56844 L
s
1 0 0 r
.40955 .24701 m
.41167 .24794 L
s
.54035 .76399 m
.54032 .76563 L
s
0 0 1 r
.61381 .7433 m
.63477 .73242 L
s
1 0 0 r
.72669 .64157 m
.72243 .65069 L
s
0 0 1 r
.30109 .68059 m
.31239 .69076 L
s
.35926 .72883 m
.37956 .73992 L
s
.45138 .7642 m
.47483 .76739 L
s
.7641 .45699 m
.76199 .44065 L
s
.73321 .63263 m
.74381 .61276 L
s
1 0 0 r
.34617 .2798 m
.35235 .27764 L
s
0 0 1 r
.31424 .69402 m
.33087 .70806 L
s
1 0 0 r
.63881 .72787 m
.63694 .73108 L
s
0 0 1 r
.5919 .75233 m
.61381 .7433 L
s
1 0 0 r
.51999 .76592 m
.52007 .76783 L
s
0 0 1 r
.47483 .76739 m
.49855 .76852 L
s
.76014 .56385 m
.76501 .54346 L
s
.56921 .75943 m
.5919 .75233 L
s
.6903 .68913 m
.70616 .67208 L
s
1 0 0 r
.39489 .25288 m
.3979 .25376 L
s
0 0 1 r
.33551 .71226 m
.35419 .72503 L
s
1 0 0 r
.31601 .3044 m
.32557 .29803 L
s
0 0 1 r
.30119 .6805 m
.31359 .69153 L
s
.49855 .76852 m
.52233 .76756 L
s
1 0 0 r
.68867 .68828 m
.68549 .69414 L
s
0 0 1 r
.76685 .48375 m
.76634 .46594 L
s
.54595 .76452 m
.56921 .75943 L
s
.52233 .76756 m
.54595 .76452 L
s
.31044 .6901 m
.32643 .70379 L
s
1 0 0 r
.5 .76626 m
.5 .76845 L
s
.5 .23155 m
.5 .23374 L
s
0 0 1 r
.37956 .73992 m
.401 .74924 L
s
.76486 .53763 m
.76786 .51777 L
s
.76711 .51078 m
.76831 .49179 L
s
.30232 .68155 m
.31575 .6934 L
s
1 0 0 r
.62046 .73727 m
.6193 .74042 L
s
.33857 .28562 m
.346 .28289 L
s
0 0 1 r
.75431 .41993 m
.75137 .40603 L
s
.30709 .68654 m
.32233 .69975 L
s
.30433 .68362 m
.31872 .6962 L
s
1 0 0 r
.38176 .25914 m
.38578 .25987 L
s
0 0 1 r
.67281 .70484 m
.6903 .68913 L
s
1 0 0 r
.4804 .23242 m
.48065 .23488 L
s
0 0 1 r
.72063 .65173 m
.73321 .63263 L
s
.74423 .60928 m
.75308 .58903 L
s
1 0 0 r
.71645 .65454 m
.71301 .66305 L
s
.73846 .61784 m
.73508 .62908 L
s
0 0 1 r
.401 .74924 m
.4234 .75668 L
s
.35419 .72503 m
.37428 .7362 L
s
.33087 .70806 m
.34912 .72071 L
s
1 0 0 r
.6011 .74533 m
.60054 .74854 L
s
.46154 .23468 m
.46222 .23738 L
s
.67385 .70052 m
.67152 .70603 L
s
0 0 1 r
.65383 .71906 m
.67281 .70484 L
s
1 0 0 r
.37025 .26552 m
.37539 .26598 L
s
.33264 .29071 m
.34135 .28732 L
s
0 0 1 r
.76048 .44662 m
.7589 .43094 L
s
.31231 .69117 m
.32432 .69928 L
s
.4234 .75668 m
.44656 .76216 L
s
.75312 .58416 m
.76014 .56385 L
s
1 0 0 r
.44366 .23816 m
.44493 .24104 L
s
.58105 .7519 m
.58093 .75525 L
s
0 0 1 r
.70615 .66987 m
.72063 .65173 L
s
.32643 .70379 m
.34413 .71616 L
s
.63351 .73165 m
.65383 .71906 L
s
.76416 .4742 m
.7641 .45699 L
s
.37428 .7362 m
.39561 .74564 L
s
.73331 .629 m
.74423 .60928 L
s
.31239 .69076 m
.32558 .69975 L
s
.44656 .76216 m
.47028 .7656 L
s
1 0 0 r
.70435 .66767 m
.70175 .67568 L
s
0 0 1 r
.75967 .55766 m
.76486 .53763 L
s
1 0 0 r
.36044 .27177 m
.36679 .27184 L
s
.42698 .24265 m
.429 .24565 L
s
.65744 .71209 m
.6559 .71737 L
s
.32833 .2949 m
.33834 .29074 L
s
.56059 .75685 m
.56076 .76042 L
s
0 0 1 r
.61203 .74248 m
.63351 .73165 L
s
.34912 .72071 m
.36887 .73181 L
s
.76525 .50221 m
.76685 .48375 L
s
.32233 .69975 m
.33935 .71167 L
s
.76375 .53019 m
.76711 .51078 L
s
.31359 .69153 m
.32788 .70138 L
s
1 0 0 r
.7293 .63094 m
.72669 .64157 L
s
0 0 1 r
.47028 .7656 m
.49434 .76696 L
s
.31872 .6962 m
.33494 .70755 L
s
.68986 .68688 m
.70615 .66987 L
s
.31575 .6934 m
.33106 .70404 L
s
.58959 .75143 m
.61203 .74248 L
s
1 0 0 r
.41167 .24794 m
.4146 .25095 L
s
.54005 .76014 m
.54035 .76399 L
s
0 0 1 r
.49434 .76696 m
.51853 .76621 L
s
.56638 .75841 m
.58959 .75143 L
s
1 0 0 r
.35235 .27764 m
.36 .27719 L
s
0 0 1 r
.39561 .74564 m
.418 .75322 L
s
1 0 0 r
.32557 .29803 m
.3369 .29303 L
s
0 0 1 r
.51853 .76621 m
.54262 .76336 L
s
1 0 0 r
.63963 .72268 m
.63881 .72787 L
s
0 0 1 r
.54262 .76336 m
.56638 .75841 L
s
.74393 .60419 m
.75312 .58416 L
s
1 0 0 r
.51976 .76177 m
.51999 .76592 L
s
0 0 1 r
.7553 .43497 m
.75431 .41993 L
s
.72035 .648 m
.73331 .629 L
s
1 0 0 r
.3979 .25376 m
.40187 .25668 L
s
.69045 .68065 m
.68867 .68828 L
s
0 0 1 r
.34413 .71616 m
.36342 .72703 L
s
.6719 .70256 m
.68986 .68688 L
s
.36887 .73181 m
.38997 .74122 L
s
1 0 0 r
.5 .76181 m
.5 .76626 L
s
.5 .23374 m
.5 .23819 L
s
.346 .28289 m
.35498 .28182 L
s
0 0 1 r
.418 .75322 m
.44126 .75886 L
s
1 0 0 r
.62068 .73205 m
.62046 .73727 L
s
0 0 1 r
.75228 .57767 m
.75967 .55766 L
s
1 0 0 r
.74003 .60521 m
.73846 .61784 L
s
.71827 .64442 m
.71645 .65454 L
s
.38578 .25987 m
.3909 .26258 L
s
0 0 1 r
.76001 .46325 m
.76048 .44662 L
s
1 0 0 r
.48065 .23488 m
.48107 .23962 L
s
0 0 1 r
.33935 .71167 m
.35805 .72216 L
s
.65242 .71675 m
.6719 .70256 L
s
.32432 .69928 m
.33818 .70605 L
s
.75817 .54985 m
.76375 .53019 L
s
.44126 .75886 m
.46517 .76247 L
s
.70543 .66607 m
.72035 .648 L
s
.76208 .49214 m
.76416 .4742 L
s
1 0 0 r
.67486 .69314 m
.67385 .70052 L
s
.60087 .73999 m
.6011 .74533 L
s
.34135 .28732 m
.35171 .28552 L
s
.46222 .23738 m
.46323 .24235 L
s
0 0 1 r
.76146 .52118 m
.76525 .50221 L
s
.73261 .62375 m
.74393 .60419 L
s
.32558 .69975 m
.34061 .70742 L
s
.33494 .70755 m
.35291 .71749 L
s
.38997 .74122 m
.41224 .74882 L
s
1 0 0 r
.37539 .26598 m
.38177 .26836 L
s
0 0 1 r
.63157 .72931 m
.65242 .71675 L
s
.36342 .72703 m
.38416 .73626 L
s
.32788 .70138 m
.344 .70989 L
s
.33106 .70404 m
.34816 .71332 L
s
.46517 .76247 m
.48952 .76399 L
s
1 0 0 r
.44493 .24104 m
.44671 .24618 L
s
.5805 .74634 m
.58105 .7519 L
s
.33834 .29074 m
.35008 .28813 L
s
0 0 1 r
.60955 .74008 m
.63157 .72931 L
s
1 0 0 r
.70539 .65796 m
.70435 .66767 L
s
.36679 .27184 m
.37451 .27377 L
s
0 0 1 r
.48952 .76399 m
.51408 .7634 L
s
.68867 .68302 m
.70543 .66607 L
s
1 0 0 r
.65775 .70483 m
.65744 .71209 L
s
.429 .24565 m
.4317 .25086 L
s
.73014 .61882 m
.7293 .63094 L
s
0 0 1 r
.74269 .59748 m
.75228 .57767 L
s
1 0 0 r
.55991 .75101 m
.56059 .75685 L
s
0 0 1 r
.58656 .74896 m
.60955 .74008 L
s
.41224 .74882 m
.43549 .7545 L
s
.51408 .7634 m
.53859 .76067 L
s
.35805 .72216 m
.37829 .73105 L
s
.56284 .75585 m
.58656 .74896 L
s
.53859 .76067 m
.56284 .75585 L
s
1 0 0 r
.3369 .29303 m
.35 .28955 L
s
0 0 1 r
.71921 .64263 m
.73261 .62375 L
s
.75424 .45107 m
.7553 .43497 L
s
1 0 0 r
.4146 .25095 m
.41836 .25614 L
s
.53941 .75398 m
.54005 .76014 L
s
.36 .27719 m
.36912 .27856 L
s
0 0 1 r
.38416 .73626 m
.40618 .74372 L
s
.75035 .56957 m
.75817 .54985 L
s
.6702 .69867 m
.68867 .68302 L
s
1 0 0 r
.63934 .71542 m
.63963 .72268 L
s
0 0 1 r
.75739 .48071 m
.76001 .46325 L
s
.35291 .71749 m
.3725 .7259 L
s
.43549 .7545 m
.4595 .75816 L
s
1 0 0 r
.51934 .75528 m
.51976 .76177 L
s
.69074 .67121 m
.69045 .68065 L
s
.40187 .25668 m
.40682 .26174 L
s
0 0 1 r
.75542 .54048 m
.76146 .52118 L
s
.75778 .51069 m
.76208 .49214 L
s
1 0 0 r
.73968 .59124 m
.74003 .60521 L
s
0 0 1 r
.33818 .70605 m
.35385 .71136 L
s
1 0 0 r
.35498 .28182 m
.36554 .28251 L
s
0 0 1 r
.34816 .71332 m
.36697 .7211 L
s
1 0 0 r
.5 .755 m
.5 .76181 L
s
.5 .23819 m
.5 .245 L
s
.71836 .63271 m
.71827 .64442 L
s
0 0 1 r
.65017 .71284 m
.6702 .69867 L
s
.34061 .70742 m
.35744 .71362 L
s
1 0 0 r
.61992 .72468 m
.62068 .73205 L
s
0 0 1 r
.73091 .61687 m
.74269 .59748 L
s
.70382 .66063 m
.71921 .64263 L
s
.344 .70989 m
.36188 .71693 L
s
.4595 .75816 m
.48406 .75975 L
s
1 0 0 r
.3909 .26258 m
.39715 .26738 L
s
0 0 1 r
.40618 .74372 m
.42929 .7493 L
s
.37829 .73105 m
.39992 .73822 L
s
1 0 0 r
.48107 .23962 m
.48167 .24672 L
s
.35171 .28552 m
.36371 .28543 L
s
.67445 .68385 m
.67486 .69314 L
s
0 0 1 r
.62877 .72536 m
.65017 .71284 L
s
1 0 0 r
.59979 .73241 m
.60087 .73999 L
s
.46323 .24235 m
.4646 .24968 L
s
0 0 1 r
.48406 .75975 m
.5089 .75922 L
s
1 0 0 r
.38177 .26836 m
.38941 .27278 L
s
0 0 1 r
.74028 .58916 m
.75035 .56957 L
s
.60621 .73611 m
.62877 .72536 L
s
1 0 0 r
.35008 .28813 m
.36352 .28719 L
s
0 0 1 r
.68654 .67754 m
.70382 .66063 L
s
.3725 .7259 m
.39359 .73262 L
s
.5089 .75922 m
.53379 .75656 L
s
1 0 0 r
.44671 .24618 m
.44901 .25365 L
s
.57926 .73848 m
.5805 .74634 L
s
0 0 1 r
.42929 .7493 m
.45329 .75289 L
s
1 0 0 r
.70476 .64653 m
.70539 .65796 L
s
.72908 .60524 m
.73014 .61882 L
s
0 0 1 r
.75101 .46811 m
.75424 .45107 L
s
.58269 .74495 m
.60621 .73611 L
s
.71702 .63564 m
.73091 .61687 L
s
.53379 .75656 m
.55847 .75179 L
s
1 0 0 r
.37451 .27377 m
.38361 .27768 L
s
0 0 1 r
.7471 .55993 m
.75542 .54048 L
s
.55847 .75179 m
.58269 .74495 L
s
1 0 0 r
.65675 .69555 m
.65775 .70483 L
s
.35 .28955 m
.36483 .2877 L
s
0 0 1 r
.39992 .73822 m
.42275 .74354 L
s
1 0 0 r
.4317 .25086 m
.43509 .25839 L
s
0 0 1 r
.75253 .49887 m
.75739 .48071 L
s
1 0 0 r
.5587 .74282 m
.55991 .75101 L
s
0 0 1 r
.36697 .7211 m
.38736 .72723 L
s
.75122 .52966 m
.75778 .51069 L
s
.66752 .69317 m
.68654 .67754 L
s
1 0 0 r
.36912 .27856 m
.37971 .28185 L
s
0 0 1 r
.45329 .75289 m
.47793 .75442 L
s
.36188 .71693 m
.38142 .72234 L
s
1 0 0 r
.41836 .25614 m
.42297 .26361 L
s
.53842 .74542 m
.53941 .75398 L
s
0 0 1 r
.35385 .71136 m
.37126 .71507 L
s
.35744 .71362 m
.37598 .71822 L
s
1 0 0 r
.63787 .70605 m
.63934 .71542 L
s
.73731 .57599 m
.73968 .59124 L
s
.68943 .65994 m
.69074 .67121 L
s
0 0 1 r
.728 .60841 m
.74028 .58916 L
s
1 0 0 r
.51875 .74636 m
.51934 .75528 L
s
0 0 1 r
.7011 .65358 m
.71702 .63564 L
s
1 0 0 r
.40682 .26174 m
.41276 .26903 L
s
0 0 1 r
.39359 .73262 m
.41599 .73754 L
s
1 0 0 r
.36554 .28251 m
.37765 .28506 L
s
0 0 1 r
.64694 .70734 m
.66752 .69317 L
s
1 0 0 r
.71661 .61942 m
.71836 .63271 L
s
0 0 1 r
.42275 .74354 m
.44659 .74692 L
s
.47793 .75442 m
.50297 .75386 L
s
1 0 0 r
.5 .74574 m
.5 .755 L
s
.5 .245 m
.5 .25426 L
s
.61811 .7151 m
.61992 .72468 L
s
.39715 .26738 m
.40453 .27435 L
s
0 0 1 r
.73652 .57933 m
.7471 .55993 L
s
1 0 0 r
.36371 .28543 m
.37733 .28715 L
s
0 0 1 r
.62499 .71988 m
.64694 .70734 L
s
1 0 0 r
.48167 .24672 m
.48244 .25627 L
s
0 0 1 r
.50297 .75386 m
.52815 .75117 L
s
.38736 .72723 m
.40916 .73159 L
s
1 0 0 r
.67255 .67261 m
.67445 .68385 L
s
0 0 1 r
.68328 .67048 m
.7011 .65358 L
s
.74557 .48595 m
.75101 .46811 L
s
.74237 .54888 m
.75122 .52966 L
s
1 0 0 r
.59781 .72254 m
.59979 .73241 L
s
0 0 1 r
.60189 .73064 m
.62499 .71988 L
s
1 0 0 r
.4646 .24968 m
.46632 .25944 L
s
.36352 .28719 m
.37862 .28802 L
s
0 0 1 r
.52815 .75117 m
.55321 .74637 L
s
1 0 0 r
.38941 .27278 m
.3983 .27932 L
s
0 0 1 r
.44659 .74692 m
.47119 .74826 L
s
.74541 .51757 m
.75253 .49887 L
s
.71358 .6271 m
.728 .60841 L
s
.57788 .73951 m
.60189 .73064 L
s
1 0 0 r
.72604 .59027 m
.72908 .60524 L
s
0 0 1 r
.55321 .74637 m
.57788 .73951 L
s
.38142 .72234 m
.40246 .72602 L
s
.41599 .73754 m
.4395 .74054 L
s
1 0 0 r
.70235 .6334 m
.70476 .64653 L
s
.36483 .2877 m
.38134 .28759 L
s
.44901 .25365 m
.45184 .26354 L
s
.5773 .72825 m
.57926 .73848 L
s
0 0 1 r
.37598 .71822 m
.39609 .72109 L
s
1 0 0 r
.38361 .27768 m
.39406 .28365 L
s
0 0 1 r
.37126 .71507 m
.3903 .71707 L
s
1 0 0 r
.65437 .68422 m
.65675 .69555 L
s
0 0 1 r
.6637 .68613 m
.68328 .67048 L
s
1 0 0 r
.43509 .25839 m
.43917 .26829 L
s
0 0 1 r
.47119 .74826 m
.4963 .74753 L
s
1 0 0 r
.55693 .7322 m
.5587 .74282 L
s
0 0 1 r
.7237 .59848 m
.73652 .57933 L
s
1 0 0 r
.73282 .55956 m
.73731 .57599 L
s
.37971 .28185 m
.39175 .28713 L
s
0 0 1 r
.40916 .73159 m
.43219 .73408 L
s
1 0 0 r
.42297 .26361 m
.42843 .27341 L
s
0 0 1 r
.69711 .64502 m
.71358 .6271 L
s
1 0 0 r
.53705 .7344 m
.53842 .74542 L
s
0 0 1 r
.4395 .74054 m
.46391 .74155 L
s
1 0 0 r
.68644 .64685 m
.68943 .65994 L
s
.63514 .69452 m
.63787 .70605 L
s
0 0 1 r
.64257 .70035 m
.6637 .68613 L
s
.4963 .74753 m
.52167 .74469 L
s
1 0 0 r
.71294 .60461 m
.71661 .61942 L
s
.37765 .28506 m
.39128 .28955 L
s
0 0 1 r
.73123 .56815 m
.74237 .54888 L
s
1 0 0 r
.51797 .73495 m
.51875 .74636 L
s
.41276 .26903 m
.4197 .2786 L
s
0 0 1 r
.40246 .72602 m
.42483 .72785 L
s
.73598 .53662 m
.74541 .51757 L
s
.73785 .50445 m
.74557 .48595 L
s
.62008 .71296 m
.64257 .70035 L
s
1 0 0 r
.5 .73398 m
.5 .74574 L
s
.5 .25426 m
.5 .26602 L
s
.37733 .28715 m
.39251 .29078 L
s
0 0 1 r
.52167 .74469 m
.54701 .73977 L
s
1 0 0 r
.61521 .70327 m
.61811 .7151 L
s
.40453 .27435 m
.41304 .28356 L
s
0 0 1 r
.67873 .66195 m
.69711 .64502 L
s
.59649 .72381 m
.62008 .71296 L
s
.70872 .61714 m
.7237 .59848 L
s
1 0 0 r
.48244 .25627 m
.4834 .26831 L
s
0 0 1 r
.54701 .73977 m
.57204 .73278 L
s
.39609 .72109 m
.41763 .72215 L
s
1 0 0 r
.37862 .28802 m
.39529 .29071 L
s
0 0 1 r
.46391 .74155 m
.48896 .74051 L
s
1 0 0 r
.66909 .65944 m
.67255 .67261 L
s
0 0 1 r
.57204 .73278 m
.59649 .72381 L
s
.43219 .73408 m
.45623 .7346 L
s
1 0 0 r
.72094 .574 m
.72604 .59027 L
s
.38134 .28759 m
.39942 .28931 L
s
0 0 1 r
.3903 .71707 m
.41083 .71725 L
s
1 0 0 r
.5949 .71034 m
.59781 .72254 L
s
.3983 .27932 m
.40843 .28802 L
s
.46632 .25944 m
.46841 .27169 L
s
.6981 .61863 m
.70235 .6334 L
s
.45184 .26354 m
.4552 .27589 L
s
0 0 1 r
.65861 .67768 m
.67873 .66195 L
s
.71786 .58724 m
.73123 .56815 L
s
1 0 0 r
.57458 .71563 m
.5773 .72825 L
s
.39406 .28365 m
.40584 .29173 L
s
0 0 1 r
.48896 .74051 m
.51437 .7374 L
s
1 0 0 r
.65055 .67085 m
.65437 .68422 L
s
.72617 .54209 m
.73282 .55956 L
s
0 0 1 r
.42483 .72785 m
.44832 .72775 L
s
1 0 0 r
.43917 .26829 m
.44394 .28062 L
s
0 0 1 r
.6917 .6351 m
.70872 .61714 L
s
1 0 0 r
.5546 .71913 m
.55693 .7322 L
s
.39175 .28713 m
.40519 .29447 L
s
0 0 1 r
.72429 .55582 m
.73598 .53662 L
s
.45623 .7346 m
.48104 .73311 L
s
.63695 .69202 m
.65861 .67768 L
s
.72786 .52341 m
.73785 .50445 L
s
.51437 .7374 m
.53987 .73221 L
s
1 0 0 r
.42843 .27341 m
.43473 .28558 L
s
.68171 .632 m
.68644 .64685 L
s
.5353 .72089 m
.53705 .7344 L
s
.70727 .58837 m
.71294 .60461 L
s
0 0 1 r
.41763 .72215 m
.4404 .72129 L
s
1 0 0 r
.39128 .28955 m
.40635 .29605 L
s
.63113 .68084 m
.63514 .69452 L
s
0 0 1 r
.61399 .70479 m
.63695 .69202 L
s
1 0 0 r
.517 .72103 m
.51797 .73495 L
s
0 0 1 r
.53987 .73221 m
.56516 .725 L
s
1 0 0 r
.4197 .2786 m
.42762 .29048 L
s
.39251 .29078 m
.40916 .29635 L
s
0 0 1 r
.41083 .71725 m
.43269 .71554 L
s
.70233 .60595 m
.71786 .58724 L
s
.67278 .65213 m
.6917 .6351 L
s
.58996 .71582 m
.61399 .70479 L
s
.56516 .725 m
.58996 .71582 L
s
1 0 0 r
.39529 .29071 m
.41343 .29532 L
s
.5 .7197 m
.5 .73398 L
s
.5 .26602 m
.5 .2803 L
s
0 0 1 r
.48104 .73311 m
.50634 .72958 L
s
1 0 0 r
.61118 .6892 m
.61521 .70327 L
s
0 0 1 r
.44832 .72775 m
.47271 .72566 L
s
1 0 0 r
.39942 .28931 m
.41894 .29293 L
s
.41304 .28356 m
.42263 .29502 L
s
.71373 .55654 m
.72094 .574 L
s
.664 .64437 m
.66909 .65944 L
s
.4834 .26831 m
.48454 .28287 L
s
0 0 1 r
.71037 .57495 m
.72429 .55582 L
s
1 0 0 r
.40843 .28802 m
.41974 .29892 L
s
.69196 .6023 m
.6981 .61863 L
s
.59105 .69582 m
.5949 .71034 L
s
.46841 .27169 m
.47085 .28642 L
s
0 0 1 r
.65215 .66802 m
.67278 .65213 L
s
1 0 0 r
.71732 .52371 m
.72617 .54209 L
s
0 0 1 r
.50634 .72958 m
.53185 .72401 L
s
.4404 .72129 m
.46417 .71848 L
s
.71562 .54263 m
.72786 .52341 L
s
1 0 0 r
.40584 .29173 m
.41888 .30195 L
s
.4552 .27589 m
.45909 .29068 L
s
0 0 1 r
.68478 .62403 m
.70233 .60595 L
s
1 0 0 r
.5711 .70062 m
.57458 .71563 L
s
.64526 .65547 m
.65055 .67085 L
s
0 0 1 r
.47271 .72566 m
.49772 .72156 L
s
.63003 .68257 m
.65215 .66802 L
s
1 0 0 r
.44394 .28062 m
.44939 .29535 L
s
.40519 .29447 m
.41994 .30388 L
s
0 0 1 r
.53185 .72401 m
.55727 .71643 L
s
1 0 0 r
.55169 .70363 m
.5546 .71913 L
s
0 0 1 r
.43269 .71554 m
.45565 .71189 L
s
1 0 0 r
.69958 .57081 m
.70727 .58837 L
s
.6752 .61545 m
.68171 .632 L
s
.40635 .29605 m
.42275 .30458 L
s
0 0 1 r
.60666 .69559 m
.63003 .68257 L
s
1 0 0 r
.43473 .28558 m
.44184 .30011 L
s
0 0 1 r
.55727 .71643 m
.58231 .70693 L
s
1 0 0 r
.53317 .70492 m
.5353 .72089 L
s
.62581 .66505 m
.63113 .68084 L
s
0 0 1 r
.69433 .59379 m
.71037 .57495 L
s
1 0 0 r
.40916 .29635 m
.42715 .30392 L
s
0 0 1 r
.58231 .70693 m
.60666 .69559 L
s
.66537 .64126 m
.68478 .62403 L
s
1 0 0 r
.41894 .29293 m
.43974 .29849 L
s
.41343 .29532 m
.43289 .30189 L
s
.51585 .70462 m
.517 .72103 L
s
.42762 .29048 m
.43646 .30466 L
s
0 0 1 r
.49772 .72156 m
.52307 .71546 L
s
.46417 .71848 m
.48869 .71369 L
s
1 0 0 r
.70441 .53806 m
.71373 .55654 L
s
0 0 1 r
.7012 .5619 m
.71562 .54263 L
s
1 0 0 r
.5 .70294 m
.5 .7197 L
s
.5 .2803 m
.5 .29706 L
s
.60601 .67293 m
.61118 .6892 L
s
.42263 .29502 m
.43326 .30872 L
s
.7063 .50462 m
.71732 .52371 L
s
.65727 .6275 m
.664 .64437 L
s
.48454 .28287 m
.48587 .29989 L
s
.6839 .58452 m
.69196 .6023 L
s
0 0 1 r
.64429 .65741 m
.66537 .64126 L
s
.52307 .71546 m
.54846 .70739 L
s
1 0 0 r
.41974 .29892 m
.43217 .312 L
s
0 0 1 r
.45565 .71189 m
.47949 .70627 L
s
1 0 0 r
.58624 .67902 m
.59105 .69582 L
s
0 0 1 r
.6763 .61209 m
.69433 .59379 L
s
1 0 0 r
.47085 .28642 m
.47364 .3036 L
s
.41888 .30195 m
.43309 .31429 L
s
0 0 1 r
.48869 .71369 m
.51369 .70691 L
s
.62179 .67228 m
.64429 .65741 L
s
1 0 0 r
.45909 .29068 m
.46348 .30788 L
s
0 0 1 r
.54846 .70739 m
.57358 .69742 L
s
1 0 0 r
.56685 .68328 m
.5711 .70062 L
s
.63848 .63817 m
.64526 .65547 L
s
.41994 .30388 m
.43588 .31537 L
s
.68987 .5521 m
.69958 .57081 L
s
0 0 1 r
.59813 .68567 m
.62179 .67228 L
s
1 0 0 r
.44939 .29535 m
.45549 .31244 L
s
0 0 1 r
.57358 .69742 m
.59813 .68567 L
s
.6847 .58096 m
.7012 .5619 L
s
1 0 0 r
.43974 .29849 m
.4616 .30601 L
s
.42275 .30458 m
.44037 .31513 L
s
.54822 .68575 m
.55169 .70363 L
s
.66691 .59733 m
.6752 .61545 L
s
.42715 .30392 m
.44632 .31348 L
s
.43289 .30189 m
.45349 .31042 L
s
0 0 1 r
.65647 .62962 m
.6763 .61209 L
s
1 0 0 r
.44184 .30011 m
.44972 .31695 L
s
.69298 .51873 m
.70441 .53806 L
s
.53067 .68654 m
.53317 .70492 L
s
.61917 .64723 m
.62581 .66505 L
s
0 0 1 r
.51369 .70691 m
.53886 .69821 L
s
.47949 .70627 m
.50392 .69871 L
s
1 0 0 r
.69315 .48503 m
.7063 .50462 L
s
.43646 .30466 m
.44618 .3211 L
s
.51451 .68581 m
.51585 .70462 L
s
0 0 1 r
.63505 .64615 m
.65647 .62962 L
s
1 0 0 r
.5 .68377 m
.5 .70294 L
s
.5 .29706 m
.5 .31623 L
s
.59971 .65455 m
.60601 .67293 L
s
.43326 .30872 m
.44484 .32461 L
s
.6489 .60893 m
.65727 .6275 L
s
.67393 .56545 m
.6839 .58452 L
s
0 0 1 r
.53886 .69821 m
.56389 .68765 L
s
.66629 .5996 m
.6847 .58096 L
s
1 0 0 r
.48587 .29989 m
.48736 .3193 L
s
.43217 .312 m
.4456 .32721 L
s
0 0 1 r
.6123 .66146 m
.63505 .64615 L
s
.50392 .69871 m
.52867 .68924 L
s
1 0 0 r
.58048 .66005 m
.58624 .67902 L
s
0 0 1 r
.56389 .68765 m
.58848 .67535 L
s
1 0 0 r
.47364 .3036 m
.47677 .32313 L
s
.4616 .30601 m
.48429 .31545 L
s
.43309 .31429 m
.44834 .3287 L
s
.67817 .53241 m
.68987 .5521 L
s
0 0 1 r
.58848 .67535 m
.6123 .66146 L
s
1 0 0 r
.63022 .61906 m
.63848 .63817 L
s
.46348 .30788 m
.46835 .3274 L
s
.43588 .31537 m
.45289 .32889 L
s
.45349 .31042 m
.47501 .32089 L
s
.56186 .66371 m
.56685 .68328 L
s
.44037 .31513 m
.45902 .32767 L
s
.44632 .31348 m
.46648 .32499 L
s
.67953 .49877 m
.69298 .51873 L
s
0 0 1 r
.64615 .61755 m
.66629 .5996 L
s
1 0 0 r
.67796 .46516 m
.69315 .48503 L
s
.65684 .5778 m
.66691 .59733 L
s
.45549 .31244 m
.46219 .33179 L
s
.5442 .66561 m
.54822 .68575 L
s
0 0 1 r
.52867 .68924 m
.55342 .67796 L
s
1 0 0 r
.44972 .31695 m
.45831 .33599 L
s
.61123 .62752 m
.61917 .64723 L
s
.52781 .66587 m
.53067 .68654 L
s
0 0 1 r
.62452 .63458 m
.64615 .61755 L
s
1 0 0 r
.44618 .3211 m
.45669 .33968 L
s
.513 .6647 m
.51451 .68581 L
s
.66211 .54529 m
.67393 .56545 L
s
0 0 1 r
.55342 .67796 m
.57786 .66498 L
s
1 0 0 r
.48429 .31545 m
.50755 .32675 L
s
.63893 .58884 m
.6489 .60893 L
s
.5923 .6342 m
.59971 .65455 L
s
.44484 .32461 m
.45727 .34258 L
s
.5 .66233 m
.5 .68377 L
s
.5 .31623 m
.5 .33767 L
s
0 0 1 r
.60166 .65046 m
.62452 .63458 L
s
.57786 .66498 m
.60166 .65046 L
s
1 0 0 r
.66088 .44526 m
.67796 .46516 L
s
.4456 .32721 m
.45993 .34445 L
s
.48736 .3193 m
.48902 .34096 L
s
.66456 .51196 m
.67817 .53241 L
s
.47501 .32089 m
.4972 .33321 L
s
.66415 .47842 m
.67953 .49877 L
s
.57382 .63903 m
.58048 .66005 L
s
.44834 .3287 m
.46449 .34509 L
s
.47677 .32313 m
.4802 .34487 L
s
.46648 .32499 m
.48741 .33837 L
s
.45289 .32889 m
.47077 .34433 L
s
.45902 .32767 m
.4785 .3421 L
s
.62053 .59833 m
.63022 .61906 L
s
.46835 .3274 m
.47366 .34908 L
s
.64507 .55705 m
.65684 .5778 L
s
.55615 .64205 m
.56186 .66371 L
s
.50755 .32675 m
.53108 .33982 L
s
.46219 .33179 m
.46943 .35325 L
s
.53965 .64335 m
.5442 .66561 L
s
.64208 .4256 m
.66088 .44526 L
s
.45831 .33599 m
.46753 .35708 L
s
.60204 .6061 m
.61123 .62752 L
s
.64851 .52425 m
.66211 .54529 L
s
.52462 .64309 m
.52781 .66587 L
s
.4972 .33321 m
.51979 .3473 L
s
.45669 .33968 m
.46789 .36025 L
s
.647 .45793 m
.66415 .47842 L
s
.51132 .64149 m
.513 .6647 L
s
.64916 .49101 m
.66456 .51196 L
s
.62741 .56742 m
.63893 .58884 L
s
.53108 .33982 m
.55459 .35451 L
s
.45727 .34258 m
.47043 .36249 L
s
.58383 .61206 m
.5923 .6342 L
s
.5 .6388 m
.5 .66233 L
s
.5 .33767 m
.5 .3612 L
s
.48741 .33837 m
.50885 .35351 L
s
.45993 .34445 m
.47498 .36357 L
s
.62178 .40644 m
.64208 .4256 L
s
.48902 .34096 m
.49082 .36468 L
s
.4785 .3421 m
.49858 .3583 L
s
.46449 .34509 m
.48135 .36331 L
s
.47077 .34433 m
.48931 .36157 L
s
.56629 .61618 m
.57382 .63903 L
s
.4802 .34487 m
.48391 .36863 L
s
.63169 .53532 m
.64507 .55705 L
s
.60948 .57618 m
.62053 .59833 L
s
.55459 .35451 m
.57774 .37065 L
s
.51979 .3473 m
.54249 .36298 L
s
.60024 .38804 m
.62178 .40644 L
s
.47366 .34908 m
.47934 .37272 L
s
.62826 .43757 m
.647 .45793 L
s
.54977 .61852 m
.55615 .64205 L
s
.57774 .37065 m
.60024 .38804 L
s
.63328 .50259 m
.64851 .52425 L
s
.46943 .35325 m
.47714 .37662 L
s
.63212 .46981 m
.64916 .49101 L
s
.53462 .6192 m
.53965 .64335 L
s
.59168 .58318 m
.60204 .6061 L
s
.50885 .35351 m
.53052 .37024 L
s
.46753 .35708 m
.47727 .38002 L
s
.52111 .61842 m
.52462 .64309 L
s
.61446 .54492 m
.62741 .56742 L
s
.54249 .36298 m
.56499 .38008 L
s
.46789 .36025 m
.47965 .38261 L
s
.60817 .41763 m
.62826 .43757 L
s
.5095 .6164 m
.51132 .64149 L
s
.49858 .3583 m
.51901 .37609 L
s
.47043 .36249 m
.48415 .38414 L
s
.57439 .58836 m
.58383 .61206 L
s
.48931 .36157 m
.5083 .38042 L
s
.5 .61342 m
.5 .6388 L
s
.5 .3612 m
.5 .38658 L
s
.47498 .36357 m
.49058 .38438 L
s
.48135 .36331 m
.49872 .38317 L
s
.56499 .38008 m
.58698 .39838 L
s
.61684 .51287 m
.63169 .53532 L
s
.58698 .39838 m
.60817 .41763 L
s
.49082 .36468 m
.49275 .3902 L
s
.61366 .44866 m
.63212 .46981 L
s
.55797 .59173 m
.56629 .61618 L
s
.59718 .55287 m
.60948 .57618 L
s
.61657 .48059 m
.63328 .50259 L
s
.53052 .37024 m
.55213 .38836 L
s
.48391 .36863 m
.48785 .39414 L
s
.47934 .37272 m
.48534 .39806 L
s
.54279 .59337 m
.54977 .61852 L
s
.47714 .37662 m
.48522 .40163 L
s
.51901 .37609 m
.5395 .39528 L
s
.59399 .42784 m
.61366 .44866 L
s
.52915 .59344 m
.53462 .6192 L
s
.58026 .55904 m
.59168 .58318 L
s
.55213 .38836 m
.57338 .40765 L
s
.60021 .52163 m
.61446 .54492 L
s
.47727 .38002 m
.48741 .40454 L
s
.51733 .59213 m
.52111 .61842 L
s
.5083 .38042 m
.52747 .40066 L
s
.47965 .38261 m
.49182 .4065 L
s
.57338 .40765 m
.59399 .42784 L
s
.59859 .45856 m
.61657 .48059 L
s
.60068 .49 m
.61684 .51287 L
s
.48415 .38414 m
.49827 .40726 L
s
.49872 .38317 m
.51637 .40445 L
s
.50756 .58972 m
.5095 .6164 L
s
.49058 .38438 m
.50653 .40662 L
s
.56406 .5634 m
.57439 .58836 L
s
.5 .58649 m
.5 .61342 L
s
.5 .38658 m
.5 .41351 L
s
.5395 .39528 m
.55979 .4156 L
s
.58377 .52869 m
.59718 .55287 L
s
.49275 .3902 m
.49478 .41723 L
s
.54896 .56599 m
.55797 .59173 L
s
.57958 .43679 m
.59859 .45856 L
s
.48785 .39414 m
.49197 .42111 L
s
.55979 .4156 m
.57958 .43679 L
s
.52747 .40066 m
.54656 .42204 L
s
.48534 .39806 m
.49158 .4248 L
s
.53528 .56692 m
.54279 .59337 L
s
.58483 .49784 m
.60021 .52163 L
s
.58342 .46703 m
.60068 .49 L
s
.5679 .53398 m
.58026 .55904 L
s
.48522 .40163 m
.49357 .42799 L
s
.52333 .56637 m
.52915 .59344 L
s
.51637 .40445 m
.53405 .42687 L
s
.48741 .40454 m
.49784 .43036 L
s
.49182 .4065 m
.50425 .43163 L
s
.51334 .56457 m
.51733 .59213 L
s
.50653 .40662 m
.52262 .43003 L
s
.49827 .40726 m
.51259 .43158 L
s
.54656 .42204 m
.5653 .44427 L
s
.55298 .53748 m
.56406 .5634 L
s
.50551 .56179 m
.50756 .58972 L
s
.5653 .44427 m
.58342 .46703 L
s
.5694 .50397 m
.58377 .52869 L
s
.5 .55835 m
.5 .58649 L
s
.5 .41351 m
.5 .44165 L
s
.56853 .47389 m
.58483 .49784 L
s
.49478 .41723 m
.49689 .44542 L
s
.53936 .53928 m
.54896 .56599 L
s
.53405 .42687 m
.55152 .45012 L
s
.49197 .42111 m
.49622 .44918 L
s
.55477 .50834 m
.5679 .53398 L
s
.49158 .4248 m
.49798 .4526 L
s
.52735 .5395 m
.53528 .56692 L
s
.52262 .43003 m
.53861 .45429 L
s
.55152 .45012 m
.56853 .47389 L
s
.49357 .42799 m
.50208 .45534 L
s
.51721 .53835 m
.52333 .56637 L
s
.49784 .43036 m
.5084 .45712 L
s
.51259 .43158 m
.52692 .45677 L
s
.55428 .47905 m
.5694 .50397 L
s
.50425 .43163 m
.51675 .45767 L
s
.50917 .53608 m
.51334 .56457 L
s
.5413 .51097 m
.55298 .53748 L
s
.50339 .53299 m
.50551 .56179 L
s
.53861 .45429 m
.55428 .47905 L
s
.5 .52939 m
.5 .55835 L
s
.5 .44165 m
.5 .47061 L
s
.52931 .51197 m
.53936 .53928 L
s
.54104 .48248 m
.55477 .50834 L
s
.49689 .44542 m
.49905 .47438 L
s
.49622 .44918 m
.50055 .47797 L
s
.52692 .45677 m
.54104 .48248 L
s
.51909 .5115 m
.52735 .5395 L
s
.49798 .4526 m
.50444 .48105 L
s
.51675 .45767 m
.52916 .48424 L
s
.50208 .45534 m
.51062 .48331 L
s
.5084 .45712 m
.51893 .48445 L
s
.52916 .48424 m
.5413 .51097 L
s
.51088 .50978 m
.51721 .53835 L
s
.50488 .50708 m
.50917 .53608 L
s
.50123 .50371 m
.50339 .53299 L
s
.51893 .48445 m
.52931 .51197 L
s
.5 .5 m
.5 .52939 L
s
.5 .47061 m
.5 .5 L
s
.49905 .47438 m
.50123 .50371 L
s
.51062 .48331 m
.51909 .5115 L
s
.50055 .47797 m
.50488 .50708 L
s
.50444 .48105 m
.51088 .50978 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0029Ool00g`0Oomoo`03Ool0
0g`0Oomoo`2>Ool008Aoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo08ioo`00Ogoo00=l
07ooOol00Woo00=l07ooOol00Woo0W`0100O00=l000O01l00`0ORgoo001iOol2O004Ool01W`0Oomo
ogoo01ml00D07`03O01oogoo009oo`03O01oogoo00=oo`L07hAoo`00MGoo00Ml07ooOomoog`0Ooml
0002Ool201l01G`001l07gooO0001@0O00=l000O01l00P0O00=l000O01l0100O1Woo1@0OOgoo001d
Ool3O002Ool00g`0Ooml000201l00goo01ml000301l2O004Ool00g`0Oomoo`02Ool00g`0Oomoo`04
Ool601l5Ool301mlOol0071oo`=l0005Ooml07ooO01oo`0301l017`001l07`0O0W`00goo0W`0100O
00=l000O01l00P0O00=l000O01l0400O0Woo0`0ONGoo001`Ool01g`0Oomoog`0Ooml000O009l00<0
7`05O01oogoo01ml000401l00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`0:Ool301l3Ool8
01mfOol006aoo`=l0007Ooml07oo01ml000OO0000P0O00El07oo01l07g`000807`03O01oog`000=o
o`03O0007`0O00807`03O0007`0O00807`03O0007`0O00D07`Qoo`@07`Aoo`H07g=oo`00K7oo00=l
07ooOol00W`000<07goo01l00W`00Woo00<07g`0O0000Woo00El07ooO0007g`000<07`03O01oogoo
009oo`03O01oogoo009oo`03O01oogoo00Eoo`H07`Ioo`D07`9oo`807`04Ool07`0O01m`Ool006Uo
o`=l0004Ool07`0OOol2O000100OOomoog`00P0O00Aoog`0O01oo`807`04O0007g`0O003Ool2O003
Ool00g`0Oomoo`0201l00g`001l07`0601l5Ool601l5Ool201l2Ool201l2Ool201m^Ool006Moo`9l
009oo`0401ml07`0Ool201l00gooO01l000201l01W`0Oomoo`0OO0007`9oo`05O01oog`0O01oo`03
01l01G`001l07`0OO0000P0O0Woo00=l07ooOol01Woo1P0O1Goo1@0O0Woo0P0O0Woo0P0O0Woo0P0O
K7oo001VOol7O0001@0OO01l07`0Ool00P0O0W`000@07g`001moo`9l009oo`05O01oo`0O01ml0002
Ool2O003Ool00g`0Oomoo`02Ool00g`0Oomoo`0<Ool601l4Ool301l00goo01l07`02Ool201l2Ool2
01mZOol006Aoo`Ml00807`9l000401ml07`0Ool201l2O0001GooO01oogooO0000`0O0W`000Aoog`0
Oomoo`9l009oo`0301ml000O00<07`03O0007`0O00d07`Eoo`D07`9oo`807`03Ool07`0O009oo`80
7`9oo`0301moogoo06Moo`00Hgoo17`000@07goo01l07`9l00807`9l000401ml07ooOol2O0001@0O
O0007`0OO0000goo0W`000=oog`001l00`0O00=l000OOol00W`00goo00=l07ooOol03Goo1@0O1Goo
0P0O0Woo0P0O00=oo`0O01l00Woo0P0O00=oo`0OOol0Igoo001QOol>O00201l01W`0Ooml07`001ml
009oo`07O01oog`0O01oo`0OO0000P0O00Il07ooOoml07ooO002Ool2O003Ool00g`001l07`0801l:
Ool201l5Ool201l2Ool201l00goo01l07`02Ool0100OOol07`0OIWoo001POolDO000400OO01l07`0
Ooml07oo01ml000OOoml07ooO01oog`00Woo0W`00Woo00<07g`001l00P0O00=l07ooOol027oo1P0O
1Woo0`0O17oo0P0O0Woo00<07gooOol00P0O00Eoo`0O01moo`0O06Eoo`00Ggoo27`00P0O0goo00=l
07ooO0001W`000Moog`0Ooml000OO01oo`02O002Ool2O0000gooO0007`0201l00g`001l07`02O003
Ool00g`0Oomoo`0>Ool601l3Ool301l3Ool201l00goo01l07`02Ool00`0OOomoo`0301mTOol005eo
o`Ml000601moo`0OOoml07oo0P0O00=l07ooOol00P0O00=oog`0O0002W`00P0O00Al000O01ml009o
o`9l009oo`9l00=oo`03O01oo`0O00l07`Eoo`@07`9oo`<07`9oo`D07`03Ool07`0O009oo`807f=o
o`00G7oo0g`000=oo`0O01l00P0O00Ioo`0OOomoog`001l3Ool201l3Ool00g`001ml000=O002Ool0
17`0Ool07g`00`0O00Il000O01l07g`001l@Ool501l4Ool301l2Ool201l3Ool401l017oo01l07goo
0`0OHGoo001KOol3O0001Goo01ml000OOol00P0O0Woo00@07g`0Oomoo`807`04O01oogooOol201l3
Ool7O0000gooO01oo`03O0000gooO0007`02O003Ool01G`0OomoogooO0005Woo1@0O0Woo0`0O00Ao
o`0O01l07`9oo`@07`03Ool07`0O00<07f1oo`00FWoo00Al07ooOoml00807`05O0007`0OOoml0002
01l017ooO0007`0O0goo00El000O01moog`0009oo`<07`Al0007Ooml07`0O0007g`001l01G`00goo
00El000O01l07g`001L07`Aoo`807`=oo`807`9oo`807`9oo`0701moo`0O01moo`0OOol00P0OGgoo
001IOol2O0001WooO0007`0OOol07`9oo`807`=oo`0301moogoo009oo`807`=oo`<07`=oo`Ul0004
Ooml07ooOol3O00301l01G`0OomoogooO0005goo1@0O00Aoo`0O01l07`9oo`<07`04Ool07`0OOol2
01l01Goo01moo`0OOol00P0OGWoo001HOol00g`0Ooml000301l027oo01ml07oo01moog`0Ool201l0
0gooO01oo`0201l00gooO01oo`0201l00gooO01oo`03Ool00g`001l07`08O00201l017`001ml07`0
0Woo00El07ooOomoog`000=ooa007`Uoo`807`9oo`807`=oo`807`0:Ool07`0OOol07goo01moo`0O
Ool301mLOol005Moo`9l0009Ooml07oo01moo`0OOoml000O009oo`807`=oo`03O0007goo009oo`80
7`=oo`03O01oogoo00<07`=oo`Al000301ml07`000=l0003Ooml07`000=l009oo`0301ml000O0080
7a1ooa807`9oo`807`0<Ool07`0O01moo`0OOol07goo01moo`0OFgoo001GOol2O0001P0OO0007g`0
01moo`807`9oo`0301moog`0009oo`807`9oo`807`03Ooml07oo009oo`03O0007`0O00=oo`04O01o
ogooOol3O0001GooO01l07`0Ool017`00P0O0g`000=oog`0Ool02Goo2P0O2Woo2P0O00Aoo`0O01mo
o`@07`06Ool07goo01moo`0OFWoo001FOol2O0002`0OO0007goo01moo`0OOoml07oo01l00Woo00Ml
000O01moog`0Ool07`03Ool00g`0Oomoo`0201l00g`0Oomoo`02Ool01G`0Ool07`0OOol01g`000@0
7g`0O01l009oo`03O01oogoo009l00Eoo`D07`Yoo`/07`=oo`807`9oo`@07`05Ool07`0O01moo`02
01l01Woo01l07`0OOol07eUoo`00EGoo00Ul07ooO01oo`0OOol07goo01l00Woo00=l000OOol00Woo
00@07gooOomoo`807`Aoo`03O0007`0O009oo`04O01oogooOol301l3Ool6O0000gooO01l0005O003
Ool3O00301l<Ool:01l4Ool801l017oo01l07`0O0Woo0`0O00Aoo`0OOomoo`807`03Ool07goo05Mo
o`00EGoo00Ul07oo01l07g`001moo`0OO0000Woo00<07g`0Ool00P0O00Il07oo01l07gooO003Ool2
01l00g`0Oomoo`02Ool01G`001l07gooO0001Goo00<07g`0O0000g`000Ioog`0O01l07oo01l2O002
01l00g`0Oomoo`02O002Ool;01l:Ool>01l02Goo01l07`0OOol07goo01moo`0201l017oo01l07`0O
F7oo001EOol03W`001ml07oo01moo`0OOoml07oo01moog`001l3Ool00`0OOomoo`02Ool00g`0Ool0
7`02Ool00g`0Oomoo`0301l4Ool00g`0Oomoo`0201l00g`0Ooml0005O000100OO0007goo1G`000Ao
o`0O01l07`9l00Moob407`05Ool07`0O01moo`0201l017oo01l07`0OEgoo001DOol01g`001l07g`0
01ml000O009oo`05O0007goo01ml0003Ool00`0OO01oo`03Ool201l3Ool00g`001l07`03Ool017`0
Oomoogoo0`0O0Woo00=l07ooO0000g`000@07g`0O01oo`Al00807`9l00Eoo`9l00D07`Iooad07`04
Ool07`0OOol201l017oo01l07`0OEWoo001DOol201l017`001moo`0O0Woo0P0O00Eoo`0OOomoog`0
00807`04Ooml07ooOol201l017ooO01oogoo0P0O1Goo00El07oo01l07g`000Aoo`03O01oo`0O009l
0003Ooml07`000=l0003Ooml07`0009oo`05O01oog`0O01oo`0401l00g`0Oomoo`03Ool501l00goo
01l07`0301lAOol:01l01Goo01l07`0OOol00P0OEGoo001COol201l02Woo01moo`0OO01oo`0OOoml
000O0goo00=l07ooOol00Woo00=l000OOol00Woo00=l000O01l00Woo00Al07ooOomoo`<07`=oo`04
O01oogooOol201l2Ool3O0001WooO0007g`001moo`9l0003Ooml07oo00807`9l00Aoo`9l00<07`=o
o`<07aYoo`/07`03Ool07`0O05Aoo`00Dgoo0`0O00El000OOomoo`0O009oo`0601ml07ooOol07g`0
0goo0P0O0goo0P0O17oo00Il07oo01l07gooO004Ool01W`001l07`0OOoml00=oo`9l000301ml07`0
00Al000401ml07`001l4Ool017`001l07`0O0Woo0W`00Woo0P0O87oo2@0O00=oo`0OOol0Dgoo001B
Ool201l02g`0Ooml000OOol07g`0Ool07gooO0000P0O0Woo00El000O01moog`0009oo`0401moogoo
O003Ool201l4Ool00g`0Oomoo`0201l01G`0OomoogooO0000Woo00<07g`0O00017`00P0O00=l07oo
Ool00g`000Eoo`0O01moog`000Aoo`807`9l02Aoo`X07e=oo`00DGoo0`0O00Ql07oo01ml000OOoml
000O0Woo00<07gooOol00Woo00<07gooOol00Woo0P0O0goo00Il07oo01l07gooO004Ool301l2Ool0
1G`0OomoogooO0000P0O00=oog`0O0000W`000@07g`0O01oo`Al00807`03O01oogoo009oo`04O000
7`0O01l4Ool00g`0Oomoo`0SOol901mBOol0051oo`<07`05Ooml000OOoml0002Ool01@0OO01oo`0O
O0000goo00@07g`0Oomoo`807`03O01oogoo009oo`807`=oo`03O01oogoo00807`03O01oogoo009o
o`03O01oo`0O00807`04O01oogooOol8O0000goo01ml0003Ool01G`0Ool07`0OOol00W`01Woo00=l
07ooOol08goo1P0O00=oo`0OOol0DGoo001@Ool301l02Woo01moo`0OO01oo`0OOoml000O0Woo00=l
000O01l00Woo00=l000OOol00Woo00Il07ooOol07gooO004Ool00g`001moo`02Ool017`0Oomoogoo
0P0O0goo00Al07oo01l07`Il000401ml000OOol2O00017oo01l07g`01Goo00=l07ooOol017oo00=l
07ooOol097oo1`0ODGoo001?Ool301l01goo01ml000OOoml000O009oo`0501moogooOoml0004Ool0
0`0OOomoo`02Ool00g`001l07`03Ool01G`0Ool07`0OO00017oo00Il000O01l07gooO003Ool017`0
01moogoo17`000<07g`0Ool00W`000Aoog`001ml00=oo`9l00Aoo`03O01oogoo00Aoo`9l02Eoo`L0
7e1oo`00Cgoo0`0O00Ioo`0OO0007goo01l2Ool01`0OOoml07oo01moog`0009oo`0301moog`0009o
o`807`03O01oogoo009oo`807`=oo`03O01oogoo00807`06O01oogooOoml07oo0P0O00Ql07ooOomo
og`0Ooml000O17`000=oog`0O0000Woo00=l07ooOol00Woo00=l07ooOol00Woo0W`01Woo00=l07oo
Ool08goo200OCWoo001>Ool301l02Goo01moo`0OOol07g`0Ool07`02Ool01g`001moogooO01oo`0O
009oo`03O01oo`0O009oo`06O01oogooOol07g`017oo00=l000O01l00Woo00Al07ooOomoo`807`9o
o`04O01oogooOol201l4O0000gooO0007`02O003Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0
Oomoo`04Ool00g`0Oomoo`0SOol501l2Ool00`0OOomoo`1;Ool004ioo`807`09Ool07gooOol07goo
01ml000O00=oo`0301moogoo009oo`0601moogooOoml000O0goo00Al07ooOol07`9oo`03O01oogoo
00807`06O01oogooOoml07oo0P0O00=oog`0Ool00Woo0`0O00=oog`0O0000g`000D07g`0O01oog`0
00Aoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Aoo`9l02Aoo`H07`03Ool07goo04]o
o`00CGoo100O0Woo00H07g`001moo`0OO002Ool00`0OO01oo`02Ool0100OO01oogoo0P0O00=l07oo
Ool00Woo0P0O0goo00=l000O01l00Woo00Al07ooOomoo`807`=oo`05O01oo`0O01ml0003Ool01G`0
01ml07`0Ool01W`017oo00=l07ooOol00Woo00=l07ooOol00goo0W`01Woo00=l07ooOol08Woo1`0O
C7oo001=Ool201l01Woo01moo`0OOol07`9oo`0401ml07oo01l2Ool01g`001l07gooO01oo`0O009o
o`06O01oogooOol07g`017oo00<07gooOol00Woo00Il07oo01l07gooO003Ool01G`001moogooO000
0Woo0P0O00=oog`0O00017`000Aoog`0Ooml00Aoo`03O01oogoo009oo`9l00Eoo`03O01oogoo00Ao
o`03O01oogoo029oo`L07d]oo`00C7oo100O00Yoo`0OOol07gooO0007gooO0007`=oo`03O01oogoo
009oo`0601moogooOoml07oo0P0O0Woo00Il07ooOol07gooO004Ool01P0OOomoogooO01oo`807`05
O01oogooOoml000201l00gooO01oo`06O0001GooO01l07ooO00017oo00=l07ooOol00goo00=l07oo
Ool00goo00=l07ooOol017oo0W`08goo1@0O00=oo`0OOol0BGoo001<Ool201l027oo01moo`0OOol0
7goo01l2Ool01P0OO01oogoo01ml00=oo`0301ml07oo009oo`807`Aoo`03O0007`0O009oo`03O01o
ogoo00807`04O01oogooOol201l3Ool01G`0Ool07`0OO0000goo00=l07ooO0000W`000=oog`0Ool0
0W`00Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol01Goo00=l07oo
Ool087oo1`0OBWoo001;Ool401l03Goo01moo`0OOol07g`0Ool07gooO01oo`0O009oo`05O01oo`0O
Ooml0002Ool00`0OOoml0004Ool00`0OO01oo`03Ool01G`001moogooO0000Woo00<07gooO0000goo
00El000OOomoog`000=oo`03O01oog`000Il0004Ooml07ooOol2O003Ool00g`0Oomoo`03Ool00g`0
Oomoo`03Ool2O006Ool00g`0Oomoo`0POol701m9Ool004]oo`<07`09Ool07gooOol07goo01ml000O
00=oo`06O01oogooOoml000O0goo00=l000OOol00Woo00Il07ooOol07gooO003Ool201l4Ool01G`0
01moogooO0000goo00D07g`0Oomoog`000=oo`03O01oogoo00Il009oo`05O01oogooOoml0003Ool0
0g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`0POol401l00goo01moo`18
Ool004Yoo`D07`9oo`0601moo`0OOol07g`00Woo00<07g`0Ool00Woo00<07g`0Ool00Woo00<07goo
Ool00goo0P0O0goo00=l000O01l00Woo00=l07ooOol00P0O17oo00El000O01moog`000=oo`04O01o
ogooO002Ool4O0000gooO01oo`02Ool01G`0OomoogooO0000goo00=l07ooOol00goo0W`01Goo00=l
07ooOol017oo0W`08Goo1@0OBGoo001:Ool301l01Woo01moo`0OOol07`9oo`0401ml07oo01l2Ool0
0g`0Ool07`02Ool01G`0Ool07gooO0000goo00<07g`0Ool00goo00<07g`0Ool00Woo00=l07oo01l0
0Woo00El07ooOomoo`0O00=oo`05O01oogooOoml0003Ool00g`0Oomoo`06O002Ool00g`0Oomoo`02
Ool01G`0OomoogooO0001Woo00=l07ooOol00goo00=l07ooOol01Goo00=l07ooOol07Woo1P0OB7oo
001:Ool401l2Ool201l2Ool0100OOoml000O0goo00=l000OOol00Woo00=l000OOol00Woo00=l07oo
01l00Woo00Il07ooOol07gooO004Ool01@0OOomoogooO0000Woo00<07gooO0000goo00El07ooOomo
og`0009oo`03O01oogoo00El0005Ooml07ooOoml0003Ool00g`0Oomoo`02Ool00g`0Oomoo`04Ool0
0g`0Oomoo`03Ool00g`0Oomoo`05Ool00g`0Oomoo`0NOol201l00goo01l07`18Ool004Uoo`<07`08
Ool07goo01moo`0OOol07`=oo`0501moogooOol07`04Ool00`0OO01oo`02Ool201l4Ool201l3Ool0
1G`0Ool07`0OO00017oo0P0O0Woo00El07ooOomoog`000=oo`04O01oogooO002Ool6O0001GooO01o
ogooO0000goo00=l07ooOol00Woo00=l07ooOol017oo00=l07ooOol00goo0W`01Woo00=l07ooOol0
7Goo1@0OB7oo0019Ool401l2Ool201l2Ool01@0OOomoo`0OO0000Woo00@07gooO01oo`807`07Ooml
07ooOol07gooO0000goo00<07g`0Ool017oo00D07gooOomoog`0009oo`0301ml07oo00=oo`04O01o
ogooO003Ool017`0Oomoog`00Woo1W`000=oog`0Ool00Woo00El07ooOomoog`000Aoo`03O01oogoo
00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo01eoo`D07dMoo`00BGoo0P0O00Qoo`0O
Ool07goo01moo`0O0Woo00D07gooOoml000O009oo`03O0007goo00=oo`03O0007goo009oo`03O01o
o`0O009oo`06O01oogooOol07g`00goo00=l000O01l00Woo00El07ooOomoog`0009oo`05O01oogoo
Ooml0002Ool00g`0Oomoo`05O00017ooO01oog`00Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l
07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol077oo0`0O00=oo`0OOol0AWoo
0018Ool401l017oo01moo`0O0Woo00<07goo01l00goo00Il000OOomoo`0OO004Ool00`0OOomoo`02
Ool201l4Ool00g`001l07`02Ool01G`0Ool07`0OO0000goo00=l07ooOol00Woo00Al07ooOoml00=o
o`05O01oogooO01oo`05O00017ooO01oog`00goo00El07ooOomoog`000Eoo`03O01oogoo00Aoo`03
O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo01aoo`@07dMoo`00B7oo100O00=oo`0O01l00Woo
00@07gooOol07`=oo`0601ml07oo01moog`00goo00<07gooO0000Woo00<07gooO00017oo00<07goo
Ool00Woo00=l000OOol00Woo00El07ooOomoog`000=oo`04O01oogooO003Ool01g`0Oomoog`0Ooml
07oo00=l009oo`03O01oog`000=oo`05O01oogooOoml0005Ool00g`0Oomoo`04Ool00g`0Oomoo`04
Ool00g`0Oomoo`04Ool00g`0Oomoo`0KOol501m6Ool004Qoo`<07`06Ool07goo01moo`0O0Woo00T0
7gooOomoo`0OOoml07oo01l00Woo00=l07oo01l00Woo00=l07oo01l00Woo00Ml07ooOomoo`0OOoml
0003Ool00`0OO01oo`02Ool01G`0OomoogooO00017oo00Al07ooOoml009oo`07O01oogooO01oog`0
Ool017`000Aoog`0Ooml00Aoo`05O01oogooOoml0005Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool0
0g`0Oomoo`04Ool00g`0Oomoo`0JOol501m6Ool004Moo`@07`03Ool07`0O009oo`0301moo`0O00=o
o`0501moogooOoml0003Ool00g`001moo`03Ool00`0OOomoo`02Ool00g`001l07`02Ool01W`0Ool0
7`0OOoml00Aoo`05O01oogooOoml0003Ool017`0Oomoog`00Woo00Ml07ooOoml07ooO01oo`04O002
Ool00g`0Ooml0004Ool01G`0OomoogooO0001Goo00=l07ooOol017oo00=l07ooOol017oo00=l07oo
Ool017oo00=l07ooOol06Woo100OAWoo0017Ool501l01Woo01moo`0OOol07`=oo`0601moogooOol0
7g`00goo00<07g`0Ool00Woo00<07g`0Ool00goo00<07gooOol00goo00<07gooOol00Woo00El07oo
Oomoog`000=oo`05O01oogooOoml0003Ool00g`0Ooml0002Ool017`0Ooml07oo17`00Woo00Al07oo
Ooml00=oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01o
ogoo00Aoo`03O01oogoo01Uoo`@07dIoo`00Agoo0`0O00=oo`0O01l00Woo00<07goo01l00Woo00D0
7gooOomoo`0O009oo`03O01oo`0O009oo`03O01oo`0O009oo`06O01oogoo01moog`00goo00<07goo
O0000goo00=l07ooOol00Woo00El07ooOomoog`000=oo`04O01oogooO002Ool01G`0Oomoog`0Ool0
17`000Moog`0Oomoog`0Ooml0004Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool0
0g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`0HOol501m5Ool004Ioo`D07`06Ool07goo01mo
o`0O0Woo00D07gooOomoo`0O00=oo`03O0007goo009oo`03O0007goo00=oo`06O0007gooOoml07oo
0P0O0Woo00=l07ooOol00Woo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool00g`0Ooml0002
Ool017`0Ooml07oo0W`000Eoog`0Oomoog`0009oo`03O01oogoo009oo`03O01oogoo009oo`03O01o
ogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo01Qoo`@07dEo
o`00AWoo1P0O0Woo00D07goo01moo`0O00=oo`0301moogoo009oo`0301ml07oo009oo`0301ml07oo
00=oo`0301moogoo009oo`03O01oogoo00=oo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo
00Il07ooOoml07ooO002Ool017`0Ooml07oo0W`00Woo00Al07ooOoml009oo`03O01oogoo009oo`03
O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03
O01oogoo01Moo`@07dEoo`00AWoo100O00Ioo`0OOol07goo01l2Ool0100OOomoo`0O17oo00<07goo
O0000goo00<07gooO0000Woo00<07gooO0000Woo00<07gooO0001Goo00El07ooOomoog`000=oo`03
O01oogoo009oo`04O01oogooO002Ool00g`0Ooml0002Ool017`0Ooml07oo0g`000Eoog`0Oomoog`0
00=oo`05O01oogooOoml0005Ool00g`0Oomoo`02Ool00g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0
Oomoo`05Ool00g`0Oomoo`0FOol501m4Ool004Eoo`H07`9oo`0501moo`0OOol07`02Ool00`0OOomo
o`03Ool01P0OOomoog`0Ool07`9oo`03O01oo`0O00=oo`05O0007gooOoml0005Ool01G`0Oomoogoo
O00017oo00El07ooOomoog`000=oo`03O01oog`0009oo`06O01oog`0Ooml07oo0g`00Woo00Al07oo
Ooml009oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Eoo`03O01o
ogoo00=oo`03O01oogoo00Eoo`03O01oogoo01Ioo`@07dAoo`00AGoo1P0O00Aoo`0OOol07`9oo`04
01moogoo01l4Ool01P0OOomoogooO0007`Aoo`0301moogoo00=oo`0501moogooOoml0005Ool01G`0
OomoogooO00017oo00El07ooOomoog`0009oo`06O01oogooO01oog`00Woo00=l07ooO00017`000Eo
og`0Oomoog`000=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Eo
o`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo01Ioo`@07dAoo`00AGoo100O00Qoo`0OOol0
7goo01moo`0O0Woo00<07gooOol00Woo00<07gooOol00Woo00<07g`0Ool00Woo00<07g`0Ool00goo
00<07g`0Ool00goo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`000=oo`07O01oogoo
Ooml07ooO0000Woo00Al07ooO01oo`El009oo`04O01oogooO003Ool01G`0OomoogooO0001Goo00=l
07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol05Goo100O
A7oo0015Ool501l2Ool201l2Ool0100OOomoo`0O0goo00<07gooOol00Woo00H07gooOoml07oo01l2
Ool017`0Oomoo`0O0Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomo
og`000=oo`06O01oogooO01oog`00Woo00Al07ooO01oo`El009oo`05O01oogooOoml0002Ool00g`0
Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0
Oomoo`04Ool00g`0Oomoo`0COol00`0OOol07`0201m4Ool004Eoo`D07`06Ool07goo01moo`0O0Woo
00<07gooOol00Woo00D07gooOomoo`0O00Aoo`0301moogoo009oo`03O0007goo00=oo`05O01oogoo
Ooml0004Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00Al07ooOoml009oo`06O01oog`0Ooml
07oo0g`000=oog`0O0000Woo00Al07ooOoml00=oo`03O01oogoo009oo`03O01oogoo009oo`03O01o
ogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo019oo`0301mo
o`0O00<07d=oo`00AGoo100O0Woo0P0O0Woo00@07gooOol07`=oo`0501moogooOol07`04Ool00`0O
Ooml0003Ool00`0OOomoo`04Ool01G`0OomoogooO00017oo00=l07ooOol00Woo00El07ooOomoog`0
009oo`07O01oogooOoml07ooO0000Woo00=l07ooO0000g`000=oog`0O0000Woo00El07ooOomoog`0
00=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Eoo`03O01oogoo
00=oo`03O01oogoo00Eoo`03O01oogoo015oo`0301moo`0O00<07d=oo`00AGoo100O00Aoo`0OOol0
7`9oo`0301moo`0O00=oo`0501moogooOol07`04Ool02@0OOomoogooO01oo`0OOoml0005Ool00g`0
Oomoo`02Ool01G`0OomoogooO0001Goo00Al07ooOoml00=oo`04O01oogooO002Ool017`0Ooml07oo
17`000=oog`0O0000goo00Al07ooOoml00Aoo`05O01oogooOoml0005Ool00g`0Oomoo`03Ool00g`0
Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`0AOol00`0OOol07`0301m3Ool0
04Eoo`@07`03Ool07`0O009oo`0401moogoo01l2Ool00`0OOomoo`02Ool01@0OOomoogoo01l017oo
00=l000OOol00Woo00=l07ooOol00goo00=l07ooOol00Woo00El07ooOomoog`000Aoo`05O01oogoo
Ooml0002Ool02W`0OomoogooO01oog`0Ooml07oo1W`000Eoog`0Oomoog`000=oo`05O01oogooOoml
0004Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomo
o`04Ool00g`0Oomoo`0?Ool00`0OOomoo`0401m3Ool004Eoo`@07`03Ool07`0O009oo`0301moo`0O
00=oo`0501moogooOol07`03Ool00`0OOomoo`03Ool00`0OO01oo`03Ool00g`0Oomoo`03Ool01G`0
OomoogooO00017oo00=l07ooOol00Woo00Al07ooOoml00=oo`09O01oogooO01oog`0Ooml07oo00El
0003Ooml07`000=oo`04O01oogooO004Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`04
Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`0>Ool00`0OOomoo`04
01m3Ool004Eoo`<07`08Ool07goo01moo`0OOol07`=oo`0501moogooOol07`04Ool00`0OOomoo`02
Ool0100OOomoog`017oo00=l07ooOol00goo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool0
1G`0OomoogooO0000Woo00Al07ooO01oo`Il0004Ooml07ooO002Ool01G`0OomoogooO00017oo00El
07ooOomoog`000Eoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=o
o`03O01oogoo00eoo`0401moogooOol401m3Ool004Aoo`@07`03Ool07`0O009oo`0301moo`0O009o
o`0501moogooOol07`04Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00g`0Oomoo`02Ool00g`0Oomo
o`02Ool00g`0Oomoo`02Ool01G`0OomoogooO00017oo00El07ooOomoog`0009oo`09O01oogooO01o
og`0Ooml07oo00Al0004Ooml07ooO002Ool00g`0Oomoo`02Ool01G`0OomoogooO00017oo00=l07oo
Ool00goo00=l07ooOol00goo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol00goo00=l07oo
Ool037oo00<07gooOol01@0O@goo0014Ool501l01Woo01moo`0OOol07`=oo`0501moogooOol07`03
Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02
Ool01G`0OomoogooO00017oo00Al07ooOoml00=oo`07O01oogooO01oog`0Ool01G`000Aoog`0Ooml
00=oo`05O01oogooOoml0004Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0
Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`0;Ool00`0OOomoo`0501m3Ool0
04Aoo`H07`9oo`0301moo`0O009oo`0501moogooOol07`03Ool00`0OOomoo`03Ool00`0OOomoo`04
Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool01G`0OomoogooO00017oo00El07ooOomoog`000=oo`04
O01oogooO002Ool017`0Ooml07oo17`000Ioog`0Ooml07ooO002Ool00g`0Oomoo`02Ool01G`0Oomo
ogooO00017oo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol01Goo00=l07ooOol00goo00=l
07ooOol017oo00=l07ooOol02Goo00H07gooOomoo`0OOol301m3Ool004Aoo`H07`05Ool07gooOol0
7`02Ool0100OOomoo`0O17oo00<07gooOol00Woo00<07gooOol01Woo00=l07ooOol00Woo00=l07oo
Ool00goo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool02G`0Oomoog`0Ooml07ooO01oo`06
O00017ooO01oog`00goo00El07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo00=oo`03O01o
ogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Uoo`0401mo
ogoo01l2Ool301m3Ool004Aoo`H07`04Ool07goo01l3Ool0100OOomoo`0O0goo00<07gooOol00Woo
00<07gooOol027oo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`0
00Aoo`07O01oogooOoml07ooO0000Woo00=l07ooO0001W`000Eoog`0Oomoog`0009oo`03O01oogoo
009oo`05O01oogooOoml0005Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`05Ool00g`0
Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`07Ool01@0OOomoogoo01l00Woo0`0O@goo0014Ool4
01l01Woo01moo`0OOol07`9oo`0401moogoo01l3Ool00`0OOomoo`02Ool00`0OOomoo`09Ool00g`0
Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO00017oo00Al07ooOoml009o
o`06O01oog`0Ooml07oo1G`000Eoog`0Oomoog`000=oo`05O01oogooOoml0004Ool00g`0Oomoo`02
Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomoo`03
Ool00g`0Oomoo`06Ool01P0OOomoogoo01moo`@07d=oo`00A7oo1@0O00Eoo`0OOomoo`0O009oo`04
01moogoo01l2Ool00`0OOomoo`03Ool00`0OOomoo`0:Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool0
0g`0Oomoo`02Ool01G`0OomoogooO0000goo00Ml07ooOomoog`0Ooml0002Ool00g`0Ooml0004O000
17ooO01oog`00Woo00Al07ooOoml00Aoo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00Ao
o`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Eo
o`0501moogooOol07`02Ool401m3Ool004Aoo`D07`07Ool07gooOol07goo01l00Woo00D07gooOomo
o`0O00Aoo`0301moogoo00aoo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`05O01o
ogooOoml0003Ool017`0Oomoog`00Woo00Al07ooO01oo`El0004Ooml07ooO002Ool01G`0Oomoogoo
O0000goo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol017oo00=l07oo
Ool017oo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00D07gooOomoo`0O009oo`@0
7d=oo`00A7oo1P0O0Woo00@07gooOol07`9oo`0401moogoo01l4Ool00`0OOomoo`0>Ool00g`0Oomo
o`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool017`0Oomoog`00goo00Yl07ooOomoog`0Ooml07oo
O01oo`El0004Ooml07ooO002Ool01G`0OomoogooO00017oo00=l07ooOol00Woo00=l07ooOol00goo
00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol00goo
00=l07ooOol00goo00D07gooOomoo`0O00=oo`@07d=oo`00A7oo1P0O0Woo00<07goo01l00Woo00@0
7gooOol07`Aoo`0301moogoo011oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`04
O01oogooO003Ool017`0Oomoog`00Woo00Al07ooO01oo`=l0003Ooml07`0009oo`04O01oogooO003
Ool01G`0OomoogooO00017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07oo
Ool017oo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00D07gooOomoo`0O009oo`D0
7d=oo`00A7oo1P0O00Eoo`0OOomoo`0O009oo`0401moogoo01l4Ool00`0OOomoo`0AOol00g`0Oomo
o`02Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool017`0Oomoog`00goo00Ul07ooOoml07ooO01oog`0
Ool01G`000Aoog`0Ooml009oo`05O01oogooOoml0003Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool0
0g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool0
1G`0Oomoogoo01l017oo00<07gooOol01@0O@goo0014Ool401l01Woo01moo`0OOol07`9oo`0401mo
ogoo01l4Ool00`0OOomoo`0COol00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool017`0
Oomoog`00Woo00Al07ooOoml009oo`04O01oog`0Ool4O00017ooO01oog`00Woo00El07ooOomoog`0
00Aoo`03O01oogoo009oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo
00Aoo`03O01oogoo00=oo`03O01oogoo00=oo`04O01oogoo01l3Ool0100OOomoogoo1@0O@goo0014
Ool401l01Woo01moo`0OOol07`9oo`0401moogoo01l3Ool00`0OOomoo`0EOol00g`0Oomoo`02Ool0
0g`0Oomoo`03Ool00g`0Oomoo`02Ool017`0Oomoog`00Woo00Al07ooOoml009oo`9l0003Ooml07`0
009l0005Ooml07ooOoml0002Ool01G`0OomoogooO0000goo00=l07ooOol00goo00=l07ooOol00goo
00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo
00=l000OOol00goo00D07gooOol07goo00@07d=oo`00A7oo100O00Qoo`0OOol07goo01moo`0O0goo
00D07gooOomoo`0O01Qoo`03O01oogoo009oo`03O01oogoo00=oo`05O01oogooOoml0003Ool017`0
Oomoog`00Woo00Al07ooO01oo`Al0003Ooml07`0009oo`04O01oogooO003Ool00g`0Oomoo`02Ool0
0g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool0
0g`0Oomoo`04Ool00g`0Oomoo`02Ool00g`001moo`03Ool01@0OOomoo`0OOol0100O@goo0015Ool3
01l00goo01l07`02Ool00`0OOol07`02Ool01@0OOomoogoo01l06Woo00=l07ooOol00Woo0W`017oo
00El07ooOomoog`000=oo`06O01oogooO01oog`00Woo0W`000Moog`0O01oog`0Ooml0002Ool017`0
Oomoog`00goo00El07ooOomoog`000Eoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Ao
o`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo009oo`0301ml07oo009oo`0601moogooOol0
7goo100O@goo0015Ool301l01Goo01l07goo01l00Woo00@07gooOol07`=oo`0301moogoo01Uoo`03
O01oogoo00=oo`05O01oogooOoml0004Ool01g`0OomoogooO01oog`0009oo`04O01oog`0Ool3O000
17ooO01oog`00Woo00Al07ooOoml00=oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=o
o`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`06O01oogooOol0
7g`00goo00D07gooOol07goo00@07dAoo`00AGoo0`0O00Eoo`0O01moo`0O009oo`0301moo`0O00=o
o`0301moogoo01]oo`03O01oogoo00=oo`05O01oogooOoml0004Ool017`0Oomoog`00Woo00El07oo
Ooml07oo00Al0004Ooml07ooO002Ool017`0Oomoog`00goo00=l07ooOol00Woo00=l07ooOol00goo
00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo
00Al07ooOol07`9oo`03O01oo`0O00=oo`0301moo`0O00<07dAoo`00AGoo100O00Ioo`0OOol07goo
01l2Ool01@0OOomoogoo01l07Woo00=l07ooOol00goo00El07ooOomoog`000=oo`05O01oogooOoml
0002Ool00g`0Oomoo`05O00017ooO01oog`00Woo00El07ooOomoog`000=oo`03O01oogoo009oo`03
O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03
O01oogoo00Aoo`03O0007goo009oo`03O0007goo009oo`0301moogoo00@07dAoo`00AGoo1@0O0Woo
00<07goo01l00Woo00@07gooOol07b1oo`03O01oogoo00=oo`05O01oogooOoml0003Ool01G`0Oomo
ogooO0000Woo00Al07ooO01oo`El009oo`04O01oogooO002Ool01G`0OomoogooO00017oo00=l07oo
Ool00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00goo00=l07oo
Ool017oo00=l000OOol00goo00P07gooOomoo`0OOol07goo0`0OA7oo0015Ool501l2Ool01@0OOol0
7goo01l00goo00<07gooOol07goo00=l07ooOol00goo00Al07ooOomoo`9l009oo`07O01oogooOoml
07ooO0000Woo1G`000Aoog`0Ooml009oo`04O01oogooO004Ool00g`0Oomoo`02Ool00g`0Oomoo`03
Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03
Ool00`0OO01oo`02Ool01@0OO01oogoo01l00Woo1@0OA7oo0016Ool401l01goo01moogoo01moo`0O
009oo`0301moogoo025oo`9l00Aoo`03O01oogoo009oo`04O01oogooO002Ool017`0Oomoog`00Woo
17`000Aoog`0Ooml009oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0
Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool01g`0Oomoogoo01moog`0
009oo`0901moogooO01oo`0OOol07goo00@07dAoo`00AWoo100O00Aoo`0OOol07`9oo`0401moogoo
01lUOol00g`0Oomoo`02Ool00g`0Oomoo`02Ool017`0Oomoog`00Woo00Al07ooOoml009oo`El0005
Ooml07ooOoml0003Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`04
Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool02G`0Oomoogoo01moog`0Ool07`03
Ool01W`001moogoo01moo`<07dEoo`00AWoo100O00Aoo`0OOol07`9oo`0301moo`0O02Moo`03O01o
ogoo009oo`03O01oogoo009oo`04O01oogooO002Ool01G`0Oomoog`0Ool01G`00Woo00Al07ooOoml
00=oo`05O01oogooOoml0004Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0
Oomoo`03Ool00g`0Oomoo`04Ool00g`0Ool07`03Ool00g`001moo`02Ool01@0OOomoo`0OOol0100O
AGoo0016Ool401l01Woo01moo`0OOol07`9oo`0301moogoo02Ioo`9l00=oo`03O01oogoo009oo`04
O01oogooO002Ool017`0Ooml07oo1G`00Woo00Al07ooOoml00=oo`05O01oogooOoml0005Ool00g`0
Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0
01moo`03Ool00`0OOomoo`02Ool01@0OOomoo`0OOol0100OAGoo0016Ool501l2Ool00`0OOol07`02
Ool00`0OOomoo`0XOol01G`0OomoogooO00017oo00Al07ooOoml009oo`Ql009oo`04O01oogooO003
Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04
Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool00`0OO01oo`02Ool00`0OOoml0002Ool0100OOoml000O
0Woo100OAGoo0017Ool401l2Ool01@0OOol07goo01l0;7oo00El07ooOomoog`000Aoo`03O01oogoo
009l009oo`Il009oo`04O01oogooO004Ool01G`0OomoogooO0001Goo00=l07ooOol00goo00=l07oo
Ool017oo00=l07ooOol00goo00=l07ooOol017oo00Ml07ooOomoo`0OOoml0003Ool01@0OOoml07oo
01l00Woo00=l000OOol01@0OAGoo0017Ool401l01goo01moogoo01moo`0O02eoo`05O01oogooOoml
0004Ool2O002Ool00g`0Oomoo`05O002Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00=l07oo
Ool00Woo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07oo
01l00goo00=l07oo01l00Woo00=l07oo01l00Woo00=l07ooOol0100OAWoo0017Ool401l017oo01mo
o`0O0Woo00<07gooOol0;7oo00El07ooOomoog`000Eoo`05O01oogooO01oo`06O0000gooO01oo`02
Ool00g`0Oomoo`02Ool01G`0OomoogooO0001Goo00=l07ooOol00goo00=l07ooOol017oo00=l07oo
Ool00goo00=l07ooOol017oo00=l000OOol00goo00=l000OOol00goo00H07gooOomoo`0OOol501m6
Ool004Moo`@07`04Ool07goo01l2Ool00`0OOomoo`0]Ool017`0Oomoogoo0W`017oo00Al07ooO01o
o`Il009oo`04O01oogooO004Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0
Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00`0OO01oo`03Ool00`0OO01oo`03Ool01P0O
Oomoo`0OO01oo`D07dIoo`00Agoo1P0O00Aoo`0OOol07c5oo`03O01oogoo009oo`05O01oogooOoml
0002Ool2O0000gooO01l0003O0001GooO01oogooO0001Goo00El07ooOomoog`000Aoo`03O01oogoo
00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo009oo`0301moog`000Aoo`0301ml07oo
009oo`0401moog`001l2Ool00g`001l07`0201m7Ool004Qoo`D07`04Ool07goo01lbOol2O003Ool0
1G`0OomoogooO0000Woo00=l07ooO00017`000=oog`0Ool00Woo00=l07ooOol00Woo00El07ooOomo
og`000Eoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`04O01oogoo01l3Ool01W`0
Oomoo`0OOoml009oo`0501moogooO0007`02Ool501m7Ool004Qoo`D07`04Ool07goo01ldOol017`0
Oomoogoo0W`00Woo00=l07ooO00027`00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol0
0Woo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00Al07ooOol07`=oo`03O01oo`0O
00=oo`03O0007goo009oo`0501moogoo01ml000301m8Ool004Qoo`D07`04Ool07goo01leOol00g`0
Oomoo`02Ool00g`0Oomoo`02O0000gooO01l0005O003Ool00g`0Oomoo`03Ool01G`0OomoogooO000
1Goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l000OOol017oo00<07gooOol0
0Woo00X07gooOomoo`0OO01oo`0OOoml00<07dQoo`00BGoo100O00=oo`0O01l0=goo0W`00goo0W`0
00Eoog`0O01l07oo00Il00=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo009oo`03O01o
ogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`0301moogoo00=oo`0301ml07oo009oo`0501mo
og`0Ool07`02Ool00g`001moo`0301m9Ool004Uoo`@07`03Ool07`0O03Uoo`9l00=oo`9l0003Ooml
07`000Il00=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Aoo`03
O01oogoo00=oo`03O01oogoo009oo`0301moog`000=oo`0301moog`0009oo`0601moogooO01oo`0O
0Woo00=l07oo01l00`0OBGoo0019Ool401l00goo01l07`0kOol2O002Ool5O0000gooO01l0002O003
Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`04Ool00g`0Oomoo`04
Ool017`0Oomoo`0O0Woo00Al07ooOol07`=oo`03O0007goo009oo`07O0007gooOol07g`0Ool0100O
BGoo001:Ool301l00goo01l07`0mOol3O0000gooO01l0007O002Ool00g`0Oomoo`03Ool00g`0Oomo
o`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`001l07`04Ool00g`001mo
o`03Ool00`0OOomoo`02Ool0200OOomoo`0OOoml000OO00201m:Ool004Yoo`<07`03Ool07`0O03mo
o`03O01oog`0009l0004Ooml07`0Ool3O002Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomo
o`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00`0OO01oo`04Ool00`0OOomoo`02Ool00`0OOoml
0003Ool00`0OO0007`02Ool00g`001l07`0201m:Ool004]oo`D07cmoo`Ul0003Ooml07`0009oo`03
O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`03
01moog`000Aoo`0301ml07oo00=oo`0301moog`0009oo`0401moog`001l2Ool401m;Ool004]oo`D0
7cmoo`03O01oog`0009l0003Ooml07`000El0003Ooml07oo00Aoo`03O01oogoo009oo`03O01oogoo
00=oo`03O01oogoo00=oo`05O01oogooOol07`02Ool00g`0Oomoo`0201l2Ool017`0Oomoo`0O0Woo
00=l07oo01l00Woo00D07gooOol07g`000<07d]oo`00C7oo100O?goo00=l07ooO0002g`000=oog`0
Ool00goo00=l07ooOol00Woo00=l07ooOol017oo00=l07ooOol00goo00=l07oo01l017oo00=l000O
Ool00goo00=l07oo01l00goo00Ml000OOomoo`0OO01oo`0201l00g`001l07`1<Ool004aoo`@07cmo
o`05O01oogooO01oo`04O0000gooO01l0004O004Ool00g`0Oomoo`02Ool00g`0Oomoo`04Ool00g`0
Oomoo`03Ool201l5Ool00g`0Oomoo`04Ool00`0OOomoo`02Ool0100OO01oo`0O0Woo00=l000O01l0
0`0OC7oo001<Ool501lnOol02G`0Oomoog`0Ooml07ooO01oo`07O004Ool00g`0Oomoo`03Ool00g`0
Oomoo`03Ool00g`0Oomoo`02Ool00`0OOoml0004Ool00`0OO01oo`04Ool00`0OO01oo`02Ool01@0O
Ooml07oo01l00Woo00El000O01ml000O04eoo`00CGoo100O?Woo00]l07ooOoml07ooO01oog`0Ooml
07oo00Il00Aoo`03O01oogoo009oo`03O01oogoo00Aoo`04O01oogoo01l2Ool01G`0Oomoogoo01l0
0Woo00=l07ooOol00P0O00Eoog`0Oomoo`0O009oo`06O0007gooOol07g`00P0O00=l000OOol0C7oo
001=Ool401lnOol01g`0Oomoog`0Ooml07oo009l0004Ooml07`0Ool6O002Ool00g`0Oomoo`03Ool0
0g`0Oomoo`03Ool00g`001l07`04Ool00g`001l07`03Ool00g`0Ool07`04Ool00g`001moo`02Ool0
1P0OOomoo`0OOoml00<07dioo`00CWoo0`0O?Woo00Al07ooOoml009oo`=l0003Ooml07`0009l0003
Ooml07`000=l0003Ooml07oo00Aoo`03O01oogoo009oo`807`03O01oogoo00=oo`0301moogoo00Ao
o`0301moogoo00=oo`0301moogoo009oo`0401ml000OOol301l00g`0Oomoo`1=Ool004ioo`@07ceo
o`04O01oogooO002Ool3O0002GooO01l07`0Ooml07ooO01oo`03O0000gooO01oo`04Ool017`0Ool0
7`0O0Woo00=l07ooOol00Woo00<07gooO0000goo0P0O00=l07ooOol00Woo00<07gooO0000Woo00D0
7gooO0007goo00@07dmoo`00Cgoo100O?7oo00Al07ooOoml009oo`=l009oo`=l0005Ooml07ooO01o
o`04O005Ool00g`001moo`03Ool00g`0Oomoo`0201l2Ool017`0Oomoo`0O0goo00Al07ooOol07`9o
o`03O0007`0O009oo`0601moo`0O01ml000OD7oo001@Ool401lkOol017`0Oomoog`00Woo0W`000=o
og`0Ool00g`000=oog`0Ool00g`000=oog`0O0000W`00Woo0P0O00=l07ooOol00goo0P0O1Goo00=l
000OOol00goo00=l07oo01l00goo00H07gooOomoo`0OO00401mAOol0051oo`@07c]oo`03O01oogoo
009l0003Ooml07oo009l0006Ooml07`0Ooml07oo0g`000=oog`0Ool00g`00P0O00=l07ooO0000goo
0P0O00=l07ooOol00goo00<07g`0Ool017oo0P0O0Woo0P0O00Il07ooOol07gooO00301mBOol0055o
o`@07cYoo`03O01oogoo009l0003Ooml07oo009l009oo`03O01oog`0009oo`Al009oo`03O0007g`0
00Il000501moogooOoml0002Ool201l00gooO01oo`03Ool01@0OOoml07oo01l00Woo00Il07oo01mo
o`0OO00301mBOol0055oo`D07cUoo`03O01oogoo009l0003Ooml07oo009l009oo`9l0004Ooml07oo
Ool2O0000gooO0007`02O0000gooO01l0002O00201l5O0000goo01moo`02Ool00g`0Oomoo`0201l2
Ool00g`001moo`02Ool00g`001ml000201l00g`001l07`1COol0059oo`D07cQoo`03O01oogoo009l
0006Ooml07ooO01oog`00Woo00=l07ooO0000Woo00Il07oo01l07g`0Ool2O00017ooO0007`0O1W`0
0P0O1W`000H07gooOomoog`001l4O0000`0OO0007`0401mDOol005=oo`D07cMoo`03O01oogoo009l
0006Ooml07ooO01oog`00Woo00El07ooOoml07oo00807`03Ooml07oo009l0004Ool07`0OOol6O000
0`0OO01l0002O002Ool201l4O0000`0OOoml0002Ool00`0OOoml000401l00g`0Oomoo`1BOol005Ao
o`@07cMoo`05O01oogooOoml0002Ool2O0001GooO01oogooO0000Woo0P0O0W`00Woo00Il07ooO000
7gooO002Ool2O00017oo01l07goo0g`000=oo`0O01l01G`000@07g`0O01l00807`9l00D07eEoo`00
EGoo100O=Woo00El07ooOomoog`0009oo`9l0003Ooml07oo009oo`807`03Ooml07oo009l009oo`80
7`9l0004Ooml07ooO00201l00gooO01l0002Ool00g`001ml0003O002Ool01@0OOomoogoo01l00goo
00<07g`001l00P0OEWoo001FOol401leOol01G`0OomoogooO0000Woo00El07ooO01l07oo00807`05
O01oogooO01oo`02O00201l01WooO01l07ooO01oo`807`08O01oog`0O01oog`001ml00Aoo`03O000
7`0O009l00807`9l00<07`03O0007`0O05Moo`00Egoo100O=7oo00El07ooOomoog`0009oo`03O01o
og`000807`9oo`04O01oogooOol2O000100OO01oogoo0W`00Woo00@07gooOoml00=oo`807`03Ooml
07`0009l00807`04O01oogoo01l2Ool00g`001moo`0401mHOol005Qoo`D07c9oo`05O01oogooOoml
0002Ool201l00g`0Ooml0002Ool00g`0Oomoo`0201l017`0Oomoog`00Woo00Al000O01ml00=oo`9l
000301moog`0009l0003Ool07`0O00=l00807`9oo`L07eUoo`00FGoo0`0O00=oo`0OOol0<7oo00El
07ooOomoog`000807`05Ooml07`0Ooml0002Ool017`001l07goo0W`00Woo00El07oo01l07g`0009o
o`03O01oogoo00807`06O01oogooOoml000O17oo00D07g`0O01l000O009l00@07eYoo`00FWoo0`0O
00=oo`0OOol0;goo00=l07ooOol00P0O0goo0W`00Woo00Al000O01ml00=oo`9l0003Ool07`0O009o
o`04O01oogooOol201l01G`0Oomoog`0Ool00P0O0g`00P0O00Eoog`0Ool07goo00D07e]oo`00Fgoo
0`0O00=oo`0OOol0;Woo00Al000O01moo`9l009oo`03O01oo`0O00807`9oo`9l009oo`9l000301mo
og`0009oo`9l00807`9oo`9l009oo`0701moogooO01oo`0OOol00g`000D07goo01l07g`000807eao
o`00G7oo1P0O:Goo100O00Al07ooOomoo`9l00@07`03O01oog`0009oo`9l0004Ool07`0OO003Ool0
1G`0Ool07`0OO00017oo00Al000O01moo`9l00807`=oo`H07`03O0007goo05aoo`00GGoo1P0O9Goo
0`0O17oo00=l07ooOol00P0O00Ql07ooOoml07ooO01oog`00Woo00=l000O01l00Woo00=l07ooOol0
0`0O00Aoog`0Ooml009oo`807`03O01oogoo00807`9l009oo`0301moog`000<07`03O0007goo05eo
o`00GWoo1P0O87oo100O1Woo100O00=oog`0O0000Woo00=l07ooO0000Woo0`0O00Eoog`0Oomoog`0
00807`9oo`03O01oog`0009oo`807`03Ooml07oo00807`=oo`9l000301moo`0O00D07emoo`00Ggoo
2@0O67oo100O1goo0`0O00=oog`0Ool00Woo0W`00goo100O00El07ooOoml07oo00<07`03O01oogoo
009oo`9l00807`07O01oogooOol07gooO0000goo0P0O00Al000O01ml00807f5oo`00HGoo7`0O1goo
100O17oo00=l07ooOol00Woo00Al000O01l07`9l009oo`03O01oo`0O00807`03O01oogoo009l009o
o`<07`=oo`04O0007`0OO002Ool017`001l07g`0100O00=l000OOol0HGoo001ROolB01l>Ool501l8
Ool00g`0Ool07`0301l3Ool2O00401l017ooO01oog`00Woo00Al07oo01l07`9oo`9l0003Ool07`0O
00=l00<07`03Ooml000O00@07fAoo`00I7oo1P0O00=oo`0O01l00`0O17oo3P0O2Goo1P0O0goo00=l
07ooOol00`0O0goo00=l07ooO0000Woo00El07oo01l07g`000=oo`0301ml000O00=oo`807`=oo`80
7`04O0007`0O01mUOol006Eoo`L07`9ooad07`Aoo`04O01oogooOol401l00gooO01l0003Ool017`0
Ooml07oo0`0O00Aoog`0Ooml00807`04Ooml07ooOol201l00gooO01l000701mVOol006Ioo`T07`=o
o`L07aEoo`D07`03Ooml07oo009oo`03O01oog`0009oo`@07`05Ooml07ooOoml000201l3Ool301l3
Ool201l00g`001l07`0201mXOol006Qoo``07`EooaD07`03Ooml07oo00=oo`03O01oogoo00H07`03
Ooml07`000=oo`<07`03Ooml07oo00807`04Ooml07`0O00301l00g`001l07`0201mYOol006Uooa80
7aAoo`03O0007`0O00D07`9oo`9l00=oo`03O0007`0O00807`04O01oogooO00201l3Ool301l017`0
01l07g`00`0OJWoo001[Ool=01l3OolE01l4Ool00g`0Oomoo`02Ool601l01GooO01oogooO0000`0O
00=oog`001l00P0O00=l000O01l01@0OK7oo001]Ool@01lBOol00g`0Oomoo`0201l00g`001l07`02
01l2O003Ool00g`0Ooml000301l00g`0Ool07`0;01m^Ool0071oo`/07`9ooa807`03O0007`0O009o
o`03O01oogoo009oo`9l00D07`03O01oo`0O00<07`03O0007`0O00H07g5oo`00LWoo100O00=oo`0O
01l01P0O47oo00=l07ooOol00Woo1`0O17oo00<07g`001l02@0O00=l07ooOol0LWoo001dOolK01l0
0g`001l07`0201l2O004Ool00g`001l07`0201l00g`001l07`0701mgOol007Mooa807`Iooa407`03
O0007`0O00<07`03O01oogoo07Moo`00Ngoo500O00=l000O01l00`0O00=l000O01l00P0O00=l000O
01l01P0OOGoo001oOolP01n1Ool008EooaD07hIoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {585.688, 356.313}} -> {-0.399192, \
1.55342, 0.00348777, 0.00348777}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Analytical Equations to Generate the Left-Handed Circularly Polarized \
Photon Electric and Magnetic Vector Field by Rotation of the Great-Circle \
Basis Elements about the (",
  Cell[BoxData[
      \(TraditionalForm\`i\_x\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(-i\_y\)\)]],
  ",0",
  Cell[BoxData[
      \(TraditionalForm\`i\_z\)]],
  ")-Axis by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]],
  "."
}], "Section",
  TextJustification->1],

Cell[TextData[{
  StyleBox["The left-handed circularly polarized (LHCP) photon electric and \
magnetic vector field (photon-e&mvf) is also generated following a similar \
procedure as that used to generate the orbitsphere in Appendix III: \
Analytical Equations to Generate the Orbitsphere Current Vector Field and the \
Uniform Current (Charge)-Density Function ",
    FontFamily->"New York"],
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_0\^0\)(\[Phi], \[Theta])\)]],
  StyleBox[".  The LHCP photon-e&mvf is generated by the rotation of the \
basis elements comprising the great circle magnetic field line in the \
xz-plane and the great circle electric field line in the yz-plane about the ",
    
    FontFamily->"New York"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`i\_x\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(-i\_y\)\)]],
  ",0",
  Cell[BoxData[
      \(TraditionalForm\`i\_z\)]],
  ")",
  StyleBox["-axis by ",
    FontFamily->"New York"],
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]],
  StyleBox[".  A first transformation matrix is generated by the combined \
rotation of the great circles about the z-axis by ",
    FontFamily->"New York"],
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/4\)]],
  StyleBox[" then about the x-axis by \[Theta] where positive rotations about \
an axis are defined as clockwise:",
    FontFamily->"New York"]
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[{\(Clear[\[Theta]]\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Equ6", ":=", 
        RowBox[{"(", GridBox[{
              {\(Cos[\[Pi]\/4]\), \(-Sin[\[Pi]\/4]\), "0"},
              {\(Sin[\[Pi]\/4] Cos[\[Theta]]\), \(Cos[\[Pi]\/4] 
                  Cos[\[Theta]]\), \(Sin[\[Theta]]\)},
              {\(\(-Sin[\[Pi]\/4]\) Sin[\[Theta]]\), \(\(-Cos[\[Pi]\/4]\) 
                  Sin[\[Theta]]\), \(Cos[\[Theta]]\)}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(ComponentFunct[
        Equ6, {R\ \ Cos[\[Phi]], 0, R\ \ Sin[\[Phi]]}, Blue];\)}], "Input",
  TextJustification->1],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.59119 .32505 m
.61015 .33551 L
s
.57163 .31575 m
.59119 .32505 L
s
.55158 .30765 m
.57163 .31575 L
s
.61015 .33551 m
.62841 .34706 L
s
.53114 .30081 m
.55158 .30765 L
s
.62841 .34706 m
.64587 .35966 L
s
.51043 .29526 m
.53114 .30081 L
s
.64587 .35966 m
.66243 .37323 L
s
.48954 .29104 m
.51043 .29526 L
s
.66243 .37323 m
.67799 .38772 L
s
.46861 .28819 m
.48954 .29104 L
s
.67799 .38772 m
.69247 .40304 L
s
.44773 .28673 m
.46861 .28819 L
s
.69247 .40304 m
.70576 .41912 L
s
.42704 .2867 m
.44773 .28673 L
s
.70576 .41912 m
.71779 .43589 L
s
.40665 .2881 m
.42704 .2867 L
s
.71779 .43589 m
.72846 .45324 L
s
.38668 .29095 m
.40665 .2881 L
s
.72846 .45324 m
.73768 .4711 L
s
.36726 .29526 m
.38668 .29095 L
s
.73768 .4711 m
.74539 .48935 L
s
.34852 .30102 m
.36726 .29526 L
s
.74539 .48935 m
.75151 .5079 L
s
.33058 .30824 m
.34852 .30102 L
s
.75151 .5079 m
.75597 .52664 L
s
.31358 .31689 m
.33058 .30824 L
s
.75597 .52664 m
.7587 .54546 L
s
.29764 .32694 m
.31358 .31689 L
s
.7587 .54546 m
.75966 .56423 L
s
.28289 .33836 m
.29764 .32694 L
s
.75966 .56423 m
.7588 .58282 L
s
.26946 .35111 m
.28289 .33836 L
s
.7588 .58282 m
.75608 .60111 L
s
.25747 .36513 m
.26946 .35111 L
s
.75608 .60111 m
.75147 .61896 L
s
.24705 .38034 m
.25747 .36513 L
s
.75147 .61896 m
.74497 .63623 L
s
.2383 .39667 m
.24705 .38034 L
s
.74497 .63623 m
.73658 .65279 L
s
.23133 .41402 m
.2383 .39667 L
s
.73658 .65279 m
.72632 .66849 L
s
.22624 .43229 m
.23133 .41402 L
s
.72632 .66849 m
.71421 .68319 L
s
.22311 .45134 m
.22624 .43229 L
s
.71421 .68319 m
.70031 .69675 L
s
.22201 .47106 m
.22311 .45134 L
s
.70031 .69675 m
.68469 .70904 L
s
.223 .4913 m
.22201 .47106 L
s
.68469 .70904 m
.66743 .71993 L
s
.22611 .51189 m
.223 .4913 L
s
.66743 .71993 m
.64865 .72929 L
s
.23137 .53267 m
.22611 .51189 L
s
.64865 .72929 m
.62848 .73702 L
s
.23877 .55347 m
.23137 .53267 L
s
.62848 .73702 m
.60706 .74301 L
s
.24829 .5741 m
.23877 .55347 L
s
.60706 .74301 m
.58455 .74718 L
s
.25988 .59438 m
.24829 .5741 L
s
.58455 .74718 m
.56114 .74946 L
s
.27347 .61412 m
.25988 .59438 L
s
.56114 .74946 m
.53702 .74981 L
s
.28896 .63313 m
.27347 .61412 L
s
.53702 .74981 m
.51242 .74819 L
s
.30622 .65123 m
.28896 .63313 L
s
.51242 .74819 m
.48754 .7446 L
s
.32513 .66824 m
.30622 .65123 L
s
.48754 .7446 m
.46263 .73905 L
s
.34551 .68399 m
.32513 .66824 L
s
.46263 .73905 m
.4379 .73157 L
s
.36719 .69834 m
.34551 .68399 L
s
.4379 .73157 m
.4136 .72224 L
s
.38995 .71112 m
.36719 .69834 L
s
.4136 .72224 m
.38995 .71112 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0079ooaL07iMo
o`00K7oo1P0O5goo1P0OTGoo001XOol401lSOol501n<Ool006Ioo`807baoo`<07hUoo`00Hgoo0`0O
<Goo0`0OQWoo001POol301lgOol301n3Ool005eoo`<07ceoo`<07h1oo`00Fgoo0P0O@goo0`0OOGoo
001IOol201m8Ool201mkOol005Qoo`0301moogoo04Yoo`807gUoo`00EWoo0P0OCgoo0P0OMgoo001E
Ool00`0OOomoo`1AOol00`0OOomoo`1dOol005Aoo`0301moogoo05=oo`807gAoo`00Dgoo00<07goo
Ool0EWoo0P0OLWoo001BOol00`0OOomoo`1IOol201m`Ool0055oo`0301moogoo05aoo`807fioo`00
D7oo00<07gooOol0Ggoo0P0OK7oo001>Ool201mTOol00`0OOomoo`1YOol004eoo`0301moogoo06Eo
o`0301moogoo06Qoo`00C7oo00<07gooOol0Igoo0P0OJ7oo001;Ool00`0OOomoo`1ZOol00`0OOomo
o`1UOol004Yoo`0301moogoo06aoo`0301moogoo06Aoo`00BGoo00<07gooOol0KWoo00<07gooOol0
Hgoo0018Ool00`0OOomoo`1`Ool201mSOol004Qoo`0301moogoo079oo`0301moogoo061oo`00Agoo
00<07gooOol0M7oo00<07gooOol0Ggoo0017Ool00`0OOomoo`1eOol00`0OOomoo`1NOol004Ioo`03
01moogoo07Moo`0301moogoo05eoo`00AGoo00<07gooOol0NGoo00<07gooOol0G7oo0015Ool00`0O
Oomoo`1jOol00`0OOomoo`1KOol004Aoo`0301moogoo07aoo`0301moogoo05Yoo`00A7oo00<07goo
Ool0OGoo00<07gooOol0FGoo0014Ool00`0OOomoo`1nOol00`0OOomoo`1HOol004=oo`0301moogoo
081oo`0301moogoo05Moo`00@goo00<07gooOol0PGoo00<07gooOol0EWoo0012Ool00`0OOomoo`23
Ool00`0OOomoo`1EOol0049oo`0301moogoo08=oo`0301moogoo05Eoo`00@Woo00<07gooOol0Q7oo
00<07gooOol0E7oo0011Ool00`0OOomoo`26Ool00`0OOomoo`1COol0045oo`0301moogoo08Moo`03
01moogoo059oo`00@Goo00<07gooOol0R7oo00<07gooOol0DGoo0010Ool00`0OOomoo`29Ool00`0O
Oomoo`1AOol0041oo`0301moogoo08Yoo`0301moogoo051oo`00@7oo00<07gooOol0Rgoo00<07goo
Ool0Cgoo0010Ool00`0OOomoo`2<Ool00`0OOomoo`1>Ool0041oo`0301moogoo08aoo`0301moogoo
04ioo`00@7oo00<07gooOol0SGoo00<07gooOol0CGoo0010Ool00`0OOomoo`2=Ool00`0OOomoo`1=
Ool0041oo`0301moogoo08ioo`0301moogoo04aoo`00@7oo00<07gooOol0SWoo00<07gooOol0C7oo
000oOol00`0OOomoo`2@Ool00`0OOomoo`1;Ool003moo`0301moogoo091oo`0301moogoo04]oo`00
?goo00<07gooOol0TGoo00<07gooOol0BWoo000oOol00`0OOomoo`2AOol00`0OOomoo`1:Ool003mo
o`0301moogoo095oo`0301moogoo04Yoo`00?goo00<07gooOol0TWoo00<07gooOol0BGoo000oOol0
0`0OOomoo`2BOol00`0OOomoo`19Ool0041oo`0301moogoo099oo`0301moogoo04Qoo`00@7oo00<0
7gooOol0TWoo00<07gooOol0B7oo0010Ool00`0OOomoo`2BOol00`0OOomoo`18Ool0041oo`0301mo
ogoo09=oo`0301moogoo04Moo`00@7oo00<07gooOol0Tgoo00<07gooOol0Agoo0010Ool00`0OOomo
o`2DOol00`0OOomoo`16Ool0041oo`0301moogoo09Aoo`0301moogoo04Ioo`00@7oo00<07gooOol0
U7oo00<07gooOol0AWoo0010Ool00`0OOomoo`2DOol00`0OOomoo`16Ool0045oo`0301moogoo09=o
o`0301moogoo04Ioo`00@Goo00<07gooOol0U7oo00<07gooOol0AGoo0011Ool00`0OOomoo`2DOol0
0`0OOomoo`15Ool0049oo`0301moogoo09=oo`0301moogoo04Eoo`00@Woo00<07gooOol0Tgoo00<0
7gooOol0AGoo0012Ool00`0OOomoo`2COol00`0OOomoo`15Ool004=oo`0301moogoo09=oo`0301mo
ogoo04Aoo`00@goo00<07gooOol0Tgoo00<07gooOol0A7oo0013Ool00`0OOomoo`2COol00`0OOomo
o`14Ool004Aoo`0301moogoo099oo`0301moogoo04Aoo`00A7oo00<07gooOol0TWoo00<07gooOol0
A7oo0014Ool00`0OOomoo`2COol00`0OOomoo`13Ool004Eoo`0301moogoo099oo`0301moogoo04=o
o`00AGoo00<07gooOol0TWoo00<07gooOol0@goo0016Ool00`0OOomoo`2AOol00`0OOomoo`13Ool0
04Ioo`0301moogoo095oo`0301moogoo04=oo`00Agoo00<07gooOol0Sgoo00<07gooOol0A7oo0017
Ool00`0OOomoo`2?Ool00`0OOomoo`14Ool004Qoo`0301moogoo08ioo`0301moogoo04Aoo`00B7oo
00<07gooOol0SWoo00<07gooOol0A7oo0019Ool00`0OOomoo`2=Ool00`0OOomoo`14Ool004Uoo`03
01moogoo08eoo`0301moogoo04Aoo`00BWoo00<07gooOol0Rgoo00<07gooOol0AGoo001;Ool00`0O
Oomoo`2:Ool00`0OOomoo`15Ool004]oo`0301moogoo08Yoo`0301moogoo04Eoo`00C7oo00<07goo
Ool0RGoo00<07gooOol0AGoo001=Ool00`0OOomoo`28Ool00`0OOomoo`15Ool004eoo`0301moogoo
08Moo`0301moogoo04Ioo`00CWoo00<07gooOol0QWoo00<07gooOol0AWoo001?Ool00`0OOomoo`25
Ool00`0OOomoo`16Ool0051oo`0301moogoo08Aoo`0301moogoo04Ioo`00D7oo00<07gooOol0Pgoo
00<07gooOol0Agoo001AOol00`0OOomoo`22Ool00`0OOomoo`17Ool0059oo`0301moogoo081oo`03
01moogoo04Qoo`00Dgoo00<07gooOol0Ogoo00<07gooOol0B7oo001DOol00`0OOomoo`1nOol00`0O
Oomoo`18Ool005Eoo`0301moogoo07aoo`0301moogoo04Uoo`00EWoo00<07gooOol0Ngoo00<07goo
Ool0BGoo001GOol00`0OOomoo`1iOol00`0OOomoo`1:Ool005Qoo`0301moogoo07Qoo`0301moogoo
04Yoo`00FGoo00<07gooOol0MWoo00<07gooOol0Bgoo001JOol201meOol00`0OOomoo`1<Ool005ao
o`0301moogoo079oo`0301moogoo04aoo`00GGoo00<07gooOol0L7oo00<07gooOol0CGoo001NOol0
0`0OOomoo`1^Ool00`0OOomoo`1>Ool005moo`0301moogoo06aoo`0301moogoo04moo`00H7oo0P0O
K7oo00<07gooOol0Cgoo001ROol00`0OOomoo`1XOol00`0OOomoo`1@Ool006=oo`0301moogoo06Io
o`0301moogoo055oo`00I7oo0P0OIGoo00<07gooOol0DWoo001VOol00`0OOomoo`1POol201mEOol0
06Moo`807emoo`0301moogoo05Eoo`00JGoo00<07gooOol0Fgoo00<07gooOol0EWoo001ZOol201mJ
Ool00`0OOomoo`1GOol006aoo`0301moogoo05Ioo`0301moogoo05Qoo`00KGoo0P0OEGoo00<07goo
Ool0FGoo001_Ool201mAOol201mLOol0075oo`807deoo`807eioo`00Lgoo0P0OBWoo00<07gooOol0
GWoo001eOol301m5Ool201mQOol007Qoo`@07cmoo`807f=oo`00O7oo0`0O>Woo0P0OIGoo001oOol2
01leOol301mWOol0085oo`807c1oo`<07fYoo`00Pgoo1@0O:7oo0`0OKGoo0028Ool701lLOol501m`
Ool008moo`P07`ioo`H07gEoo`00Ugoo3P0ONgoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.61757 .28183 m
.6398 .295 L
s
.59455 .27011 m
.61757 .28183 L
s
.6398 .295 m
.66112 .30955 L
s
.57088 .25991 m
.59455 .27011 L
s
.66112 .30955 m
.6814 .32539 L
s
.54667 .25128 m
.57088 .25991 L
s
.6814 .32539 m
.70053 .34246 L
s
.52206 .24429 m
.54667 .25128 L
s
.70053 .34246 m
.7184 .36064 L
s
.4972 .23899 m
.52206 .24429 L
s
.7184 .36064 m
.73489 .37986 L
s
.47221 .23541 m
.4972 .23899 L
s
.73489 .37986 m
.74989 .40001 L
s
.44725 .23359 m
.47221 .23541 L
s
.74989 .40001 m
.76332 .42097 L
s
.42246 .23357 m
.44725 .23359 L
s
.76332 .42097 m
.77506 .44264 L
s
.39799 .23536 m
.42246 .23357 L
s
.77506 .44264 m
.78503 .4649 L
s
.37399 .23898 m
.39799 .23536 L
s
.78503 .4649 m
.79314 .48761 L
s
.35061 .24443 m
.37399 .23898 L
s
.79314 .48761 m
.79931 .51065 L
s
.32801 .2517 m
.35061 .24443 L
s
.79931 .51065 m
.80348 .53388 L
s
.30635 .26079 m
.32801 .2517 L
s
.80348 .53388 m
.80557 .55714 L
s
.28578 .27166 m
.30635 .26079 L
s
.80557 .55714 m
.80555 .5803 L
s
.26645 .28428 m
.28578 .27166 L
s
.80555 .5803 m
.80336 .60319 L
s
.24853 .2986 m
.26645 .28428 L
s
.80336 .60319 m
.79899 .62565 L
s
.23217 .31455 m
.24853 .2986 L
s
.79899 .62565 m
.79241 .64751 L
s
.2175 .33205 m
.23217 .31455 L
s
.79241 .64751 m
.78363 .66862 L
s
.20467 .35101 m
.2175 .33205 L
s
.78363 .66862 m
.77266 .68879 L
s
.19382 .37133 m
.20467 .35101 L
s
.77266 .68879 m
.75955 .70787 L
s
.18506 .39287 m
.19382 .37133 L
s
.75955 .70787 m
.74434 .72568 L
s
.17851 .41551 m
.18506 .39287 L
s
.74434 .72568 m
.7271 .74206 L
s
.17426 .43908 m
.17851 .41551 L
s
.7271 .74206 m
.70794 .75686 L
s
.1724 .46343 m
.17426 .43908 L
s
.70794 .75686 m
.68696 .76991 L
s
.17298 .48836 m
.1724 .46343 L
s
.68696 .76991 m
.6643 .78109 L
s
.17605 .51369 m
.17298 .48836 L
s
.6643 .78109 m
.64013 .79026 L
s
.18162 .53921 m
.17605 .51369 L
s
.64013 .79026 m
.6146 .79732 L
s
.1897 .56471 m
.18162 .53921 L
s
.6146 .79732 m
.58793 .80216 L
s
.20025 .58997 m
.1897 .56471 L
s
.58793 .80216 m
.56033 .80472 L
s
.21321 .61476 m
.20025 .58997 L
s
.56033 .80472 m
.53202 .80493 L
s
.22851 .63886 m
.21321 .61476 L
s
.53202 .80493 m
.50325 .80278 L
s
.24603 .66205 m
.22851 .63886 L
s
.50325 .80278 m
.47427 .79824 L
s
.26564 .68412 m
.24603 .66205 L
s
.47427 .79824 m
.44533 .79135 L
s
.28718 .70485 m
.26564 .68412 L
s
.44533 .79135 m
.41671 .78215 L
s
.31047 .72404 m
.28718 .70485 L
s
.41671 .78215 m
.38865 .77071 L
s
.33529 .74153 m
.31047 .72404 L
s
.38865 .77071 m
.36143 .75713 L
s
.36143 .75713 m
.33529 .74153 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol006mooa`07iEo
o`00JWoo1@0O77oo1@0OT7oo001VOol401lVOol401n<Ool006=oo`<07bioo`<07hUoo`00H7oo0`0O
=7oo100OQGoo001MOol301lkOol301n2Ool005Uoo`@07d5oo`@07gioo`00Egoo0P0OBGoo0`0ONgoo
001EOol201m>Ool201miOol005=oo`807e9oo`807gMoo`00DWoo00<07gooOol0E7oo0`0OM7oo001@
Ool201mJOol201mbOol004moo`0301moogoo05aoo`807g1oo`00CGoo0P0OHGoo0P0OKWoo001<Ool0
0`0OOomoo`1SOol201m/Ool004]oo`0301moogoo06Ioo`0301moogoo06Uoo`00BGoo0P0OJWoo0P0O
JGoo0018Ool00`0OOomoo`1/Ool00`0OOomoo`1VOol004Moo`0301moogoo06ioo`807fIoo`00AWoo
00<07gooOol0LGoo00<07gooOol0Hgoo0015Ool00`0OOomoo`1cOol201mSOol004Aoo`0301moogoo
07Ioo`0301moogoo061oo`00@goo00<07gooOol0N7oo00<07gooOol0Ggoo0012Ool00`0OOomoo`1j
Ool00`0OOomoo`1NOol0045oo`0301moogoo07aoo`807eioo`00@7oo00<07gooOol0Ogoo00<07goo
Ool0Fgoo0010Ool00`0OOomoo`20Ool00`0OOomoo`1JOol003moo`0301moogoo089oo`0301moogoo
05Uoo`00?Woo00<07gooOol0Q7oo00<07gooOol0F7oo000mOol00`0OOomoo`26Ool201mHOol003ao
o`0301moogoo08Uoo`0301moogoo05Eoo`00?7oo00<07gooOol0RWoo00<07gooOol0E7oo000kOol0
0`0OOomoo`2<Ool00`0OOomoo`1COol003Yoo`0301moogoo08ioo`0301moogoo059oo`00>Goo00<0
7gooOol0T7oo00<07gooOol0DGoo000iOol00`0OOomoo`2AOol00`0OOomoo`1@Ool003Qoo`0301mo
ogoo09=oo`0301moogoo04moo`00>7oo00<07gooOol0U7oo00<07gooOol0CWoo000gOol00`0OOomo
o`2EOol00`0OOomoo`1>Ool003Moo`0301moogoo09Ioo`0301moogoo04eoo`00=goo00<07gooOol0
Ugoo00<07gooOol0C7oo000fOol00`0OOomoo`2HOol00`0OOomoo`1<Ool003Ioo`0301moogoo09Uo
o`0301moogoo04]oo`00=Woo00<07gooOol0VWoo00<07gooOol0BWoo000eOol00`0OOomoo`2LOol0
0`0OOomoo`19Ool003Eoo`0301moogoo09eoo`0301moogoo04Qoo`00=Goo00<07gooOol0WWoo00<0
7gooOol0Agoo000dOol00`0OOomoo`2POol00`0OOomoo`16Ool003Aoo`0301moogoo0:5oo`0301mo
ogoo04Eoo`00=7oo00<07gooOol0XGoo00<07gooOol0AGoo000dOol00`0OOomoo`2ROol00`0OOomo
o`14Ool003=oo`0301moogoo0:Aoo`0301moogoo04=oo`00<goo00<07gooOol0Y7oo00<07gooOol0
@goo000cOol00`0OOomoo`2UOol00`0OOomoo`12Ool003=oo`0301moogoo0:Eoo`0301moogoo049o
o`00<goo00<07gooOol0YWoo00<07gooOol0@Goo000bOol00`0OOomoo`2WOol00`0OOomoo`11Ool0
039oo`0301moogoo0:Qoo`0301moogoo041oo`00<Woo00<07gooOol0Z7oo00<07gooOol0@7oo000b
Ool00`0OOomoo`2YOol00`0OOomoo`0oOol0039oo`0301moogoo0:Uoo`0301moogoo03moo`00<Woo
00<07gooOol0ZGoo00<07gooOol0?goo000bOol00`0OOomoo`2ZOol00`0OOomoo`0nOol0035oo`03
01moogoo0:]oo`0301moogoo03ioo`00<Goo00<07gooOol0[7oo00<07gooOol0?Goo000aOol00`0O
Oomoo`2/Ool00`0OOomoo`0mOol0035oo`0301moogoo0:eoo`0301moogoo03aoo`00<Goo00<07goo
Ool0[Goo00<07gooOol0?7oo000aOol00`0OOomoo`2^Ool00`0OOomoo`0kOol0035oo`0301moogoo
0:ioo`0301moogoo03]oo`00<Goo00<07gooOol0[Woo00<07gooOol0>goo000aOol00`0OOomoo`2_
Ool00`0OOomoo`0jOol0035oo`0301moogoo0:moo`0301moogoo03Yoo`00<Goo00<07gooOol0[goo
00<07gooOol0>Woo000aOol00`0OOomoo`2`Ool00`0OOomoo`0iOol0035oo`0301moogoo0;1oo`03
01moogoo03Uoo`00<Goo00<07gooOol0/7oo00<07gooOol0>Goo000bOol00`0OOomoo`2_Ool00`0O
Oomoo`0iOol0039oo`0301moogoo0;1oo`0301moogoo03Qoo`00<Woo00<07gooOol0/7oo00<07goo
Ool0>7oo000bOol00`0OOomoo`2`Ool00`0OOomoo`0hOol0039oo`0301moogoo0;1oo`0301moogoo
03Qoo`00<goo00<07gooOol0[goo00<07gooOol0>7oo000cOol00`0OOomoo`2`Ool00`0OOomoo`0g
Ool003=oo`0301moogoo0;1oo`0301moogoo03Moo`00<goo00<07gooOol0/7oo00<07gooOol0=goo
000dOol00`0OOomoo`2_Ool00`0OOomoo`0gOol003Aoo`0301moogoo0:moo`0301moogoo03Moo`00
=7oo00<07gooOol0[goo00<07gooOol0=goo000dOol00`0OOomoo`2_Ool00`0OOomoo`0gOol003Eo
o`0301moogoo0:moo`0301moogoo03Ioo`00=Goo00<07gooOol0[goo00<07gooOol0=Woo000eOol0
0`0OOomoo`2_Ool00`0OOomoo`0fOol003Eoo`0301moogoo0:moo`0301moogoo03Ioo`00=Woo00<0
7gooOol0[Woo00<07gooOol0=Woo000fOol00`0OOomoo`2^Ool00`0OOomoo`0fOol003Ioo`0301mo
ogoo0:ioo`0301moogoo03Ioo`00=goo00<07gooOol0[Goo00<07gooOol0=Woo000gOol00`0OOomo
o`2]Ool00`0OOomoo`0fOol003Qoo`0301moogoo0:aoo`0301moogoo03Ioo`00>7oo00<07gooOol0
[7oo00<07gooOol0=Woo000iOol00`0OOomoo`2[Ool00`0OOomoo`0fOol003Uoo`0301moogoo0:]o
o`0301moogoo03Ioo`00>Woo00<07gooOol0ZGoo00<07gooOol0=goo000jOol00`0OOomoo`2YOol0
0`0OOomoo`0gOol003]oo`0301moogoo0:Qoo`0301moogoo03Moo`00>goo00<07gooOol0Z7oo00<0
7gooOol0=goo000lOol00`0OOomoo`2WOol00`0OOomoo`0gOol003aoo`0301moogoo0:Moo`0301mo
ogoo03Moo`00?Goo00<07gooOol0YGoo00<07gooOol0>7oo000nOol00`0OOomoo`2TOol00`0OOomo
o`0hOol003ioo`0301moogoo0:Aoo`0301moogoo03Qoo`00?goo00<07gooOol0Xgoo00<07gooOol0
>7oo000oOol00`0OOomoo`2SOol00`0OOomoo`0hOol0041oo`0301moogoo0:5oo`0301moogoo03Uo
o`00@7oo00<07gooOol0XGoo00<07gooOol0>Goo0011Ool00`0OOomoo`2POol00`0OOomoo`0iOol0
049oo`0301moogoo09ioo`0301moogoo03Yoo`00@Woo00<07gooOol0WWoo00<07gooOol0>Woo0013
Ool00`0OOomoo`2LOol00`0OOomoo`0kOol004Aoo`0301moogoo09]oo`0301moogoo03]oo`00AGoo
00<07gooOol0VGoo00<07gooOol0?7oo0015Ool00`0OOomoo`2IOol00`0OOomoo`0lOol004Ioo`03
01moogoo09Moo`0301moogoo03eoo`00Agoo00<07gooOol0UWoo00<07gooOol0?Goo0018Ool00`0O
Oomoo`2DOol00`0OOomoo`0nOol004Uoo`0301moogoo09=oo`0301moogoo03ioo`00BWoo00<07goo
Ool0TGoo00<07gooOol0?goo001;Ool00`0OOomoo`2@Ool00`0OOomoo`0oOol004aoo`0301moogoo
08ioo`0301moogoo041oo`00CGoo00<07gooOol0SGoo00<07gooOol0@7oo001>Ool00`0OOomoo`2;
Ool00`0OOomoo`11Ool004moo`0301moogoo08Yoo`0301moogoo045oo`00D7oo00<07gooOol0R7oo
00<07gooOol0@Woo001AOol00`0OOomoo`26Ool00`0OOomoo`13Ool0059oo`0301moogoo08Eoo`03
01moogoo04=oo`00Dgoo0P0OQ7oo00<07gooOol0A7oo001EOol00`0OOomoo`20Ool00`0OOomoo`15
Ool005Ioo`0301moogoo07ioo`0301moogoo04Ioo`00Egoo0P0OOWoo00<07gooOol0AWoo001IOol0
0`0OOomoo`1jOol00`0OOomoo`17Ool005Yoo`807gUoo`0301moogoo04Qoo`00G7oo00<07gooOol0
MGoo00<07gooOol0BGoo001MOol00`0OOomoo`1bOol201m<Ool005ioo`807g5oo`0301moogoo04ao
o`00H7oo00<07gooOol0KGoo00<07gooOol0CGoo001QOol201m/Ool00`0OOomoo`1>Ool006=oo`03
01moogoo06Qoo`0301moogoo04moo`00I7oo00<07gooOol0IWoo00<07gooOol0D7oo001UOol201mU
Ool00`0OOomoo`1AOol006Moo`0301moogoo065oo`0301moogoo059oo`00J7oo0P0OGgoo0P0OEGoo
001ZOol201mKOol201mGOol006aoo`807eMoo`807eUoo`00KWoo0`0ODWoo0P0OFgoo001aOol201m>
Ool201mMOol007=oo`<07dUoo`807emoo`00MWoo0`0OA7oo0P0OHGoo001iOol201lnOol401mSOol0
07]oo`<07cQoo`<07fMoo`00OWoo100O<7oo100OJWoo0022Ool401lYOol301m^Ool008Ioo`H07amo
o`@07g5oo`00S7oo200O2Goo3P0OMGoo002DOol901n3Ool00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.64881 .28677 m
.66972 .30219 L
s
.6269 .27278 m
.64881 .28677 L
s
.60413 .26031 m
.6269 .27278 L
s
.66972 .30219 m
.68953 .31896 L
s
.58062 .24942 m
.60413 .26031 L
s
.68953 .31896 m
.7081 .33698 L
s
.55649 .24019 m
.58062 .24942 L
s
.7081 .33698 m
.72533 .35615 L
s
.5319 .23267 m
.55649 .24019 L
s
.72533 .35615 m
.74111 .37638 L
s
.50698 .22692 m
.5319 .23267 L
s
.74111 .37638 m
.75534 .39755 L
s
.48186 .223 m
.50698 .22692 L
s
.75534 .39755 m
.76793 .41954 L
s
.45671 .22093 m
.48186 .223 L
s
.76793 .41954 m
.77878 .44223 L
s
.43167 .22075 m
.45671 .22093 L
s
.77878 .44223 m
.7878 .4655 L
s
.40688 .22248 m
.43167 .22075 L
s
.7878 .4655 m
.79493 .4892 L
s
.38252 .22615 m
.40688 .22248 L
s
.79493 .4892 m
.80008 .51319 L
s
.35873 .23174 m
.38252 .22615 L
s
.80008 .51319 m
.80321 .53734 L
s
.33568 .23926 m
.35873 .23174 L
s
.80321 .53734 m
.80425 .56148 L
s
.31353 .24868 m
.33568 .23926 L
s
.80425 .56148 m
.80317 .58546 L
s
.29244 .25999 m
.31353 .24868 L
s
.80317 .58546 m
.79993 .60912 L
s
.27257 .27313 m
.29244 .25999 L
s
.79993 .60912 m
.79453 .63228 L
s
.25407 .28804 m
.27257 .27313 L
s
.79453 .63228 m
.78695 .65479 L
s
.2371 .30467 m
.25407 .28804 L
s
.78695 .65479 m
.77722 .67647 L
s
.22182 .32291 m
.2371 .30467 L
s
.77722 .67647 m
.76535 .69716 L
s
.20836 .34268 m
.22182 .32291 L
s
.76535 .69716 m
.7514 .71667 L
s
.19686 .36385 m
.20836 .34268 L
s
.7514 .71667 m
.73542 .73484 L
s
.18744 .38629 m
.19686 .36385 L
s
.73542 .73484 m
.71751 .75151 L
s
.18022 .40986 m
.18744 .38629 L
s
.71751 .75151 m
.69775 .76652 L
s
.17529 .43439 m
.18022 .40986 L
s
.69775 .76652 m
.67628 .77973 L
s
.17273 .4597 m
.17529 .43439 L
s
.67628 .77973 m
.65323 .79099 L
s
.17261 .48561 m
.17273 .4597 L
s
.65323 .79099 m
.62877 .80018 L
s
.17497 .51191 m
.17261 .48561 L
s
.62877 .80018 m
.60307 .80719 L
s
.17982 .53839 m
.17497 .51191 L
s
.60307 .80719 m
.57633 .81192 L
s
.18717 .56482 m
.17982 .53839 L
s
.57633 .81192 m
.54876 .81431 L
s
.19699 .591 m
.18717 .56482 L
s
.54876 .81431 m
.52058 .8143 L
s
.20921 .61667 m
.19699 .591 L
s
.52058 .8143 m
.49203 .81187 L
s
.22377 .64162 m
.20921 .61667 L
s
.49203 .81187 m
.46337 .80701 L
s
.24056 .66563 m
.22377 .64162 L
s
.46337 .80701 m
.43483 .79973 L
s
.25944 .68846 m
.24056 .66563 L
s
.43483 .79973 m
.40667 .7901 L
s
.28026 .70991 m
.25944 .68846 L
s
.40667 .7901 m
.37915 .77818 L
s
.30285 .72978 m
.28026 .70991 L
s
.37915 .77818 m
.35252 .76407 L
s
.327 .74788 m
.30285 .72978 L
s
.35252 .76407 m
.327 .74788 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo001aOolK01nDOol006aoo`D07a]oo`@07i1oo`00J7oo100O97oo1@0O
Rgoo001UOol301l]Ool501n6Ool0069oo`<07cEoo`@07h9oo`00Ggoo0`0O?7oo0`0OOgoo001MOol2
01m2Ool201mmOol005]oo`807dIoo`807g]oo`00FGoo0P0OBWoo0`0ON7oo001GOol201m?Ool201mf
Ool005Eoo`807e=oo`807gAoo`00Dgoo0P0OEgoo0P0OLWoo001BOol00`0OOomoo`1IOol201m`Ool0
051oo`807eioo`0301moogoo06eoo`00Cgoo00<07gooOol0Ggoo0P0OKGoo001>Ool00`0OOomoo`1R
Ool00`0OOomoo`1ZOol004aoo`807fIoo`807fYoo`00Bgoo00<07gooOol0J7oo0P0OJ7oo0019Ool2
01m]Ool201mVOol004Qoo`0301moogoo06moo`0301moogoo06=oo`00Agoo00<07gooOol0LGoo0P0O
Hgoo0016Ool00`0OOomoo`1dOol00`0OOomoo`1POol004Ioo`0301moogoo07Eoo`807f1oo`00AGoo
00<07gooOol0N7oo00<07gooOol0GGoo0014Ool00`0OOomoo`1jOol00`0OOomoo`1LOol004=oo`03
01moogoo07aoo`0301moogoo05]oo`00@Woo00<07gooOol0OWoo00<07gooOol0FWoo0011Ool00`0O
Oomoo`20Ool00`0OOomoo`1IOol0041oo`0301moogoo089oo`0301moogoo05Qoo`00?goo00<07goo
Ool0Q7oo00<07gooOol0Egoo000nOol00`0OOomoo`26Ool00`0OOomoo`1FOol003ioo`0301moogoo
08Moo`807eIoo`00?Goo00<07gooOol0RWoo00<07gooOol0Dgoo000lOol00`0OOomoo`2<Ool00`0O
Oomoo`1BOol003aoo`0301moogoo08eoo`0301moogoo055oo`00>goo00<07gooOol0Sgoo00<07goo
Ool0D7oo000jOol00`0OOomoo`2@Ool00`0OOomoo`1@Ool003Yoo`0301moogoo095oo`0301moogoo
04moo`00>Goo00<07gooOol0Tgoo00<07gooOol0CWoo000iOol00`0OOomoo`2DOol00`0OOomoo`1=
Ool003Qoo`0301moogoo09Ioo`0301moogoo04aoo`00>7oo00<07gooOol0UWoo00<07gooOol0C7oo
000gOol00`0OOomoo`2HOol00`0OOomoo`1;Ool003Moo`0301moogoo09Uoo`0301moogoo04Yoo`00
=Woo00<07gooOol0VWoo00<07gooOol0BWoo000fOol00`0OOomoo`2KOol00`0OOomoo`19Ool003Eo
o`0301moogoo09eoo`0301moogoo04Qoo`00=Goo00<07gooOol0WGoo00<07gooOol0B7oo000eOol0
0`0OOomoo`2NOol00`0OOomoo`17Ool003Aoo`0301moogoo0:1oo`0301moogoo04Ioo`00=7oo00<0
7gooOol0X7oo00<07gooOol0AWoo000dOol00`0OOomoo`2QOol00`0OOomoo`15Ool003Aoo`0301mo
ogoo0:9oo`0301moogoo04Aoo`00<goo00<07gooOol0Xgoo00<07gooOol0A7oo000cOol00`0OOomo
o`2TOol00`0OOomoo`13Ool003=oo`0301moogoo0:Eoo`0301moogoo049oo`00<goo00<07gooOol0
YGoo00<07gooOol0@Woo000cOol00`0OOomoo`2VOol00`0OOomoo`11Ool0039oo`0301moogoo0:Mo
o`0301moogoo045oo`00<Woo00<07gooOol0Z7oo00<07gooOol0@7oo000bOol00`0OOomoo`2XOol0
0`0OOomoo`10Ool0039oo`0301moogoo0:Uoo`0301moogoo03moo`00<Woo00<07gooOol0ZGoo00<0
7gooOol0?goo000bOol00`0OOomoo`2ZOol00`0OOomoo`0nOol0039oo`0301moogoo0:Yoo`0301mo
ogoo03ioo`00<Goo00<07gooOol0[7oo00<07gooOol0?Goo000aOol00`0OOomoo`2/Ool00`0OOomo
o`0mOol0035oo`0301moogoo0:eoo`0301moogoo03aoo`00<Goo00<07gooOol0[Goo00<07gooOol0
?7oo000aOol00`0OOomoo`2^Ool00`0OOomoo`0kOol0035oo`0301moogoo0:ioo`0301moogoo03]o
o`00<Goo00<07gooOol0[Woo00<07gooOol0>goo000aOol00`0OOomoo`2_Ool00`0OOomoo`0jOol0
035oo`0301moogoo0:moo`0301moogoo03Yoo`00<Goo00<07gooOol0[goo00<07gooOol0>Woo000a
Ool00`0OOomoo`2_Ool00`0OOomoo`0jOol0035oo`0301moogoo0;1oo`0301moogoo03Uoo`00<Goo
00<07gooOol0/7oo00<07gooOol0>Goo000aOol00`0OOomoo`2`Ool00`0OOomoo`0iOol0035oo`03
01moogoo0;1oo`0301moogoo03Uoo`00<Woo00<07gooOol0[goo00<07gooOol0>Goo000bOol00`0O
Oomoo`2`Ool00`0OOomoo`0hOol0039oo`0301moogoo0;1oo`0301moogoo03Qoo`00<Woo00<07goo
Ool0/7oo00<07gooOol0>7oo000bOol00`0OOomoo`2`Ool00`0OOomoo`0hOol0039oo`0301moogoo
0;1oo`0301moogoo03Qoo`00<Woo00<07gooOol0/7oo00<07gooOol0>7oo000bOol00`0OOomoo`2`
Ool00`0OOomoo`0hOol003=oo`0301moogoo0;1oo`0301moogoo03Moo`00<goo00<07gooOol0/7oo
00<07gooOol0=goo000cOol00`0OOomoo`2`Ool00`0OOomoo`0gOol003=oo`0301moogoo0;1oo`03
01moogoo03Moo`00<goo00<07gooOol0/7oo00<07gooOol0=goo000cOol00`0OOomoo`2`Ool00`0O
Oomoo`0gOol003Aoo`0301moogoo0:moo`0301moogoo03Moo`00=7oo00<07gooOol0[goo00<07goo
Ool0=goo000dOol00`0OOomoo`2_Ool00`0OOomoo`0gOol003Aoo`0301moogoo0:moo`0301moogoo
03Moo`00=Goo00<07gooOol0[Woo00<07gooOol0=goo000eOol00`0OOomoo`2^Ool00`0OOomoo`0g
Ool003Eoo`0301moogoo0:ioo`0301moogoo03Moo`00=Woo00<07gooOol0[Goo00<07gooOol0=goo
000fOol00`0OOomoo`2]Ool00`0OOomoo`0gOol003Moo`0301moogoo0:aoo`0301moogoo03Moo`00
=goo00<07gooOol0[7oo00<07gooOol0=goo000hOol00`0OOomoo`2[Ool00`0OOomoo`0gOol003Qo
o`0301moogoo0:]oo`0301moogoo03Moo`00>Goo00<07gooOol0ZWoo00<07gooOol0=goo000iOol0
0`0OOomoo`2YOol00`0OOomoo`0hOol003Yoo`0301moogoo0:Qoo`0301moogoo03Qoo`00>Woo00<0
7gooOol0Z7oo00<07gooOol0>7oo000kOol00`0OOomoo`2WOol00`0OOomoo`0hOol003]oo`0301mo
ogoo0:Moo`0301moogoo03Qoo`00?7oo00<07gooOol0YWoo00<07gooOol0>7oo000lOol00`0OOomo
o`2VOol00`0OOomoo`0hOol003eoo`0301moogoo0:Aoo`0301moogoo03Uoo`00?Goo00<07gooOol0
Y7oo00<07gooOol0>Goo000nOol00`0OOomoo`2SOol00`0OOomoo`0iOol003ioo`0301moogoo0:=o
o`0301moogoo03Uoo`00?goo00<07gooOol0XGoo00<07gooOol0>Woo000oOol00`0OOomoo`2QOol0
0`0OOomoo`0jOol0041oo`0301moogoo09moo`0301moogoo03]oo`00@Goo00<07gooOol0WWoo00<0
7gooOol0>goo0011Ool00`0OOomoo`2MOol00`0OOomoo`0lOol0049oo`0301moogoo09aoo`0301mo
ogoo03aoo`00@goo00<07gooOol0Vgoo00<07gooOol0?7oo0014Ool00`0OOomoo`2IOol00`0OOomo
o`0mOol004Aoo`0301moogoo09Uoo`0301moogoo03eoo`00AGoo00<07gooOol0V7oo00<07gooOol0
?Goo0016Ool00`0OOomoo`2GOol00`0OOomoo`0mOol004Moo`0301moogoo09Eoo`0301moogoo03io
o`00Agoo00<07gooOol0UGoo00<07gooOol0?Woo0018Ool00`0OOomoo`2COol00`0OOomoo`0oOol0
04Uoo`0301moogoo099oo`0301moogoo03moo`00BWoo00<07gooOol0T7oo00<07gooOol0@7oo001;
Ool00`0OOomoo`2>Ool00`0OOomoo`11Ool004aoo`0301moogoo08eoo`0301moogoo045oo`00CGoo
00<07gooOol0Rgoo00<07gooOol0@Woo001>Ool00`0OOomoo`29Ool00`0OOomoo`13Ool004moo`03
01moogoo08Moo`0301moogoo04Aoo`00D7oo00<07gooOol0QWoo00<07gooOol0A7oo001AOol00`0O
Oomoo`24Ool00`0OOomoo`15Ool0059oo`0301moogoo089oo`0301moogoo04Ioo`00Dgoo00<07goo
Ool0P7oo00<07gooOol0Agoo001DOol00`0OOomoo`1nOol00`0OOomoo`18Ool005Eoo`0301moogoo
07eoo`0301moogoo04Qoo`00EWoo00<07gooOol0Ngoo00<07gooOol0BGoo001GOol201mjOol00`0O
Oomoo`1:Ool005Uoo`0301moogoo07Ioo`0301moogoo04]oo`00FWoo00<07gooOol0M7oo00<07goo
Ool0C7oo001KOol201mbOol201m?Ool005eoo`0301moogoo06ioo`0301moogoo04moo`00GWoo0P0O
KGoo00<07gooOol0D7oo001POol00`0OOomoo`1YOol00`0OOomoo`1AOol0065oo`807fMoo`807eAo
o`00Hgoo0P0OI7oo00<07gooOol0E7oo001UOol00`0OOomoo`1POol00`0OOomoo`1EOol006Ioo`80
7eioo`807eQoo`00J7oo0P0OFgoo00<07gooOol0F7oo001ZOol201mGOol201mKOol006aoo`807eAo
o`0301moogoo05]oo`00KWoo0P0OD7oo0P0OGWoo001`Ool301m;Ool201mPOol007=oo`<07dIoo`80
7f9oo`00MWoo0P0O@Woo0P0OI7oo001hOol301lkOol401mVOol007]oo`<07cEoo`<07fYoo`00OWoo
100O;Goo100OKGoo0022Ool501lUOol301maOol008Moo`@07aeoo`@07gAoo`00Rgoo7@0ON7oo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.67792 .29676 m
.69715 .31442 L
s
.65751 .28047 m
.67792 .29676 L
s
.63602 .26565 m
.65751 .28047 L
s
.69715 .31442 m
.71506 .33336 L
s
.61358 .25239 m
.63602 .26565 L
s
.71506 .33336 m
.73157 .35347 L
s
.59032 .24077 m
.61358 .25239 L
s
.73157 .35347 m
.74655 .37463 L
s
.56637 .23087 m
.59032 .24077 L
s
.74655 .37463 m
.75993 .39673 L
s
.54187 .22276 m
.56637 .23087 L
s
.75993 .39673 m
.7716 .41964 L
s
.51696 .21649 m
.54187 .22276 L
s
.7716 .41964 m
.78149 .44323 L
s
.49179 .21212 m
.51696 .21649 L
s
.78149 .44323 m
.78951 .46737 L
s
.46651 .2097 m
.49179 .21212 L
s
.78951 .46737 m
.7956 .4919 L
s
.44126 .20925 m
.46651 .2097 L
s
.7956 .4919 m
.7997 .51669 L
s
.41622 .21081 m
.44126 .20925 L
s
.7997 .51669 m
.80176 .54158 L
s
.39154 .21439 m
.41622 .21081 L
s
.80176 .54158 m
.80174 .56641 L
s
.36738 .21999 m
.39154 .21439 L
s
.80174 .56641 m
.7996 .59102 L
s
.3439 .22761 m
.36738 .21999 L
s
.7996 .59102 m
.79533 .61524 L
s
.32128 .23724 m
.3439 .22761 L
s
.79533 .61524 m
.78893 .63891 L
s
.29968 .24883 m
.32128 .23724 L
s
.78893 .63891 m
.78039 .66186 L
s
.27927 .26234 m
.29968 .24883 L
s
.78039 .66186 m
.76975 .68391 L
s
.2602 .2777 m
.27927 .26234 L
s
.76975 .68391 m
.75705 .7049 L
s
.24264 .29485 m
.2602 .2777 L
s
.75705 .7049 m
.74233 .72465 L
s
.22674 .3137 m
.24264 .29485 L
s
.74233 .72465 m
.72568 .74299 L
s
.21264 .33412 m
.22674 .3137 L
s
.72568 .74299 m
.70717 .75977 L
s
.20049 .356 m
.21264 .33412 L
s
.70717 .75977 m
.68692 .77483 L
s
.1904 .37919 m
.20049 .356 L
s
.68692 .77483 m
.66506 .78803 L
s
.1825 .40355 m
.1904 .37919 L
s
.66506 .78803 m
.64172 .79922 L
s
.17688 .42889 m
.1825 .40355 L
s
.64172 .79922 m
.61708 .80829 L
s
.17362 .45503 m
.17688 .42889 L
s
.61708 .80829 m
.5913 .81514 L
s
.17279 .48178 m
.17362 .45503 L
s
.5913 .81514 m
.56458 .81967 L
s
.17443 .50892 m
.17279 .48178 L
s
.56458 .81967 m
.53713 .8218 L
s
.17856 .53623 m
.17443 .50892 L
s
.53713 .8218 m
.50917 .82151 L
s
.18518 .56349 m
.17856 .53623 L
s
.50917 .82151 m
.48093 .81875 L
s
.19425 .59046 m
.18518 .56349 L
s
.48093 .81875 m
.45265 .81352 L
s
.20573 .61691 m
.19425 .59046 L
s
.45265 .81352 m
.42457 .80586 L
s
.21954 .6426 m
.20573 .61691 L
s
.42457 .80586 m
.39694 .79579 L
s
.23558 .66732 m
.21954 .6426 L
s
.39694 .79579 m
.37 .78341 L
s
.25372 .69083 m
.23558 .66732 L
s
.37 .78341 m
.34399 .76879 L
s
.27381 .71292 m
.25372 .69083 L
s
.34399 .76879 m
.31914 .75208 L
s
.29568 .7334 m
.27381 .71292 L
s
.31914 .75208 m
.29568 .7334 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001dOolK
01nAOol006moo`D07a]oo`@07heoo`00Jgoo100O97oo1@0OR7oo001XOol301l]Ool501n3Ool006Ao
o`@07cEoo`807h5oo`00HWoo0P0O>goo0P0OOgoo001POol201loOol301mlOol005ioo`807dAoo`80
7gYoo`00G7oo0P0OB7oo0P0ON7oo001JOol201m<Ool301meOol005Qoo`807e5oo`807g=oo`00EWoo
0P0OEGoo0P0OLGoo001DOol201mIOol201m_Ool005=oo`0301moogoo05]oo`807feoo`00DGoo0P0O
H7oo00<07gooOol0JWoo001@Ool00`0OOomoo`1QOol201mZOol004ioo`807fIoo`0301moogoo06Mo
o`00CGoo00<07gooOol0Igoo0P0OIgoo001;Ool201m/Ool00`0OOomoo`1TOol004Yoo`0301moogoo
06eoo`807fAoo`00BGoo00<07gooOol0L7oo00<07gooOol0HGoo0018Ool00`0OOomoo`1bOol00`0O
Oomoo`1POol004Moo`0301moogoo07Aoo`0301moogoo05moo`00AWoo00<07gooOol0MWoo0P0OGgoo
0015Ool00`0OOomoo`1iOol00`0OOomoo`1LOol004Aoo`0301moogoo07]oo`0301moogoo05]oo`00
A7oo00<07gooOol0O7oo00<07gooOol0FWoo0013Ool00`0OOomoo`1nOol00`0OOomoo`1IOol0049o
o`0301moogoo081oo`807eUoo`00@Woo00<07gooOol0PWoo00<07gooOol0EWoo0011Ool00`0OOomo
o`24Ool00`0OOomoo`1EOol0041oo`0301moogoo08Ioo`0301moogoo05Aoo`00?goo00<07gooOol0
R7oo00<07gooOol0Dgoo000oOol00`0OOomoo`29Ool00`0OOomoo`1BOol003ioo`0301moogoo08]o
o`0301moogoo055oo`00?Goo00<07gooOol0SGoo00<07gooOol0D7oo000lOol00`0OOomoo`2?Ool0
0`0OOomoo`1?Ool003aoo`0301moogoo08moo`0301moogoo04moo`00>goo00<07gooOol0TGoo00<0
7gooOol0CWoo000kOol00`0OOomoo`2BOol00`0OOomoo`1=Ool003Yoo`0301moogoo09=oo`0301mo
ogoo04eoo`00>Woo00<07gooOol0U7oo00<07gooOol0C7oo000iOol00`0OOomoo`2FOol00`0OOomo
o`1;Ool003Qoo`0301moogoo09Qoo`0301moogoo04Yoo`00>7oo00<07gooOol0V7oo00<07gooOol0
BWoo000gOol00`0OOomoo`2JOol00`0OOomoo`19Ool003Moo`0301moogoo09]oo`0301moogoo04Qo
o`00=Woo00<07gooOol0WGoo00<07gooOol0Agoo000fOol00`0OOomoo`2NOol00`0OOomoo`16Ool0
03Ioo`0301moogoo09ioo`0301moogoo04Ioo`00=Goo00<07gooOol0X7oo00<07gooOol0AGoo000e
Ool00`0OOomoo`2QOol00`0OOomoo`14Ool003Eoo`0301moogoo0:5oo`0301moogoo04Aoo`00=Goo
00<07gooOol0XWoo00<07gooOol0@goo000dOol00`0OOomoo`2SOol00`0OOomoo`13Ool003Aoo`03
01moogoo0:Aoo`0301moogoo049oo`00=7oo00<07gooOol0Y7oo00<07gooOol0@Woo000cOol00`0O
Oomoo`2VOol00`0OOomoo`11Ool003=oo`0301moogoo0:Ioo`0301moogoo045oo`00<goo00<07goo
Ool0Ygoo00<07gooOol0@7oo000cOol00`0OOomoo`2WOol00`0OOomoo`10Ool0039oo`0301moogoo
0:Qoo`0301moogoo041oo`00<Woo00<07gooOol0ZGoo00<07gooOol0?goo000bOol00`0OOomoo`2Y
Ool00`0OOomoo`0oOol0039oo`0301moogoo0:Yoo`0301moogoo03ioo`00<Woo00<07gooOol0ZWoo
00<07gooOol0?Woo000bOol00`0OOomoo`2[Ool00`0OOomoo`0mOol0035oo`0301moogoo0:aoo`03
01moogoo03eoo`00<Goo00<07gooOol0[7oo00<07gooOol0?Goo000aOol00`0OOomoo`2]Ool00`0O
Oomoo`0lOol0035oo`0301moogoo0:eoo`0301moogoo03aoo`00<Goo00<07gooOol0[Goo00<07goo
Ool0?7oo000aOol00`0OOomoo`2]Ool00`0OOomoo`0lOol0035oo`0301moogoo0:ioo`0301moogoo
03]oo`00<Goo00<07gooOol0[Woo00<07gooOol0>goo000aOol00`0OOomoo`2^Ool00`0OOomoo`0k
Ool0035oo`0301moogoo0:moo`0301moogoo03Yoo`00<Goo00<07gooOol0[goo00<07gooOol0>Woo
000aOol00`0OOomoo`2_Ool00`0OOomoo`0jOol0035oo`0301moogoo0:moo`0301moogoo03Yoo`00
<Goo00<07gooOol0/7oo00<07gooOol0>Goo000aOol00`0OOomoo`2`Ool00`0OOomoo`0iOol0035o
o`0301moogoo0;1oo`0301moogoo03Uoo`00<Woo00<07gooOol0[goo00<07gooOol0>Goo000bOol0
0`0OOomoo`2_Ool00`0OOomoo`0iOol0039oo`0301moogoo0;1oo`0301moogoo03Qoo`00<Woo00<0
7gooOol0/7oo00<07gooOol0>7oo000bOol00`0OOomoo`2`Ool00`0OOomoo`0hOol0039oo`0301mo
ogoo0;1oo`0301moogoo03Qoo`00<Woo00<07gooOol0/7oo00<07gooOol0>7oo000cOol00`0OOomo
o`2_Ool00`0OOomoo`0hOol003=oo`0301moogoo0:moo`0301moogoo03Qoo`00<goo00<07gooOol0
/7oo00<07gooOol0=goo000cOol00`0OOomoo`2`Ool00`0OOomoo`0gOol003=oo`0301moogoo0;1o
o`0301moogoo03Moo`00<goo00<07gooOol0/7oo00<07gooOol0=goo000dOol00`0OOomoo`2_Ool0
0`0OOomoo`0gOol003Aoo`0301moogoo0:moo`0301moogoo03Moo`00=7oo00<07gooOol0[goo00<0
7gooOol0=goo000dOol00`0OOomoo`2_Ool00`0OOomoo`0gOol003Eoo`0301moogoo0:ioo`0301mo
ogoo03Moo`00=Goo00<07gooOol0[Woo00<07gooOol0=goo000eOol00`0OOomoo`2^Ool00`0OOomo
o`0gOol003Eoo`0301moogoo0:ioo`0301moogoo03Moo`00=Woo00<07gooOol0[Goo00<07gooOol0
=goo000fOol00`0OOomoo`2]Ool00`0OOomoo`0gOol003Ioo`0301moogoo0:aoo`0301moogoo03Qo
o`00=Woo00<07gooOol0[7oo00<07gooOol0>7oo000gOol00`0OOomoo`2[Ool00`0OOomoo`0hOol0
03Moo`0301moogoo0:]oo`0301moogoo03Qoo`00=goo00<07gooOol0Zgoo00<07gooOol0>7oo000h
Ool00`0OOomoo`2ZOol00`0OOomoo`0hOol003Qoo`0301moogoo0:Yoo`0301moogoo03Qoo`00>Goo
00<07gooOol0Z7oo00<07gooOol0>Goo000iOol00`0OOomoo`2XOol00`0OOomoo`0iOol003Yoo`03
01moogoo0:Moo`0301moogoo03Uoo`00>Woo00<07gooOol0Ygoo00<07gooOol0>Goo000kOol00`0O
Oomoo`2VOol00`0OOomoo`0iOol003aoo`0301moogoo0:Aoo`0301moogoo03Yoo`00?7oo00<07goo
Ool0Y7oo00<07gooOol0>Woo000mOol00`0OOomoo`2SOol00`0OOomoo`0jOol003eoo`0301moogoo
0:=oo`0301moogoo03Yoo`00?Woo00<07gooOol0XGoo00<07gooOol0>goo000nOol00`0OOomoo`2Q
Ool00`0OOomoo`0kOol003moo`0301moogoo09moo`0301moogoo03aoo`00@7oo00<07gooOol0WWoo
00<07gooOol0?7oo0010Ool00`0OOomoo`2MOol00`0OOomoo`0mOol0045oo`0301moogoo09aoo`03
01moogoo03eoo`00@Goo00<07gooOol0Vgoo00<07gooOol0?Woo0012Ool00`0OOomoo`2JOol00`0O
Oomoo`0nOol0049oo`0301moogoo09Yoo`0301moogoo03ioo`00@goo00<07gooOol0V7oo00<07goo
Ool0?goo0014Ool00`0OOomoo`2GOol00`0OOomoo`0oOol004Aoo`0301moogoo09Ioo`0301moogoo
041oo`00AGoo00<07gooOol0UGoo00<07gooOol0@7oo0016Ool00`0OOomoo`2COol00`0OOomoo`11
Ool004Moo`0301moogoo099oo`0301moogoo045oo`00Agoo00<07gooOol0TGoo00<07gooOol0@Woo
0018Ool00`0OOomoo`2@Ool00`0OOomoo`12Ool004Uoo`0301moogoo08ioo`0301moogoo04=oo`00
BWoo00<07gooOol0SGoo00<07gooOol0@goo001;Ool00`0OOomoo`2;Ool00`0OOomoo`14Ool004ao
o`0301moogoo08Yoo`0301moogoo04Aoo`00CGoo00<07gooOol0R7oo00<07gooOol0AGoo001>Ool0
0`0OOomoo`26Ool00`0OOomoo`16Ool004moo`0301moogoo08Eoo`0301moogoo04Ioo`00D7oo00<0
7gooOol0Pgoo00<07gooOol0Agoo001AOol00`0OOomoo`21Ool00`0OOomoo`18Ool0059oo`0301mo
ogoo07moo`0301moogoo04Uoo`00Dgoo00<07gooOol0OGoo00<07gooOol0BWoo001DOol00`0OOomo
o`1kOol00`0OOomoo`1;Ool005Eoo`807g]oo`0301moogoo04]oo`00Egoo00<07gooOol0Mgoo00<0
7gooOol0C7oo001HOol00`0OOomoo`1eOol00`0OOomoo`1=Ool005Uoo`807gAoo`0301moogoo04io
o`00Fgoo00<07gooOol0L7oo00<07gooOol0Cgoo001LOol201m^Ool201mBOol005ioo`0301moogoo
06Yoo`0301moogoo059oo`00Ggoo00<07gooOol0J7oo00<07gooOol0Dgoo001POol201mWOol00`0O
Oomoo`1DOol0069oo`0301moogoo069oo`807eMoo`00Hgoo0P0OHGoo00<07gooOol0Egoo001UOol2
01mNOol00`0OOomoo`1HOol006Moo`807eYoo`807e]oo`00JGoo0P0OEWoo0P0OGGoo001[Ool201mB
Ool201mOOol006eoo`807dmoo`0301moogoo05moo`00Kgoo0P0OBgoo0P0OHWoo001aOol201m7Ool2
01mTOol007=oo`807d9oo`<07fIoo`00MGoo0`0O>goo100OJGoo001hOol301leOol301m]Ool007]o
o`@07beoo`@07g1oo`00Ogoo1`0O8Woo100OM7oo0026Ool801lFOol401mhOol008iooaH07gaoo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.70433 .31159 m
.7215 .3314 L
s
.68578 .29307 m
.70433 .31159 L
s
.66596 .27593 m
.68578 .29307 L
s
.7215 .3314 m
.73719 .35237 L
s
.64498 .26029 m
.66596 .27593 L
s
.73719 .35237 m
.7513 .37438 L
s
.62297 .24624 m
.64498 .26029 L
s
.7513 .37438 m
.76374 .39731 L
s
.60005 .23387 m
.62297 .24624 L
s
.76374 .39731 m
.77443 .42102 L
s
.57635 .22326 m
.60005 .23387 L
s
.77443 .42102 m
.78329 .44537 L
s
.55202 .21449 m
.57635 .22326 L
s
.78329 .44537 m
.79026 .47023 L
s
.52719 .20764 m
.55202 .21449 L
s
.79026 .47023 m
.79528 .49544 L
s
.50202 .20275 m
.52719 .20764 L
s
.79528 .49544 m
.79829 .52084 L
s
.47666 .19988 m
.50202 .20275 L
s
.79829 .52084 m
.79927 .5463 L
s
.45126 .19907 m
.47666 .19988 L
s
.79927 .5463 m
.79817 .57163 L
s
.42599 .20034 m
.45126 .19907 L
s
.79817 .57163 m
.79498 .59668 L
s
.40102 .20373 m
.42599 .20034 L
s
.79498 .59668 m
.7897 .62128 L
s
.3765 .20923 m
.40102 .20373 L
s
.7897 .62128 m
.78232 .64527 L
s
.35262 .21683 m
.3765 .20923 L
s
.78232 .64527 m
.77287 .66846 L
s
.32954 .22653 m
.35262 .21683 L
s
.77287 .66846 m
.76139 .6907 L
s
.30744 .23828 m
.32954 .22653 L
s
.76139 .6907 m
.7479 .7118 L
s
.28648 .25203 m
.30744 .23828 L
s
.7479 .7118 m
.73249 .73161 L
s
.26683 .26772 m
.28648 .25203 L
s
.73249 .73161 m
.71523 .74996 L
s
.24867 .28527 m
.26683 .26772 L
s
.71523 .74996 m
.69622 .7667 L
s
.23213 .30457 m
.24867 .28527 L
s
.69622 .7667 m
.67556 .78166 L
s
.21738 .32552 m
.23213 .30457 L
s
.67556 .78166 m
.65339 .79472 L
s
.20456 .34798 m
.21738 .32552 L
s
.65339 .79472 m
.62985 .80574 L
s
.19379 .3718 m
.20456 .34798 L
s
.62985 .80574 m
.60511 .8146 L
s
.18519 .39682 m
.19379 .3718 L
s
.60511 .8146 m
.57933 .8212 L
s
.17886 .42285 m
.18519 .39682 L
s
.57933 .8212 m
.55271 .82545 L
s
.17489 .44971 m
.17886 .42285 L
s
.55271 .82545 m
.52546 .82729 L
s
.17334 .47717 m
.17489 .44971 L
s
.52546 .82729 m
.49778 .82667 L
s
.17425 .50503 m
.17334 .47717 L
s
.49778 .82667 m
.46991 .82357 L
s
.17765 .53306 m
.17425 .50503 L
s
.46991 .82357 m
.44207 .81798 L
s
.18352 .56103 m
.17765 .53306 L
s
.44207 .81798 m
.41449 .80993 L
s
.19185 .58868 m
.18352 .56103 L
s
.41449 .80993 m
.38742 .79947 L
s
.20259 .6158 m
.19185 .58868 L
s
.38742 .79947 m
.3611 .78665 L
s
.21565 .64214 m
.20259 .6158 L
s
.3611 .78665 m
.33574 .77159 L
s
.23094 .66747 m
.21565 .64214 L
s
.33574 .77159 m
.31158 .7544 L
s
.24833 .69156 m
.23094 .66747 L
s
.31158 .7544 m
.28883 .73522 L
s
.26768 .71421 m
.24833 .69156 L
s
.28883 .73522 m
.26768 .71421 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001gOolE01nDOol0079oo`D07aEoo`P07haoo`00
KWoo100O8Woo1@0OQgoo001[Ool301l[Ool401n3Ool006Moo`@07c9oo`<07h1oo`00I7oo0`0O>Goo
0P0OOWoo001ROol201lnOol201mlOol0061oo`807d9oo`<07gUoo`00GWoo0P0OAgoo0P0OMgoo001L
Ool201m;Ool201meOol005Yoo`807dmoo`807g=oo`00F7oo0P0ODgoo0P0OLGoo001FOol201mGOol2
01m_Ool005Eoo`0301moogoo05Uoo`807feoo`00Dgoo0P0OGWoo0P0OJgoo001BOol00`0OOomoo`1P
Ool201mYOol0051oo`807fEoo`807fMoo`00Cgoo00<07gooOol0Igoo00<07gooOol0I7oo001=Ool2
01m[Ool00`0OOomoo`1SOol004aoo`0301moogoo06aoo`0301moogoo069oo`00Bgoo00<07gooOol0
KWoo0P0OHWoo001:Ool00`0OOomoo`1aOol00`0OOomoo`1OOol004Uoo`0301moogoo07=oo`0301mo
ogoo05ioo`00B7oo00<07gooOol0MGoo00<07gooOol0GGoo0017Ool00`0OOomoo`1gOol00`0OOomo
o`1LOol004Ioo`0301moogoo07Uoo`0301moogoo05]oo`00AGoo00<07gooOol0Ngoo00<07gooOol0
FWoo0014Ool00`0OOomoo`1mOol00`0OOomoo`1IOol004Aoo`0301moogoo07ioo`0301moogoo05Qo
o`00@goo00<07gooOol0P7oo00<07gooOol0Egoo0012Ool00`0OOomoo`22Ool201mGOol0045oo`03
01moogoo08Eoo`0301moogoo05Aoo`00@Goo00<07gooOol0QWoo00<07gooOol0Dgoo0010Ool00`0O
Oomoo`28Ool00`0OOomoo`1BOol003moo`0301moogoo08Yoo`0301moogoo055oo`00?goo00<07goo
Ool0RWoo00<07gooOol0DGoo000nOol00`0OOomoo`2<Ool00`0OOomoo`1@Ool003eoo`0301moogoo
08ioo`0301moogoo04moo`00?Goo00<07gooOol0Sgoo00<07gooOol0CWoo000lOol00`0OOomoo`2A
Ool00`0OOomoo`1=Ool003]oo`0301moogoo099oo`0301moogoo04eoo`00>goo00<07gooOol0Tgoo
00<07gooOol0C7oo000jOol00`0OOomoo`2EOol00`0OOomoo`1;Ool003Yoo`0301moogoo09Eoo`03
01moogoo04]oo`00>Goo00<07gooOol0Ugoo00<07gooOol0BWoo000iOol00`0OOomoo`2HOol00`0O
Oomoo`19Ool003Qoo`0301moogoo09Uoo`0301moogoo04Uoo`00>7oo00<07gooOol0VWoo00<07goo
Ool0B7oo000gOol00`0OOomoo`2LOol00`0OOomoo`17Ool003Moo`0301moogoo09aoo`0301moogoo
04Moo`00=goo00<07gooOol0WGoo00<07gooOol0AWoo000fOol00`0OOomoo`2OOol00`0OOomoo`15
Ool003Ioo`0301moogoo09moo`0301moogoo04Eoo`00=Woo00<07gooOol0X7oo00<07gooOol0A7oo
000fOol00`0OOomoo`2POol00`0OOomoo`14Ool003Eoo`0301moogoo0:9oo`0301moogoo04=oo`00
=Goo00<07gooOol0XWoo00<07gooOol0@goo000eOol00`0OOomoo`2SOol00`0OOomoo`12Ool003Ao
o`0301moogoo0:Aoo`0301moogoo049oo`00=7oo00<07gooOol0YGoo00<07gooOol0@Goo000dOol0
0`0OOomoo`2UOol00`0OOomoo`11Ool003Aoo`0301moogoo0:Ioo`0301moogoo041oo`00<goo00<0
7gooOol0Ygoo00<07gooOol0@7oo000cOol00`0OOomoo`2XOol00`0OOomoo`0oOol003=oo`0301mo
ogoo0:Qoo`0301moogoo03moo`00<goo00<07gooOol0ZGoo00<07gooOol0?Woo000cOol00`0OOomo
o`2YOol00`0OOomoo`0nOol003=oo`0301moogoo0:Uoo`0301moogoo03ioo`00<Woo00<07gooOol0
ZWoo00<07gooOol0?Woo000bOol00`0OOomoo`2[Ool00`0OOomoo`0mOol0039oo`0301moogoo0:]o
o`0301moogoo03eoo`00<Woo00<07gooOol0Zgoo00<07gooOol0?Goo000bOol00`0OOomoo`2/Ool0
0`0OOomoo`0lOol0039oo`0301moogoo0:aoo`0301moogoo03aoo`00<Woo00<07gooOol0[7oo00<0
7gooOol0?7oo000bOol00`0OOomoo`2/Ool00`0OOomoo`0lOol0035oo`0301moogoo0:ioo`0301mo
ogoo03]oo`00<Goo00<07gooOol0[Woo00<07gooOol0>goo000aOol00`0OOomoo`2^Ool00`0OOomo
o`0kOol0035oo`0301moogoo0:ioo`0301moogoo03]oo`00<Goo00<07gooOol0[goo00<07gooOol0
>Woo000aOol00`0OOomoo`2_Ool00`0OOomoo`0jOol0035oo`0301moogoo0:moo`0301moogoo03Yo
o`00<Goo00<07gooOol0[goo00<07gooOol0>Woo000bOol00`0OOomoo`2_Ool00`0OOomoo`0iOol0
039oo`0301moogoo0:moo`0301moogoo03Uoo`00<Woo00<07gooOol0[goo00<07gooOol0>Goo000b
Ool00`0OOomoo`2_Ool00`0OOomoo`0iOol0039oo`0301moogoo0:moo`0301moogoo03Uoo`00<Woo
00<07gooOol0/7oo00<07gooOol0>7oo000bOol00`0OOomoo`2`Ool00`0OOomoo`0hOol0039oo`03
01moogoo0;1oo`0301moogoo03Qoo`00<Woo00<07gooOol0/7oo00<07gooOol0>7oo000bOol00`0O
Oomoo`2`Ool00`0OOomoo`0hOol0039oo`0301moogoo0;1oo`0301moogoo03Qoo`00<Woo00<07goo
Ool0/7oo00<07gooOol0>7oo000bOol00`0OOomoo`2`Ool00`0OOomoo`0hOol0039oo`0301moogoo
0;1oo`0301moogoo03Qoo`00<goo00<07gooOol0[goo00<07gooOol0>7oo000cOol00`0OOomoo`2_
Ool00`0OOomoo`0hOol003=oo`0301moogoo0:moo`0301moogoo03Qoo`00<goo00<07gooOol0[goo
00<07gooOol0>7oo000dOol00`0OOomoo`2^Ool00`0OOomoo`0hOol003Aoo`0301moogoo0:ioo`03
01moogoo03Qoo`00=7oo00<07gooOol0[Woo00<07gooOol0>7oo000dOol00`0OOomoo`2^Ool00`0O
Oomoo`0hOol003Eoo`0301moogoo0:eoo`0301moogoo03Qoo`00=Goo00<07gooOol0[Goo00<07goo
Ool0>7oo000fOol00`0OOomoo`2/Ool00`0OOomoo`0hOol003Ioo`0301moogoo0:aoo`0301moogoo
03Qoo`00=goo00<07gooOol0Zgoo00<07gooOol0>7oo000gOol00`0OOomoo`2ZOol00`0OOomoo`0i
Ool003Moo`0301moogoo0:Yoo`0301moogoo03Uoo`00>7oo00<07gooOol0ZGoo00<07gooOol0>Goo
000hOol00`0OOomoo`2YOol00`0OOomoo`0iOol003Qoo`0301moogoo0:Uoo`0301moogoo03Uoo`00
>Goo00<07gooOol0Ygoo00<07gooOol0>Woo000iOol00`0OOomoo`2WOol00`0OOomoo`0jOol003Yo
o`0301moogoo0:Ioo`0301moogoo03Yoo`00>Woo00<07gooOol0YWoo00<07gooOol0>Woo000jOol0
0`0OOomoo`2UOol00`0OOomoo`0kOol003]oo`0301moogoo0:Aoo`0301moogoo03]oo`00>goo00<0
7gooOol0Y7oo00<07gooOol0>goo000kOol00`0OOomoo`2SOol00`0OOomoo`0lOol003aoo`0301mo
ogoo0:9oo`0301moogoo03aoo`00?7oo00<07gooOol0XWoo00<07gooOol0?7oo000mOol00`0OOomo
o`2QOol00`0OOomoo`0lOol003eoo`0301moogoo0:1oo`0301moogoo03eoo`00?Woo00<07gooOol0
Wgoo00<07gooOol0?Goo000nOol00`0OOomoo`2NOol00`0OOomoo`0nOol003moo`0301moogoo09eo
o`0301moogoo03ioo`00@7oo00<07gooOol0Vgoo00<07gooOol0?goo0011Ool00`0OOomoo`2JOol0
0`0OOomoo`0oOol0045oo`0301moogoo09Uoo`0301moogoo041oo`00@Woo00<07gooOol0V7oo00<0
7gooOol0@7oo0013Ool00`0OOomoo`2GOol00`0OOomoo`10Ool004=oo`0301moogoo09Ioo`0301mo
ogoo045oo`00A7oo00<07gooOol0UGoo00<07gooOol0@Goo0015Ool00`0OOomoo`2COol00`0OOomo
o`12Ool004Ioo`0301moogoo099oo`0301moogoo049oo`00AWoo00<07gooOol0TGoo00<07gooOol0
@goo0017Ool00`0OOomoo`2@Ool00`0OOomoo`13Ool004Qoo`0301moogoo08ioo`0301moogoo04Ao
o`00BGoo00<07gooOol0SGoo00<07gooOol0A7oo0019Ool00`0OOomoo`2<Ool00`0OOomoo`15Ool0
04Yoo`0301moogoo08Yoo`0301moogoo04Ioo`00Bgoo00<07gooOol0RGoo00<07gooOol0AWoo001<
Ool00`0OOomoo`27Ool00`0OOomoo`17Ool004eoo`0301moogoo08Eoo`0301moogoo04Qoo`00CWoo
00<07gooOol0Pgoo00<07gooOol0BGoo001?Ool00`0OOomoo`22Ool00`0OOomoo`19Ool004moo`03
01moogoo085oo`0301moogoo04Yoo`00D7oo00<07gooOol0Ogoo00<07gooOol0Bgoo001AOol00`0O
Oomoo`1mOol00`0OOomoo`1<Ool0059oo`0301moogoo07]oo`0301moogoo04eoo`00Dgoo0P0ONWoo
00<07gooOol0CWoo001EOol00`0OOomoo`1gOol00`0OOomoo`1>Ool005Ioo`0301moogoo07Eoo`03
01moogoo04moo`00Egoo0P0OM7oo00<07gooOol0D7oo001IOol00`0OOomoo`1`Ool00`0OOomoo`1A
Ool005Yoo`807fmoo`0301moogoo059oo`00G7oo00<07gooOol0JWoo0P0OEGoo001MOol00`0OOomo
o`1XOol00`0OOomoo`1EOol005ioo`807fMoo`0301moogoo05Ioo`00H7oo00<07gooOol0HWoo0P0O
FGoo001QOol201mQOol00`0OOomoo`1IOol006=oo`807eeoo`807eaoo`00IGoo0P0OFWoo00<07goo
Ool0G7oo001WOol00`0OOomoo`1EOol201mOOol006Qoo`807eAoo`0301moogoo05moo`00JWoo0P0O
D7oo0P0OHWoo001/Ool201m<Ool201mTOol006ioo`<07dMoo`807fIoo`00LGoo0P0O@goo0P0OJ7oo
001cOol201lnOol301mZOol007Eoo`<07cMoo`@07feoo`00N7oo100O<7oo0`0OLGoo001lOol401lX
Ool401mdOol0081oo`@07amoo`D07gQoo`00Q7oo1P0O4Goo200OOGoo002:OolA01n5Ool00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.7272 .33104 m
.74197 .35276 L
s
.71088 .31047 m
.7272 .33104 L
s
.74197 .35276 m
.7551 .37549 L
s
.69311 .29116 m
.71088 .31047 L
s
.7551 .37549 m
.76652 .39911 L
s
.67399 .27323 m
.69311 .29116 L
s
.76652 .39911 m
.77615 .42346 L
s
.65364 .25681 m
.67399 .27323 L
s
.77615 .42346 m
.78392 .44841 L
s
.63216 .24199 m
.65364 .25681 L
s
.78392 .44841 m
.78978 .4738 L
s
.60969 .22887 m
.63216 .24199 L
s
.78978 .4738 m
.79368 .49949 L
s
.58636 .21755 m
.60969 .22887 L
s
.79368 .49949 m
.79558 .52532 L
s
.56229 .2081 m
.58636 .21755 L
s
.79558 .52532 m
.79546 .55113 L
s
.53764 .20062 m
.56229 .2081 L
s
.79546 .55113 m
.79329 .57676 L
s
.51256 .19516 m
.53764 .20062 L
s
.79329 .57676 m
.78907 .60205 L
s
.4872 .19178 m
.51256 .19516 L
s
.78907 .60205 m
.7828 .62682 L
s
.46172 .19052 m
.4872 .19178 L
s
.7828 .62682 m
.77449 .65091 L
s
.43629 .19143 m
.46172 .19052 L
s
.77449 .65091 m
.76418 .67415 L
s
.41108 .19453 m
.43629 .19143 L
s
.76418 .67415 m
.75191 .69637 L
s
.38625 .19982 m
.41108 .19453 L
s
.75191 .69637 m
.73773 .71742 L
s
.362 .20729 m
.38625 .19982 L
s
.73773 .71742 m
.72171 .73712 L
s
.33849 .21695 m
.362 .20729 L
s
.72171 .73712 m
.70393 .75532 L
s
.3159 .22873 m
.33849 .21695 L
s
.70393 .75532 m
.68451 .77187 L
s
.29441 .2426 m
.3159 .22873 L
s
.68451 .77187 m
.66354 .78661 L
s
.27419 .25849 m
.29441 .2426 L
s
.66354 .78661 m
.64117 .79942 L
s
.25541 .2763 m
.27419 .25849 L
s
.64117 .79942 m
.61753 .81017 L
s
.23824 .29594 m
.25541 .2763 L
s
.61753 .81017 m
.59279 .81875 L
s
.22283 .31729 m
.23824 .29594 L
s
.59279 .81875 m
.56711 .82505 L
s
.20932 .34019 m
.22283 .31729 L
s
.56711 .82505 m
.54069 .82899 L
s
.19786 .36451 m
.20932 .34019 L
s
.54069 .82899 m
.51373 .83052 L
s
.18855 .39005 m
.19786 .36451 L
s
.51373 .83052 m
.48642 .82958 L
s
.1815 .41664 m
.18855 .39005 L
s
.48642 .82958 m
.45899 .82615 L
s
.1768 .44407 m
.1815 .41664 L
s
.45899 .82615 m
.43166 .82023 L
s
.17451 .47212 m
.1768 .44407 L
s
.43166 .82023 m
.40466 .81185 L
s
.17468 .50056 m
.17451 .47212 L
s
.40466 .81185 m
.37821 .80104 L
s
.17733 .52917 m
.17468 .50056 L
s
.37821 .80104 m
.35254 .78787 L
s
.18245 .55771 m
.17733 .52917 L
s
.35254 .78787 m
.32788 .77245 L
s
.19002 .58592 m
.18245 .55771 L
s
.32788 .77245 m
.30444 .75488 L
s
.2 .61357 m
.19002 .58592 L
s
.30444 .75488 m
.28243 .7353 L
s
.21229 .64042 m
.2 .61357 L
s
.28243 .7353 m
.26203 .71388 L
s
.22682 .66623 m
.21229 .64042 L
s
.26203 .71388 m
.24344 .69079 L
s
.24344 .69079 m
.22682 .66623 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo001jOol>01nHOol007Aoo`H07`ioo`L07i5oo`00L7oo100O6goo200ORGoo001]Ool301lW
Ool501n4Ool006Uoo`@07bmoo`@07h1oo`00Igoo0P0O=goo0`0OOGoo001UOol201llOol201mkOol0
06=oo`807d1oo`807gUoo`00H7oo0`0OA7oo0P0OMgoo001NOol201m9Ool201meOol005aoo`807deo
o`807g=oo`00FWoo0P0ODGoo0P0OLGoo001HOol201mEOol201m_Ool005Moo`0301moogoo05Moo`80
7feoo`00EGoo0P0OG7oo0P0OJgoo001DOol00`0OOomoo`1NOol00`0OOomoo`1XOol005=oo`0301mo
ogoo061oo`807fQoo`00DWoo00<07gooOol0Hgoo00<07gooOol0IGoo001@Ool201mWOol201mUOol0
04moo`0301moogoo06Uoo`0301moogoo069oo`00CWoo00<07gooOol0Jgoo00<07gooOol0HGoo001=
Ool00`0OOomoo`1]Ool00`0OOomoo`1POol004aoo`0301moogoo06moo`807f1oo`00Bgoo00<07goo
Ool0LWoo00<07gooOol0GGoo001:Ool00`0OOomoo`1dOol00`0OOomoo`1LOol004Uoo`0301moogoo
07Ioo`0301moogoo05]oo`00B7oo00<07gooOol0N7oo00<07gooOol0FWoo0017Ool00`0OOomoo`1j
Ool00`0OOomoo`1IOol004Ioo`0301moogoo07aoo`0301moogoo05Qoo`00AGoo00<07gooOol0OWoo
00<07gooOol0Egoo0014Ool00`0OOomoo`20Ool00`0OOomoo`1FOol004=oo`0301moogoo089oo`03
01moogoo05Eoo`00@goo00<07gooOol0Pgoo00<07gooOol0E7oo0012Ool00`0OOomoo`25Ool00`0O
Oomoo`1COol0045oo`0301moogoo08Moo`0301moogoo059oo`00@7oo00<07gooOol0RGoo00<07goo
Ool0DGoo0010Ool00`0OOomoo`2:Ool00`0OOomoo`1@Ool003moo`0301moogoo08]oo`0301moogoo
051oo`00?Woo00<07gooOol0SGoo00<07gooOol0Cgoo000nOol00`0OOomoo`2>Ool00`0OOomoo`1>
Ool003eoo`0301moogoo08moo`0301moogoo04ioo`00?Goo00<07gooOol0T7oo00<07gooOol0CGoo
000lOol00`0OOomoo`2BOol00`0OOomoo`1<Ool003aoo`0301moogoo099oo`0301moogoo04aoo`00
>goo00<07gooOol0U7oo00<07gooOol0Bgoo000kOol00`0OOomoo`2EOol00`0OOomoo`1:Ool003Yo
o`0301moogoo09Ioo`0301moogoo04Yoo`00>Woo00<07gooOol0Ugoo00<07gooOol0BGoo000iOol0
0`0OOomoo`2IOol00`0OOomoo`18Ool003Uoo`0301moogoo09Uoo`0301moogoo04Qoo`00>7oo00<0
7gooOol0Vgoo00<07gooOol0Agoo000hOol00`0OOomoo`2LOol00`0OOomoo`16Ool003Moo`0301mo
ogoo09eoo`0301moogoo04Ioo`00=goo00<07gooOol0WWoo00<07gooOol0AGoo000gOol00`0OOomo
o`2NOol00`0OOomoo`15Ool003Moo`0301moogoo09moo`0301moogoo04Aoo`00=Woo00<07gooOol0
X7oo00<07gooOol0A7oo000fOol00`0OOomoo`2QOol00`0OOomoo`13Ool003Ioo`0301moogoo0:5o
o`0301moogoo04=oo`00=Goo00<07gooOol0Xgoo00<07gooOol0@Woo000eOol00`0OOomoo`2SOol0
0`0OOomoo`12Ool003Eoo`0301moogoo0:=oo`0301moogoo049oo`00=Goo00<07gooOol0Y7oo00<0
7gooOol0@Goo000dOol00`0OOomoo`2UOol00`0OOomoo`11Ool003Aoo`0301moogoo0:Ioo`0301mo
ogoo041oo`00=7oo00<07gooOol0YWoo00<07gooOol0@7oo000dOol00`0OOomoo`2WOol00`0OOomo
o`0oOol003=oo`0301moogoo0:Qoo`0301moogoo03moo`00<goo00<07gooOol0Z7oo00<07gooOol0
?goo000cOol00`0OOomoo`2YOol00`0OOomoo`0nOol003=oo`0301moogoo0:Uoo`0301moogoo03io
o`00<Woo00<07gooOol0ZWoo00<07gooOol0?Woo000bOol00`0OOomoo`2ZOol00`0OOomoo`0nOol0
039oo`0301moogoo0:]oo`0301moogoo03eoo`00<Woo00<07gooOol0Zgoo00<07gooOol0?Goo000b
Ool00`0OOomoo`2[Ool00`0OOomoo`0mOol0039oo`0301moogoo0:aoo`0301moogoo03aoo`00<Woo
00<07gooOol0[7oo00<07gooOol0?7oo000bOol00`0OOomoo`2/Ool00`0OOomoo`0lOol0039oo`03
01moogoo0:aoo`0301moogoo03aoo`00<Woo00<07gooOol0[Goo00<07gooOol0>goo000bOol00`0O
Oomoo`2]Ool00`0OOomoo`0kOol0039oo`0301moogoo0:eoo`0301moogoo03]oo`00<Woo00<07goo
Ool0[Goo00<07gooOol0>goo000bOol00`0OOomoo`2]Ool00`0OOomoo`0kOol0039oo`0301moogoo
0:eoo`0301moogoo03]oo`00<Woo00<07gooOol0[Woo00<07gooOol0>Woo000bOol00`0OOomoo`2^
Ool00`0OOomoo`0jOol0039oo`0301moogoo0:ioo`0301moogoo03Yoo`00<Woo00<07gooOol0[Woo
00<07gooOol0>Woo000bOol00`0OOomoo`2^Ool00`0OOomoo`0jOol0039oo`0301moogoo0:ioo`03
01moogoo03Yoo`00<Woo00<07gooOol0[Woo00<07gooOol0>Woo000bOol00`0OOomoo`2_Ool00`0O
Oomoo`0iOol0039oo`0301moogoo0:moo`0301moogoo03Uoo`00<Woo00<07gooOol0[goo00<07goo
Ool0>Goo000bOol00`0OOomoo`2_Ool00`0OOomoo`0iOol0039oo`0301moogoo0:moo`0301moogoo
03Uoo`00<Woo00<07gooOol0[goo00<07gooOol0>Goo000bOol00`0OOomoo`2_Ool00`0OOomoo`0i
Ool003=oo`0301moogoo0:ioo`0301moogoo03Uoo`00<goo00<07gooOol0[Woo00<07gooOol0>Goo
000cOol00`0OOomoo`2^Ool00`0OOomoo`0iOol003=oo`0301moogoo0:ioo`0301moogoo03Uoo`00
=7oo00<07gooOol0[Goo00<07gooOol0>Goo000dOol00`0OOomoo`2]Ool00`0OOomoo`0iOol003Ao
o`0301moogoo0:eoo`0301moogoo03Uoo`00=7oo00<07gooOol0[Goo00<07gooOol0>Goo000dOol0
0`0OOomoo`2/Ool00`0OOomoo`0jOol003Eoo`0301moogoo0:]oo`0301moogoo03Yoo`00=Goo00<0
7gooOol0Zgoo00<07gooOol0>Woo000eOol00`0OOomoo`2[Ool00`0OOomoo`0jOol003Eoo`0301mo
ogoo0:]oo`0301moogoo03Yoo`00=Woo00<07gooOol0ZWoo00<07gooOol0>Woo000fOol00`0OOomo
o`2ZOol00`0OOomoo`0jOol003Ioo`0301moogoo0:Uoo`0301moogoo03]oo`00=goo00<07gooOol0
Z7oo00<07gooOol0>goo000gOol00`0OOomoo`2XOol00`0OOomoo`0kOol003Moo`0301moogoo0:Qo
o`0301moogoo03]oo`00>7oo00<07gooOol0Ygoo00<07gooOol0>goo000hOol00`0OOomoo`2VOol0
0`0OOomoo`0lOol003Uoo`0301moogoo0:Eoo`0301moogoo03aoo`00>Goo00<07gooOol0YGoo00<0
7gooOol0?7oo000iOol00`0OOomoo`2UOol00`0OOomoo`0lOol003Yoo`0301moogoo0:=oo`0301mo
ogoo03eoo`00>Woo00<07gooOol0Xgoo00<07gooOol0?Goo000kOol00`0OOomoo`2ROol00`0OOomo
o`0mOol003]oo`0301moogoo0:5oo`0301moogoo03ioo`00?7oo00<07gooOol0X7oo00<07gooOol0
?Woo000lOol00`0OOomoo`2POol00`0OOomoo`0nOol003eoo`0301moogoo09moo`0301moogoo03io
o`00?Goo00<07gooOol0WWoo00<07gooOol0?goo000nOol00`0OOomoo`2MOol00`0OOomoo`0oOol0
03ioo`0301moogoo09eoo`0301moogoo03moo`00?goo00<07gooOol0Vgoo00<07gooOol0@7oo0010
Ool00`0OOomoo`2JOol00`0OOomoo`10Ool0041oo`0301moogoo09Uoo`0301moogoo045oo`00@Goo
00<07gooOol0V7oo00<07gooOol0@Goo0012Ool00`0OOomoo`2FOol00`0OOomoo`12Ool0049oo`03
01moogoo09Ioo`0301moogoo049oo`00@goo00<07gooOol0U7oo00<07gooOol0@goo0013Ool00`0O
Oomoo`2DOol00`0OOomoo`13Ool004Aoo`0301moogoo099oo`0301moogoo04Aoo`00A7oo00<07goo
Ool0TGoo00<07gooOol0AGoo0015Ool00`0OOomoo`2@Ool00`0OOomoo`15Ool004Ioo`0301moogoo
08ioo`0301moogoo04Ioo`00Agoo00<07gooOol0S7oo00<07gooOol0Agoo0018Ool00`0OOomoo`2;
Ool00`0OOomoo`17Ool004Uoo`0301moogoo08Uoo`0301moogoo04Qoo`00BWoo00<07gooOol0Qgoo
00<07gooOol0BGoo001;Ool00`0OOomoo`26Ool00`0OOomoo`19Ool004aoo`0301moogoo08Aoo`03
01moogoo04Yoo`00CGoo00<07gooOol0PWoo00<07gooOol0Bgoo001>Ool00`0OOomoo`21Ool00`0O
Oomoo`1;Ool004ioo`0301moogoo081oo`0301moogoo04aoo`00Cgoo00<07gooOol0OWoo00<07goo
Ool0CGoo001@Ool00`0OOomoo`1mOol00`0OOomoo`1=Ool0055oo`0301moogoo07]oo`0301moogoo
04ioo`00DWoo00<07gooOol0NGoo00<07gooOol0Cgoo001COol00`0OOomoo`1gOol00`0OOomoo`1@
Ool005Aoo`807gIoo`0301moogoo055oo`00EWoo00<07gooOol0LWoo00<07gooOol0DWoo001GOol0
0`0OOomoo`1`Ool00`0OOomoo`1COol005Qoo`807fmoo`0301moogoo05Aoo`00FWoo00<07gooOol0
Jgoo00<07gooOol0EGoo001KOol00`0OOomoo`1XOol201mHOol005aoo`807fMoo`0301moogoo05Qo
o`00GWoo00<07gooOol0Hgoo00<07gooOol0FGoo001OOol201mQOol201mLOol0065oo`0301moogoo
05eoo`0301moogoo05aoo`00HWoo00<07gooOol0FWoo0P0OGgoo001SOol201mIOol00`0OOomoo`1O
Ool006Eoo`807eEoo`807f9oo`00Igoo0P0ODWoo00<07gooOol0HWoo001YOol201m>Ool201mUOol0
06]oo`<07dUoo`807fMoo`00KWoo0P0OAGoo0P0OJGoo001`Ool301m0Ool201m[Ool007=oo`<07cYo
o`<07feoo`00MWoo0P0O=7oo100OL7oo001hOol201l_Ool301mdOol007Yoo`<07bQoo`@07gMoo`00
OGoo100O7Woo1P0ONgoo0021Ool601lAOol701n1Ool008Mooa407hQoo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.75803 .37764 m
.76835 .40179 L
s
.74596 .35432 m
.75803 .37764 L
s
.76835 .40179 m
.77684 .42662 L
s
.7322 .33197 m
.74596 .35432 L
s
.77684 .42662 m
.78347 .452 L
s
.71684 .31073 m
.7322 .33197 L
s
.78347 .452 m
.78817 .47775 L
s
.69995 .29073 m
.71684 .31073 L
s
.78817 .47775 m
.79093 .50374 L
s
.68165 .27209 m
.69995 .29073 L
s
.79093 .50374 m
.7917 .52981 L
s
.66203 .25494 m
.68165 .27209 L
s
.7917 .52981 m
.79047 .55579 L
s
.6412 .23938 m
.66203 .25494 L
s
.79047 .55579 m
.78724 .58153 L
s
.61929 .22554 m
.6412 .23938 L
s
.78724 .58153 m
.782 .60685 L
s
.59641 .21351 m
.61929 .22554 L
s
.782 .60685 m
.77477 .63161 L
s
.57271 .20339 m
.59641 .21351 L
s
.77477 .63161 m
.76558 .65563 L
s
.54833 .19526 m
.57271 .20339 L
s
.76558 .65563 m
.75447 .67874 L
s
.52342 .18919 m
.54833 .19526 L
s
.75447 .67874 m
.74147 .7008 L
s
.49814 .18525 m
.52342 .18919 L
s
.74147 .7008 m
.72667 .72164 L
s
.47264 .1835 m
.49814 .18525 L
s
.72667 .72164 m
.71012 .7411 L
s
.4471 .18397 m
.47264 .1835 L
s
.71012 .7411 m
.69192 .75903 L
s
.4217 .1867 m
.4471 .18397 L
s
.69192 .75903 m
.67217 .77528 L
s
.3966 .1917 m
.4217 .1867 L
s
.67217 .77528 m
.65099 .78972 L
s
.372 .19896 m
.3966 .1917 L
s
.65099 .78972 m
.6285 .80221 L
s
.34807 .20847 m
.372 .19896 L
s
.6285 .80221 m
.60485 .81264 L
s
.325 .2202 m
.34807 .20847 L
s
.60485 .81264 m
.5802 .82089 L
s
.30298 .23409 m
.325 .2202 L
s
.5802 .82089 m
.55471 .82687 L
s
.28218 .25007 m
.30298 .23409 L
s
.55471 .82687 m
.52857 .83051 L
s
.26279 .26805 m
.28218 .25007 L
s
.52857 .83051 m
.50196 .83173 L
s
.24496 .28792 m
.26279 .26805 L
s
.50196 .83173 m
.47509 .8305 L
s
.22887 .30955 m
.24496 .28792 L
s
.47509 .8305 m
.44817 .8268 L
s
.21466 .3328 m
.22887 .30955 L
s
.44817 .8268 m
.4214 .82061 L
s
.20247 .35749 m
.21466 .3328 L
s
.4214 .82061 m
.39502 .81196 L
s
.19243 .38346 m
.20247 .35749 L
s
.39502 .81196 m
.36923 .80089 L
s
.18464 .41049 m
.19243 .38346 L
s
.36923 .80089 m
.34425 .78746 L
s
.17919 .43838 m
.18464 .41049 L
s
.34425 .78746 m
.32031 .77177 L
s
.17614 .4669 m
.17919 .43838 L
s
.32031 .77177 m
.29761 .75393 L
s
.17555 .49582 m
.17614 .4669 L
s
.29761 .75393 m
.27636 .73406 L
s
.17743 .5249 m
.17555 .49582 L
s
.27636 .73406 m
.25673 .71234 L
s
.18179 .55389 m
.17743 .5249 L
s
.25673 .71234 m
.23891 .68893 L
s
.18859 .58254 m
.18179 .55389 L
s
.23891 .68893 m
.22306 .66403 L
s
.19779 .6106 m
.18859 .58254 L
s
.22306 .66403 m
.20931 .63785 L
s
.20931 .63785 m
.19779 .6106 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol007eoo`h07iEo
o`00N7oo1@0O3Woo1`0OSWoo001dOol401lJOol601n8Ool0071oo`@07bAoo`@07hAoo`00K7oo100O
;7oo0`0OPGoo001YOol301lcOol401mmOol006Eoo`@07cYoo`<07gYoo`00Hgoo0P0O@Goo0P0ON7oo
001QOol201m5Ool201mfOol0061oo`0301moogoo04Moo`807gAoo`00GWoo0P0OC7oo0P0OLWoo001M
Ool00`0OOomoo`1>Ool201m`Ool005]oo`807e=oo`807fioo`00FGoo0P0OEgoo0P0OK7oo001GOol2
01mKOol201mZOol005Ioo`0301moogoo05eoo`807fQoo`00E7oo0P0OHWoo00<07gooOol0IGoo001C
Ool00`0OOomoo`1SOol00`0OOomoo`1TOol0055oo`807fMoo`0301moogoo06=oo`00D7oo00<07goo
Ool0J7oo0P0OHgoo001?Ool00`0OOomoo`1[Ool00`0OOomoo`1POol004ioo`0301moogoo06eoo`03
01moogoo05moo`00CGoo00<07gooOol0Kgoo00<07gooOol0GWoo001<Ool00`0OOomoo`1aOol00`0O
Oomoo`1MOol004]oo`0301moogoo07=oo`0301moogoo05aoo`00BWoo00<07gooOol0MGoo00<07goo
Ool0Fgoo0019Ool00`0OOomoo`1gOol00`0OOomoo`1JOol004Qoo`0301moogoo07Uoo`0301moogoo
05Uoo`00B7oo00<07gooOol0NWoo00<07gooOol0F7oo0017Ool00`0OOomoo`1lOol00`0OOomoo`1G
Ool004Ioo`0301moogoo07ioo`0301moogoo05Ioo`00AGoo00<07gooOol0P7oo00<07gooOol0EGoo
0014Ool00`0OOomoo`22Ool00`0OOomoo`1DOol004=oo`0301moogoo08Aoo`0301moogoo05=oo`00
@goo00<07gooOol0Q7oo00<07gooOol0Dgoo0012Ool00`0OOomoo`26Ool00`0OOomoo`1BOol0045o
o`0301moogoo08Qoo`0301moogoo055oo`00@7oo00<07gooOol0RWoo00<07gooOol0D7oo0010Ool0
0`0OOomoo`2;Ool00`0OOomoo`1?Ool003moo`0301moogoo08eoo`0301moogoo04ioo`00?goo00<0
7gooOol0SGoo00<07gooOol0CWoo000nOol00`0OOomoo`2?Ool00`0OOomoo`1=Ool003ioo`0301mo
ogoo091oo`0301moogoo04aoo`00?Goo00<07gooOol0TWoo00<07gooOol0Bgoo000mOol00`0OOomo
o`2COol00`0OOomoo`1:Ool003aoo`0301moogoo09Aoo`0301moogoo04Yoo`00?7oo00<07gooOol0
UGoo00<07gooOol0BGoo000kOol00`0OOomoo`2GOol00`0OOomoo`18Ool003]oo`0301moogoo09Mo
o`0301moogoo04Qoo`00>Woo00<07gooOol0VGoo00<07gooOol0Agoo000jOol00`0OOomoo`2IOol0
0`0OOomoo`17Ool003Yoo`0301moogoo09Yoo`0301moogoo04Ioo`00>Goo00<07gooOol0Vgoo00<0
7gooOol0AWoo000iOol00`0OOomoo`2LOol00`0OOomoo`15Ool003Qoo`0301moogoo09eoo`0301mo
ogoo04Eoo`00>7oo00<07gooOol0WWoo00<07gooOol0A7oo000hOol00`0OOomoo`2NOol00`0OOomo
o`14Ool003Moo`0301moogoo09moo`0301moogoo04Aoo`00=goo00<07gooOol0X7oo00<07gooOol0
@goo000gOol00`0OOomoo`2POol00`0OOomoo`13Ool003Ioo`0301moogoo0:9oo`0301moogoo049o
o`00=Woo00<07gooOol0XWoo00<07gooOol0@Woo000eOol00`0OOomoo`2TOol00`0OOomoo`11Ool0
03Eoo`0301moogoo0:Aoo`0301moogoo045oo`00=7oo00<07gooOol0YGoo00<07gooOol0@Goo000d
Ool00`0OOomoo`2VOol00`0OOomoo`10Ool003Aoo`0301moogoo0:Ioo`0301moogoo041oo`00=7oo
00<07gooOol0YWoo00<07gooOol0@7oo000dOol00`0OOomoo`2VOol00`0OOomoo`10Ool003=oo`03
01moogoo0:Qoo`0301moogoo03moo`00<goo00<07gooOol0Z7oo00<07gooOol0?goo000cOol00`0O
Oomoo`2XOol00`0OOomoo`0oOol003=oo`0301moogoo0:Uoo`0301moogoo03ioo`00<goo00<07goo
Ool0ZGoo00<07gooOol0?Woo000cOol00`0OOomoo`2YOol00`0OOomoo`0nOol003=oo`0301moogoo
0:Uoo`0301moogoo03ioo`00<goo00<07gooOol0ZWoo00<07gooOol0?Goo000bOol00`0OOomoo`2[
Ool00`0OOomoo`0mOol0039oo`0301moogoo0:]oo`0301moogoo03eoo`00<Woo00<07gooOol0Zgoo
00<07gooOol0?Goo000bOol00`0OOomoo`2/Ool00`0OOomoo`0lOol0039oo`0301moogoo0:aoo`03
01moogoo03aoo`00<Woo00<07gooOol0[7oo00<07gooOol0?7oo000bOol00`0OOomoo`2/Ool00`0O
Oomoo`0lOol0039oo`0301moogoo0:eoo`0301moogoo03]oo`00<Woo00<07gooOol0[Goo00<07goo
Ool0>goo000bOol00`0OOomoo`2]Ool00`0OOomoo`0kOol0039oo`0301moogoo0:eoo`0301moogoo
03]oo`00<Woo00<07gooOol0[Goo00<07gooOol0>goo000bOol00`0OOomoo`2]Ool00`0OOomoo`0k
Ool0039oo`0301moogoo0:eoo`0301moogoo03]oo`00<Woo00<07gooOol0[Goo00<07gooOol0>goo
000bOol00`0OOomoo`2]Ool00`0OOomoo`0kOol0039oo`0301moogoo0:eoo`0301moogoo03]oo`00
<Woo00<07gooOol0[Goo00<07gooOol0>goo000bOol00`0OOomoo`2]Ool00`0OOomoo`0kOol0039o
o`0301moogoo0:eoo`0301moogoo03]oo`00<Woo00<07gooOol0[Woo00<07gooOol0>Woo000bOol0
0`0OOomoo`2^Ool00`0OOomoo`0jOol0039oo`0301moogoo0:ioo`0301moogoo03Yoo`00<Woo00<0
7gooOol0[Woo00<07gooOol0>Woo000cOol00`0OOomoo`2]Ool00`0OOomoo`0jOol003=oo`0301mo
ogoo0:eoo`0301moogoo03Yoo`00<goo00<07gooOol0[Goo00<07gooOol0>Woo000cOol00`0OOomo
o`2/Ool00`0OOomoo`0kOol003Aoo`0301moogoo0:]oo`0301moogoo03]oo`00=7oo00<07gooOol0
Zgoo00<07gooOol0>goo000dOol00`0OOomoo`2[Ool00`0OOomoo`0kOol003Aoo`0301moogoo0:]o
o`0301moogoo03]oo`00=Goo00<07gooOol0ZWoo00<07gooOol0>goo000eOol00`0OOomoo`2ZOol0
0`0OOomoo`0kOol003Eoo`0301moogoo0:Uoo`0301moogoo03aoo`00=Goo00<07gooOol0ZGoo00<0
7gooOol0?7oo000fOol00`0OOomoo`2XOol00`0OOomoo`0lOol003Ioo`0301moogoo0:Qoo`0301mo
ogoo03aoo`00=Woo00<07gooOol0Z7oo00<07gooOol0?7oo000fOol00`0OOomoo`2XOol00`0OOomo
o`0lOol003Ioo`0301moogoo0:Qoo`0301moogoo03aoo`00=goo00<07gooOol0YWoo00<07gooOol0
?Goo000gOol00`0OOomoo`2VOol00`0OOomoo`0mOol003Moo`0301moogoo0:Ioo`0301moogoo03eo
o`00=goo00<07gooOol0YWoo00<07gooOol0?Goo000hOol00`0OOomoo`2UOol00`0OOomoo`0mOol0
03Qoo`0301moogoo0:Eoo`0301moogoo03eoo`00>7oo00<07gooOol0Y7oo00<07gooOol0?Woo000i
Ool00`0OOomoo`2SOol00`0OOomoo`0nOol003Uoo`0301moogoo0:=oo`0301moogoo03ioo`00>Woo
00<07gooOol0XWoo00<07gooOol0?Woo000jOol00`0OOomoo`2QOol00`0OOomoo`0oOol003]oo`03
01moogoo0:1oo`0301moogoo03moo`00>goo00<07gooOol0X7oo00<07gooOol0?goo000lOol00`0O
Oomoo`2NOol00`0OOomoo`10Ool003eoo`0301moogoo09eoo`0301moogoo041oo`00?Goo00<07goo
Ool0W7oo00<07gooOol0@Goo000nOol00`0OOomoo`2KOol00`0OOomoo`11Ool003ioo`0301moogoo
09Yoo`0301moogoo049oo`00?goo00<07gooOol0VGoo00<07gooOol0@Woo000oOol00`0OOomoo`2H
Ool00`0OOomoo`13Ool0041oo`0301moogoo09Moo`0301moogoo04=oo`00@Goo00<07gooOol0UGoo
00<07gooOol0A7oo0011Ool00`0OOomoo`2EOol00`0OOomoo`14Ool0049oo`0301moogoo09=oo`03
01moogoo04Eoo`00@Woo00<07gooOol0Tgoo00<07gooOol0AGoo0013Ool00`0OOomoo`2AOol00`0O
Oomoo`16Ool004=oo`0301moogoo095oo`0301moogoo04Ioo`00A7oo00<07gooOol0Sgoo00<07goo
Ool0Agoo0015Ool00`0OOomoo`2>Ool00`0OOomoo`17Ool004Eoo`0301moogoo08eoo`0301moogoo
04Qoo`00AWoo00<07gooOol0S7oo00<07gooOol0B7oo0017Ool00`0OOomoo`2:Ool00`0OOomoo`19
Ool004Qoo`0301moogoo08Qoo`0301moogoo04Yoo`00B7oo00<07gooOol0R7oo00<07gooOol0BWoo
0019Ool00`0OOomoo`26Ool00`0OOomoo`1;Ool004Yoo`0301moogoo08Aoo`0301moogoo04aoo`00
Bgoo00<07gooOol0Pgoo00<07gooOol0C7oo001<Ool00`0OOomoo`21Ool00`0OOomoo`1=Ool004eo
o`0301moogoo07moo`0301moogoo04ioo`00CWoo00<07gooOol0OGoo00<07gooOol0Cgoo001?Ool0
0`0OOomoo`1kOol00`0OOomoo`1@Ool0051oo`0301moogoo07Uoo`0301moogoo055oo`00DGoo00<0
7gooOol0Mgoo00<07gooOol0DWoo001BOol00`0OOomoo`1eOol00`0OOomoo`1COol005=oo`0301mo
ogoo07=oo`0301moogoo05Aoo`00E7oo00<07gooOol0LGoo00<07gooOol0EGoo001EOol00`0OOomo
o`1_Ool00`0OOomoo`1FOol005Ioo`0301moogoo06eoo`0301moogoo05Moo`00Egoo00<07gooOol0
Jgoo00<07gooOol0F7oo001HOol201mZOol00`0OOomoo`1IOol005Yoo`0301moogoo06Eoo`807eao
o`00Fgoo00<07gooOol0Hgoo00<07gooOol0G7oo001LOol201mROol00`0OOomoo`1MOol005ioo`80
7eioo`807f1oo`00H7oo0P0OFgoo00<07gooOol0H7oo001ROol00`0OOomoo`1FOol201mSOol006=o
o`807eEoo`0301moogoo06=oo`00IGoo0P0ODGoo0P0OIWoo001WOol201m>Ool00`0OOomoo`1VOol0
06Uoo`0301moogoo04Uoo`807fUoo`00JWoo0P0OAgoo0P0OJgoo001/Ool201m3Ool201m]Ool006io
o`807cmoo`807fmoo`00L7oo0`0O>Goo0`0OLGoo001cOol401laOol401mdOol007Moo`<07b]oo`<0
7gQoo`00NWoo100O8goo100ONgoo001nOol601lHOol501moOol008AooaP07hAoo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.77625 .43026 m
.78167 .45587 L
s
.76895 .40513 m
.77625 .43026 L
s
.78167 .45587 m
.78518 .48179 L
s
.75981 .38062 m
.76895 .40513 L
s
.78518 .48179 m
.78676 .50788 L
s
.7489 .35687 m
.75981 .38062 L
s
.78676 .50788 m
.78639 .53398 L
s
.73626 .33405 m
.7489 .35687 L
s
.78639 .53398 m
.78406 .55993 L
s
.72196 .31228 m
.73626 .33405 L
s
.78406 .55993 m
.77978 .58557 L
s
.70609 .2917 m
.72196 .31228 L
s
.77978 .58557 m
.77357 .61075 L
s
.68872 .27246 m
.70609 .2917 L
s
.77357 .61075 m
.76543 .6353 L
s
.66996 .25467 m
.68872 .27246 L
s
.76543 .6353 m
.75542 .65907 L
s
.64991 .23846 m
.66996 .25467 L
s
.75542 .65907 m
.74357 .68191 L
s
.62868 .22395 m
.64991 .23846 L
s
.74357 .68191 m
.72994 .70365 L
s
.6064 .21125 m
.62868 .22395 L
s
.72994 .70365 m
.71459 .72414 L
s
.58319 .20047 m
.6064 .21125 L
s
.71459 .72414 m
.69761 .74323 L
s
.5592 .19169 m
.58319 .20047 L
s
.69761 .74323 m
.67909 .76079 L
s
.53457 .18501 m
.5592 .19169 L
s
.67909 .76079 m
.65912 .77667 L
s
.50946 .18049 m
.53457 .18501 L
s
.65912 .77667 m
.63783 .79073 L
s
.48404 .17821 m
.50946 .18049 L
s
.63783 .79073 m
.61533 .80286 L
s
.45848 .1782 m
.48404 .17821 L
s
.61533 .80286 m
.59179 .81293 L
s
.43296 .18051 m
.45848 .1782 L
s
.59179 .81293 m
.56733 .82085 L
s
.40765 .18515 m
.43296 .18051 L
s
.56733 .82085 m
.54213 .82653 L
s
.38275 .19212 m
.40765 .18515 L
s
.54213 .82653 m
.51636 .82988 L
s
.35845 .20142 m
.38275 .19212 L
s
.51636 .82988 m
.4902 .83085 L
s
.33494 .213 m
.35845 .20142 L
s
.4902 .83085 m
.46385 .82938 L
s
.3124 .22682 m
.33494 .213 L
s
.46385 .82938 m
.43751 .82547 L
s
.29104 .24279 m
.3124 .22682 L
s
.43751 .82547 m
.41138 .81909 L
s
.27103 .26084 m
.29104 .24279 L
s
.41138 .81909 m
.38567 .81028 L
s
.25254 .28084 m
.27103 .26084 L
s
.38567 .81028 m
.36059 .79905 L
s
.23576 .30266 m
.25254 .28084 L
s
.36059 .79905 m
.33636 .78548 L
s
.22083 .32614 m
.23576 .30266 L
s
.33636 .78548 m
.31319 .76965 L
s
.20791 .35111 m
.22083 .32614 L
s
.31319 .76965 m
.29127 .75167 L
s
.19711 .37738 m
.20791 .35111 L
s
.29127 .75167 m
.2708 .73166 L
s
.18856 .40475 m
.19711 .37738 L
s
.2708 .73166 m
.25197 .70977 L
s
.18233 .43298 m
.18856 .40475 L
s
.25197 .70977 m
.23495 .68618 L
s
.17851 .46186 m
.18233 .43298 L
s
.23495 .68618 m
.2199 .66107 L
s
.17713 .49113 m
.17851 .46186 L
s
.2199 .66107 m
.20695 .63466 L
s
.17823 .52055 m
.17713 .49113 L
s
.20695 .63466 m
.19622 .60716 L
s
.1818 .54986 m
.17823 .52055 L
s
.19622 .60716 m
.18781 .57881 L
s
.18781 .57881 m
.1818 .54986 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001kOolI01n<Ool007Moo`@0
7aUoo`@07hQoo`00Lgoo100O8Goo0`0OQGoo001_Ool401lXOol401n1Ool006aoo`<07c1oo`<07gio
o`00J7oo100O=Woo100ONWoo001VOol201lnOol301mgOol006Aoo`807d=oo`807gEoo`00Hgoo00<0
7gooOol0AGoo0P0OLgoo001QOol201m:Ool201maOol0061oo`0301moogoo04aoo`807fmoo`00GWoo
0P0ODGoo00<07gooOol0K7oo001LOol201mDOol201m/Ool005Yoo`807eQoo`0301moogoo06Uoo`00
FGoo00<07gooOol0FGoo0P0OJGoo001GOol201mNOol00`0OOomoo`1VOol005Ioo`0301moogoo05mo
o`807fIoo`00E7oo0P0OI7oo00<07gooOol0Hgoo001COol00`0OOomoo`1UOol00`0OOomoo`1ROol0
059oo`0301moogoo06Moo`0301moogoo065oo`00DGoo00<07gooOol0JGoo0P0OHGoo001?Ool201m^
Ool00`0OOomoo`1NOol004ioo`0301moogoo06moo`0301moogoo05eoo`00CGoo00<07gooOol0LGoo
00<07gooOol0G7oo001<Ool00`0OOomoo`1cOol00`0OOomoo`1KOol004]oo`0301moogoo07Eoo`03
01moogoo05Yoo`00BWoo00<07gooOol0Mgoo00<07gooOol0FGoo001:Ool00`0OOomoo`1hOol00`0O
Oomoo`1HOol004Uoo`0301moogoo07Yoo`0301moogoo05Moo`00B7oo00<07gooOol0O7oo00<07goo
Ool0EWoo0017Ool00`0OOomoo`1nOol00`0OOomoo`1EOol004Ioo`0301moogoo081oo`0301moogoo
05Aoo`00AGoo00<07gooOol0PWoo00<07gooOol0Dgoo0015Ool00`0OOomoo`23Ool00`0OOomoo`1B
Ool004Aoo`0301moogoo08Eoo`0301moogoo055oo`00@goo00<07gooOol0QWoo00<07gooOol0DGoo
0012Ool00`0OOomoo`28Ool00`0OOomoo`1@Ool0049oo`0301moogoo08Uoo`0301moogoo04moo`00
@Goo00<07gooOol0Rgoo00<07gooOol0CWoo0011Ool00`0OOomoo`2<Ool00`0OOomoo`1=Ool0041o
o`0301moogoo08eoo`0301moogoo04eoo`00@7oo00<07gooOol0SWoo00<07gooOol0C7oo000oOol0
0`0OOomoo`2@Ool00`0OOomoo`1;Ool003ioo`0301moogoo095oo`0301moogoo04]oo`00?Woo00<0
7gooOol0TWoo00<07gooOol0BWoo000mOol00`0OOomoo`2COol00`0OOomoo`1:Ool003eoo`0301mo
ogoo09Aoo`0301moogoo04Uoo`00?7oo00<07gooOol0UGoo00<07gooOol0BGoo000lOol00`0OOomo
o`2FOol00`0OOomoo`18Ool003]oo`0301moogoo09Moo`0301moogoo04Qoo`00>goo00<07gooOol0
V7oo00<07gooOol0Agoo000jOol00`0OOomoo`2IOol00`0OOomoo`17Ool003Yoo`0301moogoo09Yo
o`0301moogoo04Ioo`00>Goo00<07gooOol0Vgoo00<07gooOol0AWoo000iOol00`0OOomoo`2LOol0
0`0OOomoo`15Ool003Uoo`0301moogoo09aoo`0301moogoo04Eoo`00>7oo00<07gooOol0WWoo00<0
7gooOol0A7oo000hOol00`0OOomoo`2NOol00`0OOomoo`14Ool003Qoo`0301moogoo09moo`0301mo
ogoo04=oo`00=goo00<07gooOol0X7oo00<07gooOol0@goo000gOol00`0OOomoo`2QOol00`0OOomo
o`12Ool003Moo`0301moogoo0:5oo`0301moogoo049oo`00=goo00<07gooOol0XGoo00<07gooOol0
@Woo000fOol00`0OOomoo`2ROol00`0OOomoo`12Ool003Ioo`0301moogoo0:=oo`0301moogoo045o
o`00=Woo00<07gooOol0Xgoo00<07gooOol0@Goo000fOol00`0OOomoo`2SOol00`0OOomoo`11Ool0
03Eoo`0301moogoo0:Eoo`0301moogoo041oo`00=Goo00<07gooOol0YGoo00<07gooOol0@7oo000e
Ool00`0OOomoo`2UOol00`0OOomoo`10Ool003Eoo`0301moogoo0:Eoo`0301moogoo041oo`00=7oo
00<07gooOol0Ygoo00<07gooOol0?goo000dOol00`0OOomoo`2WOol00`0OOomoo`0oOol003Aoo`03
01moogoo0:Moo`0301moogoo03moo`00=7oo00<07gooOol0Z7oo00<07gooOol0?Woo000dOol00`0O
Oomoo`2XOol00`0OOomoo`0nOol003Aoo`0301moogoo0:Qoo`0301moogoo03ioo`00<goo00<07goo
Ool0ZGoo00<07gooOol0?Woo000cOol00`0OOomoo`2ZOol00`0OOomoo`0mOol003=oo`0301moogoo
0:Yoo`0301moogoo03eoo`00<goo00<07gooOol0ZWoo00<07gooOol0?Goo000cOol00`0OOomoo`2Z
Ool00`0OOomoo`0mOol003=oo`0301moogoo0:Yoo`0301moogoo03eoo`00<goo00<07gooOol0ZWoo
00<07gooOol0?Goo000cOol00`0OOomoo`2[Ool00`0OOomoo`0lOol0039oo`0301moogoo0:aoo`03
01moogoo03aoo`00<Woo00<07gooOol0[7oo00<07gooOol0?7oo000bOol00`0OOomoo`2/Ool00`0O
Oomoo`0lOol0039oo`0301moogoo0:aoo`0301moogoo03aoo`00<Woo00<07gooOol0[7oo00<07goo
Ool0?7oo000bOol00`0OOomoo`2/Ool00`0OOomoo`0lOol0039oo`0301moogoo0:aoo`0301moogoo
03aoo`00<Woo00<07gooOol0[7oo00<07gooOol0?7oo000bOol00`0OOomoo`2/Ool00`0OOomoo`0l
Ool003=oo`0301moogoo0:]oo`0301moogoo03aoo`00<goo00<07gooOol0Zgoo00<07gooOol0?7oo
000cOol00`0OOomoo`2[Ool00`0OOomoo`0lOol003=oo`0301moogoo0:]oo`0301moogoo03aoo`00
<goo00<07gooOol0Zgoo00<07gooOol0?7oo000cOol00`0OOomoo`2[Ool00`0OOomoo`0lOol003=o
o`0301moogoo0:]oo`0301moogoo03aoo`00<goo00<07gooOol0Zgoo00<07gooOol0?7oo000cOol0
0`0OOomoo`2[Ool00`0OOomoo`0lOol003Aoo`0301moogoo0:Yoo`0301moogoo03aoo`00=7oo00<0
7gooOol0ZWoo00<07gooOol0?7oo000dOol00`0OOomoo`2ZOol00`0OOomoo`0lOol003Aoo`0301mo
ogoo0:Yoo`0301moogoo03aoo`00=7oo00<07gooOol0ZWoo00<07gooOol0?7oo000dOol00`0OOomo
o`2ZOol00`0OOomoo`0lOol003Aoo`0301moogoo0:Yoo`0301moogoo03aoo`00=7oo00<07gooOol0
ZWoo00<07gooOol0?7oo000eOol00`0OOomoo`2XOol00`0OOomoo`0mOol003Eoo`0301moogoo0:Qo
o`0301moogoo03eoo`00=Goo00<07gooOol0Z7oo00<07gooOol0?Goo000eOol00`0OOomoo`2XOol0
0`0OOomoo`0mOol003Eoo`0301moogoo0:Moo`0301moogoo03ioo`00=Goo00<07gooOol0Ygoo00<0
7gooOol0?Woo000fOol00`0OOomoo`2VOol00`0OOomoo`0nOol003Ioo`0301moogoo0:Ioo`0301mo
ogoo03ioo`00=Woo00<07gooOol0YWoo00<07gooOol0?Woo000gOol00`0OOomoo`2UOol00`0OOomo
o`0nOol003Moo`0301moogoo0:Aoo`0301moogoo03moo`00>7oo00<07gooOol0Xgoo00<07gooOol0
?goo000hOol00`0OOomoo`2SOol00`0OOomoo`0oOol003Qoo`0301moogoo0:=oo`0301moogoo03mo
o`00>Goo00<07gooOol0XWoo00<07gooOol0?goo000iOol00`0OOomoo`2QOol00`0OOomoo`10Ool0
03Uoo`0301moogoo0:5oo`0301moogoo041oo`00>Woo00<07gooOol0Wgoo00<07gooOol0@Goo000j
Ool00`0OOomoo`2OOol00`0OOomoo`11Ool003]oo`0301moogoo09eoo`0301moogoo049oo`00>goo
00<07gooOol0WGoo00<07gooOol0@Woo000lOol00`0OOomoo`2LOol00`0OOomoo`12Ool003aoo`03
01moogoo09]oo`0301moogoo04=oo`00?Goo00<07gooOol0VWoo00<07gooOol0@goo000mOol00`0O
Oomoo`2IOol00`0OOomoo`14Ool003ioo`0301moogoo09Qoo`0301moogoo04Aoo`00?Woo00<07goo
Ool0Ugoo00<07gooOol0AGoo000oOol00`0OOomoo`2FOol00`0OOomoo`15Ool0041oo`0301moogoo
09Aoo`0301moogoo04Ioo`00@7oo00<07gooOol0U7oo00<07gooOol0AWoo0011Ool00`0OOomoo`2B
Ool00`0OOomoo`17Ool0045oo`0301moogoo099oo`0301moogoo04Moo`00@Woo00<07gooOol0T7oo
00<07gooOol0B7oo0012Ool00`0OOomoo`2@Ool00`0OOomoo`18Ool004=oo`0301moogoo08ioo`03
01moogoo04Uoo`00A7oo00<07gooOol0SGoo00<07gooOol0BGoo0014Ool00`0OOomoo`2<Ool00`0O
Oomoo`1:Ool004Eoo`0301moogoo08Yoo`0301moogoo04]oo`00AWoo00<07gooOol0RGoo00<07goo
Ool0Bgoo0017Ool00`0OOomoo`27Ool00`0OOomoo`1<Ool004Moo`0301moogoo08Ioo`0301moogoo
04eoo`00B7oo00<07gooOol0QGoo00<07gooOol0CGoo0019Ool00`0OOomoo`23Ool00`0OOomoo`1>
Ool004Yoo`0301moogoo085oo`0301moogoo04moo`00BWoo00<07gooOol0PGoo00<07gooOol0Cgoo
001;Ool00`0OOomoo`1oOol00`0OOomoo`1@Ool004aoo`0301moogoo07eoo`0301moogoo055oo`00
CGoo00<07gooOol0Ngoo00<07gooOol0DWoo001>Ool00`0OOomoo`1iOol00`0OOomoo`1COol004mo
o`0301moogoo07Qoo`0301moogoo05=oo`00D7oo00<07gooOol0MWoo00<07gooOol0E7oo001AOol0
0`0OOomoo`1dOol00`0OOomoo`1EOol0059oo`0301moogoo079oo`0301moogoo05Ioo`00Dgoo00<0
7gooOol0L7oo00<07gooOol0Egoo001DOol00`0OOomoo`1]Ool201mJOol005Eoo`0301moogoo06]o
o`0301moogoo05Yoo`00EWoo0P0OJWoo00<07gooOol0Fgoo001HOol00`0OOomoo`1VOol00`0OOomo
o`1LOol005Uoo`0301moogoo06=oo`807emoo`00FWoo0P0OHWoo00<07gooOol0Ggoo001LOol00`0O
Oomoo`1NOol00`0OOomoo`1POol005eoo`0301moogoo05]oo`807f=oo`00GWoo0P0OFWoo00<07goo
Ool0Hgoo001POol00`0OOomoo`1EOol201mVOol0065oo`807eAoo`0301moogoo06Ioo`00Hgoo0P0O
D7oo0P0OJGoo001UOol201m<Ool201m[Ool006Moo`807dQoo`807feoo`00JGoo0P0OA7oo0P0OKgoo
001[Ool201m0Ool201maOol006eoo`<07c]oo`807g=oo`00L7oo0P0O=Woo0`0OMGoo001bOol301l_
Ool401mhOol007Eoo`D07bMoo`<07gaoo`00NWoo1@0O7Woo100OOgoo001oOol401lEOol501n3Ool0
08=ooaD07hQoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.78201 .48553 m
.7824 .51165 L
s
.77971 .45952 m
.78201 .48553 L
s
.77551 .43376 m
.77971 .45952 L
s
.7824 .51165 m
.78088 .5377 L
s
.76943 .40841 m
.77551 .43376 L
s
.78088 .5377 m
.77745 .56355 L
s
.7615 .38361 m
.76943 .40841 L
s
.77745 .56355 m
.77212 .58903 L
s
.75177 .35952 m
.7615 .38361 L
s
.77212 .58903 m
.76492 .61398 L
s
.74028 .33629 m
.75177 .35952 L
s
.76492 .61398 m
.75588 .63827 L
s
.72708 .31407 m
.74028 .33629 L
s
.75588 .63827 m
.74505 .66173 L
s
.71225 .293 m
.72708 .31407 L
s
.74505 .66173 m
.73247 .68422 L
s
.69587 .27321 m
.71225 .293 L
s
.73247 .68422 m
.7182 .70558 L
s
.67801 .25485 m
.69587 .27321 L
s
.7182 .70558 m
.70233 .72567 L
s
.65877 .23806 m
.67801 .25485 L
s
.70233 .72567 m
.68492 .74436 L
s
.63827 .22295 m
.65877 .23806 L
s
.68492 .74436 m
.66609 .76149 L
s
.61662 .20964 m
.63827 .22295 L
s
.66609 .76149 m
.64592 .77695 L
s
.59395 .19825 m
.61662 .20964 L
s
.64592 .77695 m
.62453 .7906 L
s
.57038 .18889 m
.59395 .19825 L
s
.62453 .7906 m
.60205 .80233 L
s
.54608 .18164 m
.57038 .18889 L
s
.60205 .80233 m
.57862 .81203 L
s
.5212 .17659 m
.54608 .18164 L
s
.57862 .81203 m
.55438 .8196 L
s
.4959 .17382 m
.5212 .17659 L
s
.55438 .8196 m
.52949 .82495 L
s
.47035 .17337 m
.4959 .17382 L
s
.52949 .82495 m
.50413 .82802 L
s
.44475 .17528 m
.47035 .17337 L
s
.50413 .82802 m
.47845 .82873 L
s
.41927 .17959 m
.44475 .17528 L
s
.47845 .82873 m
.45266 .82705 L
s
.39411 .1863 m
.41927 .17959 L
s
.45266 .82705 m
.42694 .82295 L
s
.36947 .19539 m
.39411 .1863 L
s
.42694 .82295 m
.40148 .81643 L
s
.34554 .20683 m
.36947 .19539 L
s
.40148 .81643 m
.3765 .80749 L
s
.32252 .22057 m
.34554 .20683 L
s
.3765 .80749 m
.35219 .79617 L
s
.30062 .23654 m
.32252 .22057 L
s
.35219 .79617 m
.32875 .78252 L
s
.28001 .25463 m
.30062 .23654 L
s
.32875 .78252 m
.30639 .76663 L
s
.26089 .27473 m
.28001 .25463 L
s
.30639 .76663 m
.28531 .74859 L
s
.24344 .29669 m
.26089 .27473 L
s
.28531 .74859 m
.26568 .72852 L
s
.22781 .32035 m
.24344 .29669 L
s
.26568 .72852 m
.2477 .70658 L
s
.21415 .34554 m
.22781 .32035 L
s
.2477 .70658 m
.23153 .68292 L
s
.20261 .37204 m
.21415 .34554 L
s
.23153 .68292 m
.21732 .65772 L
s
.19329 .39966 m
.20261 .37204 L
s
.21732 .65772 m
.20521 .6312 L
s
.18629 .42815 m
.19329 .39966 L
s
.20521 .6312 m
.19532 .60358 L
s
.18168 .45727 m
.18629 .42815 L
s
.19532 .60358 m
.18774 .57507 L
s
.17951 .48678 m
.18168 .45727 L
s
.18774 .57507 m
.18255 .54594 L
s
.1798 .51642 m
.17951 .48678 L
s
.18255 .54594 m
.1798 .51642 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol008=oo`l07hioo`00O7oo1`0O3goo1@0ORGoo001gOol5
01lKOol401n5Ool007=oo`@07bAoo`<07h9oo`00L7oo0`0O:goo100OOWoo001^Ool201lbOol301mk
Ool006aoo`807cMoo`@07gMoo`00JGoo0`0O?Goo0P0OMGoo001WOol201m2Ool201mcOol006Eoo`80
7dIoo`0301moogoo071oo`00Hgoo0P0OBGoo0P0OL7oo001QOol201m=Ool201m^Ool005moo`807e5o
o`807faoo`00GGoo0P0OEGoo0P0OJWoo001LOol00`0OOomoo`1GOol201mXOol005Yoo`807eaoo`03
01moogoo06Eoo`00FGoo00<07gooOol0GGoo00<07gooOol0I7oo001GOol201mQOol201mTOol005Io
o`0301moogoo06=oo`0301moogoo065oo`00EGoo00<07gooOol0IGoo00<07gooOol0H7oo001DOol0
0`0OOomoo`1WOol00`0OOomoo`1OOol005=oo`0301moogoo06Uoo`0301moogoo05ioo`00DWoo00<0
7gooOol0Jgoo00<07gooOol0GGoo001AOol00`0OOomoo`1]Ool00`0OOomoo`1LOol0051oo`0301mo
ogoo06moo`0301moogoo05]oo`00Cgoo00<07gooOol0LGoo00<07gooOol0FWoo001>Ool00`0OOomo
o`1cOol00`0OOomoo`1IOol004aoo`807gMoo`0301moogoo05Qoo`00Bgoo00<07gooOol0N7oo00<0
7gooOol0Egoo001:Ool00`0OOomoo`1jOol00`0OOomoo`1FOol004Uoo`0301moogoo07aoo`0301mo
ogoo05Eoo`00BGoo00<07gooOol0OGoo00<07gooOol0E7oo0018Ool00`0OOomoo`1nOol00`0OOomo
o`1DOol004Moo`0301moogoo081oo`0301moogoo05=oo`00AWoo00<07gooOol0PWoo00<07gooOol0
DWoo0016Ool00`0OOomoo`23Ool00`0OOomoo`1AOol004Eoo`0301moogoo08Eoo`0301moogoo051o
o`00A7oo00<07gooOol0QWoo00<07gooOol0D7oo0014Ool00`0OOomoo`27Ool00`0OOomoo`1?Ool0
04=oo`0301moogoo08Uoo`0301moogoo04ioo`00@Woo00<07gooOol0RWoo00<07gooOol0CWoo0012
Ool00`0OOomoo`2;Ool00`0OOomoo`1=Ool0045oo`0301moogoo08eoo`0301moogoo04aoo`00@7oo
00<07gooOol0SWoo00<07gooOol0C7oo0010Ool00`0OOomoo`2?Ool00`0OOomoo`1;Ool003moo`03
01moogoo095oo`0301moogoo04Yoo`00?goo00<07gooOol0TGoo00<07gooOol0BWoo000nOol00`0O
Oomoo`2COol00`0OOomoo`19Ool003ioo`0301moogoo09=oo`0301moogoo04Uoo`00?Goo00<07goo
Ool0UGoo00<07gooOol0B7oo000mOol00`0OOomoo`2EOol00`0OOomoo`18Ool003eoo`0301moogoo
09Ioo`0301moogoo04Moo`00?7oo00<07gooOol0Ugoo00<07gooOol0Agoo000lOol00`0OOomoo`2H
Ool00`0OOomoo`16Ool003]oo`0301moogoo09Uoo`0301moogoo04Ioo`00>goo00<07gooOol0VGoo
00<07gooOol0AWoo000jOol00`0OOomoo`2KOol00`0OOomoo`15Ool003Yoo`0301moogoo09]oo`03
01moogoo04Eoo`00>Woo00<07gooOol0W7oo00<07gooOol0A7oo000iOol00`0OOomoo`2MOol00`0O
Oomoo`14Ool003Uoo`0301moogoo09ioo`0301moogoo04=oo`00>7oo00<07gooOol0Wgoo00<07goo
Ool0@goo000hOol00`0OOomoo`2OOol00`0OOomoo`13Ool003Qoo`0301moogoo0:1oo`0301moogoo
049oo`00=goo00<07gooOol0XGoo00<07gooOol0@Woo000gOol00`0OOomoo`2QOol00`0OOomoo`12
Ool003Moo`0301moogoo0:5oo`0301moogoo049oo`00=Woo00<07gooOol0Xgoo00<07gooOol0@Goo
000fOol00`0OOomoo`2SOol00`0OOomoo`11Ool003Ioo`0301moogoo0:=oo`0301moogoo045oo`00
=Woo00<07gooOol0Y7oo00<07gooOol0@7oo000eOol00`0OOomoo`2UOol00`0OOomoo`10Ool003Eo
o`0301moogoo0:Eoo`0301moogoo041oo`00=Goo00<07gooOol0YGoo00<07gooOol0@7oo000eOol0
0`0OOomoo`2VOol00`0OOomoo`0oOol003Eoo`0301moogoo0:Ioo`0301moogoo03moo`00=Goo00<0
7gooOol0YWoo00<07gooOol0?goo000eOol00`0OOomoo`2VOol00`0OOomoo`0oOol003Aoo`0301mo
ogoo0:Moo`0301moogoo03moo`00=7oo00<07gooOol0Z7oo00<07gooOol0?Woo000dOol00`0OOomo
o`2XOol00`0OOomoo`0nOol003Aoo`0301moogoo0:Qoo`0301moogoo03ioo`00=7oo00<07gooOol0
Z7oo00<07gooOol0?Woo000dOol00`0OOomoo`2XOol00`0OOomoo`0nOol003Aoo`0301moogoo0:Qo
o`0301moogoo03ioo`00=7oo00<07gooOol0Z7oo00<07gooOol0?Woo000cOol00`0OOomoo`2YOol0
0`0OOomoo`0nOol003=oo`0301moogoo0:Yoo`0301moogoo03eoo`00<goo00<07gooOol0ZWoo00<0
7gooOol0?Goo000cOol00`0OOomoo`2ZOol00`0OOomoo`0mOol003=oo`0301moogoo0:Yoo`0301mo
ogoo03eoo`00<goo00<07gooOol0ZWoo00<07gooOol0?Goo000cOol00`0OOomoo`2ZOol00`0OOomo
o`0mOol003=oo`0301moogoo0:Yoo`0301moogoo03eoo`00<goo00<07gooOol0ZWoo00<07gooOol0
?Goo000cOol00`0OOomoo`2ZOol00`0OOomoo`0mOol003=oo`0301moogoo0:Yoo`0301moogoo03eo
o`00<goo00<07gooOol0ZWoo00<07gooOol0?Goo000cOol00`0OOomoo`2ZOol00`0OOomoo`0mOol0
03=oo`0301moogoo0:Yoo`0301moogoo03eoo`00<goo00<07gooOol0ZWoo00<07gooOol0?Goo000c
Ool00`0OOomoo`2ZOol00`0OOomoo`0mOol003=oo`0301moogoo0:Yoo`0301moogoo03eoo`00<goo
00<07gooOol0ZWoo00<07gooOol0?Goo000dOol00`0OOomoo`2YOol00`0OOomoo`0mOol003Aoo`03
01moogoo0:Uoo`0301moogoo03eoo`00=7oo00<07gooOol0ZGoo00<07gooOol0?Goo000dOol00`0O
Oomoo`2YOol00`0OOomoo`0mOol003Aoo`0301moogoo0:Uoo`0301moogoo03eoo`00=7oo00<07goo
Ool0Z7oo00<07gooOol0?Woo000dOol00`0OOomoo`2XOol00`0OOomoo`0nOol003Aoo`0301moogoo
0:Qoo`0301moogoo03ioo`00=Goo00<07gooOol0Ygoo00<07gooOol0?Woo000eOol00`0OOomoo`2W
Ool00`0OOomoo`0nOol003Eoo`0301moogoo0:Ioo`0301moogoo03moo`00=Goo00<07gooOol0YWoo
00<07gooOol0?goo000eOol00`0OOomoo`2VOol00`0OOomoo`0oOol003Eoo`0301moogoo0:Ioo`03
01moogoo03moo`00=Woo00<07gooOol0Y7oo00<07gooOol0@7oo000fOol00`0OOomoo`2TOol00`0O
Oomoo`10Ool003Ioo`0301moogoo0:Aoo`0301moogoo041oo`00=goo00<07gooOol0Xgoo00<07goo
Ool0@7oo000gOol00`0OOomoo`2ROol00`0OOomoo`11Ool003Qoo`0301moogoo0:5oo`0301moogoo
045oo`00>7oo00<07gooOol0XGoo00<07gooOol0@Goo000hOol00`0OOomoo`2QOol00`0OOomoo`11
Ool003Qoo`0301moogoo0:1oo`0301moogoo049oo`00>Goo00<07gooOol0Wgoo00<07gooOol0@Woo
000iOol00`0OOomoo`2OOol00`0OOomoo`12Ool003Uoo`0301moogoo09ioo`0301moogoo04=oo`00
>Goo00<07gooOol0WWoo00<07gooOol0@goo000jOol00`0OOomoo`2LOol00`0OOomoo`14Ool003Yo
o`0301moogoo09aoo`0301moogoo04Aoo`00>goo00<07gooOol0VWoo00<07gooOol0AGoo000kOol0
0`0OOomoo`2JOol00`0OOomoo`15Ool003aoo`0301moogoo09Qoo`0301moogoo04Ioo`00?7oo00<0
7gooOol0V7oo00<07gooOol0AWoo000mOol00`0OOomoo`2FOol00`0OOomoo`17Ool003eoo`0301mo
ogoo09Ioo`0301moogoo04Moo`00?Woo00<07gooOol0U7oo00<07gooOol0B7oo000oOol00`0OOomo
o`2COol00`0OOomoo`18Ool003moo`0301moogoo09=oo`0301moogoo04Qoo`00@7oo00<07gooOol0
TGoo00<07gooOol0BGoo0010Ool00`0OOomoo`2AOol00`0OOomoo`19Ool0045oo`0301moogoo08mo
o`0301moogoo04Yoo`00@Goo00<07gooOol0Sgoo00<07gooOol0BWoo0012Ool00`0OOomoo`2=Ool0
0`0OOomoo`1;Ool004=oo`0301moogoo08aoo`0301moogoo04]oo`00@goo00<07gooOol0Rgoo00<0
7gooOol0C7oo0014Ool00`0OOomoo`2:Ool00`0OOomoo`1<Ool004Eoo`0301moogoo08Qoo`0301mo
ogoo04eoo`00AWoo00<07gooOol0QWoo00<07gooOol0CWoo0016Ool00`0OOomoo`26Ool00`0OOomo
o`1>Ool004Moo`0301moogoo08Aoo`0301moogoo04moo`00B7oo00<07gooOol0PWoo00<07gooOol0
D7oo0018Ool00`0OOomoo`21Ool00`0OOomoo`1AOol004Uoo`0301moogoo07moo`0301moogoo059o
o`00BWoo00<07gooOol0OWoo00<07gooOol0DWoo001;Ool00`0OOomoo`1lOol00`0OOomoo`1COol0
04]oo`0301moogoo07]oo`0301moogoo05Aoo`00C7oo00<07gooOol0NGoo00<07gooOol0EGoo001=
Ool00`0OOomoo`1gOol00`0OOomoo`1FOol004ioo`0301moogoo07Eoo`0301moogoo05Moo`00Cgoo
00<07gooOol0Lgoo00<07gooOol0F7oo001@Ool00`0OOomoo`1aOol00`0OOomoo`1IOol0055oo`03
01moogoo06moo`0301moogoo05Yoo`00DWoo00<07gooOol0KGoo00<07gooOol0Fgoo001COol00`0O
Oomoo`1[Ool00`0OOomoo`1LOol005Aoo`0301moogoo06Uoo`0301moogoo05eoo`00EGoo00<07goo
Ool0Igoo00<07gooOol0GWoo001FOol00`0OOomoo`1TOol201mQOol005Moo`0301moogoo069oo`03
01moogoo065oo`00F7oo0P0OH7oo0P0OI7oo001JOol201mMOol00`0OOomoo`1TOol005aoo`807eUo
o`807fMoo`00GWoo00<07gooOol0EGoo00<07gooOol0Igoo001OOol201mCOol201mZOol0065oo`80
7e1oo`0301moogoo06Yoo`00Hgoo0P0OC7oo0P0OKGoo001UOol201m8Ool201m_Ool006Moo`807dAo
o`807g5oo`00JGoo0P0O@Goo00<07gooOol0LGoo001[Ool301llOol201mdOol006ioo`807cQoo`80
7gIoo`00L7oo0P0O<goo0`0ON7oo001bOol301l/Ool401mkOol007Eoo`@07b=oo`D07gmoo`00NGoo
1@0O5Woo200OQ7oo001nOolF01n<Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.77519 .5408 m
.77067 .5665 L
s
.77786 .51483 m
.77519 .5408 L
s
.77865 .48875 m
.77786 .51483 L
s
.77067 .5665 m
.7643 .59178 L
s
.77755 .46271 m
.77865 .48875 L
s
.7643 .59178 m
.75613 .61649 L
s
.77457 .43686 m
.77755 .46271 L
s
.75613 .61649 m
.7462 .64049 L
s
.76971 .41136 m
.77457 .43686 L
s
.7462 .64049 m
.73455 .66363 L
s
.763 .38636 m
.76971 .41136 L
s
.73455 .66363 m
.72125 .68575 L
s
.75446 .36201 m
.763 .38636 L
s
.72125 .68575 m
.70637 .70673 L
s
.74414 .33848 m
.75446 .36201 L
s
.70637 .70673 m
.68997 .72642 L
s
.73207 .31589 m
.74414 .33848 L
s
.68997 .72642 m
.67215 .74469 L
s
.71831 .29442 m
.73207 .31589 L
s
.67215 .74469 m
.653 .76141 L
s
.70294 .2742 m
.71831 .29442 L
s
.653 .76141 m
.63264 .77645 L
s
.68602 .25538 m
.70294 .2742 L
s
.63264 .77645 m
.61116 .7897 L
s
.66765 .2381 m
.68602 .25538 L
s
.61116 .7897 m
.5887 .80104 L
s
.64794 .22249 m
.66765 .2381 L
s
.5887 .80104 m
.56539 .81037 L
s
.62698 .20869 m
.64794 .22249 L
s
.56539 .81037 m
.54138 .8176 L
s
.6049 .1968 m
.62698 .20869 L
s
.54138 .8176 m
.51682 .82265 L
s
.58183 .18695 m
.6049 .1968 L
s
.51682 .82265 m
.49186 .82544 L
s
.55793 .17924 m
.58183 .18695 L
s
.49186 .82544 m
.46669 .82591 L
s
.53334 .17375 m
.55793 .17924 L
s
.46669 .82591 m
.44148 .82404 L
s
.50824 .17056 m
.53334 .17375 L
s
.44148 .82404 m
.41641 .81978 L
s
.48279 .16974 m
.50824 .17056 L
s
.41641 .81978 m
.39167 .81313 L
s
.45718 .17133 m
.48279 .16974 L
s
.39167 .81313 m
.36745 .8041 L
s
.4316 .17536 m
.45718 .17133 L
s
.36745 .8041 m
.34395 .79273 L
s
.40626 .18184 m
.4316 .17536 L
s
.34395 .79273 m
.32136 .77905 L
s
.38134 .19076 m
.40626 .18184 L
s
.32136 .77905 m
.29988 .76315 L
s
.35707 .20209 m
.38134 .19076 L
s
.29988 .76315 m
.2797 .74512 L
s
.33363 .21576 m
.35707 .20209 L
s
.2797 .74512 m
.26099 .72507 L
s
.31124 .2317 m
.33363 .21576 L
s
.26099 .72507 m
.24393 .70315 L
s
.29009 .24981 m
.31124 .2317 L
s
.24393 .70315 m
.22869 .67951 L
s
.27037 .26997 m
.29009 .24981 L
s
.22869 .67951 m
.2154 .65432 L
s
.25228 .29202 m
.27037 .26997 L
s
.2154 .65432 m
.20422 .6278 L
s
.23596 .31581 m
.25228 .29202 L
s
.20422 .6278 m
.19524 .60016 L
s
.22159 .34113 m
.23596 .31581 L
s
.19524 .60016 m
.18856 .57162 L
s
.20929 .36778 m
.22159 .34113 L
s
.18856 .57162 m
.18426 .54242 L
s
.1992 .39554 m
.20929 .36778 L
s
.18426 .54242 m
.18238 .51282 L
s
.19139 .42418 m
.1992 .39554 L
s
.18238 .51282 m
.18295 .48308 L
s
.18596 .45344 m
.19139 .42418 L
s
.18295 .48308 m
.18596 .45344 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0027Ool>01n;Ool0081oo`L07`ioo`H07hEoo`00NWoo1P0O6goo100O
PGoo001fOol401lUOol301mnOol007=oo`<07baoo`<07g]oo`00Kgoo100O<Woo0`0ON7oo001/Ool3
01liOol201mfOol006Yoo`807cioo`807gAoo`00J7oo0P0O@Woo0P0OLWoo001VOol201m6Ool201m`
Ool006Aoo`807dYoo`807fioo`00HWoo0P0OCWoo0P0OK7oo001POol201mBOol201mZOol005moo`03
01moogoo05Aoo`0301moogoo06Moo`00GWoo00<07gooOol0EWoo0P0OIgoo001MOol00`0OOomoo`1I
Ool00`0OOomoo`1TOol005]oo`807eeoo`0301moogoo06=oo`00FWoo00<07gooOol0GWoo00<07goo
Ool0HWoo001IOol00`0OOomoo`1POol201mROol005Qoo`0301moogoo06=oo`0301moogoo05moo`00
Egoo00<07gooOol0IGoo00<07gooOol0GWoo001EOol201mYOol00`0OOomoo`1MOol005Aoo`0301mo
ogoo06Yoo`0301moogoo05aoo`00Dgoo00<07gooOol0K7oo00<07gooOol0Fgoo001BOol00`0OOomo
o`1^Ool00`0OOomoo`1JOol0055oo`0301moogoo071oo`0301moogoo05Uoo`00D7oo00<07gooOol0
LWoo00<07gooOol0F7oo001?Ool00`0OOomoo`1dOol00`0OOomoo`1GOol004ioo`0301moogoo07Io
o`0301moogoo05Ioo`00CGoo00<07gooOol0N7oo00<07gooOol0EGoo001<Ool00`0OOomoo`1jOol0
0`0OOomoo`1DOol004]oo`0301moogoo07aoo`0301moogoo05=oo`00BWoo00<07gooOol0OWoo00<0
7gooOol0DWoo001:Ool00`0OOomoo`1nOol00`0OOomoo`1BOol004Uoo`0301moogoo081oo`0301mo
ogoo055oo`00B7oo00<07gooOol0PWoo00<07gooOol0D7oo0017Ool00`0OOomoo`24Ool00`0OOomo
o`1?Ool004Moo`0301moogoo08Eoo`0301moogoo04ioo`00AWoo00<07gooOol0QWoo00<07gooOol0
CWoo0015Ool00`0OOomoo`28Ool00`0OOomoo`1=Ool004Aoo`0301moogoo08Yoo`0301moogoo04ao
o`00A7oo00<07gooOol0RWoo00<07gooOol0C7oo0013Ool00`0OOomoo`2<Ool00`0OOomoo`1;Ool0
049oo`0301moogoo08eoo`0301moogoo04]oo`00@Woo00<07gooOol0SWoo00<07gooOol0BWoo0011
Ool00`0OOomoo`2?Ool00`0OOomoo`1:Ool0045oo`0301moogoo091oo`0301moogoo04Uoo`00@7oo
00<07gooOol0TGoo00<07gooOol0BGoo0010Ool00`0OOomoo`2BOol00`0OOomoo`18Ool003moo`03
01moogoo09=oo`0301moogoo04Qoo`00?goo00<07gooOol0Tgoo00<07gooOol0B7oo000nOol00`0O
Oomoo`2EOol00`0OOomoo`17Ool003ioo`0301moogoo09Eoo`0301moogoo04Moo`00?Goo00<07goo
Ool0Ugoo00<07gooOol0AWoo000mOol00`0OOomoo`2GOol00`0OOomoo`16Ool003eoo`0301moogoo
09Qoo`0301moogoo04Eoo`00?7oo00<07gooOol0VGoo00<07gooOol0AGoo000lOol00`0OOomoo`2J
Ool00`0OOomoo`14Ool003aoo`0301moogoo09Yoo`0301moogoo04Aoo`00>goo00<07gooOol0Vgoo
00<07gooOol0A7oo000kOol00`0OOomoo`2KOol00`0OOomoo`14Ool003Yoo`0301moogoo09eoo`03
01moogoo04=oo`00>Woo00<07gooOol0WGoo00<07gooOol0@goo000jOol00`0OOomoo`2MOol00`0O
Oomoo`13Ool003Uoo`0301moogoo09ioo`0301moogoo04=oo`00>Goo00<07gooOol0Wgoo00<07goo
Ool0@Woo000iOol00`0OOomoo`2OOol00`0OOomoo`12Ool003Qoo`0301moogoo0:1oo`0301moogoo
049oo`00>7oo00<07gooOol0X7oo00<07gooOol0@Woo000gOol00`0OOomoo`2ROol00`0OOomoo`11
Ool003Moo`0301moogoo0:9oo`0301moogoo045oo`00=goo00<07gooOol0XWoo00<07gooOol0@Goo
000fOol00`0OOomoo`2TOol00`0OOomoo`10Ool003Ioo`0301moogoo0:Aoo`0301moogoo041oo`00
=Woo00<07gooOol0Y7oo00<07gooOol0@7oo000fOol00`0OOomoo`2TOol00`0OOomoo`10Ool003Io
o`0301moogoo0:Eoo`0301moogoo03moo`00=Woo00<07gooOol0YGoo00<07gooOol0?goo000eOol0
0`0OOomoo`2VOol00`0OOomoo`0oOol003Eoo`0301moogoo0:Ioo`0301moogoo03moo`00=Goo00<0
7gooOol0YWoo00<07gooOol0?goo000eOol00`0OOomoo`2WOol00`0OOomoo`0nOol003Eoo`0301mo
ogoo0:Moo`0301moogoo03ioo`00=Goo00<07gooOol0Ygoo00<07gooOol0?Woo000eOol00`0OOomo
o`2WOol00`0OOomoo`0nOol003Eoo`0301moogoo0:Moo`0301moogoo03ioo`00=7oo00<07gooOol0
Z7oo00<07gooOol0?Woo000dOol00`0OOomoo`2XOol00`0OOomoo`0nOol003Aoo`0301moogoo0:Qo
o`0301moogoo03ioo`00=7oo00<07gooOol0Z7oo00<07gooOol0?Woo000dOol00`0OOomoo`2XOol0
0`0OOomoo`0nOol003Aoo`0301moogoo0:Qoo`0301moogoo03ioo`00=7oo00<07gooOol0Z7oo00<0
7gooOol0?Woo000dOol00`0OOomoo`2XOol00`0OOomoo`0nOol003Aoo`0301moogoo0:Qoo`0301mo
ogoo03ioo`00=7oo00<07gooOol0Z7oo00<07gooOol0?Woo000dOol00`0OOomoo`2XOol00`0OOomo
o`0nOol003Aoo`0301moogoo0:Qoo`0301moogoo03ioo`00=7oo00<07gooOol0Z7oo00<07gooOol0
?Woo000dOol00`0OOomoo`2XOol00`0OOomoo`0nOol003Aoo`0301moogoo0:Qoo`0301moogoo03io
o`00=7oo00<07gooOol0Z7oo00<07gooOol0?Woo000dOol00`0OOomoo`2XOol00`0OOomoo`0nOol0
03Aoo`0301moogoo0:Moo`0301moogoo03moo`00=7oo00<07gooOol0Ygoo00<07gooOol0?goo000d
Ool00`0OOomoo`2WOol00`0OOomoo`0oOol003Aoo`0301moogoo0:Moo`0301moogoo03moo`00=7oo
00<07gooOol0Ygoo00<07gooOol0?goo000dOol00`0OOomoo`2WOol00`0OOomoo`0oOol003Aoo`03
01moogoo0:Moo`0301moogoo03moo`00=Goo00<07gooOol0YWoo00<07gooOol0?goo000eOol00`0O
Oomoo`2UOol00`0OOomoo`10Ool003Eoo`0301moogoo0:Eoo`0301moogoo041oo`00=Goo00<07goo
Ool0YGoo00<07gooOol0@7oo000fOol00`0OOomoo`2TOol00`0OOomoo`10Ool003Ioo`0301moogoo
0:Aoo`0301moogoo041oo`00=Woo00<07gooOol0Xgoo00<07gooOol0@Goo000fOol00`0OOomoo`2S
Ool00`0OOomoo`11Ool003Ioo`0301moogoo0:=oo`0301moogoo045oo`00=goo00<07gooOol0XWoo
00<07gooOol0@Goo000gOol00`0OOomoo`2QOol00`0OOomoo`12Ool003Moo`0301moogoo0:5oo`03
01moogoo049oo`00=goo00<07gooOol0XGoo00<07gooOol0@Woo000hOol00`0OOomoo`2OOol00`0O
Oomoo`13Ool003Qoo`0301moogoo09moo`0301moogoo04=oo`00>7oo00<07gooOol0Wgoo00<07goo
Ool0@goo000hOol00`0OOomoo`2OOol00`0OOomoo`13Ool003Uoo`0301moogoo09eoo`0301moogoo
04Aoo`00>Goo00<07gooOol0WGoo00<07gooOol0A7oo000iOol00`0OOomoo`2MOol00`0OOomoo`14
Ool003Uoo`0301moogoo09aoo`0301moogoo04Eoo`00>Woo00<07gooOol0Vgoo00<07gooOol0AGoo
000jOol00`0OOomoo`2JOol00`0OOomoo`16Ool003Yoo`0301moogoo09Yoo`0301moogoo04Ioo`00
>goo00<07gooOol0V7oo00<07gooOol0Agoo000kOol00`0OOomoo`2HOol00`0OOomoo`17Ool003ao
o`0301moogoo09Ioo`0301moogoo04Qoo`00?7oo00<07gooOol0UWoo00<07gooOol0B7oo000mOol0
0`0OOomoo`2DOol00`0OOomoo`19Ool003eoo`0301moogoo09Aoo`0301moogoo04Uoo`00?Goo00<0
7gooOol0Tgoo00<07gooOol0BWoo000nOol00`0OOomoo`2BOol00`0OOomoo`1:Ool003ioo`0301mo
ogoo095oo`0301moogoo04]oo`00?goo00<07gooOol0Sgoo00<07gooOol0C7oo000oOol00`0OOomo
o`2?Ool00`0OOomoo`1<Ool0041oo`0301moogoo08eoo`0301moogoo04eoo`00@7oo00<07gooOol0
SGoo00<07gooOol0CGoo0011Ool00`0OOomoo`2;Ool00`0OOomoo`1>Ool0049oo`0301moogoo08Yo
o`0301moogoo04ioo`00@goo00<07gooOol0R7oo00<07gooOol0Cgoo0013Ool00`0OOomoo`27Ool0
0`0OOomoo`1@Ool004Aoo`0301moogoo08Eoo`0301moogoo055oo`00AGoo00<07gooOol0Q7oo00<0
7gooOol0DGoo0016Ool00`0OOomoo`22Ool00`0OOomoo`1BOol004Moo`0301moogoo081oo`0301mo
ogoo05=oo`00Agoo00<07gooOol0Ogoo00<07gooOol0E7oo0018Ool00`0OOomoo`1nOol00`0OOomo
o`1DOol004Qoo`0301moogoo07eoo`0301moogoo05Eoo`00BGoo00<07gooOol0Ngoo00<07gooOol0
EWoo0019Ool00`0OOomoo`1kOol00`0OOomoo`1FOol004Yoo`0301moogoo07Uoo`0301moogoo05Mo
o`00Bgoo00<07gooOol0Mgoo00<07gooOol0F7oo001<Ool00`0OOomoo`1eOol00`0OOomoo`1IOol0
04eoo`807g=oo`807eaoo`00Cgoo00<07gooOol0Kgoo00<07gooOol0G7oo001@Ool00`0OOomoo`1]
Ool00`0OOomoo`1MOol0055oo`0301moogoo06]oo`0301moogoo05ioo`00DWoo00<07gooOol0JGoo
00<07gooOol0Ggoo001COol00`0OOomoo`1WOol00`0OOomoo`1POol005Aoo`0301moogoo06Eoo`03
01moogoo065oo`00EGoo00<07gooOol0Hgoo00<07gooOol0HWoo001FOol00`0OOomoo`1POol201mU
Ool005Moo`807emoo`0301moogoo06Eoo`00FGoo00<07gooOol0FWoo0P0OJ7oo001JOol201mIOol0
0`0OOomoo`1XOol005aoo`0301moogoo05Aoo`807f]oo`00GGoo0P0ODgoo00<07gooOol0Jgoo001O
Ool00`0OOomoo`1>Ool201m^Ool0061oo`807daoo`807g1oo`00HWoo0P0OB7oo0P0OLWoo001TOol2
01m4Ool201mdOol006Ioo`807d1oo`807gIoo`00J7oo0`0O>goo0P0ON7oo001[Ool201lgOol201mj
Ool006eoo`807c9oo`<07gaoo`00Kgoo0`0O:goo100OOgoo001bOol401lTOol301n3Ool007Ioo`D0
7a]oo`@07hIoo`00Ngoo1`0O27oo300ORWoo0022Ool801nFOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.76247 .56834 m
.75513 .59331 L
s
.76804 .54291 m
.76247 .56834 L
s
.77182 .51717 m
.76804 .54291 L
s
.75513 .59331 m
.74606 .61768 L
s
.77376 .49127 m
.77182 .51717 L
s
.74606 .61768 m
.73531 .6413 L
s
.77386 .46536 m
.77376 .49127 L
s
.73531 .6413 m
.72294 .66404 L
s
.77211 .4396 m
.77386 .46536 L
s
.72294 .66404 m
.70901 .68576 L
s
.7685 .41412 m
.77211 .4396 L
s
.70901 .68576 m
.6936 .70631 L
s
.76305 .3891 m
.7685 .41412 L
s
.6936 .70631 m
.67678 .72558 L
s
.75577 .36468 m
.76305 .3891 L
s
.67678 .72558 m
.65864 .74343 L
s
.74668 .34101 m
.75577 .36468 L
s
.65864 .74343 m
.63929 .75974 L
s
.73582 .31825 m
.74668 .34101 L
s
.63929 .75974 m
.61882 .77439 L
s
.72324 .29656 m
.73582 .31825 L
s
.61882 .77439 m
.59735 .78727 L
s
.709 .27608 m
.72324 .29656 L
s
.59735 .78727 m
.575 .79827 L
s
.69316 .25696 m
.709 .27608 L
s
.575 .79827 m
.55191 .80729 L
s
.6758 .23936 m
.69316 .25696 L
s
.55191 .80729 m
.52821 .81425 L
s
.65702 .2234 m
.6758 .23936 L
s
.52821 .81425 m
.50405 .81906 L
s
.63691 .20922 m
.65702 .2234 L
s
.50405 .81906 m
.47959 .82167 L
s
.61559 .19696 m
.63691 .20922 L
s
.47959 .82167 m
.455 .822 L
s
.59319 .18673 m
.61559 .19696 L
s
.455 .822 m
.43043 .82002 L
s
.56986 .17864 m
.59319 .18673 L
s
.43043 .82002 m
.40608 .8157 L
s
.54573 .17278 m
.56986 .17864 L
s
.40608 .8157 m
.38212 .80904 L
s
.52098 .16925 m
.54573 .17278 L
s
.38212 .80904 m
.35874 .80003 L
s
.49579 .1681 m
.52098 .16925 L
s
.35874 .80003 m
.33611 .7887 L
s
.47033 .1694 m
.49579 .1681 L
s
.33611 .7887 m
.31444 .77511 L
s
.44479 .17316 m
.47033 .1694 L
s
.31444 .77511 m
.2939 .75931 L
s
.41939 .17942 m
.44479 .17316 L
s
.2939 .75931 m
.27468 .7414 L
s
.39432 .18814 m
.41939 .17942 L
s
.27468 .7414 m
.25695 .72149 L
s
.3698 .19931 m
.39432 .18814 L
s
.25695 .72149 m
.24089 .6997 L
s
.34603 .21287 m
.3698 .19931 L
s
.24089 .6997 m
.22664 .67619 L
s
.32322 .22874 m
.34603 .21287 L
s
.22664 .67619 m
.21435 .65113 L
s
.30158 .2468 m
.32322 .22874 L
s
.21435 .65113 m
.20416 .62473 L
s
.2813 .26694 m
.30158 .2468 L
s
.20416 .62473 m
.19616 .59718 L
s
.26258 .289 m
.2813 .26694 L
s
.19616 .59718 m
.19046 .56871 L
s
.24559 .31281 m
.26258 .289 L
s
.19046 .56871 m
.18712 .53957 L
s
.2305 .33817 m
.24559 .31281 L
s
.18712 .53957 m
.18618 .51 L
s
.21743 .36486 m
.2305 .33817 L
s
.18618 .51 m
.18767 .48027 L
s
.20653 .39267 m
.21743 .36486 L
s
.18767 .48027 m
.19158 .45063 L
s
.19788 .42134 m
.20653 .39267 L
s
.19158 .45063 m
.19788 .42134 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0023OolF01n7Ool007ioo`D07aIoo`D07h9oo`00NWoo100O87oo100O
OWoo001gOol301lXOol301mkOol007=oo`@07bioo`@07gMoo`00LGoo0P0O=Woo0P0OMGoo001_Ool2
01ljOol201mcOol006eoo`807cioo`807g5oo`00Jgoo0P0O@Woo0P0OKgoo001ZOol00`0OOomoo`14
Ool201m]Ool006Qoo`807dUoo`0301moogoo06Yoo`00IWoo0P0OC7oo0P0OJWoo001TOol201m@Ool0
0`0OOomoo`1WOol006=oo`0301moogoo055oo`807fMoo`00HGoo0P0OEWoo00<07gooOol0I7oo001O
Ool201mIOol201mTOol005eoo`807eeoo`0301moogoo065oo`00G7oo00<07gooOol0GWoo00<07goo
Ool0H7oo001KOol00`0OOomoo`1POol201mPOol005Yoo`0301moogoo06=oo`0301moogoo05eoo`00
F7oo0P0OIgoo00<07gooOol0G7oo001GOol00`0OOomoo`1XOol00`0OOomoo`1KOol005Ioo`0301mo
ogoo06Yoo`0301moogoo05Yoo`00EGoo00<07gooOol0K7oo00<07gooOol0FGoo001DOol00`0OOomo
o`1^Ool00`0OOomoo`1HOol005=oo`0301moogoo071oo`0301moogoo05Moo`00DWoo00<07gooOol0
LWoo00<07gooOol0EWoo001AOol00`0OOomoo`1dOol00`0OOomoo`1EOol0051oo`0301moogoo07Eo
o`0301moogoo05Eoo`00Cgoo00<07gooOol0Mgoo00<07gooOol0E7oo001>Ool00`0OOomoo`1iOol0
0`0OOomoo`1COol004eoo`0301moogoo07]oo`0301moogoo059oo`00CGoo00<07gooOol0O7oo00<0
7gooOol0DGoo001<Ool00`0OOomoo`1mOol00`0OOomoo`1AOol004]oo`0301moogoo07moo`0301mo
ogoo051oo`00BWoo00<07gooOol0PGoo00<07gooOol0Cgoo001:Ool00`0OOomoo`21Ool00`0OOomo
o`1?Ool004Uoo`0301moogoo08=oo`0301moogoo04ioo`00B7oo00<07gooOol0QGoo00<07gooOol0
CGoo0017Ool00`0OOomoo`26Ool00`0OOomoo`1=Ool004Moo`0301moogoo08Moo`0301moogoo04ao
o`00AWoo00<07gooOol0RGoo00<07gooOol0Bgoo0015Ool00`0OOomoo`2:Ool00`0OOomoo`1;Ool0
04Eoo`0301moogoo08]oo`0301moogoo04Yoo`00A7oo00<07gooOol0S7oo00<07gooOol0BWoo0014
Ool00`0OOomoo`2=Ool00`0OOomoo`19Ool004=oo`0301moogoo08ioo`0301moogoo04Uoo`00@goo
00<07gooOol0Sgoo00<07gooOol0B7oo0012Ool00`0OOomoo`2@Ool00`0OOomoo`18Ool0049oo`03
01moogoo095oo`0301moogoo04Moo`00@Goo00<07gooOol0TWoo00<07gooOol0Agoo0011Ool00`0O
Oomoo`2COol00`0OOomoo`16Ool0041oo`0301moogoo09Aoo`0301moogoo04Ioo`00@7oo00<07goo
Ool0U7oo00<07gooOol0AWoo000oOol00`0OOomoo`2EOol00`0OOomoo`16Ool003moo`0301moogoo
09Ioo`0301moogoo04Eoo`00?Woo00<07gooOol0Ugoo00<07gooOol0AGoo000nOol00`0OOomoo`2G
Ool00`0OOomoo`15Ool003eoo`0301moogoo09Uoo`0301moogoo04Aoo`00?Goo00<07gooOol0VGoo
00<07gooOol0A7oo000lOol00`0OOomoo`2JOol00`0OOomoo`14Ool003aoo`0301moogoo09Yoo`03
01moogoo04Aoo`00?7oo00<07gooOol0Vgoo00<07gooOol0@goo000kOol00`0OOomoo`2LOol00`0O
Oomoo`13Ool003]oo`0301moogoo09aoo`0301moogoo04=oo`00>goo00<07gooOol0WGoo00<07goo
Ool0@Woo000jOol00`0OOomoo`2NOol00`0OOomoo`12Ool003Yoo`0301moogoo09ioo`0301moogoo
049oo`00>Goo00<07gooOol0Wgoo00<07gooOol0@Woo000iOol00`0OOomoo`2POol00`0OOomoo`11
Ool003Uoo`0301moogoo0:1oo`0301moogoo045oo`00>7oo00<07gooOol0XGoo00<07gooOol0@Goo
000hOol00`0OOomoo`2QOol00`0OOomoo`11Ool003Qoo`0301moogoo0:5oo`0301moogoo045oo`00
>7oo00<07gooOol0XGoo00<07gooOol0@Goo000gOol00`0OOomoo`2SOol00`0OOomoo`10Ool003Mo
o`0301moogoo0:=oo`0301moogoo041oo`00=goo00<07gooOol0Xgoo00<07gooOol0@7oo000gOol0
0`0OOomoo`2SOol00`0OOomoo`10Ool003Ioo`0301moogoo0:Aoo`0301moogoo041oo`00=Woo00<0
7gooOol0Y7oo00<07gooOol0@7oo000fOol00`0OOomoo`2TOol00`0OOomoo`10Ool003Ioo`0301mo
ogoo0:Eoo`0301moogoo03moo`00=Woo00<07gooOol0YGoo00<07gooOol0?goo000fOol00`0OOomo
o`2UOol00`0OOomoo`0oOol003Eoo`0301moogoo0:Ioo`0301moogoo03moo`00=Goo00<07gooOol0
YWoo00<07gooOol0?goo000eOol00`0OOomoo`2VOol00`0OOomoo`0oOol003Eoo`0301moogoo0:Io
o`0301moogoo03moo`00=Goo00<07gooOol0YWoo00<07gooOol0?goo000eOol00`0OOomoo`2VOol0
0`0OOomoo`0oOol003Eoo`0301moogoo0:Ioo`0301moogoo03moo`00=Goo00<07gooOol0YWoo00<0
7gooOol0?goo000eOol00`0OOomoo`2VOol00`0OOomoo`0oOol003Eoo`0301moogoo0:Ioo`0301mo
ogoo03moo`00=Goo00<07gooOol0YWoo00<07gooOol0?goo000eOol00`0OOomoo`2UOol00`0OOomo
o`10Ool003Eoo`0301moogoo0:Eoo`0301moogoo041oo`00=Goo00<07gooOol0YGoo00<07gooOol0
@7oo000eOol00`0OOomoo`2UOol00`0OOomoo`10Ool003Eoo`0301moogoo0:Eoo`0301moogoo041o
o`00=Goo00<07gooOol0YGoo00<07gooOol0@7oo000eOol00`0OOomoo`2UOol00`0OOomoo`10Ool0
03Eoo`0301moogoo0:Eoo`0301moogoo041oo`00=Goo00<07gooOol0Y7oo00<07gooOol0@Goo000e
Ool00`0OOomoo`2TOol00`0OOomoo`11Ool003Eoo`0301moogoo0:Aoo`0301moogoo045oo`00=Goo
00<07gooOol0Y7oo00<07gooOol0@Goo000eOol00`0OOomoo`2TOol00`0OOomoo`11Ool003Eoo`03
01moogoo0:=oo`0301moogoo049oo`00=Goo00<07gooOol0Xgoo00<07gooOol0@Woo000fOol00`0O
Oomoo`2ROol00`0OOomoo`12Ool003Ioo`0301moogoo0:9oo`0301moogoo049oo`00=Woo00<07goo
Ool0XGoo00<07gooOol0@goo000fOol00`0OOomoo`2QOol00`0OOomoo`13Ool003Ioo`0301moogoo
0:5oo`0301moogoo04=oo`00=Woo00<07gooOol0XGoo00<07gooOol0@goo000fOol00`0OOomoo`2P
Ool00`0OOomoo`14Ool003Moo`0301moogoo09moo`0301moogoo04Aoo`00=goo00<07gooOol0Wgoo
00<07gooOol0A7oo000gOol00`0OOomoo`2OOol00`0OOomoo`14Ool003Moo`0301moogoo09ioo`03
01moogoo04Eoo`00>7oo00<07gooOol0WGoo00<07gooOol0AGoo000hOol00`0OOomoo`2MOol00`0O
Oomoo`15Ool003Qoo`0301moogoo09aoo`0301moogoo04Ioo`00>7oo00<07gooOol0W7oo00<07goo
Ool0AWoo000iOol00`0OOomoo`2KOol00`0OOomoo`16Ool003Uoo`0301moogoo09]oo`0301moogoo
04Ioo`00>Goo00<07gooOol0VWoo00<07gooOol0Agoo000iOol00`0OOomoo`2JOol00`0OOomoo`17
Ool003Yoo`0301moogoo09Uoo`0301moogoo04Moo`00>Woo00<07gooOol0V7oo00<07gooOol0B7oo
000jOol00`0OOomoo`2HOol00`0OOomoo`18Ool003]oo`0301moogoo09Ioo`0301moogoo04Uoo`00
>goo00<07gooOol0UWoo00<07gooOol0BGoo000lOol00`0OOomoo`2DOol00`0OOomoo`1:Ool003ao
o`0301moogoo09Aoo`0301moogoo04Yoo`00?Goo00<07gooOol0TWoo00<07gooOol0Bgoo000mOol0
0`0OOomoo`2BOol00`0OOomoo`1;Ool003eoo`0301moogoo095oo`0301moogoo04aoo`00?Woo00<0
7gooOol0Sgoo00<07gooOol0CGoo000nOol00`0OOomoo`2?Ool00`0OOomoo`1=Ool003moo`0301mo
ogoo08eoo`0301moogoo04ioo`00?goo00<07gooOol0S7oo00<07gooOol0Cgoo0010Ool00`0OOomo
o`2;Ool00`0OOomoo`1?Ool0041oo`0301moogoo08Yoo`0301moogoo051oo`00@Goo00<07gooOol0
R7oo00<07gooOol0DGoo0012Ool00`0OOomoo`27Ool00`0OOomoo`1AOol0049oo`0301moogoo08Io
o`0301moogoo059oo`00@goo00<07gooOol0Q7oo00<07gooOol0Dgoo0014Ool00`0OOomoo`23Ool0
0`0OOomoo`1COol004Aoo`0301moogoo089oo`0301moogoo05Aoo`00AGoo00<07gooOol0P7oo00<0
7gooOol0EGoo0016Ool00`0OOomoo`1oOol00`0OOomoo`1EOol004Ioo`0301moogoo07ioo`0301mo
ogoo05Ioo`00Agoo00<07gooOol0O7oo00<07gooOol0Egoo0017Ool00`0OOomoo`1kOol00`0OOomo
o`1HOol004Qoo`0301moogoo07Uoo`0301moogoo05Uoo`00B7oo00<07gooOol0NGoo00<07gooOol0
FGoo0019Ool00`0OOomoo`1gOol00`0OOomoo`1JOol004Yoo`0301moogoo07Eoo`0301moogoo05]o
o`00Bgoo00<07gooOol0Lgoo00<07gooOol0G7oo001<Ool00`0OOomoo`1aOol00`0OOomoo`1MOol0
04eoo`0301moogoo06moo`0301moogoo05ioo`00CWoo00<07gooOol0KGoo00<07gooOol0Ggoo001?
Ool00`0OOomoo`1[Ool00`0OOomoo`1POol0051oo`0301moogoo06Uoo`0301moogoo065oo`00DGoo
0P0OJ7oo00<07gooOol0HWoo001COol00`0OOomoo`1SOol201mUOol005Aoo`0301moogoo065oo`03
01moogoo06Eoo`00EGoo00<07gooOol0Ggoo00<07gooOol0IWoo001FOol00`0OOomoo`1LOol201mY
Ool005Moo`807e]oo`0301moogoo06Uoo`00FGoo00<07gooOol0EWoo0P0OK7oo001JOol00`0OOomo
o`1DOol00`0OOomoo`1/Ool005]oo`807e9oo`807fmoo`00GGoo00<07gooOol0CGoo0P0OLGoo001N
Ool201m;Ool201mcOol0061oo`0301moogoo04Ioo`807gEoo`00HGoo0P0OAGoo00<07gooOol0MGoo
001SOol201m1Ool201mhOol006Eoo`<07caoo`807gYoo`00J7oo0P0O=Woo100OO7oo001ZOol201la
Ool301n0Ool006aoo`<07bYoo`@07h=oo`00Kgoo100O8goo0`0OQgoo001cOol501lJOol401n:Ool0
07QooaX07hioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.74475 .59356 m
.73486 .61752 L
s
.75301 .56897 m
.74475 .59356 L
s
.75958 .5439 m
.75301 .56897 L
s
.73486 .61752 m
.72337 .64073 L
s
.76441 .51849 m
.75958 .5439 L
s
.72337 .64073 m
.71036 .66305 L
s
.76748 .49288 m
.76441 .51849 L
s
.71036 .66305 m
.69589 .68434 L
s
.76876 .46723 m
.76748 .49288 L
s
.69589 .68434 m
.68004 .70448 L
s
.76824 .44168 m
.76876 .46723 L
s
.68004 .70448 m
.66289 .72334 L
s
.76589 .41638 m
.76824 .44168 L
s
.66289 .72334 m
.64453 .74079 L
s
.76171 .39148 m
.76589 .41638 L
s
.64453 .74079 m
.62505 .75674 L
s
.75573 .36713 m
.76171 .39148 L
s
.62505 .75674 m
.60457 .77105 L
s
.74793 .3435 m
.75573 .36713 L
s
.60457 .77105 m
.5832 .78362 L
s
.73836 .32072 m
.74793 .3435 L
s
.5832 .78362 m
.56104 .79435 L
s
.72705 .29897 m
.73836 .32072 L
s
.56104 .79435 m
.53825 .80315 L
s
.71404 .27839 m
.72705 .29897 L
s
.53825 .80315 m
.51494 .80992 L
s
.69939 .25914 m
.71404 .27839 L
s
.51494 .80992 m
.49126 .8146 L
s
.68317 .24135 m
.69939 .25914 L
s
.49126 .8146 m
.46737 .81711 L
s
.66545 .22519 m
.68317 .24135 L
s
.46737 .81711 m
.44342 .8174 L
s
.64634 .21079 m
.66545 .22519 L
s
.44342 .8174 m
.41957 .81543 L
s
.62593 .19827 m
.64634 .21079 L
s
.41957 .81543 m
.396 .81116 L
s
.60436 .18778 m
.62593 .19827 L
s
.396 .81116 m
.37288 .80458 L
s
.58175 .17941 m
.60436 .18778 L
s
.37288 .80458 m
.35038 .7957 L
s
.55824 .17329 m
.58175 .17941 L
s
.35038 .7957 m
.32869 .78454 L
s
.53401 .16948 m
.55824 .17329 L
s
.32869 .78454 m
.30799 .77113 L
s
.50922 .16808 m
.53401 .16948 L
s
.30799 .77113 m
.28845 .75555 L
s
.48405 .16913 m
.50922 .16808 L
s
.28845 .75555 m
.27026 .73786 L
s
.4587 .17267 m
.48405 .16913 L
s
.27026 .73786 m
.25358 .71818 L
s
.43337 .17872 m
.4587 .17267 L
s
.25358 .71818 m
.23856 .69663 L
s
.40827 .18727 m
.43337 .17872 L
s
.23856 .69663 m
.22538 .67335 L
s
.3836 .19829 m
.40827 .18727 L
s
.22538 .67335 m
.21415 .64852 L
s
.35958 .21172 m
.3836 .19829 L
s
.21415 .64852 m
.20502 .62232 L
s
.33644 .22749 m
.35958 .21172 L
s
.20502 .62232 m
.19807 .59496 L
s
.31437 .24548 m
.33644 .22749 L
s
.19807 .59496 m
.19341 .56666 L
s
.29358 .26556 m
.31437 .24548 L
s
.19341 .56666 m
.19109 .53766 L
s
.27427 .28758 m
.29358 .26556 L
s
.19109 .53766 m
.19115 .50822 L
s
.25662 .31136 m
.27427 .28758 L
s
.19115 .50822 m
.19362 .47858 L
s
.2408 .33669 m
.25662 .31136 L
s
.19362 .47858 m
.19848 .44901 L
s
.22695 .36337 m
.2408 .33669 L
s
.19848 .44901 m
.2057 .41978 L
s
.21522 .39114 m
.22695 .36337 L
s
.2057 .41978 m
.21522 .39114 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0027OolF01n3Ool0089oo`D07aIoo`D07gioo`00OWoo100O87oo0`0O
Ngoo001kOol301lWOol301mhOol007Moo`@07beoo`@07gAoo`00M7oo0`0O=Goo0P0OLWoo001bOol2
01ljOol201m`Ool0071oo`807cioo`807fioo`00KWoo0P0O@Woo0P0OK7oo001/Ool201m6Ool201mZ
Ool006Yoo`807dYoo`0301moogoo06Moo`00J7oo0P0OCGoo0P0OIgoo001WOol00`0OOomoo`1?Ool0
0`0OOomoo`1TOol006Eoo`807e=oo`0301moogoo06=oo`00I7oo00<07gooOol0E7oo0P0OHgoo001S
Ool00`0OOomoo`1GOol00`0OOomoo`1POol0065oo`807e]oo`0301moogoo05moo`00H7oo00<07goo
Ool0G7oo00<07gooOol0GWoo001OOol00`0OOomoo`1NOol00`0OOomoo`1MOol005ioo`0301moogoo
061oo`807eeoo`00G7oo0P0OIGoo00<07gooOol0FWoo001KOol00`0OOomoo`1VOol00`0OOomoo`1I
Ool005Yoo`0301moogoo06Qoo`0301moogoo05Qoo`00FGoo00<07gooOol0JWoo00<07gooOol0Egoo
001HOol00`0OOomoo`1[Ool00`0OOomoo`1GOol005Moo`0301moogoo06eoo`0301moogoo05Ioo`00
EWoo00<07gooOol0Kgoo00<07gooOol0EGoo001EOol00`0OOomoo`1aOol00`0OOomoo`1DOol005Ao
o`0301moogoo07=oo`0301moogoo05=oo`00Dgoo00<07gooOol0M7oo00<07gooOol0Dgoo001BOol0
0`0OOomoo`1fOol00`0OOomoo`1BOol0055oo`0301moogoo07Qoo`0301moogoo055oo`00D7oo00<0
7gooOol0NWoo00<07gooOol0D7oo001?Ool00`0OOomoo`1kOol00`0OOomoo`1@Ool004ioo`0301mo
ogoo07eoo`0301moogoo04moo`00CGoo00<07gooOol0Ogoo00<07gooOol0CWoo001=Ool00`0OOomo
o`1oOol00`0OOomoo`1>Ool004aoo`0301moogoo085oo`0301moogoo04eoo`00Bgoo00<07gooOol0
PWoo00<07gooOol0CGoo001:Ool00`0OOomoo`24Ool00`0OOomoo`1<Ool004Yoo`0301moogoo08Ao
o`0301moogoo04aoo`00BGoo00<07gooOol0QWoo00<07gooOol0Bgoo0018Ool00`0OOomoo`27Ool0
0`0OOomoo`1;Ool004Qoo`0301moogoo08Qoo`0301moogoo04Yoo`00Agoo00<07gooOol0RGoo00<0
7gooOol0BWoo0017Ool00`0OOomoo`29Ool00`0OOomoo`1:Ool004Ioo`0301moogoo08]oo`0301mo
ogoo04Uoo`00AWoo00<07gooOol0Rgoo00<07gooOol0BGoo0015Ool00`0OOomoo`2=Ool00`0OOomo
o`18Ool004Aoo`0301moogoo08ioo`0301moogoo04Qoo`00A7oo00<07gooOol0Sgoo00<07gooOol0
Agoo0013Ool00`0OOomoo`2@Ool00`0OOomoo`17Ool004=oo`0301moogoo095oo`0301moogoo04Io
o`00@Woo00<07gooOol0TWoo00<07gooOol0AWoo0012Ool00`0OOomoo`2BOol00`0OOomoo`16Ool0
045oo`0301moogoo09=oo`0301moogoo04Ioo`00@Goo00<07gooOol0U7oo00<07gooOol0AGoo0010
Ool00`0OOomoo`2EOol00`0OOomoo`15Ool0041oo`0301moogoo09Eoo`0301moogoo04Eoo`00?goo
00<07gooOol0Ugoo00<07gooOol0A7oo000oOol00`0OOomoo`2GOol00`0OOomoo`14Ool003ioo`03
01moogoo09Qoo`0301moogoo04Aoo`00?Woo00<07gooOol0V7oo00<07gooOol0A7oo000mOol00`0O
Oomoo`2JOol00`0OOomoo`13Ool003eoo`0301moogoo09Yoo`0301moogoo04=oo`00?Goo00<07goo
Ool0VWoo00<07gooOol0@goo000lOol00`0OOomoo`2KOol00`0OOomoo`13Ool003aoo`0301moogoo
09]oo`0301moogoo04=oo`00?7oo00<07gooOol0W7oo00<07gooOol0@Woo000lOol00`0OOomoo`2L
Ool00`0OOomoo`12Ool003]oo`0301moogoo09eoo`0301moogoo049oo`00>goo00<07gooOol0WGoo
00<07gooOol0@Woo000kOol00`0OOomoo`2MOol00`0OOomoo`12Ool003]oo`0301moogoo09eoo`03
01moogoo049oo`00>Woo00<07gooOol0WWoo00<07gooOol0@Woo000jOol00`0OOomoo`2OOol00`0O
Oomoo`11Ool003Uoo`0301moogoo0:1oo`0301moogoo045oo`00>Goo00<07gooOol0X7oo00<07goo
Ool0@Goo000iOol00`0OOomoo`2POol00`0OOomoo`11Ool003Qoo`0301moogoo0:5oo`0301moogoo
045oo`00>7oo00<07gooOol0XGoo00<07gooOol0@Goo000hOol00`0OOomoo`2QOol00`0OOomoo`11
Ool003Qoo`0301moogoo0:5oo`0301moogoo045oo`00>7oo00<07gooOol0XGoo00<07gooOol0@Goo
000hOol00`0OOomoo`2QOol00`0OOomoo`11Ool003Moo`0301moogoo0:9oo`0301moogoo045oo`00
=goo00<07gooOol0XWoo00<07gooOol0@Goo000gOol00`0OOomoo`2ROol00`0OOomoo`11Ool003Mo
o`0301moogoo0:9oo`0301moogoo045oo`00=goo00<07gooOol0XWoo00<07gooOol0@Goo000gOol0
0`0OOomoo`2ROol00`0OOomoo`11Ool003Moo`0301moogoo0:9oo`0301moogoo045oo`00=goo00<0
7gooOol0XWoo00<07gooOol0@Goo000fOol00`0OOomoo`2SOol00`0OOomoo`11Ool003Ioo`0301mo
ogoo0:=oo`0301moogoo045oo`00=Woo00<07gooOol0Xgoo00<07gooOol0@Goo000fOol00`0OOomo
o`2SOol00`0OOomoo`11Ool003Ioo`0301moogoo0:9oo`0301moogoo049oo`00=Woo00<07gooOol0
XWoo00<07gooOol0@Woo000fOol00`0OOomoo`2ROol00`0OOomoo`12Ool003Ioo`0301moogoo0:9o
o`0301moogoo049oo`00=Woo00<07gooOol0XWoo00<07gooOol0@Woo000fOol00`0OOomoo`2ROol0
0`0OOomoo`12Ool003Ioo`0301moogoo0:9oo`0301moogoo049oo`00=Woo00<07gooOol0XGoo00<0
7gooOol0@goo000fOol00`0OOomoo`2QOol00`0OOomoo`13Ool003Ioo`0301moogoo0:5oo`0301mo
ogoo04=oo`00=Woo00<07gooOol0XGoo00<07gooOol0@goo000fOol00`0OOomoo`2QOol00`0OOomo
o`13Ool003Ioo`0301moogoo0:5oo`0301moogoo04=oo`00=Woo00<07gooOol0X7oo00<07gooOol0
A7oo000gOol00`0OOomoo`2OOol00`0OOomoo`14Ool003Moo`0301moogoo09moo`0301moogoo04Ao
o`00=goo00<07gooOol0Wgoo00<07gooOol0A7oo000gOol00`0OOomoo`2NOol00`0OOomoo`15Ool0
03Moo`0301moogoo09ioo`0301moogoo04Eoo`00=goo00<07gooOol0WWoo00<07gooOol0AGoo000g
Ool00`0OOomoo`2MOol00`0OOomoo`16Ool003Moo`0301moogoo09eoo`0301moogoo04Ioo`00>7oo
00<07gooOol0Vgoo00<07gooOol0Agoo000hOol00`0OOomoo`2KOol00`0OOomoo`17Ool003Qoo`03
01moogoo09Yoo`0301moogoo04Qoo`00>7oo00<07gooOol0VWoo00<07gooOol0B7oo000hOol00`0O
Oomoo`2JOol00`0OOomoo`18Ool003Qoo`0301moogoo09Uoo`0301moogoo04Uoo`00>Goo00<07goo
Ool0V7oo00<07gooOol0BGoo000iOol00`0OOomoo`2GOol00`0OOomoo`1:Ool003Uoo`0301moogoo
09Moo`0301moogoo04Yoo`00>Goo00<07gooOol0UWoo00<07gooOol0Bgoo000jOol00`0OOomoo`2E
Ool00`0OOomoo`1;Ool003Yoo`0301moogoo09Aoo`0301moogoo04aoo`00>Woo00<07gooOol0U7oo
00<07gooOol0C7oo000kOol00`0OOomoo`2BOol00`0OOomoo`1=Ool003]oo`0301moogoo099oo`03
01moogoo04eoo`00>goo00<07gooOol0TGoo00<07gooOol0CWoo000lOol00`0OOomoo`2@Ool00`0O
Oomoo`1>Ool003aoo`0301moogoo08moo`0301moogoo04moo`00?Goo00<07gooOol0SWoo00<07goo
Ool0Cgoo000mOol00`0OOomoo`2=Ool00`0OOomoo`1@Ool003eoo`0301moogoo08eoo`0301moogoo
051oo`00?Woo00<07gooOol0Rgoo00<07gooOol0DGoo000nOol00`0OOomoo`2;Ool00`0OOomoo`1A
Ool003moo`0301moogoo08Uoo`0301moogoo059oo`00?goo00<07gooOol0R7oo00<07gooOol0Dgoo
0010Ool00`0OOomoo`27Ool00`0OOomoo`1COol0041oo`0301moogoo08Ioo`0301moogoo05Aoo`00
@Goo00<07gooOol0Q7oo00<07gooOol0EGoo0011Ool00`0OOomoo`24Ool00`0OOomoo`1EOol0049o
o`0301moogoo089oo`0301moogoo05Ioo`00@goo00<07gooOol0P7oo00<07gooOol0Egoo0013Ool0
0`0OOomoo`20Ool00`0OOomoo`1GOol004Aoo`0301moogoo07ioo`0301moogoo05Qoo`00AGoo00<0
7gooOol0O7oo00<07gooOol0FGoo0015Ool00`0OOomoo`1lOol00`0OOomoo`1IOol004Ioo`0301mo
ogoo07Yoo`0301moogoo05Yoo`00AWoo00<07gooOol0NGoo00<07gooOol0Fgoo0017Ool00`0OOomo
o`1gOol00`0OOomoo`1LOol004Moo`0301moogoo07Ioo`0301moogoo05eoo`00B7oo00<07gooOol0
M7oo00<07gooOol0GWoo0019Ool00`0OOomoo`1bOol00`0OOomoo`1OOol004Yoo`0301moogoo071o
o`0301moogoo061oo`00Bgoo00<07gooOol0KWoo00<07gooOol0HGoo001<Ool00`0OOomoo`1[Ool2
01mTOol004eoo`0301moogoo06Uoo`0301moogoo06Aoo`00CWoo00<07gooOol0Igoo00<07gooOol0
IGoo001?Ool00`0OOomoo`1UOol00`0OOomoo`1VOol0051oo`0301moogoo06=oo`0301moogoo06Mo
o`00DGoo00<07gooOol0HGoo00<07gooOol0J7oo001BOol00`0OOomoo`1OOol00`0OOomoo`1YOol0
05=oo`0301moogoo05eoo`0301moogoo06Yoo`00E7oo00<07gooOol0FWoo0P0OKGoo001EOol201mI
Ool00`0OOomoo`1]Ool005Moo`0301moogoo05Aoo`807g1oo`00F7oo00<07gooOol0DWoo00<07goo
Ool0L7oo001IOol201m@Ool201mcOol005]oo`0301moogoo04]oo`807gEoo`00G7oo0P0OBGoo0P0O
Mgoo001NOol00`0OOomoo`14Ool201miOol005moo`807d9oo`807g]oo`00HGoo0P0O?Goo0`0OOGoo
001SOol301lhOol201n0Ool006Ioo`@07c9oo`807h9oo`00JWoo0`0O;7oo0`0OQ7oo001]Ool301lU
Ool401n7Ool0071oo`<07aeoo`D07h]oo`00Lgoo100O4goo1P0OT7oo001gOolC01nFOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.73302 .59241 m
.72238 .61593 L
s
.74211 .56827 m
.73302 .59241 L
s
.72238 .61593 m
.71025 .63869 L
s
.7496 .54364 m
.74211 .56827 L
s
.71025 .63869 m
.69669 .66057 L
s
.75544 .51864 m
.7496 .54364 L
s
.69669 .66057 m
.68179 .68143 L
s
.7596 .49344 m
.75544 .51864 L
s
.68179 .68143 m
.6656 .70116 L
s
.76203 .46816 m
.7596 .49344 L
s
.6656 .70116 m
.64823 .71963 L
s
.76271 .44295 m
.76203 .46816 L
s
.64823 .71963 m
.62975 .73674 L
s
.76162 .41795 m
.76271 .44295 L
s
.62975 .73674 m
.61027 .75236 L
s
.75874 .39332 m
.76162 .41795 L
s
.61027 .75236 m
.58988 .76639 L
s
.75408 .36921 m
.75874 .39332 L
s
.58988 .76639 m
.56871 .77873 L
s
.74763 .34576 m
.75408 .36921 L
s
.56871 .77873 m
.54686 .78927 L
s
.73941 .32314 m
.74763 .34576 L
s
.54686 .78927 m
.52445 .79793 L
s
.72945 .30149 m
.73941 .32314 L
s
.52445 .79793 m
.50163 .80461 L
s
.71777 .28098 m
.72945 .30149 L
s
.50163 .80461 m
.47853 .80926 L
s
.70442 .26174 m
.71777 .28098 L
s
.47853 .80926 m
.4553 .81179 L
s
.68946 .24395 m
.70442 .26174 L
s
.4553 .81179 m
.43208 .81215 L
s
.67295 .22774 m
.68946 .24395 L
s
.43208 .81215 m
.40904 .81029 L
s
.65499 .21325 m
.67295 .22774 L
s
.40904 .81029 m
.38634 .80619 L
s
.63566 .20063 m
.65499 .21325 L
s
.38634 .80619 m
.36414 .79982 L
s
.61508 .19001 m
.63566 .20063 L
s
.36414 .79982 m
.34261 .79119 L
s
.59337 .1815 m
.61508 .19001 L
s
.34261 .79119 m
.32194 .7803 L
s
.57067 .17521 m
.59337 .1815 L
s
.32194 .7803 m
.30229 .7672 L
s
.54713 .17124 m
.57067 .17521 L
s
.30229 .7672 m
.28384 .75194 L
s
.52293 .16966 m
.54713 .17124 L
s
.28384 .75194 m
.26675 .7346 L
s
.49823 .17054 m
.52293 .16966 L
s
.26675 .7346 m
.25118 .71527 L
s
.47323 .17392 m
.49823 .17054 L
s
.25118 .71527 m
.2373 .69406 L
s
.44814 .17982 m
.47323 .17392 L
s
.2373 .69406 m
.22525 .67113 L
s
.42314 .18822 m
.44814 .17982 L
s
.22525 .67113 m
.21517 .64663 L
s
.39847 .19911 m
.42314 .18822 L
s
.21517 .64663 m
.20716 .62074 L
s
.37434 .21242 m
.39847 .19911 L
s
.20716 .62074 m
.20133 .59367 L
s
.35097 .22808 m
.37434 .21242 L
s
.20133 .59367 m
.19777 .56564 L
s
.32856 .24598 m
.35097 .22808 L
s
.19777 .56564 m
.19653 .53688 L
s
.30734 .26598 m
.32856 .24598 L
s
.19653 .53688 m
.19765 .50764 L
s
.2875 .28792 m
.30734 .26598 L
s
.19765 .50764 m
.20114 .47819 L
s
.26924 .31162 m
.2875 .28792 L
s
.20114 .47819 m
.20698 .44877 L
s
.25272 .33688 m
.26924 .31162 L
s
.20698 .44877 m
.21514 .41967 L
s
.23811 .36347 m
.25272 .33688 L
s
.21514 .41967 m
.22555 .39115 L
s
.22555 .39115 m
.23811 .36347 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo002;Ool?01n6Ool008Ioo`D07`moo`H07h1oo`00PWoo100O6Woo1@0O
Ngoo001oOol301lSOol401mgOol007eoo`807bYoo`<07gAoo`00Ngoo0P0O;goo0`0OLGoo001hOol3
01ldOol201m_Ool007Ioo`807cUoo`807feoo`00M7oo0P0O?Goo0P0OJgoo001aOol301m1Ool201mY
Ool006moo`807dIoo`0301moogoo06Ioo`00KGoo0P0OBGoo0P0OIWoo001[Ool201m=Ool00`0OOomo
o`1SOol006Uoo`807e1oo`0301moogoo069oo`00J7oo00<07gooOol0DGoo0P0OHWoo001WOol00`0O
Oomoo`1DOol00`0OOomoo`1OOol006Eoo`807eQoo`807emoo`00I7oo00<07gooOol0FWoo00<07goo
Ool0G7oo001SOol00`0OOomoo`1LOol00`0OOomoo`1KOol0069oo`0301moogoo05ioo`0301moogoo
05Yoo`00H7oo0P0OHGoo00<07gooOol0FWoo001OOol00`0OOomoo`1ROol00`0OOomoo`1IOol005io
o`0301moogoo06Aoo`0301moogoo05Qoo`00GGoo00<07gooOol0IWoo00<07gooOol0Egoo001LOol0
0`0OOomoo`1XOol00`0OOomoo`1FOol005]oo`0301moogoo06Yoo`0301moogoo05Eoo`00FWoo00<0
7gooOol0K7oo00<07gooOol0E7oo001IOol00`0OOomoo`1^Ool00`0OOomoo`1COol005Qoo`0301mo
ogoo071oo`0301moogoo059oo`00Egoo00<07gooOol0LWoo00<07gooOol0DGoo001FOol00`0OOomo
o`1cOol00`0OOomoo`1AOol005Eoo`0301moogoo07Eoo`0301moogoo051oo`00E7oo00<07gooOol0
Mgoo00<07gooOol0Cgoo001COol00`0OOomoo`1hOol00`0OOomoo`1?Ool0059oo`0301moogoo07Yo
o`0301moogoo04ioo`00DGoo00<07gooOol0Ngoo00<07gooOol0CWoo001AOol00`0OOomoo`1lOol0
0`0OOomoo`1=Ool0051oo`0301moogoo07eoo`0301moogoo04eoo`00Cgoo00<07gooOol0Ogoo00<0
7gooOol0C7oo001>Ool00`0OOomoo`20Ool00`0OOomoo`1<Ool004ioo`0301moogoo085oo`0301mo
ogoo04]oo`00CGoo00<07gooOol0PWoo00<07gooOol0Bgoo001<Ool00`0OOomoo`24Ool00`0OOomo
o`1:Ool004aoo`0301moogoo08Aoo`0301moogoo04Yoo`00Bgoo00<07gooOol0QWoo00<07gooOol0
BGoo001:Ool00`0OOomoo`27Ool00`0OOomoo`19Ool004Uoo`0301moogoo08Uoo`0301moogoo04Qo
o`00BGoo00<07gooOol0RGoo00<07gooOol0B7oo0018Ool00`0OOomoo`2:Ool00`0OOomoo`18Ool0
04Moo`0301moogoo08]oo`0301moogoo04Qoo`00Agoo00<07gooOol0S7oo00<07gooOol0Agoo0016
Ool00`0OOomoo`2=Ool00`0OOomoo`17Ool004Ioo`0301moogoo08eoo`0301moogoo04Moo`00AGoo
00<07gooOol0Sgoo00<07gooOol0AWoo0015Ool00`0OOomoo`2?Ool00`0OOomoo`16Ool004Aoo`03
01moogoo091oo`0301moogoo04Ioo`00A7oo00<07gooOol0TGoo00<07gooOol0AGoo0013Ool00`0O
Oomoo`2BOol00`0OOomoo`15Ool004=oo`0301moogoo099oo`0301moogoo04Eoo`00@Woo00<07goo
Ool0Tgoo00<07gooOol0AGoo0012Ool00`0OOomoo`2COol00`0OOomoo`15Ool0045oo`0301moogoo
09Eoo`0301moogoo04Aoo`00@Goo00<07gooOol0UGoo00<07gooOol0A7oo0010Ool00`0OOomoo`2F
Ool00`0OOomoo`14Ool0041oo`0301moogoo09Ioo`0301moogoo04Aoo`00@7oo00<07gooOol0UWoo
00<07gooOol0A7oo000oOol00`0OOomoo`2GOol00`0OOomoo`14Ool003moo`0301moogoo09Moo`03
01moogoo04Aoo`00?Woo00<07gooOol0VGoo00<07gooOol0@goo000nOol00`0OOomoo`2IOol00`0O
Oomoo`13Ool003ioo`0301moogoo09Uoo`0301moogoo04=oo`00?Goo00<07gooOol0VWoo00<07goo
Ool0@goo000mOol00`0OOomoo`2JOol00`0OOomoo`13Ool003eoo`0301moogoo09Yoo`0301moogoo
04=oo`00?7oo00<07gooOol0Vgoo00<07gooOol0@goo000lOol00`0OOomoo`2KOol00`0OOomoo`13
Ool003aoo`0301moogoo09]oo`0301moogoo04=oo`00?7oo00<07gooOol0Vgoo00<07gooOol0@goo
000kOol00`0OOomoo`2LOol00`0OOomoo`13Ool003]oo`0301moogoo09aoo`0301moogoo04=oo`00
>goo00<07gooOol0W7oo00<07gooOol0@goo000kOol00`0OOomoo`2LOol00`0OOomoo`13Ool003]o
o`0301moogoo09aoo`0301moogoo04=oo`00>Woo00<07gooOol0WGoo00<07gooOol0@goo000jOol0
0`0OOomoo`2MOol00`0OOomoo`13Ool003Yoo`0301moogoo09eoo`0301moogoo04=oo`00>Woo00<0
7gooOol0WGoo00<07gooOol0@goo000iOol00`0OOomoo`2NOol00`0OOomoo`13Ool003Uoo`0301mo
ogoo09ioo`0301moogoo04=oo`00>Goo00<07gooOol0WWoo00<07gooOol0@goo000iOol00`0OOomo
o`2NOol00`0OOomoo`13Ool003Uoo`0301moogoo09ioo`0301moogoo04=oo`00>Goo00<07gooOol0
WWoo00<07gooOol0@goo000hOol00`0OOomoo`2OOol00`0OOomoo`13Ool003Qoo`0301moogoo09mo
o`0301moogoo04=oo`00>7oo00<07gooOol0WWoo00<07gooOol0A7oo000hOol00`0OOomoo`2NOol0
0`0OOomoo`14Ool003Qoo`0301moogoo09ioo`0301moogoo04Aoo`00>7oo00<07gooOol0WWoo00<0
7gooOol0A7oo000hOol00`0OOomoo`2MOol00`0OOomoo`15Ool003Qoo`0301moogoo09eoo`0301mo
ogoo04Eoo`00>7oo00<07gooOol0WGoo00<07gooOol0AGoo000hOol00`0OOomoo`2MOol00`0OOomo
o`15Ool003Qoo`0301moogoo09eoo`0301moogoo04Eoo`00>7oo00<07gooOol0W7oo00<07gooOol0
AWoo000hOol00`0OOomoo`2LOol00`0OOomoo`16Ool003Qoo`0301moogoo09aoo`0301moogoo04Io
o`00>7oo00<07gooOol0W7oo00<07gooOol0AWoo000hOol00`0OOomoo`2LOol00`0OOomoo`16Ool0
03Qoo`0301moogoo09aoo`0301moogoo04Ioo`00>7oo00<07gooOol0Vgoo00<07gooOol0Agoo000h
Ool00`0OOomoo`2KOol00`0OOomoo`17Ool003Qoo`0301moogoo09Yoo`0301moogoo04Qoo`00>7oo
00<07gooOol0VWoo00<07gooOol0B7oo000hOol00`0OOomoo`2IOol00`0OOomoo`19Ool003Qoo`03
01moogoo09Uoo`0301moogoo04Uoo`00>7oo00<07gooOol0VGoo00<07gooOol0BGoo000hOol00`0O
Oomoo`2HOol00`0OOomoo`1:Ool003Qoo`0301moogoo09Qoo`0301moogoo04Yoo`00>Goo00<07goo
Ool0Ugoo00<07gooOol0BWoo000iOol00`0OOomoo`2GOol00`0OOomoo`1:Ool003Uoo`0301moogoo
09Ioo`0301moogoo04]oo`00>Goo00<07gooOol0UWoo00<07gooOol0Bgoo000iOol00`0OOomoo`2E
Ool00`0OOomoo`1<Ool003Uoo`0301moogoo09Eoo`0301moogoo04aoo`00>Woo00<07gooOol0Tgoo
00<07gooOol0CGoo000jOol00`0OOomoo`2COol00`0OOomoo`1=Ool003Yoo`0301moogoo099oo`03
01moogoo04ioo`00>Woo00<07gooOol0TWoo00<07gooOol0CWoo000kOol00`0OOomoo`2@Ool00`0O
Oomoo`1?Ool003]oo`0301moogoo091oo`0301moogoo04moo`00>goo00<07gooOol0Sgoo00<07goo
Ool0D7oo000lOol00`0OOomoo`2>Ool00`0OOomoo`1@Ool003aoo`0301moogoo08eoo`0301moogoo
055oo`00?7oo00<07gooOol0SGoo00<07gooOol0DGoo000lOol00`0OOomoo`2<Ool00`0OOomoo`1B
Ool003eoo`0301moogoo08Yoo`0301moogoo05=oo`00?Goo00<07gooOol0RWoo00<07gooOol0Dgoo
000mOol00`0OOomoo`29Ool00`0OOomoo`1DOol003ioo`0301moogoo08Moo`0301moogoo05Eoo`00
?Woo00<07gooOol0Qgoo00<07gooOol0EGoo000oOol00`0OOomoo`25Ool00`0OOomoo`1FOol003mo
o`0301moogoo08Aoo`0301moogoo05Moo`00@7oo00<07gooOol0Pgoo00<07gooOol0Egoo0010Ool0
0`0OOomoo`22Ool00`0OOomoo`1HOol0045oo`0301moogoo081oo`0301moogoo05Uoo`00@Goo00<0
7gooOol0P7oo00<07gooOol0FGoo0012Ool00`0OOomoo`1nOol00`0OOomoo`1JOol0049oo`0301mo
ogoo07eoo`0301moogoo05]oo`00@goo00<07gooOol0O7oo00<07gooOol0Fgoo0013Ool00`0OOomo
o`1kOol00`0OOomoo`1LOol004Aoo`0301moogoo07Uoo`0301moogoo05eoo`00AGoo00<07gooOol0
N7oo00<07gooOol0GGoo0015Ool00`0OOomoo`1gOol00`0OOomoo`1NOol004Ioo`0301moogoo07Eo
o`0301moogoo05moo`00Agoo00<07gooOol0Lgoo00<07gooOol0H7oo0017Ool00`0OOomoo`1bOol0
0`0OOomoo`1QOol004Qoo`0301moogoo071oo`0301moogoo069oo`00BGoo00<07gooOol0KWoo00<0
7gooOol0Hgoo001:Ool00`0OOomoo`1/Ool00`0OOomoo`1TOol004Yoo`0301moogoo06]oo`0301mo
ogoo06Eoo`00Bgoo00<07gooOol0J7oo0P0OJ7oo001<Ool00`0OOomoo`1VOol00`0OOomoo`1XOol0
04eoo`0301moogoo06Aoo`0301moogoo06Uoo`00CWoo00<07gooOol0HWoo00<07gooOol0JWoo001?
Ool00`0OOomoo`1OOol201m]Ool0051oo`0301moogoo05eoo`0301moogoo06eoo`00DGoo00<07goo
Ool0Fgoo00<07gooOol0KWoo001BOol00`0OOomoo`1HOol201maOol005=oo`0301moogoo05Ioo`03
01moogoo075oo`00E7oo00<07gooOol0Dgoo0P0OM7oo001EOol00`0OOomoo`1AOol00`0OOomoo`1d
Ool005Ioo`0301moogoo04ioo`807gMoo`00Egoo0P0OCGoo00<07gooOol0Mgoo001IOol201m9Ool2
01mjOol005]oo`807dEoo`807gaoo`00GGoo0P0O@Goo0P0OOWoo001OOol00`0OOomoo`0lOol201n0
Ool0061oo`807cYoo`807h9oo`00HWoo0P0O=Woo0P0OQ7oo001TOol301laOol201n6Ool006Moo`<0
7bUoo`D07hQoo`00JWoo0`0O8Goo1@0OSGoo001]Ool501lIOol301nBOol0079oo`L07`Moo`/07iEo
o`00NGoo1`0OX7oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.70881 .61301 m
.69613 .63533 L
s
.72011 .58995 m
.70881 .61301 L
s
.72996 .56627 m
.72011 .58995 L
s
.69613 .63533 m
.68213 .65679 L
s
.7383 .54211 m
.72996 .56627 L
s
.68213 .65679 m
.66688 .67725 L
s
.74509 .51758 m
.7383 .54211 L
s
.66688 .67725 m
.65047 .69662 L
s
.75027 .49283 m
.74509 .51758 L
s
.65047 .69662 m
.63297 .71476 L
s
.75381 .46799 m
.75027 .49283 L
s
.63297 .71476 m
.61448 .73158 L
s
.75567 .4432 m
.75381 .46799 L
s
.61448 .73158 m
.59509 .74695 L
s
.75581 .41861 m
.75567 .4432 L
s
.59509 .74695 m
.5749 .76079 L
s
.75423 .39436 m
.75581 .41861 L
s
.5749 .76079 m
.55402 .77298 L
s
.75091 .37059 m
.75423 .39436 L
s
.55402 .77298 m
.53256 .78343 L
s
.74584 .34745 m
.75091 .37059 L
s
.53256 .78343 m
.51065 .79205 L
s
.73901 .32511 m
.74584 .34745 L
s
.51065 .79205 m
.48841 .79876 L
s
.73045 .3037 m
.73901 .32511 L
s
.48841 .79876 m
.46597 .80348 L
s
.72018 .28339 m
.73045 .3037 L
s
.46597 .80348 m
.44348 .80614 L
s
.70822 .26432 m
.72018 .28339 L
s
.44348 .80614 m
.42108 .80669 L
s
.69463 .24666 m
.70822 .26432 L
s
.42108 .80669 m
.39892 .80507 L
s
.67946 .23054 m
.69463 .24666 L
s
.39892 .80507 m
.37716 .80125 L
s
.66277 .21611 m
.67946 .23054 L
s
.37716 .80125 m
.35596 .7952 L
s
.64466 .20352 m
.66277 .21611 L
s
.35596 .7952 m
.33548 .78693 L
s
.62523 .1929 m
.64466 .20352 L
s
.33548 .78693 m
.3159 .77644 L
s
.60458 .18436 m
.62523 .1929 L
s
.3159 .77644 m
.29737 .76375 L
s
.58285 .17803 m
.60458 .18436 L
s
.29737 .76375 m
.28007 .74893 L
s
.56019 .174 m
.58285 .17803 L
s
.28007 .74893 m
.26415 .73202 L
s
.53674 .17235 m
.56019 .174 L
s
.26415 .73202 m
.24978 .71313 L
s
.51268 .17315 m
.53674 .17235 L
s
.24978 .71313 m
.2371 .69237 L
s
.4882 .17645 m
.51268 .17315 L
s
.2371 .69237 m
.22625 .66986 L
s
.4635 .18226 m
.4882 .17645 L
s
.22625 .66986 m
.21737 .64577 L
s
.43877 .19058 m
.4635 .18226 L
s
.21737 .64577 m
.21055 .62028 L
s
.41424 .20139 m
.43877 .19058 L
s
.21055 .62028 m
.2059 .59357 L
s
.39012 .21462 m
.41424 .20139 L
s
.2059 .59357 m
.2035 .56587 L
s
.36663 .23021 m
.39012 .21462 L
s
.2035 .56587 m
.20339 .53741 L
s
.344 .24804 m
.36663 .23021 L
s
.20339 .53741 m
.2056 .50843 L
s
.32243 .26797 m
.344 .24804 L
s
.2056 .50843 m
.21015 .47921 L
s
.30213 .28984 m
.32243 .26797 L
s
.21015 .47921 m
.217 .45 L
s
.28331 .31346 m
.30213 .28984 L
s
.217 .45 m
.22611 .42106 L
s
.26614 .33864 m
.28331 .31346 L
s
.22611 .42106 m
.23741 .39269 L
s
.25079 .36512 m
.26614 .33864 L
s
.23741 .39269 m
.25079 .36512 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol0091ooa807gioo`00Rgoo1@0O4Woo100ONWoo0027Ool4
01lKOol401mfOol008Aoo`<07b=oo`@07g9oo`00P7oo100O:Woo0P0OL7oo001lOol401l`Ool201m^
Ool007Yoo`807cIoo`807faoo`00N7oo0P0O>Woo0P0OJWoo001fOol201lnOol201mXOol007Aoo`80
7d9oo`807fIoo`00LWoo0P0OAWoo00<07gooOol0Hgoo001`Ool201m9Ool201mSOol006moo`0301mo
ogoo04]oo`0301moogoo061oo`00KWoo00<07gooOol0CGoo00<07gooOol0Ggoo001]Ool00`0OOomo
o`1?Ool00`0OOomoo`1NOol006]oo`807e=oo`807eioo`00JWoo00<07gooOol0EGoo00<07gooOol0
Fgoo001YOol00`0OOomoo`1GOol00`0OOomoo`1JOol006Moo`807e]oo`0301moogoo05Uoo`00IWoo
00<07gooOol0G7oo00<07gooOol0F7oo001UOol00`0OOomoo`1NOol00`0OOomoo`1GOol006=oo`80
7f9oo`0301moogoo05Ioo`00HWoo00<07gooOol0Hgoo00<07gooOol0EGoo001QOol00`0OOomoo`1U
Ool00`0OOomoo`1DOol0061oo`0301moogoo06Ioo`0301moogoo05Aoo`00GWoo0P0OJWoo00<07goo
Ool0Dgoo001MOol00`0OOomoo`1[Ool00`0OOomoo`1BOol005aoo`0301moogoo06aoo`0301moogoo
059oo`00Fgoo00<07gooOol0KWoo00<07gooOol0DGoo001JOol00`0OOomoo`1_Ool00`0OOomoo`1A
Ool005Uoo`0301moogoo075oo`0301moogoo051oo`00FGoo00<07gooOol0LGoo00<07gooOol0D7oo
001HOol00`0OOomoo`1cOol00`0OOomoo`1?Ool005Moo`0301moogoo07Aoo`0301moogoo04moo`00
EWoo00<07gooOol0MWoo00<07gooOol0CWoo001EOol00`0OOomoo`1gOol00`0OOomoo`1>Ool005Ao
o`0301moogoo07Uoo`0301moogoo04eoo`00Dgoo00<07gooOol0NWoo00<07gooOol0CGoo001COol0
0`0OOomoo`1kOol00`0OOomoo`1<Ool0059oo`0301moogoo07aoo`0301moogoo04aoo`00DGoo00<0
7gooOol0OWoo00<07gooOol0Bgoo001@Ool00`0OOomoo`1oOol00`0OOomoo`1;Ool0051oo`0301mo
ogoo081oo`0301moogoo04Yoo`00Cgoo00<07gooOol0PGoo00<07gooOol0BWoo001>Ool00`0OOomo
o`23Ool00`0OOomoo`19Ool004ioo`0301moogoo08=oo`0301moogoo04Uoo`00CGoo00<07gooOol0
QGoo00<07gooOol0B7oo001=Ool00`0OOomoo`25Ool00`0OOomoo`18Ool004aoo`0301moogoo08Io
o`0301moogoo04Qoo`00Bgoo00<07gooOol0R7oo00<07gooOol0Agoo001;Ool00`0OOomoo`28Ool0
0`0OOomoo`17Ool004Yoo`0301moogoo08Uoo`0301moogoo04Moo`00BGoo00<07gooOol0RWoo00<0
7gooOol0Agoo0018Ool00`0OOomoo`2;Ool00`0OOomoo`17Ool004Qoo`0301moogoo08aoo`0301mo
ogoo04Ioo`00Agoo00<07gooOol0SGoo00<07gooOol0AWoo0017Ool00`0OOomoo`2=Ool00`0OOomo
o`16Ool004Ioo`0301moogoo08ioo`0301moogoo04Ioo`00AWoo00<07gooOol0SWoo00<07gooOol0
AWoo0015Ool00`0OOomoo`2?Ool00`0OOomoo`16Ool004Eoo`0301moogoo08moo`0301moogoo04Io
o`00AGoo00<07gooOol0T7oo00<07gooOol0AGoo0014Ool00`0OOomoo`2AOol00`0OOomoo`15Ool0
04Aoo`0301moogoo095oo`0301moogoo04Eoo`00@goo00<07gooOol0TWoo00<07gooOol0AGoo0013
Ool00`0OOomoo`2BOol00`0OOomoo`15Ool0049oo`0301moogoo09=oo`0301moogoo04Eoo`00@Woo
00<07gooOol0Tgoo00<07gooOol0AGoo0011Ool00`0OOomoo`2DOol00`0OOomoo`15Ool0045oo`03
01moogoo09Aoo`0301moogoo04Eoo`00@7oo00<07gooOol0UGoo00<07gooOol0AGoo0010Ool00`0O
Oomoo`2EOol00`0OOomoo`15Ool0041oo`0301moogoo09Eoo`0301moogoo04Eoo`00@7oo00<07goo
Ool0UGoo00<07gooOol0AGoo000oOol00`0OOomoo`2FOol00`0OOomoo`15Ool003moo`0301moogoo
09Ioo`0301moogoo04Eoo`00?goo00<07gooOol0UWoo00<07gooOol0AGoo000oOol00`0OOomoo`2F
Ool00`0OOomoo`15Ool003ioo`0301moogoo09Moo`0301moogoo04Eoo`00?Woo00<07gooOol0Ugoo
00<07gooOol0AGoo000nOol00`0OOomoo`2GOol00`0OOomoo`15Ool003ioo`0301moogoo09Moo`03
01moogoo04Eoo`00?Goo00<07gooOol0V7oo00<07gooOol0AGoo000mOol00`0OOomoo`2HOol00`0O
Oomoo`15Ool003eoo`0301moogoo09Qoo`0301moogoo04Eoo`00?Goo00<07gooOol0V7oo00<07goo
Ool0AGoo000lOol00`0OOomoo`2IOol00`0OOomoo`15Ool003aoo`0301moogoo09Uoo`0301moogoo
04Eoo`00?7oo00<07gooOol0VGoo00<07gooOol0AGoo000lOol00`0OOomoo`2HOol00`0OOomoo`16
Ool003aoo`0301moogoo09Qoo`0301moogoo04Ioo`00?7oo00<07gooOol0V7oo00<07gooOol0AWoo
000kOol00`0OOomoo`2IOol00`0OOomoo`16Ool003]oo`0301moogoo09Uoo`0301moogoo04Ioo`00
>goo00<07gooOol0V7oo00<07gooOol0Agoo000kOol00`0OOomoo`2HOol00`0OOomoo`17Ool003]o
o`0301moogoo09Qoo`0301moogoo04Moo`00>goo00<07gooOol0V7oo00<07gooOol0Agoo000kOol0
0`0OOomoo`2GOol00`0OOomoo`18Ool003]oo`0301moogoo09Moo`0301moogoo04Qoo`00>goo00<0
7gooOol0Ugoo00<07gooOol0B7oo000jOol00`0OOomoo`2GOol00`0OOomoo`19Ool003Yoo`0301mo
ogoo09Moo`0301moogoo04Uoo`00>Woo00<07gooOol0Ugoo00<07gooOol0BGoo000jOol00`0OOomo
o`2GOol00`0OOomoo`19Ool003Yoo`0301moogoo09Ioo`0301moogoo04Yoo`00>Woo00<07gooOol0
UWoo00<07gooOol0BWoo000jOol00`0OOomoo`2FOol00`0OOomoo`1:Ool003Yoo`0301moogoo09Eo
o`0301moogoo04]oo`00>Woo00<07gooOol0UGoo00<07gooOol0Bgoo000jOol00`0OOomoo`2EOol0
0`0OOomoo`1;Ool003Yoo`0301moogoo09Eoo`0301moogoo04]oo`00>Woo00<07gooOol0U7oo00<0
7gooOol0C7oo000jOol00`0OOomoo`2DOol00`0OOomoo`1<Ool003Yoo`0301moogoo09Aoo`0301mo
ogoo04aoo`00>Woo00<07gooOol0Tgoo00<07gooOol0CGoo000jOol00`0OOomoo`2COol00`0OOomo
o`1=Ool003Yoo`0301moogoo099oo`0301moogoo04ioo`00>goo00<07gooOol0TGoo00<07gooOol0
CWoo000kOol00`0OOomoo`2@Ool00`0OOomoo`1?Ool003]oo`0301moogoo091oo`0301moogoo04mo
o`00>goo00<07gooOol0Sgoo00<07gooOol0D7oo000kOol00`0OOomoo`2?Ool00`0OOomoo`1@Ool0
03]oo`0301moogoo08ioo`0301moogoo055oo`00>goo00<07gooOol0SWoo00<07gooOol0DGoo000k
Ool00`0OOomoo`2=Ool00`0OOomoo`1BOol003aoo`0301moogoo08aoo`0301moogoo059oo`00?7oo
00<07gooOol0Rgoo00<07gooOol0Dgoo000lOol00`0OOomoo`2;Ool00`0OOomoo`1COol003aoo`03
01moogoo08Yoo`0301moogoo05Aoo`00?7oo00<07gooOol0RWoo00<07gooOol0E7oo000mOol00`0O
Oomoo`28Ool00`0OOomoo`1EOol003eoo`0301moogoo08Qoo`0301moogoo05Eoo`00?Goo00<07goo
Ool0Qgoo00<07gooOol0EWoo000mOol00`0OOomoo`26Ool00`0OOomoo`1GOol003ioo`0301moogoo
08Eoo`0301moogoo05Moo`00?Woo00<07gooOol0Q7oo00<07gooOol0F7oo000nOol00`0OOomoo`23
Ool00`0OOomoo`1IOol003moo`0301moogoo089oo`0301moogoo05Uoo`00?goo00<07gooOol0PGoo
00<07gooOol0FWoo000oOol00`0OOomoo`20Ool00`0OOomoo`1KOol003moo`0301moogoo081oo`03
01moogoo05]oo`00@7oo00<07gooOol0OWoo00<07gooOol0G7oo0010Ool00`0OOomoo`1mOol00`0O
Oomoo`1MOol0045oo`0301moogoo07aoo`0301moogoo05eoo`00@Goo00<07gooOol0Ngoo00<07goo
Ool0GWoo0012Ool00`0OOomoo`1iOol00`0OOomoo`1OOol004=oo`0301moogoo07Moo`0301moogoo
061oo`00@goo00<07gooOol0MWoo00<07gooOol0HGoo0014Ool00`0OOomoo`1dOol00`0OOomoo`1R
Ool004Aoo`0301moogoo07=oo`0301moogoo06=oo`00AGoo00<07gooOol0LGoo00<07gooOol0I7oo
0015Ool00`0OOomoo`1`Ool00`0OOomoo`1UOol004Ioo`0301moogoo06ioo`0301moogoo06Ioo`00
AWoo00<07gooOol0KWoo00<07gooOol0IWoo0017Ool00`0OOomoo`1/Ool00`0OOomoo`1WOol004Qo
o`0301moogoo06Yoo`0301moogoo06Qoo`00B7oo00<07gooOol0JGoo00<07gooOol0JGoo0019Ool0
0`0OOomoo`1VOol201m/Ool004Yoo`0301moogoo06Aoo`0301moogoo06aoo`00BWoo00<07gooOol0
Hgoo00<07gooOol0KGoo001;Ool00`0OOomoo`1QOol00`0OOomoo`1^Ool004aoo`0301moogoo05mo
o`0301moogoo06moo`00CGoo0P0OGGoo0P0OLWoo001?Ool00`0OOomoo`1IOol00`0OOomoo`1bOol0
051oo`0301moogoo05Moo`0301moogoo07=oo`00DGoo00<07gooOol0E7oo0P0OMWoo001BOol00`0O
Oomoo`1BOol00`0OOomoo`1fOol005=oo`0301moogoo04moo`807gUoo`00E7oo00<07gooOol0CGoo
00<07gooOol0NGoo001EOol00`0OOomoo`1:Ool201mlOol005Ioo`807dQoo`807gioo`00F7oo0P0O
A7oo0P0OP7oo001JOol00`0OOomoo`0oOol201n2Ool005]oo`807ceoo`807hAoo`00GGoo0P0O>Goo
0P0OQWoo001OOol201leOol201n8Ool0065oo`807c5oo`807hYoo`00Hgoo0P0O;7oo0`0OS7oo001U
Ool401lUOol301n?Ool006Uoo`D07a]oo`D07i9oo`00KWoo0`0O4Woo1P0OUgoo001aOolB01nMOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.69408 .60878 m
.68095 .63067 L
s
.70593 .58618 m
.69408 .60878 L
s
.68095 .63067 m
.66662 .65173 L
s
.71644 .56297 m
.70593 .58618 L
s
.66662 .65173 m
.65114 .67184 L
s
.72555 .5393 m
.71644 .56297 L
s
.65114 .67184 m
.63462 .69088 L
s
.7332 .51527 m
.72555 .5393 L
s
.63462 .69088 m
.61711 .70876 L
s
.73934 .49102 m
.7332 .51527 L
s
.61711 .70876 m
.59872 .72535 L
s
.74393 .46669 m
.73934 .49102 L
s
.59872 .72535 m
.57954 .74056 L
s
.74692 .4424 m
.74393 .46669 L
s
.57954 .74056 m
.55967 .75429 L
s
.74828 .41829 m
.74692 .4424 L
s
.55967 .75429 m
.5392 .76643 L
s
.74798 .3945 m
.74828 .41829 L
s
.5392 .76643 m
.51825 .77689 L
s
.74599 .37118 m
.74798 .3945 L
s
.51825 .77689 m
.49694 .78558 L
s
.7423 .34848 m
.74599 .37118 L
s
.49694 .78558 m
.47539 .79242 L
s
.73691 .32653 m
.7423 .34848 L
s
.47539 .79242 m
.45372 .79733 L
s
.72981 .30549 m
.73691 .32653 L
s
.45372 .79733 m
.43208 .80024 L
s
.721 .28551 m
.72981 .30549 L
s
.43208 .80024 m
.41059 .80108 L
s
.71053 .26674 m
.721 .28551 L
s
.41059 .80108 m
.38942 .79982 L
s
.6984 .24934 m
.71053 .26674 L
s
.38942 .79982 m
.3687 .7964 L
s
.68468 .23345 m
.6984 .24934 L
s
.3687 .7964 m
.34859 .79079 L
s
.66941 .21922 m
.68468 .23345 L
s
.34859 .79079 m
.32925 .783 L
s
.65266 .2068 m
.66941 .21922 L
s
.32925 .783 m
.31085 .77301 L
s
.63454 .19631 m
.65266 .2068 L
s
.31085 .77301 m
.29353 .76085 L
s
.61512 .18788 m
.63454 .19631 L
s
.29353 .76085 m
.27747 .74656 L
s
.59454 .18163 m
.61512 .18788 L
s
.27747 .74656 m
.2628 .73021 L
s
.57293 .17765 m
.59454 .18163 L
s
.2628 .73021 m
.2497 .71186 L
s
.55042 .17605 m
.57293 .17765 L
s
.2497 .71186 m
.23829 .69163 L
s
.5272 .17687 m
.55042 .17605 L
s
.23829 .69163 m
.22872 .66964 L
s
.50343 .18017 m
.5272 .17687 L
s
.22872 .66964 m
.2211 .64605 L
s
.4793 .18598 m
.50343 .18017 L
s
.2211 .64605 m
.21554 .62102 L
s
.45502 .19429 m
.4793 .18598 L
s
.21554 .62102 m
.21212 .59474 L
s
.4308 .20508 m
.45502 .19429 L
s
.21212 .59474 m
.21092 .56744 L
s
.40686 .2183 m
.4308 .20508 L
s
.21092 .56744 m
.21198 .53933 L
s
.38341 .23386 m
.40686 .2183 L
s
.21198 .53933 m
.21531 .51068 L
s
.36068 .25165 m
.38341 .23386 L
s
.21531 .51068 m
.22093 .48173 L
s
.33889 .27154 m
.36068 .25165 L
s
.22093 .48173 m
.22879 .45275 L
s
.31824 .29336 m
.33889 .27154 L
s
.22879 .45275 m
.23885 .42402 L
s
.29895 .31691 m
.31824 .29336 L
s
.23885 .42402 m
.25101 .39581 L
s
.2812 .342 m
.29895 .31691 L
s
.25101 .39581 m
.26517 .36838 L
s
.26517 .36838 m
.2812 .342 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00U7oo4P0ONWoo002?Ool501lBOol301mg
Ool008]oo`@07aYoo`@07g=oo`00R7oo0`0O8Woo100OKgoo0024Ool401lYOol201m]Ool0085oo`<0
7bmoo`807f]oo`00Ogoo0P0O=7oo0P0OJGoo001mOol201lhOol201mWOol007]oo`807caoo`807fEo
o`00NGoo0P0O@7oo00<07gooOol0HWoo001gOol201m3Ool201mROol007Eoo`807dMoo`807f1oo`00
M7oo00<07gooOol0BGoo00<07gooOol0GGoo001cOol00`0OOomoo`1;Ool00`0OOomoo`1LOol0079o
o`0301moogoo04eoo`0301moogoo05]oo`00L7oo0P0ODGoo00<07gooOol0FWoo001_Ool00`0OOomo
o`1BOol00`0OOomoo`1IOol006ioo`0301moogoo05Aoo`0301moogoo05Qoo`00K7oo0P0OF7oo00<0
7gooOol0Egoo001[Ool00`0OOomoo`1HOol00`0OOomoo`1GOol006Yoo`0301moogoo05Yoo`0301mo
ogoo05Ioo`00J7oo0P0OGWoo00<07gooOol0EGoo001WOol00`0OOomoo`1OOol00`0OOomoo`1DOol0
06Ioo`0301moogoo061oo`0301moogoo05Aoo`00IGoo00<07gooOol0HWoo00<07gooOol0Dgoo001S
Ool201mUOol00`0OOomoo`1COol0069oo`0301moogoo06Ioo`0301moogoo059oo`00HGoo00<07goo
Ool0J7oo00<07gooOol0DGoo001POol00`0OOomoo`1YOol00`0OOomoo`1AOol005moo`0301moogoo
06]oo`0301moogoo051oo`00GWoo00<07gooOol0K7oo00<07gooOol0D7oo001NOol00`0OOomoo`1]
Ool00`0OOomoo`1?Ool005eoo`0301moogoo06ioo`0301moogoo04moo`00G7oo00<07gooOol0L7oo
00<07gooOol0CWoo001KOol00`0OOomoo`1aOol00`0OOomoo`1>Ool005Yoo`0301moogoo07=oo`03
01moogoo04eoo`00FGoo00<07gooOol0M7oo00<07gooOol0CGoo001HOol00`0OOomoo`1fOol00`0O
Oomoo`1<Ool005Moo`0301moogoo07Moo`0301moogoo04aoo`00EWoo00<07gooOol0NGoo00<07goo
Ool0Bgoo001EOol00`0OOomoo`1jOol00`0OOomoo`1;Ool005Aoo`0301moogoo07]oo`0301moogoo
04]oo`00E7oo00<07gooOol0O7oo00<07gooOol0BWoo001COol00`0OOomoo`1mOol00`0OOomoo`1:
Ool0059oo`0301moogoo07ioo`0301moogoo04Yoo`00DWoo00<07gooOol0Ogoo00<07gooOol0BGoo
001AOol00`0OOomoo`20Ool00`0OOomoo`19Ool0055oo`0301moogoo081oo`0301moogoo04Uoo`00
D7oo00<07gooOol0PGoo00<07gooOol0BGoo001?Ool00`0OOomoo`23Ool00`0OOomoo`18Ool004mo
o`0301moogoo08=oo`0301moogoo04Qoo`00CWoo00<07gooOol0Q7oo00<07gooOol0B7oo001>Ool0
0`0OOomoo`24Ool00`0OOomoo`18Ool004eoo`0301moogoo08Eoo`0301moogoo04Qoo`00CGoo00<0
7gooOol0QWoo00<07gooOol0Agoo001<Ool00`0OOomoo`27Ool00`0OOomoo`17Ool004]oo`0301mo
ogoo08Qoo`0301moogoo04Moo`00Bgoo00<07gooOol0R7oo00<07gooOol0Agoo001:Ool00`0OOomo
o`29Ool00`0OOomoo`17Ool004Yoo`0301moogoo08Uoo`0301moogoo04Moo`00BGoo00<07gooOol0
RWoo00<07gooOol0Agoo0019Ool00`0OOomoo`2:Ool00`0OOomoo`17Ool004Qoo`0301moogoo08]o
o`0301moogoo04Moo`00B7oo00<07gooOol0Rgoo00<07gooOol0Agoo0017Ool00`0OOomoo`2<Ool0
0`0OOomoo`17Ool004Moo`0301moogoo08aoo`0301moogoo04Moo`00AWoo00<07gooOol0SGoo00<0
7gooOol0Agoo0016Ool00`0OOomoo`2=Ool00`0OOomoo`17Ool004Eoo`0301moogoo08ioo`0301mo
ogoo04Moo`00AGoo00<07gooOol0SWoo00<07gooOol0Agoo0014Ool00`0OOomoo`2?Ool00`0OOomo
o`17Ool004Aoo`0301moogoo08moo`0301moogoo04Moo`00A7oo00<07gooOol0Sgoo00<07gooOol0
Agoo0013Ool00`0OOomoo`2@Ool00`0OOomoo`17Ool004=oo`0301moogoo091oo`0301moogoo04Mo
o`00@Woo00<07gooOol0TGoo00<07gooOol0Agoo0012Ool00`0OOomoo`2AOol00`0OOomoo`17Ool0
049oo`0301moogoo095oo`0301moogoo04Moo`00@Goo00<07gooOol0TWoo00<07gooOol0Agoo0011
Ool00`0OOomoo`2BOol00`0OOomoo`17Ool0045oo`0301moogoo095oo`0301moogoo04Qoo`00@Goo
00<07gooOol0TGoo00<07gooOol0B7oo0010Ool00`0OOomoo`2BOol00`0OOomoo`18Ool0041oo`03
01moogoo099oo`0301moogoo04Qoo`00@7oo00<07gooOol0TWoo00<07gooOol0B7oo0010Ool00`0O
Oomoo`2BOol00`0OOomoo`18Ool003moo`0301moogoo09=oo`0301moogoo04Qoo`00?goo00<07goo
Ool0TWoo00<07gooOol0BGoo000oOol00`0OOomoo`2BOol00`0OOomoo`19Ool003moo`0301moogoo
099oo`0301moogoo04Uoo`00?Woo00<07gooOol0Tgoo00<07gooOol0BGoo000nOol00`0OOomoo`2C
Ool00`0OOomoo`19Ool003ioo`0301moogoo099oo`0301moogoo04Yoo`00?Woo00<07gooOol0TWoo
00<07gooOol0BWoo000mOol00`0OOomoo`2COol00`0OOomoo`1:Ool003eoo`0301moogoo09=oo`03
01moogoo04Yoo`00?Goo00<07gooOol0TWoo00<07gooOol0Bgoo000mOol00`0OOomoo`2BOol00`0O
Oomoo`1;Ool003eoo`0301moogoo099oo`0301moogoo04]oo`00?Goo00<07gooOol0TGoo00<07goo
Ool0C7oo000lOol00`0OOomoo`2BOol00`0OOomoo`1<Ool003aoo`0301moogoo099oo`0301moogoo
04aoo`00?7oo00<07gooOol0TWoo00<07gooOol0C7oo000lOol00`0OOomoo`2AOol00`0OOomoo`1=
Ool003aoo`0301moogoo095oo`0301moogoo04eoo`00?7oo00<07gooOol0TGoo00<07gooOol0CGoo
000lOol00`0OOomoo`2@Ool00`0OOomoo`1>Ool003aoo`0301moogoo091oo`0301moogoo04ioo`00
?7oo00<07gooOol0Sgoo00<07gooOol0Cgoo000lOol00`0OOomoo`2?Ool00`0OOomoo`1?Ool003ao
o`0301moogoo08ioo`0301moogoo051oo`00?7oo00<07gooOol0SWoo00<07gooOol0D7oo000lOol0
0`0OOomoo`2>Ool00`0OOomoo`1@Ool003aoo`0301moogoo08eoo`0301moogoo055oo`00?7oo00<0
7gooOol0SGoo00<07gooOol0DGoo000lOol00`0OOomoo`2<Ool00`0OOomoo`1BOol003aoo`0301mo
ogoo08aoo`0301moogoo059oo`00?7oo00<07gooOol0Rgoo00<07gooOol0Dgoo000lOol00`0OOomo
o`2;Ool00`0OOomoo`1COol003aoo`0301moogoo08Yoo`0301moogoo05Aoo`00?7oo00<07gooOol0
RWoo00<07gooOol0E7oo000lOol00`0OOomoo`29Ool00`0OOomoo`1EOol003aoo`0301moogoo08Uo
o`0301moogoo05Eoo`00?7oo00<07gooOol0R7oo00<07gooOol0EWoo000lOol00`0OOomoo`28Ool0
0`0OOomoo`1FOol003eoo`0301moogoo08Ioo`0301moogoo05Moo`00?Goo00<07gooOol0QWoo00<0
7gooOol0Egoo000mOol00`0OOomoo`25Ool00`0OOomoo`1HOol003eoo`0301moogoo08Aoo`0301mo
ogoo05Uoo`00?Goo00<07gooOol0Q7oo00<07gooOol0FGoo000nOol00`0OOomoo`22Ool00`0OOomo
o`1JOol003ioo`0301moogoo085oo`0301moogoo05]oo`00?Woo00<07gooOol0PGoo00<07gooOol0
Fgoo000nOol00`0OOomoo`20Ool00`0OOomoo`1LOol003moo`0301moogoo07moo`0301moogoo05ao
o`00?goo00<07gooOol0OWoo00<07gooOol0GGoo000oOol00`0OOomoo`1nOol00`0OOomoo`1MOol0
041oo`0301moogoo07aoo`0301moogoo05ioo`00@7oo00<07gooOol0Ngoo00<07gooOol0Ggoo0010
Ool00`0OOomoo`1jOol00`0OOomoo`1POol0041oo`0301moogoo07Uoo`0301moogoo065oo`00@Goo
00<07gooOol0Mgoo00<07gooOol0HWoo0011Ool00`0OOomoo`1fOol00`0OOomoo`1SOol0045oo`03
01moogoo07Eoo`0301moogoo06Aoo`00@Woo00<07gooOol0M7oo00<07gooOol0I7oo0012Ool00`0O
Oomoo`1cOol00`0OOomoo`1UOol004=oo`0301moogoo075oo`0301moogoo06Ioo`00@goo00<07goo
Ool0LGoo00<07gooOol0IWoo0014Ool00`0OOomoo`1_Ool00`0OOomoo`1WOol004Aoo`0301moogoo
06ioo`0301moogoo06Qoo`00AGoo00<07gooOol0K7oo00<07gooOol0JGoo0015Ool00`0OOomoo`1[
Ool00`0OOomoo`1ZOol004Ioo`0301moogoo06Uoo`0301moogoo06]oo`00AWoo00<07gooOol0J7oo
00<07gooOol0K7oo0017Ool00`0OOomoo`1VOol00`0OOomoo`1]Ool004Qoo`0301moogoo06Aoo`03
01moogoo06ioo`00BGoo00<07gooOol0HGoo0P0OLGoo0019Ool00`0OOomoo`1POol00`0OOomoo`1a
Ool004Yoo`0301moogoo05ioo`0301moogoo079oo`00Bgoo00<07gooOol0G7oo00<07gooOol0Lgoo
001<Ool00`0OOomoo`1IOol201mfOol004eoo`0301moogoo05Moo`0301moogoo07Ioo`00CGoo00<0
7gooOol0EWoo00<07gooOol0Mgoo001>Ool00`0OOomoo`1COol201mjOol004moo`0301moogoo055o
o`0301moogoo07Yoo`00D7oo00<07gooOol0CWoo0P0OOGoo001AOol201m=Ool00`0OOomoo`1mOol0
05=oo`0301moogoo04Qoo`807h1oo`00E7oo00<07gooOol0AGoo0P0OPWoo001EOol201m3Ool201n4
Ool005Moo`807cmoo`807hIoo`00FGoo00<07gooOol0>Woo0P0OR7oo001JOol201lhOol201n:Ool0
05aoo`807cAoo`807haoo`00GWoo0P0O<7oo0P0OSWoo001POol301lZOol301n@Ool006=oo`<07bAo
o`<07i=oo`00IWoo0P0O7Woo100OUWoo001XOol401lDOol601nJOol006aooa@07j1oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}]
}, Closed]]
}, Closed]],

Cell[TextData[{
  StyleBox["The transformation matrix about ",
    FontFamily->"New York"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`i\_x\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(-i\_y\)\)]],
  ",0",
  Cell[BoxData[
      \(TraditionalForm\`i\_z\)]],
  ")",
  StyleBox[" is given by multiplication of the output of the matrix given by \
Eq. (6) by the matrix corresponding to a rotation about the z-axis of ",
    FontFamily->"New York"],
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/4\)]],
  StyleBox[".  The output of the matrix given by Eq. (6) is shown in Figure 3 \
",
    FontFamily->"New York"],
  StyleBox["(consisting of parts A-C in the ",
    FontFamily->"New York"],
  StyleBox["Mathematica",
    FontFamily->"New York",
    FontSlant->"Italic"],
  StyleBox[" notebook )",
    FontFamily->"New York"],
  StyleBox[" wherein \[Theta] is varied from 0 to ",
    FontFamily->"New York"],
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]],
  StyleBox[".",
    FontFamily->"New York"]
}], "Text"],

Cell[TextData[StyleBox["Figure 3.  The electric field-line pattern given by \
Eq. (6) shown with 6 degree increments of the angle \[Theta].  (Electric \
field lines blue; Magnetic field lines red).",
  FontFamily->"New York"]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig3A\  = \ 
        Show[Array[p, {Steps}], ViewPoint \[Rule] {0, 0, 2}];\)\)], "Input",
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.49375 .49375 m
.50625 .50625 L
s
.48127 .48127 m
.49375 .49375 L
s
.50625 .50625 m
.51873 .51873 L
s
.50625 .48446 m
.51871 .49701 L
s
.49374 .47199 m
.50625 .48446 L
s
.51871 .49701 m
.53109 .50959 L
s
.46885 .46885 m
.48127 .48127 L
s
.51873 .51873 m
.53115 .53115 L
s
.48122 .45964 m
.49374 .47199 L
s
.51874 .4753 m
.53109 .48799 L
s
.50627 .46275 m
.51874 .4753 L
s
.53109 .50959 m
.54334 .52218 L
s
.53109 .48799 m
.54329 .50078 L
s
.49372 .45036 m
.50627 .46275 L
s
.54329 .50078 m
.5553 .51363 L
s
.45652 .45652 m
.46885 .46885 L
s
.53115 .53115 m
.54348 .54348 L
s
.46872 .44743 m
.48122 .45964 L
s
.53116 .46645 m
.54333 .47938 L
s
.51881 .45371 m
.53116 .46645 L
s
.54333 .47938 m
.55528 .49245 L
s
.54334 .52218 m
.55543 .53474 L
s
.5063 .4412 m
.51881 .45371 L
s
.48112 .43818 m
.49372 .45036 L
s
.55528 .49245 m
.56697 .50564 L
s
.5553 .51363 m
.56708 .52649 L
s
.49368 .42895 m
.5063 .4412 L
s
.54347 .45806 m
.55538 .47132 L
s
.5313 .44505 m
.54347 .45806 L
s
.45628 .43541 m
.46872 .44743 L
s
.44431 .44431 m
.45652 .45652 L
s
.54348 .54348 m
.55569 .55569 L
s
.55538 .47132 m
.567 .48477 L
s
.51891 .43232 m
.5313 .44505 L
s
.46852 .42625 m
.48112 .43818 L
s
.55543 .53474 m
.56733 .54722 L
s
.56697 .50564 m
.57836 .51891 L
s
.567 .48477 m
.57829 .49838 L
s
.50634 .41991 m
.51891 .43232 L
s
.48098 .41701 m
.49368 .42895 L
s
.56708 .52649 m
.57859 .53934 L
s
.5556 .45031 m
.56718 .46396 L
s
.5437 .43694 m
.5556 .45031 L
s
.56718 .46396 m
.57839 .47786 L
s
.53151 .42391 m
.5437 .43694 L
s
.44394 .42363 m
.45628 .43541 L
s
.57829 .49838 m
.58921 .51212 L
s
.43228 .43228 m
.44431 .44431 L
s
.55569 .55569 m
.56772 .56772 L
s
.45595 .41462 m
.46852 .42625 L
s
.49363 .40787 m
.50634 .41991 L
s
.57836 .51891 m
.58941 .5322 L
s
.57839 .47786 m
.5892 .49197 L
s
.56733 .54722 m
.57898 .55959 L
s
.51906 .41125 m
.53151 .42391 L
s
.46825 .40542 m
.48098 .41701 L
s
.57859 .53934 m
.58979 .55213 L
s
.56749 .44333 m
.57864 .45745 L
s
.55594 .42954 m
.56749 .44333 L
s
.57864 .45745 m
.58936 .47186 L
s
.5892 .49197 m
.59956 .50623 L
s
.54402 .41612 m
.55594 .42954 L
s
.58921 .51212 m
.59973 .52593 L
s
.5064 .399 m
.51906 .41125 L
s
.4808 .39623 m
.49363 .40787 L
s
.58936 .47186 m
.5996 .48651 L
s
.53178 .40312 m
.54402 .41612 L
s
.43175 .41211 m
.44394 .42363 L
s
.58941 .5322 m
.60009 .54549 L
s
.42046 .42046 m
.43228 .43228 L
s
.56772 .56772 m
.57954 .57954 L
s
.44345 .40331 m
.45595 .41462 L
s
.57898 .55959 m
.59035 .5718 L
s
.59956 .50623 m
.60945 .52061 L
s
.45552 .39423 m
.46825 .40542 L
s
.5996 .48651 m
.60933 .50135 L
s
.57906 .43725 m
.5897 .45189 L
s
.56795 .42297 m
.57906 .43725 L
s
.49356 .38722 m
.5064 .399 L
s
.5897 .45189 m
.59984 .46685 L
s
.51925 .39059 m
.53178 .40312 L
s
.55639 .4091 m
.56795 .42297 L
s
.59973 .52593 m
.60979 .53977 L
s
.58979 .55213 m
.60064 .56482 L
s
.59984 .46685 m
.60942 .48208 L
s
.46791 .38505 m
.4808 .39623 L
s
.54444 .3957 m
.55639 .4091 L
s
.60933 .50135 m
.61852 .51633 L
s
.60009 .54549 m
.61033 .55872 L
s
.60942 .48208 m
.61843 .49752 L
s
.50647 .37858 m
.51925 .39059 L
s
.41974 .40092 m
.43175 .41211 L
s
.60945 .52061 m
.61882 .53506 L
s
.43107 .39238 m
.44345 .40331 L
s
.4089 .4089 m
.42046 .42046 L
s
.57954 .57954 m
.5911 .5911 L
s
.59023 .43216 m
.60027 .44736 L
s
.57964 .41735 m
.59023 .43216 L
s
.48058 .37596 m
.49356 .38722 L
s
.60027 .44736 m
.60973 .4629 L
s
.53213 .38281 m
.54444 .3957 L
s
.44284 .38348 m
.45552 .39423 L
s
.56854 .40299 m
.57964 .41735 L
s
.59035 .5718 m
.6014 .58381 L
s
.60973 .4629 m
.61857 .47872 L
s
.60979 .53977 m
.61935 .5536 L
s
.61843 .49752 m
.62682 .51313 L
s
.55697 .38912 m
.56854 .40299 L
s
.455 .37437 m
.46791 .38505 L
s
.61852 .51633 m
.6271 .53142 L
s
.60064 .56482 m
.61109 .57736 L
s
.61857 .47872 m
.62677 .49478 L
s
.51949 .37048 m
.53213 .38281 L
s
.49348 .36714 m
.50647 .37858 L
s
.61024 .44391 m
.61894 .46003 L
s
.6009 .42814 m
.61024 .44391 L
s
.59093 .41278 m
.6009 .42814 L
s
.61882 .53506 m
.62762 .54953 L
s
.54496 .3758 m
.55697 .38912 L
s
.61033 .55872 m
.62011 .57185 L
s
.61894 .46003 m
.62695 .47645 L
s
.46751 .36525 m
.48058 .37596 L
s
.58038 .39788 m
.59093 .41278 L
s
.62677 .49478 m
.63428 .51101 L
s
.62682 .51313 m
.63455 .52886 L
s
.40797 .39009 m
.41974 .40092 L
s
.41886 .38189 m
.43107 .39238 L
s
.39765 .39765 m
.4089 .4089 L
s
.5911 .5911 m
.60235 .60235 L
s
.62695 .47645 m
.63425 .49311 L
s
.43026 .37322 m
.44284 .38348 L
s
.56928 .3835 m
.58038 .39788 L
s
.61935 .5536 m
.62838 .56737 L
s
.6271 .53142 m
.63506 .54655 L
s
.50656 .35877 m
.51949 .37048 L
s
.6014 .58381 m
.61206 .59557 L
s
.53254 .36308 m
.54496 .3758 L
s
.48032 .35631 m
.49348 .36714 L
s
.61953 .44156 m
.62737 .45825 L
s
.61097 .42522 m
.61953 .44156 L
s
.44211 .36425 m
.455 .37437 L
s
.60173 .4093 m
.61097 .42522 L
s
.62737 .45825 m
.63446 .47523 L
s
.63425 .49311 m
.64079 .50994 L
s
.63428 .51101 m
.64106 .52737 L
s
.61109 .57736 m
.62109 .5897 L
s
.55767 .36971 m
.56928 .3835 L
s
.59182 .39386 m
.60173 .4093 L
s
.63446 .47523 m
.64077 .49245 L
s
.62762 .54953 m
.63581 .56397 L
s
.63455 .52886 m
.64157 .54465 L
s
.45438 .35517 m
.46751 .36525 L
s
.62011 .57185 m
.62936 .58482 L
s
.58129 .37895 m
.59182 .39386 L
s
.51976 .35103 m
.53254 .36308 L
s
.64077 .49245 m
.64628 .50984 L
s
.64079 .50994 m
.64655 .5269 L
s
.62802 .44028 m
.63492 .4575 L
s
.62035 .42341 m
.62802 .44028 L
s
.49339 .34774 m
.50656 .35877 L
s
.63492 .4575 m
.64101 .47501 L
s
.54557 .35655 m
.55767 .36971 L
s
.61191 .40694 m
.62035 .42341 L
s
.63506 .54655 m
.64233 .56167 L
s
.64101 .47501 m
.64626 .49273 L
s
.40687 .37187 m
.41886 .38189 L
s
.39649 .37968 m
.40797 .39009 L
s
.64106 .52737 m
.64707 .5438 L
s
.41782 .36351 m
.43026 .37322 L
s
.38675 .38675 m
.39765 .39765 L
s
.60235 .60235 m
.61325 .61325 L
s
.62838 .56737 m
.63681 .58102 L
s
.46703 .34617 m
.48032 .35631 L
s
.60275 .39096 m
.61191 .40694 L
s
.57017 .36464 m
.58129 .37895 L
s
.64626 .49273 m
.65065 .5106 L
s
.64628 .50984 m
.65094 .52734 L
s
.61206 .59557 m
.62229 .60703 L
s
.4293 .35474 m
.44211 .36425 L
s
.64148 .4577 m
.64649 .47565 L
s
.63562 .44001 m
.64148 .4577 L
s
.62891 .42265 m
.63562 .44001 L
s
.64157 .54465 m
.64785 .56044 L
s
.64649 .47565 m
.65062 .4938 L
s
.64655 .5269 m
.65148 .54391 L
s
.59289 .37551 m
.60275 .39096 L
s
.63581 .56397 m
.64333 .57832 L
s
.50666 .33971 m
.51976 .35103 L
s
.62139 .40568 m
.62891 .42265 L
s
.53302 .34409 m
.54557 .35655 L
s
.62109 .5897 m
.63058 .60178 L
s
.65062 .4938 m
.65385 .51206 L
s
.65065 .5106 m
.65416 .52855 L
s
.44126 .34577 m
.45438 .35517 L
s
.48001 .33744 m
.49339 .34774 L
s
.55848 .35099 m
.57017 .36464 L
s
.65084 .47703 m
.65379 .4955 L
s
.64698 .45872 m
.65084 .47703 L
s
.64221 .44064 m
.64698 .45872 L
s
.65094 .52734 m
.65473 .54487 L
s
.64707 .5438 m
.65228 .56022 L
s
.61307 .38919 m
.62139 .40568 L
s
.65379 .4955 m
.6558 .51405 L
s
.63655 .42287 m
.64221 .44064 L
s
.65385 .51206 m
.65615 .53038 L
s
.62936 .58482 m
.63804 .59758 L
s
.64233 .56167 m
.64887 .57671 L
s
.58236 .36068 m
.59289 .37551 L
s
.65399 .47896 m
.65571 .49764 L
s
.65132 .4604 m
.65399 .47896 L
s
.65571 .49764 m
.65648 .51636 L
s
.64771 .44204 m
.65132 .4604 L
s
.6558 .51405 m
.65687 .53262 L
s
.65416 .52855 m
.65676 .54652 L
s
.63003 .40546 m
.63655 .42287 L
s
.45367 .33677 m
.46703 .34617 L
s
.65648 .51636 m
.6563 .53505 L
s
.65148 .54391 m
.65556 .56092 L
s
.60398 .37323 m
.61307 .38919 L
s
.39514 .3624 m
.40687 .37187 L
s
.64318 .42394 m
.64771 .44204 L
s
.38536 .36974 m
.39649 .37968 L
s
.63681 .58102 m
.64459 .59449 L
s
.65615 .53038 m
.65751 .54867 L
s
.40557 .3544 m
.41782 .36351 L
s
.52008 .3324 m
.53302 .34409 L
s
.64785 .56044 m
.65333 .57617 L
s
.54627 .33808 m
.55848 .35099 L
s
.37628 .37628 m
.38675 .38675 L
s
.61325 .61325 m
.62372 .62372 L
s
.6563 .53505 m
.65515 .55363 L
s
.65687 .53262 m
.65698 .55112 L
s
.49328 .32917 m
.50666 .33971 L
s
.62265 .38851 m
.63003 .40546 L
s
.65473 .54487 m
.65762 .56238 L
s
.4166 .34591 m
.4293 .35474 L
s
.57119 .34653 m
.58236 .36068 L
s
.63773 .40618 m
.64318 .42394 L
s
.62229 .60703 m
.63204 .61812 L
s
.64333 .57832 m
.65014 .59252 L
s
.65676 .54652 m
.65841 .56443 L
s
.65228 .56022 m
.65664 .57658 L
s
.46649 .32795 m
.48001 .33744 L
s
.59415 .35788 m
.60398 .37323 L
s
.65515 .55363 m
.65303 .57204 L
s
.65751 .54867 m
.65791 .56688 L
s
.42819 .3371 m
.44126 .34577 L
s
.65698 .55112 m
.65611 .56949 L
s
.63058 .60178 m
.63952 .61355 L
s
.61443 .37208 m
.62265 .38851 L
s
.63138 .38884 m
.63773 .40618 L
s
.65556 .56092 m
.65873 .57784 L
s
.64887 .57671 m
.65463 .59163 L
s
.53358 .32597 m
.54627 .33808 L
s
.50677 .32155 m
.52008 .3324 L
s
.63804 .59758 m
.64608 .61008 L
s
.65303 .57204 m
.64994 .59018 L
s
.55942 .33313 m
.57119 .34653 L
s
.65762 .56238 m
.65957 .57978 L
s
.44029 .32817 m
.45367 .33677 L
s
.5836 .34322 m
.59415 .35788 L
s
.65611 .56949 m
.65426 .58764 L
s
.47966 .31949 m
.49328 .32917 L
s
.65841 .56443 m
.6591 .58221 L
s
.65333 .57617 m
.65797 .59176 L
s
.65791 .56688 m
.65733 .5849 L
s
.60541 .35624 m
.61443 .37208 L
s
.62414 .372 m
.63138 .38884 L
s
.64459 .59449 m
.65166 .60773 L
s
.38375 .35353 m
.39514 .3624 L
s
.37463 .36035 m
.38536 .36974 L
s
.39359 .34596 m
.40557 .3544 L
s
.65664 .57658 m
.6601 .59281 L
s
.64994 .59018 m
.64586 .60798 L
s
.36628 .36628 m
.37628 .37628 L
s
.62372 .62372 m
.63372 .63372 L
s
.4041 .33781 m
.4166 .34591 L
s
.45286 .31932 m
.46649 .32795 L
s
.65014 .59252 m
.65618 .6065 L
s
.65873 .57784 m
.66097 .59462 L
s
.54707 .32055 m
.55942 .33313 L
s
.63204 .61812 m
.64123 .62879 L
s
.52044 .31474 m
.53358 .32597 L
s
.65426 .58764 m
.65142 .60549 L
s
.57237 .32932 m
.5836 .34322 L
s
.41523 .32924 m
.42819 .3371 L
s
.59559 .34109 m
.60541 .35624 L
s
.61601 .35574 m
.62414 .372 L
s
.65957 .57978 m
.66054 .59701 L
s
.49315 .3116 m
.50677 .32155 L
s
.65733 .5849 m
.65575 .60267 L
s
.6591 .58221 m
.6588 .59977 L
s
.65463 .59163 m
.65955 .60634 L
s
.63952 .61355 m
.64782 .62494 L
s
.64586 .60798 m
.64081 .62536 L
s
.46587 .31074 m
.47966 .31949 L
s
.42694 .32044 m
.44029 .32817 L
s
.65797 .59176 m
.66172 .60716 L
s
.64608 .61008 m
.65343 .62223 L
s
.65142 .60549 m
.64757 .62296 L
s
.6601 .59281 m
.66263 .60882 L
s
.60703 .34015 m
.61601 .35574 L
s
.56048 .31626 m
.57237 .32932 L
s
.585 .32671 m
.59559 .34109 L
s
.5342 .30889 m
.54707 .32055 L
s
.65166 .60773 m
.65797 .62066 L
s
.5069 .30445 m
.52044 .31474 L
s
.65575 .60267 m
.65315 .6201 L
s
.66097 .59462 m
.66224 .61116 L
s
.4392 .31163 m
.45286 .31932 L
s
.37275 .34533 m
.38375 .35353 L
s
.38193 .33826 m
.39359 .34596 L
s
.6588 .59977 m
.65748 .61703 L
s
.66054 .59701 m
.66052 .61397 L
s
.36437 .35156 m
.37463 .36035 L
s
.39184 .33051 m
.4041 .33781 L
s
.47927 .30264 m
.49315 .3116 L
s
.64081 .62536 m
.63478 .64221 L
s
.65618 .6065 m
.66138 .6202 L
s
.35683 .35683 m
.36628 .36628 L
s
.63372 .63372 m
.64317 .64317 L
s
.40244 .32224 m
.41523 .32924 L
s
.64123 .62879 m
.6498 .63897 L
s
.65955 .60634 m
.66359 .62077 L
s
.64757 .62296 m
.64271 .63995 L
s
.45196 .30299 m
.46587 .31074 L
s
.59721 .32531 m
.60703 .34015 L
s
.57368 .31317 m
.585 .32671 L
s
.54797 .30413 m
.56048 .31626 L
s
.64782 .62494 m
.65544 .63589 L
s
.41369 .31366 m
.42694 .32044 L
s
.66172 .60716 m
.66453 .62227 L
s
.52084 .29821 m
.5342 .30889 L
s
.65315 .6201 m
.64951 .6371 L
s
.49302 .2952 m
.5069 .30445 L
s
.66263 .60882 m
.66417 .62454 L
s
.63478 .64221 m
.62777 .65846 L
s
.65343 .62223 m
.66001 .63397 L
s
.65748 .61703 m
.65512 .6339 L
s
.66224 .61116 m
.66248 .62738 L
s
.66052 .61397 m
.65946 .63058 L
s
.42555 .30494 m
.4392 .31163 L
s
.46519 .29473 m
.47927 .30264 L
s
.65797 .62066 m
.66346 .6332 L
s
.64271 .63995 m
.63682 .65637 L
s
.58656 .31131 m
.59721 .32531 L
s
.37067 .33136 m
.38193 .33826 L
s
.36223 .33786 m
.37275 .34533 L
s
.56166 .30057 m
.57368 .31317 L
s
.37991 .32408 m
.39184 .33051 L
s
.35465 .34344 m
.36437 .35156 L
s
.66138 .6202 m
.6657 .63353 L
s
.53489 .29302 m
.54797 .30413 L
s
.34799 .34799 m
.35683 .35683 L
s
.64317 .64317 m
.65201 .65201 L
s
.3899 .3162 m
.40244 .32224 L
s
.43798 .29631 m
.45196 .30299 L
s
.64951 .6371 m
.64483 .65357 L
s
.50704 .2886 m
.52084 .29821 L
s
.66359 .62077 m
.66668 .63484 L
s
.62777 .65846 m
.6198 .67401 L
s
.6498 .63897 m
.65768 .64858 L
s
.65512 .6339 m
.65169 .65029 L
s
.47884 .28705 m
.49302 .2952 L
s
.66453 .62227 m
.66635 .63702 L
s
.40061 .30789 m
.41369 .31366 L
s
.66417 .62454 m
.66468 .63987 L
s
.65946 .63058 m
.65733 .64674 L
s
.66248 .62738 m
.66167 .64319 L
s
.65544 .63589 m
.66229 .64632 L
s
.57514 .29826 m
.58656 .31131 L
s
.63682 .65637 m
.62992 .67212 L
s
.45096 .28796 m
.46519 .29473 L
s
.66001 .63397 m
.66576 .64523 L
s
.54897 .28901 m
.56166 .30057 L
s
.41199 .29935 m
.42555 .30494 L
s
.52129 .28301 m
.53489 .29302 L
s
.66346 .6332 m
.66804 .64528 L
s
.64483 .65357 m
.63908 .66942 L
s
.6198 .67401 m
.61086 .68875 L
s
.49287 .28015 m
.50704 .2886 L
s
.35987 .32534 m
.37067 .33136 L
s
.35225 .33121 m
.36223 .33786 L
s
.6657 .63353 m
.66905 .6464 L
s
.42402 .29078 m
.43798 .29631 L
s
.36837 .31861 m
.37991 .32408 L
s
.65169 .65029 m
.64718 .66609 L
s
.34555 .33608 m
.35465 .34344 L
s
.46443 .28011 m
.47884 .28705 L
s
.37768 .31117 m
.3899 .3162 L
s
.66668 .63484 m
.66876 .64847 L
s
.33985 .33985 m
.34799 .34799 L
s
.65201 .65201 m
.66015 .66015 L
s
.65733 .64674 m
.6541 .66236 L
s
.56295 .28624 m
.57514 .29826 L
s
.66635 .63702 m
.66711 .6513 L
s
.62992 .67212 m
.62199 .6871 L
s
.66167 .64319 m
.65976 .65849 L
s
.66468 .63987 m
.66411 .65472 L
s
.38777 .30321 m
.40061 .30789 L
s
.53565 .27857 m
.54897 .28901 L
s
.65768 .64858 m
.66479 .65754 L
s
.43666 .28241 m
.45096 .28796 L
s
.5072 .2742 m
.52129 .28301 L
s
.66229 .64632 m
.6683 .65613 L
s
.61086 .68875 m
.60097 .70258 L
s
.3986 .29492 m
.41199 .29935 L
s
.63908 .66942 m
.63227 .68452 L
s
.47837 .27295 m
.49287 .28015 L
s
.66576 .64523 m
.67061 .65591 L
s
.64718 .66609 m
.64156 .68119 L
s
.66804 .64528 m
.67165 .65681 L
s
.41014 .28649 m
.42402 .29078 L
s
.44987 .27444 m
.46443 .28011 L
s
.55005 .27537 m
.56295 .28624 L
s
.62199 .6871 m
.61306 .7012 L
s
.66905 .6464 m
.67139 .65874 L
s
.6541 .66236 m
.64975 .67733 L
s
.34963 .32029 m
.35987 .32534 L
s
.35731 .31417 m
.36837 .31861 L
s
.52177 .26936 m
.53565 .27857 L
s
.3429 .32545 m
.35225 .33121 L
s
.66876 .64847 m
.66977 .66154 L
s
.36587 .30725 m
.37768 .31117 L
s
.65976 .65849 m
.65672 .67317 L
s
.33717 .32955 m
.34555 .33608 L
s
.66711 .6513 m
.66677 .66503 L
s
.66411 .65472 m
.66242 .66899 L
s
.4927 .26668 m
.5072 .2742 L
s
.60097 .70258 m
.59017 .71538 L
s
.33249 .33249 m
.33985 .33985 L
s
.66015 .66015 m
.66751 .66751 L
s
.37526 .29971 m
.38777 .30321 L
s
.42235 .27816 m
.43666 .28241 L
s
.63227 .68452 m
.62439 .69878 L
s
.66479 .65754 m
.67105 .66577 L
s
.46361 .26708 m
.47837 .27295 L
s
.38546 .29173 m
.3986 .29492 L
s
.6683 .65613 m
.67339 .66526 L
s
.64156 .68119 m
.63483 .69549 L
s
.53648 .26574 m
.55005 .27537 L
s
.61306 .7012 m
.60312 .7143 L
s
.43521 .27014 m
.44987 .27444 L
s
.67061 .65591 m
.67446 .66593 L
s
.39643 .28352 m
.41014 .28649 L
s
.50737 .26147 m
.52177 .26936 L
s
.64975 .67733 m
.64424 .69152 L
s
.67165 .65681 m
.67422 .66769 L
s
.47785 .26055 m
.4927 .26668 L
s
.59017 .71538 m
.57846 .72706 L
s
.65672 .67317 m
.65252 .68713 L
s
.67139 .65874 m
.67263 .67043 L
s
.34682 .31084 m
.35731 .31417 L
s
.34004 .31627 m
.34963 .32029 L
s
.66977 .66154 m
.66965 .67396 L
s
.66242 .66899 m
.65956 .68256 L
s
.62439 .69878 m
.61543 .71208 L
s
.66677 .66503 m
.66528 .67809 L
s
.35454 .30451 m
.36587 .30725 L
s
.33427 .32068 m
.3429 .32545 L
s
.40814 .27531 m
.42235 .27816 L
s
.32957 .32395 m
.33717 .32955 L
s
.44868 .26265 m
.46361 .26708 L
s
.36317 .29746 m
.37526 .29971 L
s
.326 .326 m
.33249 .33249 L
s
.66751 .66751 m
.674 .674 L
s
.52229 .25746 m
.53648 .26574 L
s
.63483 .69549 m
.62697 .70886 L
s
.37266 .28988 m
.38546 .29173 L
s
.60312 .7143 m
.59219 .72629 L
s
.67105 .66577 m
.67637 .67318 L
s
.49252 .25501 m
.50737 .26147 L
s
.42056 .2673 m
.43521 .27014 L
s
.67339 .66526 m
.67747 .67359 L
s
.64424 .69152 m
.63757 .70483 L
s
.38298 .28196 m
.39643 .28352 L
s
.57846 .72706 m
.56588 .73748 L
s
.46273 .25589 m
.47785 .26055 L
s
.67446 .66593 m
.67726 .67518 L
s
.65252 .68713 m
.64712 .70024 L
s
.61543 .71208 m
.60542 .72429 L
s
.67422 .66769 m
.67568 .67782 L
s
.65956 .68256 m
.65548 .69532 L
s
.67263 .67043 m
.67271 .68137 L
s
.3941 .27392 m
.40814 .27531 L
s
.43366 .25973 m
.44868 .26265 L
s
.66528 .67809 m
.66258 .69036 L
s
.66965 .67396 m
.66833 .68563 L
s
.33699 .3087 m
.34682 .31084 L
s
.50756 .25064 m
.52229 .25746 L
s
.33119 .31339 m
.34004 .31627 L
s
.34381 .30304 m
.35454 .30451 L
s
.32646 .31697 m
.33427 .32068 L
s
.59219 .72629 m
.58031 .73704 L
s
.62697 .70886 m
.61798 .72117 L
s
.35159 .29655 m
.36317 .29746 L
s
.32287 .31935 m
.32957 .32395 L
s
.4773 .25008 m
.49252 .25501 L
s
.36029 .28943 m
.37266 .28988 L
s
.40599 .266 m
.42056 .2673 L
s
.32047 .32047 m
.326 .326 L
s
.674 .674 m
.67953 .67953 L
s
.56588 .73748 m
.55249 .74654 L
s
.63757 .70483 m
.62972 .71713 L
s
.44742 .25282 m
.46273 .25589 L
s
.67637 .67318 m
.68066 .67967 L
s
.36988 .28187 m
.38298 .28196 L
s
.60542 .72429 m
.59436 .73528 L
s
.67747 .67359 m
.68047 .68104 L
s
.64712 .70024 m
.64049 .71237 L
s
.67726 .67518 m
.6789 .68355 L
s
.41864 .25842 m
.43366 .25973 L
s
.49233 .24538 m
.50756 .25064 L
s
.65548 .69532 m
.65016 .70715 L
s
.38033 .2741 m
.3941 .27392 L
s
.67568 .67782 m
.67594 .68708 L
s
.58031 .73704 m
.56751 .74643 L
s
.66258 .69036 m
.65862 .70173 L
s
.67271 .68137 m
.67156 .69144 L
s
.66833 .68563 m
.66578 .69641 L
s
.61798 .72117 m
.60787 .7323 L
s
.46179 .24677 m
.4773 .25008 L
s
.32794 .30785 m
.33699 .3087 L
s
.33377 .30291 m
.34381 .30304 L
s
.32319 .31172 m
.33119 .31339 L
s
.34063 .29706 m
.35159 .29655 L
s
.55249 .74654 m
.53832 .75411 L
s
.39162 .26633 m
.40599 .266 L
s
.31957 .31442 m
.32646 .31697 L
s
.34847 .29048 m
.36029 .28943 L
s
.43201 .25141 m
.44742 .25282 L
s
.62972 .71713 m
.62068 .72827 L
s
.31716 .31586 m
.32287 .31935 L
s
.59436 .73528 m
.58228 .74493 L
s
.316 .316 m
.32047 .32047 L
s
.67953 .67953 m
.684 .684 L
s
.35726 .28335 m
.36988 .28187 L
s
.64049 .71237 m
.63263 .72339 L
s
.47671 .2418 m
.49233 .24538 L
s
.68066 .67967 m
.68382 .68513 L
s
.40371 .25881 m
.41864 .25842 L
s
.56751 .74643 m
.55383 .75433 L
s
.68047 .68104 m
.68228 .68749 L
s
.36695 .27591 m
.38033 .2741 L
s
.65016 .70715 m
.64357 .7179 L
s
.44607 .24519 m
.46179 .24677 L
s
.60787 .7323 m
.59666 .74212 L
s
.6789 .68355 m
.67932 .69095 L
s
.65862 .70173 m
.65337 .71206 L
s
.67594 .68708 m
.67494 .69536 L
s
.53832 .75411 m
.52345 .76006 L
s
.66578 .69641 m
.66191 .70618 L
s
.67156 .69144 m
.66912 .70052 L
s
.37754 .26836 m
.39162 .26633 L
s
.41661 .25176 m
.43201 .25141 L
s
.32455 .30422 m
.33377 .30291 L
s
.31977 .30836 m
.32794 .30785 L
s
.33041 .29907 m
.34063 .29706 L
s
.62068 .72827 m
.61046 .73814 L
s
.31614 .31136 m
.32319 .31172 L
s
.58228 .74493 m
.56923 .7531 L
s
.33731 .2931 m
.34847 .29048 L
s
.31371 .31312 m
.31957 .31442 L
s
.46079 .23999 m
.47671 .2418 L
s
.34521 .28647 m
.35726 .28335 L
s
.31254 .31357 m
.31716 .31586 L
s
.38901 .26097 m
.40371 .25881 L
s
.63263 .72339 m
.62352 .73317 L
s
.55383 .75433 m
.53933 .76062 L
s
.3127 .3127 m
.316 .316 L
s
.684 .684 m
.6873 .6873 L
s
.43026 .24543 m
.44607 .24519 L
s
.35408 .27943 m
.36695 .27591 L
s
.59666 .74212 m
.58436 .75048 L
s
.68382 .68513 m
.68577 .68946 L
s
.64357 .7179 m
.63567 .72744 L
s
.52345 .76006 m
.50796 .76429 L
s
.68228 .68749 m
.68282 .69282 L
s
.65337 .71206 m
.64678 .72123 L
s
.40132 .25396 m
.41661 .25176 L
s
.67932 .69095 m
.67843 .69725 L
s
.36389 .27218 m
.37754 .26836 L
s
.66191 .70618 m
.6567 .71481 L
s
.67494 .69536 m
.67259 .70254 L
s
.66912 .70052 m
.66533 .70849 L
s
.56923 .7531 m
.55524 .75967 L
s
.61046 .73814 m
.59906 .74658 L
s
.31625 .30704 m
.32455 .30422 L
s
.32104 .30266 m
.33041 .29907 L
s
.44466 .24004 m
.46079 .23999 L
s
.3126 .31032 m
.31977 .30836 L
s
.32693 .29735 m
.33731 .2931 L
s
.31016 .31239 m
.31614 .31136 L
s
.37463 .26498 m
.38901 .26097 L
s
.53933 .76062 m
.52408 .76517 L
s
.33387 .2913 m
.34521 .28647 L
s
.62352 .73317 m
.61316 .74156 L
s
.30898 .31316 m
.31371 .31312 L
s
.41448 .24757 m
.43026 .24543 L
s
.58436 .75048 m
.57103 .75726 L
s
.30913 .31258 m
.31254 .31357 L
s
.50796 .76429 m
.49192 .76669 L
s
.34183 .28472 m
.35408 .27943 L
s
.63567 .72744 m
.62647 .73564 L
s
.31065 .31065 m
.3127 .3127 L
s
.6873 .6873 m
.68935 .68935 L
s
.38629 .25806 m
.40132 .25396 L
s
.68577 .68946 m
.6864 .69256 L
s
.35079 .27784 m
.36389 .27218 L
s
.55524 .75967 m
.54038 .7645 L
s
.64678 .72123 m
.63883 .72908 L
s
.68282 .69282 m
.682 .69694 L
s
.59906 .74658 m
.58653 .75346 L
s
.42844 .24205 m
.44466 .24004 L
s
.6567 .71481 m
.65009 .72217 L
s
.67843 .69725 m
.67614 .70232 L
s
.66533 .70849 m
.66013 .7152 L
s
.67259 .70254 m
.66884 .70849 L
s
.52408 .76517 m
.50817 .76786 L
s
.36072 .2709 m
.37463 .26498 L
s
.31265 .30788 m
.32104 .30266 L
s
.309 .31143 m
.31625 .30704 L
s
.31745 .30331 m
.32693 .29735 L
s
.39884 .25169 m
.41448 .24757 L
s
.30656 .31381 m
.3126 .31032 L
s
.61316 .74156 m
.60156 .74842 L
s
.32336 .29789 m
.33387 .2913 L
s
.49192 .76669 m
.47544 .76713 L
s
.57103 .75726 m
.55671 .76231 L
s
.30537 .3149 m
.31016 .31239 L
s
.33035 .29185 m
.34183 .28472 L
s
.30551 .31463 m
.30898 .31316 L
s
.37162 .26414 m
.38629 .25806 L
s
.62647 .73564 m
.61595 .74234 L
s
.30703 .31298 m
.30913 .31258 L
s
.54038 .7645 m
.52474 .76747 L
s
.33837 .28539 m
.35079 .27784 L
s
.41227 .2461 m
.42844 .24205 L
s
.30997 .30997 m
.31065 .31065 L
s
.68935 .68935 m
.69003 .69003 L
s
.58653 .75346 m
.5729 .75863 L
s
.63883 .72908 m
.6295 .73548 L
s
.50817 .76786 m
.4917 .76859 L
s
.6864 .69256 m
.68563 .6943 L
s
.65009 .72217 m
.64206 .72811 L
s
.34742 .27877 m
.36072 .2709 L
s
.38348 .25784 m
.39884 .25169 L
s
.682 .69694 m
.67975 .69971 L
s
.66013 .7152 m
.65348 .72054 L
s
.67614 .70232 m
.6724 .70605 L
s
.47544 .76713 m
.45865 .76554 L
s
.66884 .70849 m
.66362 .71309 L
s
.30537 .3148 m
.31265 .30788 L
s
.30902 .31102 m
.31745 .30331 L
s
.55671 .76231 m
.54148 .7655 L
s
.60156 .74842 m
.58877 .75361 L
s
.30293 .31747 m
.309 .31143 L
s
.31383 .3063 m
.32336 .29789 L
s
.30175 .31889 m
.30656 .31381 L
s
.35748 .27225 m
.37162 .26414 L
s
.31976 .30084 m
.33035 .29185 L
s
.30189 .31896 m
.30537 .3149 L
s
.52474 .76747 m
.5084 .76847 L
s
.39628 .25223 m
.41227 .2461 L
s
.61595 .74234 m
.60413 .74741 L
s
.32678 .29487 m
.33837 .28539 L
s
.30341 .31761 m
.30551 .31463 L
s
.5729 .75863 m
.55823 .76198 L
s
.4917 .76859 m
.47477 .76725 L
s
.30635 .31486 m
.30703 .31298 L
s
.36855 .26607 m
.38348 .25784 L
s
.6295 .73548 m
.6188 .74028 L
s
.33487 .28864 m
.34742 .27877 L
s
.45865 .76554 m
.44166 .76183 L
s
.31075 .31075 m
.30997 .30997 L
s
.69003 .69003 m
.68925 .68925 L
s
.64206 .72811 m
.63259 .7325 L
s
.54148 .7655 m
.52541 .76672 L
s
.68563 .6943 m
.68335 .6946 L
s
.58877 .75361 m
.57482 .75699 L
s
.67975 .69971 m
.67597 .70103 L
s
.65348 .72054 m
.64533 .72436 L
s
.30176 .32052 m
.30902 .31102 L
s
.34401 .28239 m
.35748 .27225 L
s
.30541 .31654 m
.31383 .3063 L
s
.29933 .32346 m
.30537 .3148 L
s
.6724 .70605 m
.66713 .70831 L
s
.66362 .71309 m
.65689 .71619 L
s
.29817 .32521 m
.30293 .31747 L
s
.31021 .31173 m
.31976 .30084 L
s
.38062 .2605 m
.39628 .25223 L
s
.5084 .76847 m
.49147 .76738 L
s
.29831 .32562 m
.30175 .31889 L
s
.31616 .3063 m
.32678 .29487 L
s
.47477 .76725 m
.45753 .76376 L
s
.60413 .74741 m
.59105 .75072 L
s
.29983 .32463 m
.30189 .31896 L
s
.55823 .76198 m
.54259 .76336 L
s
.35421 .2764 m
.36855 .26607 L
s
.44166 .76183 m
.42463 .75593 L
s
.32321 .3005 m
.33487 .28864 L
s
.30277 .32218 m
.30341 .31761 L
s
.6188 .74028 m
.60674 .74336 L
s
.52541 .76672 m
.50863 .76586 L
s
.30719 .31831 m
.30635 .31486 L
s
.33136 .29459 m
.34401 .28239 L
s
.57482 .75699 m
.55977 .75844 L
s
.63259 .7325 m
.62168 .7352 L
s
.31309 .31309 m
.31075 .31075 L
s
.68925 .68925 m
.68691 .68691 L
s
.36545 .27092 m
.38062 .2605 L
s
.49147 .76738 m
.47409 .76413 L
s
.29823 .32863 m
.30541 .31654 L
s
.29582 .33182 m
.30176 .32052 L
s
.68335 .6946 m
.6795 .69334 L
s
.30186 .3245 m
.31021 .31173 L
s
.64533 .72436 m
.63569 .72653 L
s
.29467 .33388 m
.29933 .32346 L
s
.67597 .70103 m
.67061 .70079 L
s
.45753 .76376 m
.44011 .75806 L
s
.65689 .71619 m
.64861 .71768 L
s
.66713 .70831 m
.66028 .709 L
s
.30666 .31966 m
.31616 .3063 L
s
.29483 .33467 m
.29817 .32521 L
s
.34061 .28883 m
.35421 .2764 L
s
.42463 .75593 m
.40771 .74781 L
s
.54259 .76336 m
.5261 .76267 L
s
.59105 .75072 m
.57676 .75212 L
s
.29636 .33405 m
.29831 .32562 L
s
.31261 .31435 m
.32321 .3005 L
s
.29931 .33197 m
.29983 .32463 L
s
.50863 .76586 m
.49124 .76282 L
s
.3197 .30881 m
.33136 .29459 L
s
.60674 .74336 m
.59335 .74458 L
s
.35094 .28349 m
.36545 .27092 L
s
.30372 .3284 m
.30277 .32218 L
s
.47409 .76413 m
.4564 .75863 L
s
.55977 .75844 m
.54373 .75784 L
s
.30964 .3234 m
.30719 .31831 L
s
.44011 .75806 m
.42268 .75009 L
s
.62168 .7352 m
.60934 .73608 L
s
.29244 .34255 m
.29823 .32863 L
s
.29483 .33915 m
.30186 .3245 L
s
.32791 .30333 m
.34061 .28883 L
s
.29132 .34492 m
.29582 .33182 L
s
.40771 .74781 m
.39106 .73745 L
s
.29843 .33493 m
.30666 .31966 L
s
.31707 .31707 m
.31309 .31309 L
s
.68691 .68691 m
.68293 .68293 L
s
.29151 .34608 m
.29467 .33388 L
s
.63569 .72653 m
.62454 .72693 L
s
.5261 .76267 m
.50886 .75981 L
s
.6795 .69334 m
.674 .69044 L
s
.30322 .33014 m
.31261 .31435 L
s
.64861 .71768 m
.63876 .71745 L
s
.57676 .75212 m
.56133 .7515 L
s
.29305 .34587 m
.29483 .33467 L
s
.67061 .70079 m
.66361 .69888 L
s
.66028 .709 m
.65183 .70799 L
s
.49124 .76282 m
.4734 .75754 L
s
.33726 .29817 m
.35094 .28349 L
s
.30918 .32502 m
.3197 .30881 L
s
.29601 .3442 m
.29636 .33405 L
s
.4564 .75863 m
.43856 .75086 L
s
.59335 .74458 m
.5787 .74382 L
s
.42268 .75009 m
.40541 .73985 L
s
.30043 .34101 m
.29931 .33197 L
s
.54373 .75784 m
.52679 .75509 L
s
.3163 .31985 m
.32791 .30333 L
s
.39106 .73745 m
.37488 .72486 L
s
.30635 .33632 m
.30372 .3284 L
s
.28926 .35561 m
.29483 .33915 L
s
.29161 .35204 m
.29843 .33493 L
s
.28818 .35826 m
.29244 .34255 L
s
.60934 .73608 m
.59563 .73504 L
s
.28839 .35979 m
.29132 .34492 L
s
.50886 .75981 m
.49101 .7547 L
s
.29518 .34779 m
.30322 .33014 L
s
.31379 .33018 m
.30964 .3234 L
s
.32457 .3149 m
.33726 .29817 L
s
.28996 .36001 m
.29151 .34608 L
s
.4734 .75754 m
.45527 .74996 L
s
.29995 .34312 m
.30918 .32502 L
s
.56133 .7515 m
.54486 .74877 L
s
.62454 .72693 m
.61192 .72545 L
s
.32274 .32274 m
.31707 .31707 L
s
.68293 .68293 m
.67726 .67726 L
s
.43856 .75086 m
.42075 .74078 L
s
.29293 .3588 m
.29305 .34587 L
s
.674 .69044 m
.66681 .68581 L
s
.63876 .71745 m
.62735 .71538 L
s
.40541 .73985 m
.38848 .72735 L
s
.66361 .69888 m
.65494 .69522 L
s
.65183 .70799 m
.64174 .70519 L
s
.37488 .72486 m
.35934 .71008 L
s
.30591 .33829 m
.3163 .31985 L
s
.29736 .35606 m
.29601 .3442 L
s
.52679 .75509 m
.50909 .75012 L
s
.5787 .74382 m
.56287 .74098 L
s
.28634 .3709 m
.29161 .35204 L
s
.2853 .3738 m
.28926 .35561 L
s
.28864 .36721 m
.29518 .34779 L
s
.30328 .35177 m
.30043 .34101 L
s
.31306 .33358 m
.32457 .3149 L
s
.28556 .37569 m
.28818 .35826 L
s
.49101 .7547 m
.47272 .74731 L
s
.29217 .363 m
.29995 .34312 L
s
.45527 .74996 m
.43702 .74007 L
s
.28715 .37636 m
.28839 .35979 L
s
.59563 .73504 m
.58061 .73196 L
s
.31072 .34595 m
.30635 .33632 L
s
.42075 .74078 m
.40315 .72842 L
s
.38848 .72735 m
.37209 .71264 L
s
.35934 .71008 m
.34463 .69319 L
s
.54486 .74877 m
.52747 .74383 L
s
.29692 .35852 m
.30591 .33829 L
s
.29015 .37565 m
.28996 .36001 L
s
.31969 .3387 m
.31379 .33018 L
s
.61192 .72545 m
.59786 .72199 L
s
.33017 .33017 m
.32274 .32274 L
s
.67726 .67726 m
.66983 .66983 L
s
.29458 .37342 m
.29293 .3588 L
s
.30288 .35407 m
.31306 .33358 L
s
.50909 .75012 m
.49078 .74286 L
s
.62735 .71538 m
.61441 .71139 L
s
.66681 .68581 m
.65789 .6794 L
s
.28274 .39137 m
.28634 .3709 L
s
.28373 .38826 m
.28864 .36721 L
s
.64174 .70519 m
.63004 .70052 L
s
.65494 .69522 m
.64459 .68974 L
s
.56287 .74098 m
.54597 .73599 L
s
.28305 .39361 m
.2853 .3738 L
s
.28598 .38451 m
.29217 .363 L
s
.47272 .74731 m
.45416 .7376 L
s
.3005 .36962 m
.29736 .35606 L
s
.43702 .74007 m
.41885 .72789 L
s
.37209 .71264 m
.35644 .6958 L
s
.40315 .72842 m
.38598 .71384 L
s
.34463 .69319 m
.33095 .67431 L
s
.28469 .39473 m
.28556 .37569 L
s
.28947 .3804 m
.29692 .35852 L
s
.30794 .36423 m
.30328 .35177 L
s
.2877 .39454 m
.28715 .37636 L
s
.58061 .73196 m
.56437 .72679 L
s
.52747 .74383 m
.50931 .73666 L
s
.29419 .37621 m
.30288 .35407 L
s
.31691 .3573 m
.31072 .34595 L
s
.29215 .39289 m
.29015 .37565 L
s
.28057 .41075 m
.28373 .38826 L
s
.2815 .40746 m
.28598 .38451 L
s
.49078 .74286 m
.47205 .73332 L
s
.28093 .4133 m
.28274 .39137 L
s
.33095 .67431 m
.31846 .6536 L
s
.35644 .6958 m
.34171 .67695 L
s
.59786 .72199 m
.58245 .71649 L
s
.38598 .71384 m
.36943 .69711 L
s
.28369 .40372 m
.28947 .3804 L
s
.45416 .7376 m
.43553 .72561 L
s
.32741 .34895 m
.31969 .3387 L
s
.41885 .72789 m
.40097 .71347 L
s
.28261 .41487 m
.28305 .39361 L
s
.29807 .38966 m
.29458 .37342 L
s
.54597 .73599 m
.52813 .7288 L
s
.61441 .71139 m
.59999 .70542 L
s
.33938 .33938 m
.33017 .33017 L
s
.66983 .66983 m
.66062 .66062 L
s
.28713 .39979 m
.29419 .37621 L
s
.28566 .41523 m
.28469 .39473 L
s
.63004 .70052 m
.61677 .69393 L
s
.65789 .6794 m
.64725 .67117 L
s
.64459 .68974 m
.63258 .68239 L
s
.3055 .38481 m
.3005 .36962 L
s
.31846 .6536 m
.30735 .63123 L
s
.34171 .67695 m
.32811 .65626 L
s
.27882 .43165 m
.2815 .40746 L
s
.29012 .4142 m
.2877 .39454 L
s
.27924 .43448 m
.28057 .41075 L
s
.50931 .73666 m
.49056 .72721 L
s
.27968 .42825 m
.28369 .40372 L
s
.36943 .69711 m
.35371 .67836 L
s
.56437 .72679 m
.54703 .71946 L
s
.28098 .43648 m
.28093 .4133 L
s
.40097 .71347 m
.38359 .6969 L
s
.28181 .42457 m
.28713 .39979 L
s
.31446 .37834 m
.30794 .36423 L
s
.47205 .73332 m
.45308 .72149 L
s
.43553 .72561 m
.41704 .71138 L
s
.29603 .41163 m
.29215 .39289 L
s
.28406 .4374 m
.28261 .41487 L
s
.30735 .63123 m
.29776 .60744 L
s
.32811 .65626 m
.31581 .63391 L
s
.32495 .37033 m
.31691 .3573 L
s
.27754 .45375 m
.27968 .42825 L
s
.58245 .71649 m
.5658 .7089 L
s
.27803 .45682 m
.27882 .43165 L
s
.27833 .45029 m
.28181 .42457 L
s
.35371 .67836 m
.33902 .65777 L
s
.52813 .7288 m
.50953 .71938 L
s
.28854 .43703 m
.28566 .41523 L
s
.27982 .45922 m
.27924 .43448 L
s
.30345 .40742 m
.29807 .38966 L
s
.33694 .36093 m
.32741 .34895 L
s
.29776 .60744 m
.28985 .58246 L
s
.38359 .6969 m
.36693 .67832 L
s
.59999 .70542 m
.58419 .69742 L
s
.28295 .46069 m
.28098 .43648 L
s
.31581 .63391 m
.30499 .61015 L
s
.49056 .72721 m
.47141 .71553 L
s
.27732 .47992 m
.27754 .45375 L
s
.27676 .47666 m
.27833 .45029 L
s
.35036 .35036 m
.33938 .33938 L
s
.66062 .66062 m
.64964 .64964 L
s
.41704 .71138 m
.39891 .69501 L
s
.29445 .43517 m
.29012 .4142 L
s
.45308 .72149 m
.4341 .70745 L
s
.61677 .69393 m
.60198 .68538 L
s
.27918 .48269 m
.27803 .45682 L
s
.31239 .40155 m
.3055 .38481 L
s
.64725 .67117 m
.63489 .66111 L
s
.28985 .58246 m
.28372 .5566 L
s
.63258 .68239 m
.61895 .67315 L
s
.33902 .65777 m
.32556 .63554 L
s
.28745 .46099 m
.28406 .4374 L
s
.27713 .50338 m
.27676 .47666 L
s
.54703 .71946 m
.52876 .70997 L
s
.30499 .61015 m
.29579 .58523 L
s
.28235 .48469 m
.27982 .45922 L
s
.27906 .50647 m
.27732 .47992 L
s
.28372 .5566 m
.27946 .53013 L
s
.27946 .53013 m
.27713 .50338 L
s
.36693 .67832 m
.35121 .6579 L
s
.30185 .43171 m
.29603 .41163 L
s
.32286 .39403 m
.31446 .37834 L
s
.28228 .50897 m
.27918 .48269 L
s
.29579 .58523 m
.28834 .55944 L
s
.28274 .53308 m
.27906 .50647 L
s
.32556 .63554 m
.31351 .6119 L
s
.29336 .4599 m
.28854 .43703 L
s
.28688 .48566 m
.28295 .46069 L
s
.28834 .55944 m
.28274 .53308 L
s
.39891 .69501 m
.38138 .67663 L
s
.50953 .71938 m
.49035 .70776 L
s
.5658 .7089 m
.54804 .69921 L
s
.28684 .5106 m
.28235 .48469 L
s
.28733 .53535 m
.28228 .50897 L
s
.33483 .38499 m
.32495 .37033 L
s
.4341 .70745 m
.41534 .69129 L
s
.31351 .6119 m
.30304 .58712 L
s
.47141 .71553 m
.45207 .70165 L
s
.31076 .42655 m
.30345 .40742 L
s
.35121 .6579 m
.33662 .63585 L
s
.29279 .48537 m
.28745 .46099 L
s
.29428 .5615 m
.28733 .53535 L
s
.30074 .45726 m
.29445 .43517 L
s
.30304 .58712 m
.29428 .5615 L
s
.58419 .69742 m
.56712 .68739 L
s
.34827 .37458 m
.33694 .36093 L
s
.29276 .51111 m
.28688 .48566 L
s
.29326 .53665 m
.28684 .5106 L
s
.38138 .67663 m
.36467 .65644 L
s
.33662 .63585 m
.32337 .61241 L
s
.52876 .70997 m
.50973 .69833 L
s
.32119 .4197 m
.31239 .40155 L
s
.36307 .36307 m
.35036 .35036 L
s
.64964 .64964 m
.63693 .63693 L
s
.60198 .68538 m
.58578 .67488 L
s
.30014 .48361 m
.29336 .4599 L
s
.63489 .66111 m
.62089 .64926 L
s
.61895 .67315 m
.60378 .66203 L
s
.30155 .56251 m
.29326 .53665 L
s
.3096 .45294 m
.30185 .43171 L
s
.32337 .61241 m
.31163 .58787 L
s
.41534 .69129 m
.39702 .67315 L
s
.31163 .58787 m
.30155 .56251 L
s
.49035 .70776 m
.47081 .694 L
s
.30008 .51027 m
.29279 .48537 L
s
.30055 .53673 m
.29276 .51111 L
s
.45207 .70165 m
.43279 .68569 L
s
.36467 .65644 m
.349 .63463 L
s
.33313 .41119 m
.32286 .39403 L
s
.54804 .69921 m
.52934 .68744 L
s
.30896 .48022 m
.30074 .45726 L
s
.31998 .44688 m
.31076 .42655 L
s
.3102 .56221 m
.30055 .53673 L
s
.349 .63463 m
.33457 .61147 L
s
.39702 .67315 m
.3794 .65321 L
s
.34654 .40116 m
.33483 .38499 L
s
.30885 .50788 m
.30014 .48361 L
s
.30926 .53538 m
.30008 .51027 L
s
.32158 .58723 m
.3102 .56221 L
s
.33457 .61147 m
.32158 .58723 L
s
.56712 .68739 m
.54895 .67537 L
s
.50973 .69833 m
.49016 .68461 L
s
.43279 .68569 m
.41379 .66779 L
s
.36135 .38982 m
.34827 .37458 L
s
.47081 .694 m
.45115 .6782 L
s
.31927 .47509 m
.3096 .45294 L
s
.33187 .43909 m
.32119 .4197 L
s
.3794 .65321 m
.36269 .6317 L
s
.58578 .67488 m
.56832 .66246 L
s
.32025 .5604 m
.30926 .53538 L
s
.63693 .63693 m
.62256 .62256 L
s
.37744 .37744 m
.36307 .36307 L
s
.60378 .66203 m
.58719 .64909 L
s
.62089 .64926 m
.60535 .63566 L
s
.31908 .50379 m
.30896 .48022 L
s
.31941 .53241 m
.30885 .50788 L
s
.36269 .6317 m
.34713 .60887 L
s
.52934 .68744 m
.50992 .67366 L
s
.33293 .585 m
.32025 .5604 L
s
.34523 .42966 m
.33313 .41119 L
s
.41379 .66779 m
.39534 .64813 L
s
.33108 .46819 m
.31998 .44688 L
s
.34713 .60887 m
.33293 .585 L
s
.49016 .68461 m
.47027 .66892 L
s
.45115 .6782 m
.4316 .66052 L
s
.33173 .5569 m
.31941 .53241 L
s
.36001 .41872 m
.34654 .40116 L
s
.33079 .49791 m
.31927 .47509 L
s
.54895 .67537 m
.52986 .66142 L
s
.39534 .64813 m
.37768 .62694 L
s
.33101 .52768 m
.31908 .50379 L
s
.34436 .45954 m
.33187 .43909 L
s
.34566 .58103 m
.33173 .5569 L
s
.3761 .40652 m
.36135 .38982 L
s
.37768 .62694 m
.36105 .60447 L
s
.56832 .66246 m
.54976 .64821 L
s
.4316 .66052 m
.41244 .64113 L
s
.36105 .60447 m
.34566 .58103 L
s
.50992 .67366 m
.48999 .65799 L
s
.62256 .62256 m
.60664 .60664 L
s
.39336 .39336 m
.37744 .37744 L
s
.58719 .64909 m
.56935 .63441 L
s
.34397 .49023 m
.33108 .46819 L
s
.60535 .63566 m
.58839 .62042 L
s
.47027 .66892 m
.45033 .6514 L
s
.34463 .55159 m
.33101 .52768 L
s
.35907 .44924 m
.34523 .42966 L
s
.34406 .52113 m
.33079 .49791 L
s
.41244 .64113 m
.39392 .62027 L
s
.52986 .66142 m
.51008 .64567 L
s
.35978 .5752 m
.34463 .55159 L
s
.37512 .43748 m
.36001 .41872 L
s
.35858 .48079 m
.34436 .45954 L
s
.39392 .62027 m
.37629 .5982 L
s
.45033 .6514 m
.43059 .63225 L
s
.37629 .5982 m
.35978 .5752 L
s
.48999 .65799 m
.46981 .64058 L
s
.35894 .54442 m
.34406 .52113 L
s
.54976 .64821 m
.53031 .63226 L
s
.35853 .51274 m
.34397 .49023 L
s
.39238 .42452 m
.3761 .40652 L
s
.56935 .63441 m
.55043 .61813 L
s
.60664 .60664 m
.58932 .58932 L
s
.41068 .41068 m
.39336 .39336 L
s
.37453 .46973 m
.35907 .44924 L
s
.58839 .62042 m
.57018 .60368 L
s
.43059 .63225 m
.41132 .61171 L
s
.37525 .56749 m
.35894 .54442 L
s
.51008 .64567 m
.48984 .62827 L
s
.46981 .64058 m
.44964 .62162 L
s
.37436 .5026 m
.35858 .48079 L
s
.41132 .61171 m
.39279 .59002 L
s
.3746 .53541 m
.35853 .51274 L
s
.39279 .59002 m
.37525 .56749 L
s
.39173 .45724 m
.37512 .43748 L
s
.53031 .63226 m
.51021 .61476 L
s
.44964 .62162 m
.42976 .60134 L
s
.41002 .44361 m
.39238 .42452 L
s
.39198 .55794 m
.3746 .53541 L
s
.39145 .49085 m
.37453 .46973 L
s
.48984 .62827 m
.46942 .60941 L
s
.55043 .61813 m
.53067 .60041 L
s
.58932 .58932 m
.5708 .5708 L
s
.4292 .4292 m
.41068 .41068 L
s
.39153 .52466 m
.37436 .5026 L
s
.57018 .60368 m
.55095 .58562 L
s
.42976 .60134 m
.41046 .58002 L
s
.41046 .58002 m
.39198 .55794 L
s
.40966 .47774 m
.39173 .45724 L
s
.51021 .61476 m
.48973 .59592 L
s
.46942 .60941 m
.4491 .58935 L
s
.40988 .54667 m
.39153 .52466 L
s
.40961 .51234 m
.39145 .49085 L
s
.42881 .46357 m
.41002 .44361 L
s
.53067 .60041 m
.51031 .58147 L
s
.4491 .58935 m
.42916 .56834 L
s
.42916 .56834 m
.40988 .54667 L
s
.5708 .5708 m
.5513 .5513 L
s
.4487 .4487 m
.4292 .4292 L
s
.55095 .58562 m
.53092 .56645 L
s
.48973 .59592 m
.46914 .57598 L
s
.42868 .49871 m
.40966 .47774 L
s
.4288 .53389 m
.40961 .51234 L
s
.51031 .58147 m
.48964 .56155 L
s
.46914 .57598 m
.44873 .5552 L
s
.44852 .48411 m
.42881 .46357 L
s
.44873 .5552 m
.4288 .53389 L
s
.53092 .56645 m
.51038 .54644 L
s
.46892 .46892 m
.4487 .4487 L
s
.5513 .5513 m
.53108 .53108 L
s
.44853 .51987 m
.42868 .49871 L
s
.48964 .56155 m
.46895 .54092 L
s
.46895 .54092 m
.44853 .51987 L
s
.46888 .50497 m
.44852 .48411 L
s
.51038 .54644 m
.4896 .52585 L
s
.53108 .53108 m
.51041 .51041 L
s
.48959 .48959 m
.46892 .46892 L
s
.4896 .52585 m
.46888 .50497 L
s
.51041 .51041 m
.48959 .48959 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
OGoo2@0OVWoo001iOol401l9Ool501nEOol007Eooa407`Eoo`@07i5oo`00Lgoo1P0O3Goo100O1Goo
0`0OSWoo001aOolA01l8Ool201l6Ool201n<Ool006ioo`@07a1oo`D07`Eoo`807`Ioo`807hYoo`00
K7oo4P0O2Goo0`0O17oo0P0O1Woo00<07gooOol0Qgoo001ZOol501l?Ool501l7Ool201l4Ool201l5
Ool201n7Ool006Uoo`@07`9oo`/07`Uoo`<07`Ioo`807`Aoo`807`Eoo`0301moogoo08Aoo`00Igoo
0`0O00=oo`0O01l00P0O2goo1@0O1goo0P0O1Woo0P0O17oo0P0O17oo00<07gooOol0Pgoo001VOol5
01l00goo01l07`0501l<Ool301l6Ool201l6Ool201l4Ool201l3Ool201n3Ool006Aoo`<07`03Ool0
7`0O00807`Moo`L07`Qoo`807`Ioo`807`Ioo`0301moogoo00=oo`807`=oo`0301moogoo081oo`00
HWoo1P0O00=oo`0O01l0100O2goo0P0O27oo0P0O1Woo0P0O1Goo0P0O1Goo00D07gooOomoo`0O085o
o`00HGoo200O1Woo100O2Goo0`0O1goo0P0O1Woo0P0O1Goo00<07gooOol00goo0P0O0Woo0P0OOgoo
001POol501l>Ool401l8Ool301l6Ool201l6Ool201l4Ool00`0OOomoo`04Ool01@0OOomoogoo01l0
OWoo001NOolB01l7Ool301l8Ool201l6Ool201l6Ool00`0OOomoo`02Ool201l5Ool01@0OOomoogoo
01l0OGoo001MOol601l=Ool401l6Ool201l8Ool201l6Ool201l5Ool201l4Ool00`0OOomoo`03Ool0
100OOomoogoo0P0ONgoo001LOol>01l:Ool301l5Ool301l7Ool201l6Ool00`0OOomoo`04Ool00`0O
Oomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`1hOol005]oo`<07`03Ool07`0O
00<07`Ioo`<07`Yoo`807`Ioo`<07`Ioo`807`Eoo`807`Eoo`0301moogoo009oo`807`Aoo`0301mo
ogoo009oo`0301moogoo07Moo`00FWoo1P0O17oo0`0O1Woo100O27oo0P0O1goo00<07gooOol01Goo
00<07gooOol017oo00<07gooOol00goo0P0O17oo00<07gooOol00Woo00D07gooOomoo`0O07Uoo`00
F7oo2P0O1Goo100O1Woo0P0O27oo0P0O1Woo0P0O1Woo0P0O1Goo00<07gooOol017oo00<07gooOol0
0Woo00<07gooOol00Woo00D07gooOomoo`0O07Qoo`00F7oo200O0Woo0`0O1Woo0`0O1Goo0P0O27oo
0P0O1Woo00<07gooOol01Goo00<07gooOol00goo0P0O1Goo00<07gooOol00Woo00<07gooOol00Woo
00D07gooOomoo`0O07Moo`00Egoo1`0O0Woo0`0O0Woo0`0O1Woo0P0O1Goo0`0O1goo0P0O1Goo0P0O
1Woo00<07gooOol017oo00<07gooOol00goo0P0O0goo00<07gooOol00Woo00D07gooOomoo`0O07Io
o`00EWoo1`0O00=oo`0OOol00goo0P0O0goo0P0O1Woo0P0O1Woo0`0O1Woo00<07gooOol017oo0P0O
1Goo0P0O1Goo00<07gooOol017oo00D07gooOomoo`0O00=oo`0501moogooOol07`1fOol005Eoo`D0
7`03Ool07`0O00@07`Aoo`807`=oo`807`Ioo`807`Moo`0301moogoo00Aoo`0301moogoo00Eoo`03
01moogoo00Aoo`0301moogoo00=oo`807`Eoo`0501moogooOol07`03Ool01@0OOomoogoo01l0MGoo
001EOol501l01goo01moo`0OOol07goo00807`Aoo`0301moogoo009oo`<07`Eoo`807`Ioo`807`Eo
o`807`Ioo`807`Eoo`0301moogoo00Aoo`0301moogoo009oo`0301moogoo009oo`0501moogooOol0
7`03Ool00`0OOomoo`1bOol005Aoo`D07`03Ool07goo009oo`0301moo`0O009oo`807`=oo`807`Eo
o`807`Eoo`807`Ioo`0301moogoo00Aoo`0301moogoo00Eoo`0301moogoo00=oo`807`Eoo`0301mo
ogoo009oo`0301moogoo009oo`0501moogooOol07`03Ool00`0OOomoo`1aOol005Aoo`L07`Aoo`04
01moo`0O01l2Ool00`0OOomoo`02Ool00`0OOomoo`04Ool201l5Ool201l5Ool201l5Ool201l6Ool0
0`0OOomoo`04Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`02Ool0100OOomoo`0O0goo
00<07gooOol0LGoo001DOol501l2Ool00`0OOomoo`02Ool0100OOomoo`0O0Woo0P0O0goo0P0O1Woo
00<07gooOol017oo00<07gooOol017oo0P0O1Goo0P0O1Goo0P0O1Goo00<07gooOol00Woo00<07goo
Ool00goo00D07gooOomoo`0O00=oo`0501moogooOol07`1bOol005=oo`H07`9oo`0301moogoo00=o
o`0401moogoo01l3Ool00`0OOomoo`02Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`05
Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`02
Ool00`0OOomoo`02Ool01@0OOomoogoo01l00goo00<07gooOol0Kgoo001COol601l3Ool00`0OOomo
o`03Ool0100OOomoo`0O0goo00<07gooOol00Woo0P0O1Goo0P0O1Goo0P0O1Woo0P0O1Goo0P0O1Goo
00<07gooOol00goo00<07gooOol00Woo00<07gooOol00Woo00<07gooOol00Woo00D07gooOomoo`0O
009oo`0301moogoo06moo`00Dgoo1@0O00Eoo`0OOomoo`0O00Ioo`0301moogoo00807`9oo`0301mo
ogoo00=oo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00Eoo`0301moogoo00Aoo`0301mo
ogoo00=oo`807`Aoo`0301moogoo009oo`807`=oo`0301moogoo009oo`0401moogoo01l3Ool00`0O
Oomoo`1^Ool0059oo`H07`03Ool07goo009oo`0301moogoo00Aoo`0501moogooOol07`02Ool201l4
Ool201l5Ool201l5Ool201l6Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`02Ool00`0O
Oomoo`03Ool01@0OOomoogoo01l00goo00D07gooOomoo`0O009oo`0301moogoo06ioo`00DWoo1P0O
0Woo00D07gooOomoo`0O00Ioo`0501moogooOol07`03Ool201l4Ool201l5Ool201l5Ool201l5Ool0
0`0OOomoo`04Ool201l5Ool00`0OOomoo`02Ool00`0OOomoo`03Ool01@0OOomoogoo01l00goo00@0
7gooOol07`=oo`0301moogoo06eoo`00DWoo1P0O0Woo00<07gooOol00Woo00<07gooOol017oo00D0
7gooOomoo`0O00Aoo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00=o
o`0301moogoo00Eoo`0301moogoo009oo`0301moogoo00=oo`0301moogoo009oo`0301moogoo009o
o`0501moogooOol07`02Ool0100OOomoo`0OKgoo001BOol401l2Ool0100OOomoo`0O17oo00<07goo
Ool017oo00D07gooOomoo`0O00Aoo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo00Aoo`80
7`Aoo`0301moogoo00Eoo`0301moogoo009oo`0301moogoo00=oo`0301moogoo009oo`0301moogoo
009oo`0501moogooOol07`02Ool0100OOomoo`0OKWoo001BOol401l2Ool0100OOomoo`0O1Goo00<0
7gooOol017oo00D07gooOomoo`0O00Aoo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo00Eo
o`0301moogoo009oo`807`Ioo`0301moogoo009oo`0301moogoo00=oo`0301moogoo009oo`0301mo
ogoo009oo`0401moogoo01l2Ool0100OOomoo`0OKWoo001AOol601l00goo01moo`02Ool00`0OOomo
o`02Ool00`0OOomoo`05Ool01@0OOomoogoo01l017oo0P0O17oo00<07gooOol017oo00<07gooOol0
1Goo00<07gooOol00goo00<07gooOol017oo00<07gooOol00Woo00<07gooOol00goo00<07gooOol0
0Woo00D07gooOomoo`0O00=oo`0401moogoo01l2Ool00`0OOomoo`1[Ool0055oo`@07`05Ool07goo
Ool07`03Ool00`0OOomoo`02Ool00`0OOomoo`05Ool01@0OOomoogoo01l01Goo00<07gooOol00Woo
0P0O1Goo0P0O1Woo00<07gooOol00goo00<07gooOol017oo00<07gooOol00Woo0P0O17oo00D07goo
Oomoo`0O00Aoo`0401moogoo01l3Ool0100OOomoo`0OK7oo001AOol401l01Goo01moogoo01l017oo
00<07gooOol00Woo00<07gooOol01Goo00@07gooOomoo`807`Aoo`0301moogoo00=oo`0301moogoo
00Aoo`0301moogoo00Aoo`0301moogoo00=oo`807`Eoo`0301moogoo00=oo`0301moogoo009oo`05
01moogooOol07`04Ool0100OOomoo`0O0Woo00@07gooOol07faoo`00DGoo100O00=oo`0OOol00Woo
00D07gooOomoo`0O00Eoo`0301moogoo00Eoo`0301moogoo009oo`0301moogoo009oo`807`Aoo`03
01moogoo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00=oo`05
01moogooOol07`04Ool01@0OOomoogoo01l00Woo00D07gooOomoo`0O009oo`0301moogoo06Uoo`00
DGoo100O0Woo00@07gooOol07`Aoo`0301moogoo00=oo`0301moogoo00Eoo`0301moogoo009oo`03
01moogoo00=oo`0301moogoo009oo`807`Eoo`807`Eoo`0301moogoo00Aoo`0301moogoo00=oo`03
01moogoo009oo`0301moogoo009oo`0301moogoo009oo`0501moogooOol07`02Ool0100OOomoo`0O
0Woo00<07gooOol0JGoo001AOol301l017oo01moo`0O0goo00<07gooOol00Woo00<07gooOol00goo
00<07gooOol01Goo00<07gooOol00Woo0P0O17oo00<07gooOol00goo00<07gooOol017oo00<07goo
Ool00goo00<07gooOol017oo00<07gooOol00goo00<07gooOol00Woo00<07gooOol00Woo00D07goo
Oomoo`0O00=oo`0401moogoo01l3Ool0100OOomoo`0OJWoo001AOol301l017oo01moo`0O0goo00<0
7gooOol00goo00<07gooOol00goo00<07gooOol01Goo00<07gooOol00goo00<07gooOol00Woo00<0
7gooOol00goo00<07gooOol017oo00<07gooOol00goo00<07gooOol017oo00<07gooOol00goo00<0
7gooOol00Woo00<07gooOol00Woo00D07gooOomoo`0O00=oo`0401moogoo01l2Ool0100OOomoo`0O
JWoo001AOol301l01Goo01moogoo01l00goo00<07gooOol00Woo00<07gooOol017oo00<07gooOol0
1Goo00<07gooOol00goo00<07gooOol00Woo00<07gooOol00goo00<07gooOol017oo00<07gooOol0
0goo00<07gooOol017oo00<07gooOol00goo00<07gooOol00Woo00D07gooOomoo`0O00=oo`0501mo
ogooOol07`03Ool00`0OOol07`02Ool00`0OOomoo`1XOol0055oo`<07`9oo`0301moo`0O00=oo`03
01moogoo00=oo`0301moogoo00Aoo`0301moogoo00Eoo`0301moogoo009oo`0301moogoo00=oo`03
01moogoo00=oo`0301moogoo00Aoo`0301moogoo00=oo`807`Eoo`0301moogoo00=oo`0301moogoo
009oo`0501moogooOol07`03Ool01@0OOomoogoo01l00Woo00@07gooOol07`9oo`0301moogoo06Mo
o`00D7oo100O0Woo00@07gooOol07`=oo`0301moogoo009oo`0301moogoo00Aoo`0301moogoo00Io
o`0301moogoo009oo`0301moogoo00=oo`807`Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301mo
ogoo00=oo`0301moogoo00=oo`0301moogoo009oo`0501moogooOol07`03Ool0100OOomoo`0O0goo
00<07goo01l00Woo00<07gooOol0Igoo001@Ool401l3Ool00`0OOol07`03Ool00`0OOomoo`03Ool0
0`0OOomoo`04Ool00`0OOomoo`06Ool00`0OOomoo`02Ool00`0OOomoo`04Ool00`0OOomoo`02Ool2
01l5Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`03Ool01@0OOomo
ogoo01l00Woo00D07gooOomoo`0O009oo`0401moogoo01l2Ool00`0OOomoo`1VOol0051oo`807`03
Ool07`0O009oo`0401moogoo01l3Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`06Ool0
0`0OOomoo`02Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`03Ool0
0`0OOomoo`04Ool00`0OOomoo`02Ool00`0OOomoo`03Ool0100OOomoo`0O0goo00D07gooOomoo`0O
009oo`0301moo`0O009oo`0301moogoo06Ioo`00D7oo0P0O00=oo`0O01l00Woo00@07gooOol07`=o
o`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00Ioo`0301moogoo009oo`0301moogoo00Ao
o`0301moogoo00=oo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo009o
o`0301moogoo009oo`0501moogooOol07`03Ool02@0OOomoogoo01moo`0OOol07`02Ool00`0OOomo
o`1VOol0051oo`807`03Ool07`0O00=oo`0401moogoo01l3Ool00`0OOomoo`03Ool00`0OOomoo`05
Ool00`0OOomoo`06Ool00`0OOomoo`02Ool00`0OOomoo`04Ool00`0OOomoo`03Ool201l4Ool00`0O
Oomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`02Ool00`0OOomoo`02Ool01@0OOomoogoo01l00goo
00@07gooOol07`9oo`0501moo`0OOol07`1XOol0051oo`807`03Ool07`0O00=oo`0401moogoo01l4
Ool00`0OOomoo`03Ool00`0OOomoo`05Ool00`0OOomoo`06Ool00`0OOomoo`02Ool00`0OOomoo`04
Ool00`0OOomoo`04Ool00`0OOomoo`02Ool201l4Ool00`0OOomoo`04Ool00`0OOomoo`02Ool00`0O
Oomoo`02Ool01@0OOomoogoo01l00Woo00T07gooOomoo`0OOol07goo01l00Woo00<07gooOol0IGoo
001@Ool201l017oo01moo`0O0Woo00D07gooOomoo`0O00Aoo`0301moogoo00=oo`0301moogoo00Eo
o`0301moogoo00Ioo`0301moogoo009oo`807`Eoo`0301moogoo00Aoo`0301moogoo00=oo`0301mo
ogoo009oo`807`Eoo`0301moogoo009oo`0301moogoo009oo`0401moogoo01l3Ool0100OOomoo`0O
0Woo00D07goo01moo`0O06Moo`00D7oo0P0O00Aoo`0OOol07`=oo`0401moogoo01l4Ool00`0OOomo
o`04Ool00`0OOomoo`05Ool00`0OOomoo`06Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomo
o`03Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`03Ool01@0OOomo
ogoo01l00goo00@07gooOol07`=oo`0701moo`0OOol07goo01l0Igoo001@Ool201l2Ool00`0OOol0
7`02Ool01@0OOomoogoo01l017oo00<07gooOol017oo00<07gooOol01Goo00<07gooOol01Woo00<0
7gooOol00goo00<07gooOol00goo00<07gooOol00goo00<07gooOol00goo00<07gooOol017oo00<0
7gooOol00Woo00<07gooOol00goo00D07gooOomoo`0O00=oo`0401moogoo01l2Ool01`0OOol07goo
01moo`0O06Moo`00D7oo0`0O00Aoo`0OOol07`9oo`0501moogooOol07`05Ool00`0OOomoo`03Ool0
0`0OOomoo`06Ool00`0OOomoo`06Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`03Ool0
0`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`02Ool00`0OOomoo`02Ool01@0OOomoogoo01l0
17oo00<07goo01l00goo00@07goo01moo`807fMoo`00D7oo0`0O00Aoo`0OOol07`=oo`0501moogoo
Ool07`05Ool00`0OOomoo`03Ool00`0OOomoo`05Ool00`0OOomoo`07Ool00`0OOomoo`03Ool00`0O
Oomoo`03Ool201l4Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`02Ool00`0OOomoo`02
Ool01@0OOomoogoo01l00goo00@07gooOol07`9oo`0701moo`0OOol07goo01l0IWoo001?Ool401l0
1Goo01moogoo01l00Woo00D07gooOomoo`0O00Ioo`0301moogoo00=oo`0301moogoo00Eoo`0301mo
ogoo00Moo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo009oo`807`Aoo`0301moogoo00Ao
o`0501moogooOol07`05Ool01@0OOomoogoo01l00goo00<07goo01l00goo00@07goo01moo`807fIo
o`00Cgoo100O0Woo00<07goo01l00Woo00<07gooOol00Woo00<07gooOol00goo00<07gooOol017oo
00<07gooOol01Goo00<07gooOol01goo00<07gooOol00goo00<07gooOol017oo00<07gooOol00goo
00<07gooOol00Woo0P0O1Goo00D07gooOomoo`0O00Eoo`0401moogoo01l3Ool0100OOomoo`0O0Woo
00@07goo01moo`807fIoo`00Cgoo0`0O00Ioo`0OOol07goo01l3Ool00`0OOomoo`02Ool00`0OOomo
o`03Ool00`0OOomoo`04Ool00`0OOomoo`05Ool00`0OOomoo`07Ool00`0OOomoo`03Ool00`0OOomo
o`03Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomo
o`02Ool01@0OOomoogoo01l00goo00T07gooOol07goo01moo`0OOol00P0OIWoo001?Ool301l017oo
01moo`0O0Woo00@07gooOol07`Aoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00Ioo`03
01moogoo00Moo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo00Aoo`03
01moogoo009oo`0301moogoo009oo`0301moogoo009oo`0501moogooOol07`02Ool0100OOomoo`0O
0Woo00<07goo01l00P0OIWoo001?Ool501l01Goo01moogoo01l00goo00<07gooOol00Woo00<07goo
Ool017oo00<07gooOol00goo00<07gooOol01Woo00<07gooOol01goo00<07gooOol00goo00<07goo
Ool00goo00<07gooOol00goo00<07gooOol00goo00<07gooOol00goo00<07gooOol00Woo00<07goo
Ool00Woo00@07gooOol07`=oo`0:01moogoo01moo`0OOol07goo01mVOol004moo`@07`06Ool07goo
01moo`0O0goo00<07gooOol00Woo00<07gooOol017oo00<07gooOol017oo00<07gooOol01Woo00<0
7gooOol01goo00<07gooOol00goo0P0O17oo00<07gooOol00goo00<07gooOol00goo00<07gooOol0
0goo00<07gooOol00Woo00<07gooOol00Woo00@07gooOol07`9oo`0401moogoo01l2Ool00`0OOol0
7`0201mUOol004moo`@07`04Ool07goo01l2Ool01@0OOomoogoo01l017oo00<07gooOol017oo00<0
7gooOol017oo00<07gooOol01Woo00<07gooOol01goo00<07gooOol017oo00<07gooOol00Woo0P0O
17oo00<07gooOol00goo00<07gooOol00Woo00<07gooOol00goo00D07gooOomoo`0O009oo`0501mo
ogooOol07`02Ool0100OOol07goo0`0OIGoo001?Ool401l017oo01moo`0O0Woo00<07gooOol00Woo
00<07gooOol00Woo00<07gooOol017oo00<07gooOol017oo00<07gooOol01Woo00<07gooOol01goo
00<07gooOol017oo00<07gooOol00goo00<07gooOol00Woo0P0O17oo00<07gooOol00Woo00<07goo
Ool00goo00D07gooOomoo`0O009oo`0401moogoo01l2Ool0100OOol07goo0`0OIGoo001?Ool401l2
Ool00`0OOol07`02Ool01@0OOomoogoo01l017oo00<07gooOol017oo00<07gooOol01Goo00<07goo
Ool01Woo00<07gooOol01goo00<07gooOol00goo00<07gooOol017oo00<07gooOol00goo00<07goo
Ool00Woo00<07gooOol00Woo00<07gooOol00Woo00<07gooOol00Woo00H07gooOol07goo01l3Ool2
01l017oo01l07`0OIGoo001?Ool301l01Woo01moo`0OOol07`9oo`0301moogoo009oo`0301moogoo
009oo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00Moo`0301moogoo00Moo`0301moogoo
00=oo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo009oo`0301moogoo009oo`0301moogoo
009oo`0501moogooOol07`02Ool0100OOomoo`0O0Woo00@07goo01moo`807fEoo`00Cgoo0`0O00Io
o`0OOol07goo01l3Ool01@0OOomoogoo01l01Goo00<07gooOol017oo00<07gooOol017oo00<07goo
Ool01goo00<07gooOol01goo00<07gooOol00goo00<07gooOol00goo00<07gooOol00goo00<07goo
Ool00goo00D07gooOomoo`0O00Eoo`0501moogooOol07`02Ool00`0OOol07`03Ool201l017oo01l0
7`0OI7oo001?Ool501l01Goo01moogoo01l00Woo00<07gooOol00Woo00<07gooOol00Woo00<07goo
Ool01Goo00<07gooOol017oo00<07gooOol01goo00<07gooOol01goo00<07gooOol00goo00<07goo
Ool00goo00<07gooOol00goo00<07gooOol00goo00D07gooOomoo`0O00Eoo`0401moogoo01l2Ool0
100OOomoo`0O0Woo0P0O00Aoo`0O01l07fAoo`00Cgoo1@0O0Woo00<07goo01l00Woo00<07gooOol0
0Woo00<07gooOol00goo00<07gooOol017oo00<07gooOol01Goo00<07gooOol01goo00<07gooOol0
1goo00<07gooOol00goo00<07gooOol00goo00<07gooOol00goo00<07gooOol00Woo00<07gooOol0
0Woo00<07gooOol00Woo00D07gooOomoo`0O009oo`0501moogoo01moo`0201l017oo01l07`0OI7oo
001?Ool401l01Woo01moo`0OOol07`=oo`0301moogoo009oo`0301moogoo00=oo`0301moogoo00Ao
o`0301moogoo00Eoo`0301moogoo00Moo`0301moogoo00Moo`0301moogoo00=oo`0301moogoo00=o
o`0301moogoo00=oo`0301moogoo009oo`0301moogoo009oo`0301moogoo009oo`0401moogoo01l2
Ool01`0OOomoo`0OOol07goo00@07fAoo`00Cgoo100O00Aoo`0OOol07`9oo`0401moogoo01l4Ool0
0`0OOomoo`03Ool00`0OOomoo`05Ool00`0OOomoo`05Ool00`0OOomoo`07Ool00`0OOomoo`07Ool0
0`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`02Ool0
0`0OOomoo`02Ool0100OOomoo`0O0Woo00D07gooOol07goo00807`03Ool07`0O06Aoo`00Cgoo100O
00Moo`0OOomoo`0OOol07`03Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`05Ool00`0O
Oomoo`05Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0O
Oomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`02Ool01@0OOomoogoo01l00Woo00@07gooOol07`9o
o`0401moo`0OOol401mSOol004moo`<07`06Ool07goo01moo`0O0Woo00@07gooOol07`Eoo`0301mo
ogoo00=oo`0301moogoo00Eoo`0301moogoo00Eoo`0301moogoo00Moo`0301moogoo00Moo`0301mo
ogoo00=oo`0301moogoo00=oo`0301moogoo00=oo`0501moogooOol07`05Ool01@0OOomoogoo01l0
0Woo00@07gooOol07`9oo`807`03Ool07`0O00807f=oo`00Cgoo0`0O00Ioo`0OOol07goo01l2Ool0
1@0OOomoogoo01l017oo00<07gooOol017oo00<07gooOol017oo00<07gooOol01Woo00<07gooOol0
1goo00<07gooOol01goo00<07gooOol00goo00<07gooOol00goo00<07gooOol00goo00D07gooOomo
o`0O00Eoo`0401moogoo01l3Ool01@0OOomoo`0OOol00P0O00=oo`0O01l00P0OHgoo001?Ool501l0
17oo01moo`0O0goo00D07gooOomoo`0O00Aoo`0301moogoo00=oo`0301moogoo00Eoo`0301moogoo
00Ioo`0301moogoo00Moo`0301moogoo00Moo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo
009oo`0301moogoo009oo`0301moogoo009oo`0501moogooOol07`02Ool01`0OOomoo`0OOol07goo
00D07f=oo`00Cgoo1@0O00Eoo`0OOomoo`0O009oo`0501moogooOol07`04Ool00`0OOomoo`04Ool0
0`0OOomoo`05Ool00`0OOomoo`06Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`03Ool0
0`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomoo`02Ool01@0OOomoogoo01l0
0Woo00D07gooOol07goo00807`04Ool07`0O01mSOol004moo`@07`06Ool07goo01moo`0O0goo00D0
7gooOomoo`0O00Aoo`0301moogoo00Aoo`0301moogoo00Eoo`0301moogoo00Ioo`0301moogoo00Mo
o`0301moogoo00Moo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo009oo`0301moogoo009o
o`807`=oo`0401moogoo01l2Ool01`0OOomoo`0OOol07goo00@07f=oo`00Cgoo100O00Ioo`0OOol0
7goo01l3Ool01@0OOomoogoo01l017oo00<07gooOol01Goo00<07gooOol017oo00<07gooOol01Woo
00<07gooOol027oo00<07gooOol01goo00<07gooOol00goo00<07gooOol00goo00<07gooOol00Woo
00<07gooOol00goo00@07gooOol07`=oo`0401moogoo01l2Ool201l00goo01l07`0201mSOol004mo
o`@07`04Ool07goo01l2Ool01@0OOomoogoo01l00goo00<07gooOol00Woo00<07gooOol017oo00<0
7gooOol01Goo00<07gooOol01Woo00<07gooOol027oo00<07gooOol01goo00<07gooOol00goo00<0
7gooOol00goo00<07gooOol00Woo00<07gooOol00goo00@07gooOol07`9oo`0401moogoo01l2Ool2
01l00goo01l07`0201mSOol004moo`@07`07Ool07gooOol07goo01l00goo00D07gooOomoo`0O00Eo
o`0301moogoo00Aoo`0301moogoo00Eoo`0301moogoo00Ioo`0301moogoo00Qoo`0301moogoo00Mo
o`0301moogoo00=oo`0301moogoo00=oo`0301moogoo009oo`0301moogoo009oo`0401moogoo01l3
Ool01`0OOomoo`0OOol07goo00D07f=oo`00D7oo0P0O00Ioo`0OOol07goo01l2Ool01@0OOomoogoo
01l00goo00<07gooOol00goo00<07gooOol017oo00<07gooOol01Goo00<07gooOol01Woo00<07goo
Ool027oo00<07gooOol01goo00<07gooOol00goo00<07gooOol00Woo00<07gooOol00goo00<07goo
Ool00Woo00@07gooOol07`9oo`0401moogoo01l2Ool201l017oo01l07`0OHgoo001@Ool401l017oo
01moo`0O0Woo00D07gooOomoo`0O00Aoo`0301moogoo009oo`0301moogoo00Eoo`0301moogoo00Eo
o`0301moogoo00Ioo`0301moogoo00Qoo`0301moogoo00Moo`0301moogoo00=oo`0301moogoo009o
o`0301moogoo00=oo`0301moogoo009oo`0401moogoo01l2Ool01`0OOomoo`0OOol07goo00@07f=o
o`00D7oo100O00Aoo`0OOol07`=oo`0501moogooOol07`03Ool00`0OOomoo`03Ool00`0OOomoo`05
Ool00`0OOomoo`05Ool00`0OOomoo`06Ool00`0OOomoo`08Ool00`0OOomoo`07Ool00`0OOomoo`03
Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOol07`02Ool0100OOomoogoo
0P0O00=oo`0O01l00P0OHgoo001@Ool401l01Goo01moogoo01l00Woo00D07gooOomoo`0O00Aoo`03
01moogoo00=oo`0301moogoo00Eoo`0301moogoo00Eoo`0301moogoo00Ioo`0301moogoo00Qoo`03
01moogoo00Moo`0301moogoo00=oo`0301moogoo009oo`0301moogoo00=oo`0501moogooOol07`02
Ool0100OOomoo`0O0Woo0P0O00=oo`0O01l00P0OHgoo001@Ool301l01Woo01moo`0OOol07`=oo`05
01moogooOol07`04Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`06Ool00`0OOomoo`06
Ool00`0OOomoo`08Ool00`0OOomoo`07Ool00`0OOomoo`03Ool00`0OOomoo`02Ool201l4Ool01@0O
Oomoogoo01l00Woo00@07gooOol07`9oo`H07f=oo`00D7oo0`0O00Ioo`0OOol07goo01l3Ool01@0O
Oomoogoo01l01Goo00<07gooOol00goo00<07gooOol017oo00<07gooOol01Woo00<07gooOol01Woo
00<07gooOol027oo00<07gooOol01goo00<07gooOol00goo00<07gooOol00goo00D07gooOomoo`0O
00Aoo`0601moogoo01moo`0O0Woo0P0O00Aoo`0O01l07f=oo`00D7oo0`0O00Aoo`0OOol07`9oo`05
01moogooOol07`03Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`05Ool00`0OOomoo`06
Ool00`0OOomoo`06Ool00`0OOomoo`08Ool00`0OOomoo`07Ool00`0OOomoo`02Ool00`0OOomoo`04
Ool01@0OOomoogoo01l00goo00@07gooOol07`9oo`0301moogoo00D07f=oo`00DGoo00T07goo01mo
o`0OOol07goo01l00goo00D07gooOomoo`0O00Eoo`0301moogoo00=oo`0301moogoo00Eoo`0301mo
ogoo00Eoo`0301moogoo00Moo`0301moogoo00Qoo`0301moogoo00Moo`0301moogoo009oo`0301mo
ogoo00=oo`0301moogoo009oo`0501moogooOol07`02Ool01@0OOomoo`0OOol01@0OHgoo001AOol3
01l017oo01moo`0O0Woo00D07gooOomoo`0O00=oo`0301moogoo00=oo`0301moogoo00=oo`0301mo
ogoo00Eoo`0301moogoo00Eoo`0301moogoo00Moo`0301moogoo00Qoo`0301moogoo00Moo`0301mo
ogoo009oo`0301moogoo00=oo`0301moogoo009oo`0401moogoo01l3Ool0100OOol07goo1@0OHgoo
001AOol301l01goo01moogoo01moo`0O00=oo`0501moogooOol07`05Ool00`0OOomoo`04Ool00`0O
Oomoo`05Ool00`0OOomoo`05Ool00`0OOomoo`07Ool00`0OOomoo`08Ool00`0OOomoo`07Ool00`0O
Oomoo`02Ool00`0OOomoo`03Ool01@0OOomoogoo01l00goo00@07gooOol07`9oo`807`04Ool07`0O
01mSOol0055oo`<07`05Ool07gooOol07`02Ool01@0OOomoogoo01l00goo00<07gooOol00goo00<0
7gooOol00goo00<07gooOol01Woo00<07gooOol01Goo00<07gooOol01goo00<07gooOol027oo00<0
7gooOol01goo00<07gooOol00Woo0P0O17oo00D07gooOomoo`0O00=oo`0701moogoo01moo`0OOol0
100OHgoo001AOol201l017oo01moo`0O0Woo00<07goo01l017oo00@07gooOol07`Ioo`0301moogoo
00=oo`0301moogoo00Eoo`0301moogoo00Ioo`0301moogoo00Moo`0301moogoo00Qoo`0301moogoo
00Moo`0301moogoo00=oo`0501moogooOol07`04Ool0100OOomoo`0O0Woo00<07gooOol00P0O00=o
o`0O01l0Hgoo001AOol201l017oo01moo`0O0Woo00@07gooOol07`=oo`0501moogooOol07`05Ool0
0`0OOomoo`04Ool00`0OOomoo`05Ool00`0OOomoo`06Ool00`0OOomoo`07Ool00`0OOomoo`08Ool0
0`0OOomoo`07Ool00`0OOomoo`03Ool01@0OOomoogoo01l00goo00D07gooOomoo`0O009oo`0501mo
o`0O01moo`0201mSOol0059oo`<07`05Ool07gooOol07`02Ool00`0OOomoo`02Ool01@0OOomoogoo
01l01Goo00<07gooOol017oo00<07gooOol01Goo00<07gooOol01Woo00<07gooOol01goo00<07goo
Ool027oo00<07gooOol01goo00<07gooOol00Woo00<07gooOol00Woo00D07gooOomoo`0O00=oo`06
01moo`0OOol07goo0`0OHgoo001BOol201l017oo01moo`0O0Woo00@07gooOol07`=oo`0301moogoo
009oo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo00Ioo`0301moogoo00Ioo`0301moogoo
00Moo`0301moogoo00Qoo`0301moogoo00Moo`0301moogoo009oo`0301moogoo009oo`0401moogoo
01l3Ool01@0OOomoo`0OOol01@0OHWoo001BOol201l017oo01moo`0O0Woo00@07gooOol07`Aoo`05
01moogooOol07`05Ool00`0OOomoo`04Ool00`0OOomoo`06Ool00`0OOomoo`06Ool00`0OOomoo`07
Ool201l9Ool00`0OOomoo`07Ool00`0OOomoo`02Ool00`0OOomoo`02Ool0100OOomoo`0O0goo00H0
7goo01moo`0OOol301mROol0059oo`807`05Ool07gooOol07`02Ool0100OOomoo`0O0goo00<07goo
Ool00Woo00<07gooOol00goo00<07gooOol017oo00<07gooOol01Woo00<07gooOol01Woo00<07goo
Ool027oo00<07gooOol01goo00<07gooOol01goo00<07gooOol00Woo00<07gooOol00Woo00@07goo
Ool07`9oo`0501moogoo01moo`0401mROol005=oo`<07`9oo`0401moogoo01l2Ool00`0OOomoo`02
Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`05Ool00`0OOomoo`07
Ool00`0OOomoo`08Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`02Ool00`0OOomoo`02
Ool0100OOomoo`0O0Woo00@07goo01moo`@07f9oo`00Dgoo0P0O00Eoo`0OOomoo`0O009oo`0401mo
ogoo01l4Ool01@0OOomoogoo01l01Woo00<07gooOol017oo00<07gooOol01Goo00<07gooOol01goo
00<07gooOol027oo00<07gooOol01goo00<07gooOol01goo00<07gooOol00Woo00D07gooOomoo`0O
00=oo`0301moo`0O009oo`D07f9oo`00Dgoo0P0O00Eoo`0OOomoo`0O009oo`0501moogooOol07`03
Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`05Ool00`0OOomoo`05Ool00`0OOomoo`07
Ool00`0OOomoo`08Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`02Ool01@0OOomoogoo
01l00goo00@07goo01moo`D07f9oo`00E7oo0`0O0Woo00D07gooOomoo`0O009oo`0301moogoo009o
o`0301moogoo009oo`0301moogoo00=oo`0301moogoo00Eoo`0301moogoo00Eoo`0301moogoo00Mo
o`0301moogoo00Qoo`0301moogoo00Moo`0301moogoo00Moo`0301moogoo009oo`0501moogooOol0
7`02Ool00`0OOol07`02Ool401mROol005Aoo`807`05Ool07gooOol07`02Ool01@0OOomoogoo01l0
0goo00<07gooOol00Woo00<07gooOol017oo00<07gooOol01Goo00<07gooOol01Goo00<07gooOol0
1goo00<07gooOol027oo00<07gooOol01goo00<07gooOol01goo00<07gooOol00Woo00D07gooOomo
o`0O009oo`0401moo`0OOol401mROol005Aoo`807`05Ool07gooOol07`03Ool0100OOomoo`0O17oo
00<07gooOol00Woo00<07gooOol017oo00<07gooOol01Goo00<07gooOol01Goo00<07gooOol01goo
00<07gooOol027oo00<07gooOol01goo00<07gooOol01goo00<07gooOol00Woo00@07gooOol07`=o
o`0501moo`0O01moo`0201mROol005Aoo`0501moo`0OOol07`02Ool0100OOomoo`0O0goo00D07goo
Oomoo`0O00Eoo`0301moogoo00Aoo`0301moogoo00Eoo`0301moogoo00Eoo`807`Qoo`0301moogoo
00Qoo`0301moogoo00Moo`0301moogoo00Moo`0501moogooOol07`03Ool01@0OOomoo`0OOol01@0O
HWoo001EOol201l01Goo01moogoo01l00goo00@07gooOol07`Aoo`0301moogoo00=oo`0301moogoo
00Aoo`0301moogoo00Eoo`0301moogoo00Ioo`0301moogoo00Ioo`0301moogoo00Qoo`0301moogoo
00Moo`0301moogoo00Moo`0501moogooOol07`03Ool00`0OOomoo`0701mQOol005Eoo`0501moo`0O
Ool07`02Ool0100OOomoo`0O0goo00<07gooOol00Woo00<07gooOol00goo00<07gooOol017oo00<0
7gooOol01Goo00<07gooOol01Woo00<07gooOol01Woo0P0O2Goo00<07gooOol01goo00<07gooOol0
1goo00D07gooOomoo`0O009oo`0301moogoo00L07f5oo`00EGoo00D07goo01moo`0O009oo`0501mo
ogooOol07`03Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomoo`05Ool00`0OOomoo`05Ool0
0`0OOomoo`06Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`07Ool0
1@0OOomoogoo01l00Woo00<07gooOol01P0OHGoo001FOol201l2Ool0100OOomoo`0O0goo00@07goo
Ool07`Aoo`0301moogoo00=oo`0301moogoo00Eoo`0301moogoo00Eoo`0301moogoo00Ioo`0301mo
ogoo00Moo`0301moogoo00Moo`0301moogoo00Moo`0301moogoo00Moo`0501moogooOol07`02Ool8
01mQOol005Ioo`0501moo`0OOol07`02Ool01@0OOomoogoo01l00goo00<07gooOol00Woo00<07goo
Ool00goo00<07gooOol01Goo00<07gooOol01Goo00<07gooOol01Woo00<07gooOol01goo00<07goo
Ool01goo00<07gooOol01goo00<07gooOol01goo00D07gooOomoo`0O009oo`L07f5oo`00Egoo0P0O
0Woo00@07gooOol07`=oo`0501moogooOol07`04Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0O
Oomoo`06Ool00`0OOomoo`06Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0OOomoo`07Ool00`0O
Oomoo`07Ool0100OOomoogoo100O00=oo`0O01l00P0OHGoo001GOol01@0OOol07goo01l00Woo00D0
7gooOomoo`0O00Aoo`0301moogoo009oo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo00Io
o`0301moogoo00Ioo`0301moogoo00Moo`807`Qoo`0301moogoo00Moo`0301moogoo00Moo`0801mo
ogooOol07goo01moo`@07f5oo`00F7oo0P0O0Woo00@07gooOol07`=oo`0501moogooOol07`05Ool0
0`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`06Ool00`0OOomoo`06Ool00`0OOomoo`08Ool0
0`0OOomoo`06Ool201l8Ool201l8Ool00`0OOomoo`0401l017oo01l07`0OHGoo001HOol01@0OOol0
7goo01l00Woo00D07gooOomoo`0O00Aoo`0301moogoo009oo`0301moogoo00=oo`0301moogoo00Eo
o`0301moogoo00Ioo`0301moogoo00Ioo`0301moogoo00Qoo`0301moogoo00Moo`0301moogoo00Mo
o`0301moogoo00Ioo`0301moo`0O00P07f1oo`00F7oo00H07gooOol07goo01l2Ool01@0OOomoogoo
01l017oo00<07gooOol00Woo00<07gooOol00goo00<07gooOol01Goo00<07gooOol01Woo00<07goo
Ool01Woo00<07gooOol027oo00<07gooOol01goo00<07gooOol01goo00<07gooOol01Woo00<07goo
01l00P0O00=oo`0O01l00P0OH7oo001IOol00`0OOol07`02Ool0100OOomoo`0O0goo00D07gooOomo
o`0O00Eoo`0301moogoo00=oo`0301moogoo00Eoo`0301moogoo00Ioo`0301moogoo00Ioo`807`Uo
o`0301moogoo00Moo`0301moogoo00Moo`0301moogoo00Eoo`<07`03Ool07goo00@07f1oo`00FGoo
00H07gooOol07goo01l2Ool01@0OOomoogoo01l017oo00<07gooOol00goo00<07gooOol00goo00<0
7gooOol01Goo0P0O1goo00<07gooOol01goo00<07gooOol01goo00<07gooOol01goo0P0O27oo0P0O
1Goo00@07goo01moo`L07emoo`00FWoo00<07goo01l00Woo00@07gooOol07`=oo`0301moogoo009o
o`0301moogoo009oo`0301moogoo00Aoo`0301moogoo00Ioo`0301moogoo00Eoo`0301moogoo00Mo
o`0301moogoo00Moo`0301moogoo00Qoo`0301moogoo00Moo`0:01moogooOol07goo01moo`0OOol6
01mOOol005Yoo`0401moogoo01l2Ool0100OOomoo`0O0goo00D07gooOomoo`0O00Eoo`0301moogoo
00Aoo`0301moogoo00Ioo`0301moogoo00Eoo`807`Qoo`807`Qoo`0301moogoo00Qoo`0301moogoo
00Moo`0701moogoo01moo`0OOol0200OGgoo001KOol00`0OOol07`02Ool0100OOomoo`0O0goo00<0
7gooOol00Woo00<07gooOol00goo00<07gooOol017oo00<07gooOol01Woo00<07gooOol01Woo00<0
7gooOol01goo00<07gooOol01Woo0P0O2Goo00<07gooOol01goo0P0O00Ioo`0OOomoo`0OOol601mO
Ool005]oo`0401moogoo01l2Ool0100OOomoo`0O0goo00<07gooOol00Woo00<07gooOol00goo00<0
7gooOol017oo00<07gooOol01Woo00<07gooOol01Woo00<07gooOol01goo0P0O27oo00<07gooOol0
1goo0P0O27oo0`0O0Woo200OGgoo001LOol0100OOomoo`0O0Woo00@07gooOol07`=oo`0301moogoo
009oo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo00Ioo`0301moogoo00Ioo`0301moogoo
00Qoo`0301moogoo00Ioo`807`Uoo`0301moogoo00Aoo`0701moo`0O01moo`0OOol00P0O00=oo`0O
01l00P0OGgoo001LOol0100OOomoo`0O0Woo00D07gooOomoo`0O00=oo`0501moogooOol07`06Ool0
0`0OOomoo`04Ool00`0OOomoo`06Ool00`0OOomoo`06Ool00`0OOomoo`08Ool00`0OOomoo`07Ool0
0`0OOomoo`07Ool00`0OOomoo`03Ool0100OOol07goo0`0O00=oo`0OOol01@0OGWoo001MOol0100O
Oomoo`0O0Woo00@07gooOol07`=oo`0301moogoo009oo`0301moogoo00Aoo`0301moogoo00Aoo`03
01moogoo00Ioo`0301moogoo00Ioo`807`Uoo`807`Qoo`807`Qoo`0701moogooOol07goo01l00Woo
0`0O00Aoo`0O01moo`@07eioo`00GGoo00D07gooOomoo`0O009oo`0401moogoo01l3Ool00`0OOomo
o`02Ool00`0OOomoo`04Ool00`0OOomoo`04Ool201l7Ool00`0OOomoo`07Ool00`0OOomoo`08Ool0
0`0OOomoo`07Ool201l7Ool201l017oo01moo`0O0Woo00T07goo01l07goo01moo`0OOol00`0OGGoo
001NOol0100OOomoo`0O0Woo00D07gooOomoo`0O00=oo`0301moogoo009oo`0301moogoo00Aoo`03
01moogoo00Eoo`0301moogoo00Eoo`0301moogoo00Moo`0301moogoo00Qoo`0301moogoo00Qoo`03
01moogoo00Ioo`0901moogoo01moo`0OOol07goo00D07`04Ool07`0O01mMOol005moo`0401moogoo
01l2Ool01@0OOomoogoo01l00goo00<07gooOol00Woo00<07gooOol017oo0P0O1Woo00<07gooOol0
1Goo0P0O27oo00<07gooOol027oo00<07gooOol027oo00<07gooOol017oo00@07goo01l07`9oo`06
01moo`0OOol07goo0`0O00Aoo`0O01l07eeoo`00H7oo00@07gooOol07`9oo`0501moogooOol07`03
Ool00`0OOomoo`02Ool00`0OOomoo`05Ool00`0OOomoo`04Ool00`0OOomoo`06Ool00`0OOomoo`06
Ool201l9Ool201l9Ool201l4Ool00`0OOomoo`0301l2Ool201l00goo01moo`0301l00goo01l07`02
01mKOol0061oo`0501moogooOol07`02Ool01@0OOomoogoo01l00goo00<07gooOol00Woo0P0O1Woo
00<07gooOol017oo00<07gooOol01Woo00<07gooOol01goo00<07gooOol027oo00<07gooOol027oo
00@07gooOol07`9oo`0301moogoo00<07`05Ool07goo01moo`0301l00goo01l07`0201mKOol0065o
o`0401moogoo01l2Ool01@0OOomoogoo01l017oo00<07gooOol00goo00<07gooOol017oo00<07goo
Ool017oo0P0O1goo0P0O27oo00<07gooOol027oo00<07gooOol027oo0`0O0Woo00<07goo01l00Woo
0P0O0Woo0P0O00=oo`0O01l01P0OFWoo001ROol0100OOomoo`0O0Woo00D07gooOomoo`0O00Aoo`03
01moogoo00=oo`0301moogoo00Aoo`0301moogoo00Eoo`0301moogoo00Ioo`0301moogoo00Ioo`80
7`Uoo`807`Uoo`@07`9oo`0401moo`0OOol301l00goo01moo`0701l00goo01moo`1HOol006=oo`04
01moogoo01l2Ool01@0OOomoogoo01l017oo00<07gooOol00goo00<07gooOol017oo00<07gooOol0
1Goo00<07gooOol01Woo0P0O27oo0P0O2Goo0P0O1Woo00<07gooOol00P0O00Aoo`0OOomoo`807`9o
o`<07`03Ool07`0O00D07e]oo`00I7oo00@07gooOol07`9oo`0501moogooOol07`04Ool00`0OOomo
o`03Ool00`0OOomoo`04Ool00`0OOomoo`05Ool00`0OOomoo`07Ool00`0OOomoo`07Ool201l9Ool2
01l4Ool01@0OOomoo`0OOol00P0O00Uoo`0OOol07goo01moo`0OOol00P0O00=oo`0O01l00P0OG7oo
001UOol0100OOomoo`0O0Woo00D07gooOomoo`0O00Aoo`0301moogoo00=oo`0301moogoo00Aoo`03
01moogoo00Eoo`807`Qoo`807`Uoo`807`Uoo`807`05Ool07gooOol07`02Ool00`0OOol07`0201l0
1Woo01moogoo01moo`H07eeoo`00IWoo00<07goo01l00goo00@07gooOomoo`807`=oo`0301moogoo
00=oo`0301moogoo00Aoo`807`Moo`0301moogoo00Moo`807`Uoo`807`Uoo`807`05Ool07gooOol0
7`02Ool00`0OOol07`0401l017oo01l07goo0`0OGWoo001WOol00`0OOol07`03Ool00`0OOomoo`02
Ool01@0OOomoogoo01l01Goo00<07gooOol01Goo00<07gooOol01Goo00<07gooOol027oo00<07goo
Ool027oo0P0O1Woo00<07gooOol00P0O0Woo00P07goo01moo`0OOol07goo1`0OH7oo001XOol00`0O
Ool07`03Ool00`0OOomoo`02Ool01@0OOomoogoo01l01Goo0P0O1Woo0P0O1Woo0P0O2Goo0P0O2Woo
0P0O17oo00D07gooOol07goo00@07`9oo`0601moo`0OOol07goo100OHGoo001YOol00`0OOol07`03
Ool00`0OOomoo`02Ool01@0OOomoogoo01l01Woo00<07gooOol01Goo00<07gooOol01Goo0P0O2Goo
0P0O2Woo0P0O00=oo`0OOol00Woo00<07goo01l00Woo300OHWoo001YOol00`0OOomoo`0201l2Ool0
0`0OOomoo`02Ool201l2Ool201l5Ool201l6Ool201l7Ool201l9Ool201l:Ool201l2Ool00`0OOol0
7`02Ool00`0OOol07`02Ool01@0OOol07`0OOol00P0OHgoo001ZOol01@0OOomoogoo01l00Woo00<0
7gooOol00goo00D07gooOomoo`0O00Ioo`0301moogoo00Eoo`807`Moo`807`Uoo`807`Moo`0301mo
ogoo00@07`9oo`0701moogoo01moo`0OOol0100OIGoo001[Ool01@0OOomoogoo01l00Woo00<07goo
Ool00goo00D07gooOomoo`0O00Ioo`807`Moo`0301moogoo00Ioo`807`Uoo`<07`=oo`0401moogoo
01l2Ool>01mVOol006aoo`807`9oo`0401moogoo01l5Ool0100OOomoogoo0P0O1Woo0P0O1Woo0P0O
27oo0P0O2Woo0`0O0Woo00@07gooOol07`=oo`0301moogoo00807`04Ool07`0O01mXOol006ioo`80
7`04Ool07`0OOol201l4Ool201l3Ool201l6Ool00`0OOomoo`05Ool201l8Ool201l8Ool901l2Ool0
0`0OOol07`0601mYOol0071oo`0401moogoo01l2Ool201l4Ool00`0OOomoo`02Ool201l5Ool201l7
Ool301l7Ool401l3Ool01@0OOomoogoo01l00goo00<07goo01l01@0O00=oo`0O01l0Jgoo001aOol2
01l00goo01moo`02Ool00`0OOomoo`02Ool00`0OOomoo`03Ool201l5Ool201l8Ool201l9Ool501l0
17oo01moogoo0P0O00Aoo`0OOomoo`D07feoo`00Lgoo100O0Woo0P0O0goo0P0O1Goo0P0O1Goo0P0O
27oo100O1Goo0P0O0Woo3P0OKgoo001eOol0100OOol07`0O0Woo0P0O0goo0P0O1Goo0P0O1Goo0`0O
2Goo1@0O0goo00H07gooOomoo`0OOol201l00goo01l07`0201maOol007Ioo`807`03Ool07`0O009o
o`807`=oo`807`Eoo`807`Ioo`@07`Moo`807`03Ool07`0O00/07gAoo`00N7oo1@0O0Woo0P0O0goo
0P0O1Goo0`0O1goo1`0O0Woo0P0O0goo00<07goo01l0100OMWoo001kOol501l017oo01l07`0O0Woo
100O17oo0`0O1goo3`0ONGoo001mOol501l2Ool301l3Ool501l2Ool;01l2Ool501mmOol0085oo`D0
7`03Ool07`0O00807`Aoo`l07h9oo`00QWoo4`0OQgoo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {707.75, 478.375}} -> {-0.399192, \
2.08557, 0.00348777, 0.00348777}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[\[Theta]];\)\), "\[IndentingNewLine]", 
    \(\(ComponentFunct[Equ6, {0, R\ \ Cos[\[Phi]], R\ \ Sin[\[Phi]]}, 
        Red];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.4459 .48391 m
.44238 .50432 L
s
.44977 .46359 m
.4459 .48391 L
s
.44238 .50432 m
.43922 .52473 L
s
.45395 .44345 m
.44977 .46359 L
s
.43922 .52473 m
.43644 .54504 L
s
.45845 .42359 m
.45395 .44345 L
s
.43644 .54504 m
.43404 .56516 L
s
.46324 .40409 m
.45845 .42359 L
s
.43404 .56516 m
.43205 .58501 L
s
.4683 .38506 m
.46324 .40409 L
s
.43205 .58501 m
.43047 .60448 L
s
.47361 .36658 m
.4683 .38506 L
s
.43047 .60448 m
.42933 .62347 L
s
.47915 .34875 m
.47361 .36658 L
s
.42933 .62347 m
.42863 .64189 L
s
.4849 .33168 m
.47915 .34875 L
s
.42863 .64189 m
.42838 .65963 L
s
.49083 .31547 m
.4849 .33168 L
s
.42838 .65963 m
.42861 .67659 L
s
.49691 .30022 m
.49083 .31547 L
s
.42861 .67659 m
.4293 .69266 L
s
.50312 .28603 m
.49691 .30022 L
s
.4293 .69266 m
.43048 .70773 L
s
.50942 .27301 m
.50312 .28603 L
s
.43048 .70773 m
.43216 .72168 L
s
.51579 .26128 m
.50942 .27301 L
s
.43216 .72168 m
.43433 .73441 L
s
.52218 .25094 m
.51579 .26128 L
s
.43433 .73441 m
.437 .74579 L
s
.52855 .2421 m
.52218 .25094 L
s
.437 .74579 m
.44016 .75572 L
s
.53488 .23486 m
.52855 .2421 L
s
.44016 .75572 m
.44383 .76407 L
s
.5411 .22934 m
.53488 .23486 L
s
.44383 .76407 m
.44798 .77074 L
s
.54718 .22563 m
.5411 .22934 L
s
.44798 .77074 m
.4526 .77562 L
s
.55307 .22383 m
.54718 .22563 L
s
.4526 .77562 m
.45769 .7786 L
s
.55871 .22402 m
.55307 .22383 L
s
.45769 .7786 m
.46322 .7796 L
s
.56405 .22627 m
.55871 .22402 L
s
.46322 .7796 m
.46916 .77852 L
s
.56905 .23064 m
.56405 .22627 L
s
.46916 .77852 m
.47549 .77531 L
s
.57363 .23718 m
.56905 .23064 L
s
.47549 .77531 m
.48215 .7699 L
s
.57776 .2459 m
.57363 .23718 L
s
.48215 .7699 m
.48911 .76227 L
s
.58138 .25682 m
.57776 .2459 L
s
.48911 .76227 m
.49632 .75241 L
s
.58444 .2699 m
.58138 .25682 L
s
.49632 .75241 m
.50372 .74032 L
s
.58688 .2851 m
.58444 .2699 L
s
.50372 .74032 m
.51124 .72606 L
s
.58868 .30234 m
.58688 .2851 L
s
.51124 .72606 m
.51881 .70969 L
s
.58978 .32151 m
.58868 .30234 L
s
.51881 .70969 m
.52637 .69131 L
s
.59017 .34246 m
.58978 .32151 L
s
.52637 .69131 m
.53383 .67107 L
s
.58982 .36502 m
.59017 .34246 L
s
.53383 .67107 m
.54112 .64912 L
s
.58872 .38901 m
.58982 .36502 L
s
.54112 .64912 m
.54816 .62566 L
s
.58687 .41418 m
.58872 .38901 L
s
.54816 .62566 m
.55487 .60091 L
s
.58427 .44029 m
.58687 .41418 L
s
.55487 .60091 m
.56117 .57512 L
s
.58095 .46707 m
.58427 .44029 L
s
.56117 .57512 m
.56699 .54855 L
s
.57693 .49423 m
.58095 .46707 L
s
.56699 .54855 m
.57226 .52149 L
s
.57226 .52149 m
.57693 .49423 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol009eoo`El07ioo`00Vgoo0W`01Goo00=l07ooOol0Ngoo
002JOol00g`0Oomoo`06Ool00g`0Oomoo`1jOol009Uoo`03O01oogoo00Moo`03O01oogoo07Yoo`00
V7oo00=l07ooOol02Goo00=l07ooOol0NGoo002GOol00g`0Oomoo`0:Ool00g`0Oomoo`1iOol009Io
o`03O01oogoo00aoo`03O01oogoo07Qoo`00UWoo00=l07ooOol037oo00=l07ooOol0N7oo002EOol0
0g`0Oomoo`0>Ool00g`0Oomoo`1gOol009Aoo`03O01oogoo00moo`03O01oogoo07Moo`00U7oo00=l
07ooOol03goo00=l07ooOol0Mgoo002COol00g`0Oomoo`0@Ool00g`0Oomoo`1gOol009=oo`03O01o
ogoo015oo`03O01oogoo07Ioo`00TWoo00=l07ooOol04Woo00=l07ooOol0MWoo002BOol00g`0Oomo
o`0BOol00g`0Oomoo`1fOol0095oo`03O01oogoo01=oo`03O01oogoo07Ioo`00TGoo00=l07ooOol0
57oo00=l07ooOol0MGoo002@Ool00g`0Oomoo`0EOol00g`0Oomoo`1eOol0091oo`03O01oogoo01Eo
o`03O01oogoo07Eoo`00Sgoo00=l07ooOol05Woo00=l07ooOol0MGoo002?Ool00g`0Oomoo`0FOol0
0g`0Oomoo`1eOol008ioo`03O01oogoo01Moo`03O01oogoo07Eoo`00SWoo00=l07ooOol05goo00=l
07ooOol0MGoo002=Ool00g`0Oomoo`0HOol00g`0Oomoo`1eOol008eoo`03O01oogoo01Qoo`03O01o
ogoo07Eoo`00S7oo00=l07ooOol06Goo00=l07ooOol0MGoo002<Ool00g`0Oomoo`0JOol00g`0Oomo
o`1dOol008aoo`03O01oogoo01Yoo`03O01oogoo07Aoo`00S7oo00=l07ooOol06Woo00=l07ooOol0
M7oo002;Ool00g`0Oomoo`0KOol00g`0Oomoo`1dOol008]oo`03O01oogoo01]oo`03O01oogoo07Ao
o`00Rgoo00=l07ooOol06goo00=l07ooOol0M7oo002;Ool00g`0Oomoo`0KOol00g`0Oomoo`1dOol0
08Yoo`03O01oogoo01aoo`03O01oogoo07Aoo`00RWoo00=l07ooOol077oo00=l07ooOol0M7oo0029
Ool00g`0Oomoo`0MOol00g`0Oomoo`1dOol008Uoo`03O01oogoo01eoo`03O01oogoo07Aoo`00RGoo
00=l07ooOol07Goo00=l07ooOol0M7oo0028Ool00g`0Oomoo`0NOol00g`0Oomoo`1dOol008Qoo`03
O01oogoo01ioo`03O01oogoo07Aoo`00Qgoo00=l07ooOol07goo00=l07ooOol0M7oo0027Ool00g`0
Oomoo`0OOol00g`0Oomoo`1dOol008Moo`03O01oogoo01moo`03O01oogoo07Aoo`00Qgoo00=l07oo
Ool07goo00=l07ooOol0M7oo0026Ool00g`0Oomoo`0OOol00g`0Oomoo`1eOol008Ioo`03O01oogoo
01moo`03O01oogoo07Eoo`00QWoo00=l07ooOol07goo00=l07ooOol0MGoo0026Ool00g`0Oomoo`0O
Ool00g`0Oomoo`1eOol008Eoo`03O01oogoo021oo`03O01oogoo07Eoo`00QGoo00=l07ooOol087oo
00=l07ooOol0MGoo0024Ool00g`0Oomoo`0QOol00g`0Oomoo`1eOol008Aoo`03O01oogoo025oo`03
O01oogoo07Eoo`00Q7oo00=l07ooOol08Goo00=l07ooOol0MGoo0024Ool00g`0Oomoo`0QOol00g`0
Oomoo`1eOol008=oo`03O01oogoo029oo`03O01oogoo07Eoo`00Pgoo00=l07ooOol08Woo00=l07oo
Ool0MGoo0023Ool00g`0Oomoo`0ROol00g`0Oomoo`1eOol008=oo`03O01oogoo029oo`03O01oogoo
07Eoo`00Pgoo00=l07ooOol08Goo00=l07ooOol0MWoo0023Ool00g`0Oomoo`0QOol00g`0Oomoo`1f
Ool0089oo`03O01oogoo029oo`03O01oogoo07Ioo`00PWoo00=l07ooOol08Woo00=l07ooOol0MWoo
0022Ool00g`0Oomoo`0ROol00g`0Oomoo`1fOol0089oo`03O01oogoo029oo`03O01oogoo07Ioo`00
PWoo00=l07ooOol08Woo00=l07ooOol0MWoo0022Ool00g`0Oomoo`0ROol00g`0Oomoo`1fOol0085o
o`03O01oogoo029oo`03O01oogoo07Moo`00PGoo00=l07ooOol08Woo00=l07ooOol0Mgoo0021Ool0
0g`0Oomoo`0ROol00g`0Oomoo`1gOol0085oo`03O01oogoo029oo`03O01oogoo07Moo`00PGoo00=l
07ooOol08Woo00=l07ooOol0Mgoo0020Ool00g`0Oomoo`0SOol00g`0Oomoo`1gOol0081oo`03O01o
ogoo02=oo`03O01oogoo07Moo`00Ogoo00=l07ooOol097oo00=l07ooOol0Mgoo001oOol00g`0Oomo
o`0SOol00g`0Oomoo`1hOol007moo`03O01oogoo02=oo`03O01oogoo07Qoo`00Ogoo00=l07ooOol0
8goo00=l07ooOol0N7oo001nOol00g`0Oomoo`0TOol00g`0Oomoo`1hOol007ioo`03O01oogoo02Ao
o`03O01oogoo07Qoo`00OWoo00=l07ooOol097oo00=l07ooOol0N7oo001nOol00g`0Oomoo`0TOol0
0g`0Oomoo`1hOol007ioo`03O01oogoo02=oo`03O01oogoo07Uoo`00OWoo00=l07ooOol08goo00=l
07ooOol0NGoo001nOol00g`0Oomoo`0SOol00g`0Oomoo`1iOol007ioo`03O01oogoo02=oo`03O01o
ogoo07Uoo`00OWoo00=l07ooOol08goo00=l07ooOol0NGoo001nOol00g`0Oomoo`0SOol00g`0Oomo
o`1iOol007ioo`03O01oogoo029oo`03O01oogoo07Yoo`00OWoo00=l07ooOol08Woo00=l07ooOol0
NWoo001mOol00g`0Oomoo`0SOol00g`0Oomoo`1jOol007eoo`03O01oogoo02=oo`03O01oogoo07Yo
o`00OGoo00=l07ooOol08Woo00=l07ooOol0Ngoo001mOol00g`0Oomoo`0ROol00g`0Oomoo`1kOol0
07eoo`03O01oogoo029oo`03O01oogoo07]oo`00OGoo00=l07ooOol08Woo00=l07ooOol0Ngoo001l
Ool00g`0Oomoo`0SOol00g`0Oomoo`1kOol007aoo`03O01oogoo02=oo`03O01oogoo07]oo`00O7oo
00=l07ooOol08Woo00=l07ooOol0O7oo001lOol00g`0Oomoo`0ROol00g`0Oomoo`1lOol007aoo`03
O01oogoo029oo`03O01oogoo07aoo`00O7oo00=l07ooOol08Woo00=l07ooOol0O7oo001lOol00g`0
Oomoo`0ROol00g`0Oomoo`1lOol007aoo`03O01oogoo029oo`03O01oogoo07aoo`00O7oo00=l07oo
Ool08Goo00=l07ooOol0OGoo001lOol00g`0Oomoo`0QOol00g`0Oomoo`1mOol007aoo`03O01oogoo
025oo`03O01oogoo07eoo`00Ngoo00=l07ooOol08Woo00=l07ooOol0OGoo001kOol00g`0Oomoo`0Q
Ool00g`0Oomoo`1nOol007]oo`03O01oogoo025oo`03O01oogoo07ioo`00Ngoo00=l07ooOol08Goo
00=l07ooOol0OWoo001kOol00g`0Oomoo`0POol00g`0Oomoo`1oOol007]oo`03O01oogoo021oo`03
O01oogoo07moo`00Ngoo00=l07ooOol087oo00=l07ooOol0Ogoo001kOol00g`0Oomoo`0POol00g`0
Oomoo`1oOol007]oo`03O01oogoo01moo`03O01oogoo081oo`00Ngoo00=l07ooOol07goo00=l07oo
Ool0P7oo001kOol00g`0Oomoo`0OOol00g`0Oomoo`20Ool007]oo`03O01oogoo01ioo`03O01oogoo
085oo`00Ngoo00=l07ooOol07Woo00=l07ooOol0PGoo001kOol00g`0Oomoo`0NOol00g`0Oomoo`21
Ool007]oo`03O01oogoo01ioo`03O01oogoo085oo`00Ngoo00=l07ooOol07Goo00=l07ooOol0PWoo
001kOol00g`0Oomoo`0MOol00g`0Oomoo`22Ool007Yoo`03O01oogoo01ioo`03O01oogoo089oo`00
NWoo00=l07ooOol07Goo00=l07ooOol0Pgoo001jOol00g`0Oomoo`0MOol00g`0Oomoo`23Ool007Yo
o`03O01oogoo01eoo`03O01oogoo08=oo`00NWoo00=l07ooOol077oo00=l07ooOol0Q7oo001kOol0
0g`0Oomoo`0KOol00g`0Oomoo`24Ool007]oo`03O01oogoo01]oo`03O01oogoo08Aoo`00Ngoo00=l
07ooOol06Woo00=l07ooOol0QGoo001kOol00g`0Oomoo`0JOol00g`0Oomoo`25Ool007]oo`03O01o
ogoo01Yoo`03O01oogoo08Eoo`00Ngoo00=l07ooOol06Goo00=l07ooOol0QWoo001kOol00g`0Oomo
o`0IOol00g`0Oomoo`26Ool007]oo`03O01oogoo01Qoo`03O01oogoo08Moo`00Ngoo00=l07ooOol0
67oo00=l07ooOol0Qgoo001kOol00g`0Oomoo`0GOol00g`0Oomoo`28Ool007]oo`03O01oogoo01Mo
o`03O01oogoo08Qoo`00Ngoo00=l07ooOol05Woo00=l07ooOol0RGoo001kOol00g`0Oomoo`0FOol0
0g`0Oomoo`29Ool007]oo`03O01oogoo01Eoo`03O01oogoo08Yoo`00O7oo00=l07ooOol057oo00=l
07ooOol0RWoo001lOol00g`0Oomoo`0COol00g`0Oomoo`2;Ool007aoo`03O01oogoo01=oo`03O01o
ogoo08]oo`00O7oo00=l07ooOol04Woo00=l07ooOol0S7oo001lOol00g`0Oomoo`0BOol00g`0Oomo
o`2<Ool007aoo`03O01oogoo015oo`03O01oogoo08eoo`00O7oo00=l07ooOol04Goo00=l07ooOol0
SGoo001mOol00g`0Oomoo`0?Ool00g`0Oomoo`2>Ool007eoo`03O01oogoo00moo`03O01oogoo08io
o`00OGoo00=l07ooOol03Woo00=l07ooOol0Sgoo001nOol00g`0Oomoo`0<Ool00g`0Oomoo`2@Ool0
07ioo`03O01oogoo00aoo`03O01oogoo091oo`00Ogoo00=l07ooOol02Woo00=l07ooOol0TGoo001o
Ool00g`0Oomoo`09Ool00g`0Oomoo`2BOol007moo`03O01oogoo00Qoo`03O01oogoo09=oo`00P7oo
00=l07ooOol01Woo00=l07ooOol0U7oo0021Ool00g`0Oomoo`04Ool00g`0Oomoo`2EOol0089oo`Il
09Qoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.42301 .48222 m
.42035 .50669 L
s
.42617 .45785 m
.42301 .48222 L
s
.42035 .50669 m
.41818 .53114 L
s
.42981 .43369 m
.42617 .45785 L
s
.41818 .53114 m
.41654 .55546 L
s
.4339 .40986 m
.42981 .43369 L
s
.41654 .55546 m
.41541 .57954 L
s
.43844 .38646 m
.4339 .40986 L
s
.41541 .57954 m
.41482 .60326 L
s
.44342 .36362 m
.43844 .38646 L
s
.41482 .60326 m
.41477 .6265 L
s
.4488 .34145 m
.44342 .36362 L
s
.41477 .6265 m
.41528 .64915 L
s
.45457 .32007 m
.4488 .34145 L
s
.41528 .64915 m
.41634 .67107 L
s
.46071 .29961 m
.45457 .32007 L
s
.41634 .67107 m
.41796 .69216 L
s
.46719 .28018 m
.46071 .29961 L
s
.41796 .69216 m
.42014 .71227 L
s
.47399 .26192 m
.46719 .28018 L
s
.42014 .71227 m
.42289 .73129 L
s
.48107 .24494 m
.47399 .26192 L
s
.42289 .73129 m
.4262 .74908 L
s
.48841 .22939 m
.48107 .24494 L
s
.4262 .74908 m
.43007 .7655 L
s
.49597 .21539 m
.48841 .22939 L
s
.43007 .7655 m
.4345 .78042 L
s
.5037 .20306 m
.49597 .21539 L
s
.4345 .78042 m
.43946 .79371 L
s
.51157 .19255 m
.5037 .20306 L
s
.43946 .79371 m
.44495 .80523 L
s
.51953 .18397 m
.51157 .19255 L
s
.44495 .80523 m
.45096 .81485 L
s
.52753 .17744 m
.51953 .18397 L
s
.45096 .81485 m
.45744 .82245 L
s
.53551 .17309 m
.52753 .17744 L
s
.45744 .82245 m
.46438 .82789 L
s
.54342 .17101 m
.53551 .17309 L
s
.46438 .82789 m
.47175 .83106 L
s
.5512 .17131 m
.54342 .17101 L
s
.47175 .83106 m
.47949 .83186 L
s
.55878 .17406 m
.5512 .17131 L
s
.47949 .83186 m
.48757 .83021 L
s
.56609 .17934 m
.55878 .17406 L
s
.48757 .83021 m
.49594 .82601 L
s
.57307 .18718 m
.56609 .17934 L
s
.49594 .82601 m
.50452 .81923 L
s
.57964 .1976 m
.57307 .18718 L
s
.50452 .81923 m
.51327 .80984 L
s
.58574 .21061 m
.57964 .1976 L
s
.51327 .80984 m
.5221 .79781 L
s
.59129 .22617 m
.58574 .21061 L
s
.5221 .79781 m
.53094 .78319 L
s
.59623 .24422 m
.59129 .22617 L
s
.53094 .78319 m
.53971 .76603 L
s
.60048 .26465 m
.59623 .24422 L
s
.53971 .76603 m
.54831 .74642 L
s
.604 .28734 m
.60048 .26465 L
s
.54831 .74642 m
.55668 .72448 L
s
.60673 .31211 m
.604 .28734 L
s
.55668 .72448 m
.56471 .70037 L
s
.60862 .33878 m
.60673 .31211 L
s
.56471 .70037 m
.57231 .67429 L
s
.60964 .36709 m
.60862 .33878 L
s
.57231 .67429 m
.57941 .64647 L
s
.60976 .39679 m
.60964 .36709 L
s
.57941 .64647 m
.58592 .61717 L
s
.60897 .42759 m
.60976 .39679 L
s
.58592 .61717 m
.59176 .58668 L
s
.60727 .45917 m
.60897 .42759 L
s
.59176 .58668 m
.59687 .5553 L
s
.60467 .49121 m
.60727 .45917 L
s
.59687 .5553 m
.60119 .52337 L
s
.60119 .52337 m
.60467 .49121 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol009Uoo`Ql07moo`00Ugoo0W`027oo00=l07ooOol0O7oo
002FOol00g`0Oomoo`09Ool00g`0Oomoo`1kOol009Eoo`03O01oogoo00]oo`03O01oogoo07Yoo`00
U7oo00=l07ooOol03Goo00=l07ooOol0NGoo002COol00g`0Oomoo`0?Ool00g`0Oomoo`1hOol0099o
o`03O01oogoo011oo`03O01oogoo07Qoo`00TGoo00=l07ooOol04Woo00=l07ooOol0Mgoo002AOol0
0g`0Oomoo`0BOol00g`0Oomoo`1gOol0091oo`03O01oogoo01Aoo`03O01oogoo07Ioo`00Sgoo00=l
07ooOol05Goo00=l07ooOol0MWoo002?Ool00g`0Oomoo`0FOol00g`0Oomoo`1eOol008ioo`03O01o
ogoo01Moo`03O01oogoo07Eoo`00SGoo00=l07ooOol067oo00=l07ooOol0MGoo002=Ool00g`0Oomo
o`0IOol00g`0Oomoo`1dOol008aoo`03O01oogoo01Yoo`03O01oogoo07Aoo`00S7oo00=l07ooOol0
6Woo00=l07ooOol0M7oo002<Ool00g`0Oomoo`0KOol00g`0Oomoo`1cOol008]oo`03O01oogoo01ao
o`03O01oogoo07=oo`00Rgoo00=l07ooOol077oo00=l07ooOol0Lgoo002:Ool00g`0Oomoo`0NOol0
0g`0Oomoo`1bOol008Yoo`03O01oogoo01ioo`03O01oogoo079oo`00RWoo00=l07ooOol07Woo00=l
07ooOol0LWoo0029Ool00g`0Oomoo`0OOol00g`0Oomoo`1bOol008Uoo`03O01oogoo021oo`03O01o
ogoo075oo`00R7oo00=l07ooOol08Goo00=l07ooOol0LGoo0028Ool00g`0Oomoo`0QOol00g`0Oomo
o`1aOol008Qoo`03O01oogoo025oo`03O01oogoo075oo`00Qgoo00=l07ooOol08Woo00=l07ooOol0
LGoo0027Ool00g`0Oomoo`0ROol00g`0Oomoo`1aOol008Ioo`03O01oogoo02Aoo`03O01oogoo071o
o`00QWoo00=l07ooOol097oo00=l07ooOol0L7oo0026Ool00g`0Oomoo`0TOol00g`0Oomoo`1`Ool0
08Eoo`03O01oogoo02Eoo`03O01oogoo071oo`00QGoo00=l07ooOol09Goo00=l07ooOol0L7oo0024
Ool00g`0Oomoo`0VOol00g`0Oomoo`1`Ool008Aoo`03O01oogoo02Ioo`03O01oogoo071oo`00Q7oo
00=l07ooOol09goo00=l07ooOol0Kgoo0023Ool00g`0Oomoo`0XOol00g`0Oomoo`1_Ool008=oo`03
O01oogoo02Qoo`03O01oogoo06moo`00Pgoo00=l07ooOol0:7oo00=l07ooOol0Kgoo0022Ool00g`0
Oomoo`0YOol00g`0Oomoo`1_Ool0089oo`03O01oogoo02Uoo`03O01oogoo06moo`00PWoo00=l07oo
Ool0:Goo00=l07ooOol0Kgoo0021Ool00g`0Oomoo`0ZOol00g`0Oomoo`1_Ool0085oo`03O01oogoo
02Yoo`03O01oogoo06moo`00PGoo00=l07ooOol0:Woo00=l07ooOol0Kgoo0020Ool00g`0Oomoo`0[
Ool00g`0Oomoo`1_Ool0081oo`03O01oogoo02]oo`03O01oogoo06moo`00P7oo00=l07ooOol0:goo
00=l07ooOol0Kgoo0020Ool00g`0Oomoo`0[Ool00g`0Oomoo`1_Ool0081oo`03O01oogoo02]oo`03
O01oogoo06moo`00Ogoo00=l07ooOol0;7oo00=l07ooOol0Kgoo001oOol00g`0Oomoo`0/Ool00g`0
Oomoo`1_Ool007moo`03O01oogoo02aoo`03O01oogoo06moo`00Ogoo00=l07ooOol0;7oo00=l07oo
Ool0Kgoo001oOol00g`0Oomoo`0/Ool00g`0Oomoo`1_Ool007ioo`03O01oogoo02eoo`03O01oogoo
06moo`00OWoo00=l07ooOol0;Goo00=l07ooOol0Kgoo001nOol00g`0Oomoo`0]Ool00g`0Oomoo`1_
Ool007eoo`03O01oogoo02ioo`03O01oogoo06moo`00OGoo00=l07ooOol0;goo00=l07ooOol0KWoo
001mOol00g`0Oomoo`0_Ool00g`0Oomoo`1^Ool007eoo`03O01oogoo02moo`03O01oogoo06ioo`00
OGoo00=l07ooOol0;goo00=l07ooOol0KWoo001lOol00g`0Oomoo`0`Ool00g`0Oomoo`1^Ool007ao
o`03O01oogoo031oo`03O01oogoo06ioo`00O7oo00=l07ooOol0<7oo00=l07ooOol0KWoo001lOol0
0g`0Oomoo`0`Ool00g`0Oomoo`1^Ool007aoo`03O01oogoo02moo`03O01oogoo06moo`00O7oo00=l
07ooOol0;goo00=l07ooOol0Kgoo001lOol00g`0Oomoo`0_Ool00g`0Oomoo`1_Ool007]oo`03O01o
ogoo031oo`03O01oogoo06moo`00Ngoo00=l07ooOol0<7oo00=l07ooOol0Kgoo001kOol00g`0Oomo
o`0`Ool00g`0Oomoo`1_Ool007]oo`03O01oogoo031oo`03O01oogoo06moo`00Ngoo00=l07ooOol0
<7oo00=l07ooOol0Kgoo001kOol00g`0Oomoo`0`Ool00g`0Oomoo`1_Ool007]oo`03O01oogoo031o
o`03O01oogoo06moo`00NWoo00=l07ooOol0<Goo00=l07ooOol0Kgoo001jOol00g`0Oomoo`0aOol0
0g`0Oomoo`1_Ool007Yoo`03O01oogoo035oo`03O01oogoo06moo`00NWoo00=l07ooOol0<Goo00=l
07ooOol0Kgoo001jOol00g`0Oomoo`0aOol00g`0Oomoo`1_Ool007Yoo`03O01oogoo035oo`03O01o
ogoo06moo`00NWoo00=l07ooOol0<Goo00=l07ooOol0Kgoo001iOol00g`0Oomoo`0bOol00g`0Oomo
o`1_Ool007Uoo`03O01oogoo035oo`03O01oogoo071oo`00NGoo00=l07ooOol0<Goo00=l07ooOol0
L7oo001iOol00g`0Oomoo`0aOol00g`0Oomoo`1`Ool007Uoo`03O01oogoo035oo`03O01oogoo071o
o`00NGoo00=l07ooOol0<Goo00=l07ooOol0L7oo001iOol00g`0Oomoo`0aOol00g`0Oomoo`1`Ool0
07Qoo`03O01oogoo039oo`03O01oogoo071oo`00N7oo00=l07ooOol0<Woo00=l07ooOol0L7oo001h
Ool00g`0Oomoo`0bOol00g`0Oomoo`1`Ool007Qoo`03O01oogoo035oo`03O01oogoo075oo`00N7oo
00=l07ooOol0<Goo00=l07ooOol0LGoo001hOol00g`0Oomoo`0aOol00g`0Oomoo`1aOol007Qoo`03
O01oogoo035oo`03O01oogoo075oo`00N7oo00=l07ooOol0<Goo00=l07ooOol0LGoo001hOol00g`0
Oomoo`0aOol00g`0Oomoo`1aOol007Qoo`03O01oogoo035oo`03O01oogoo075oo`00N7oo00=l07oo
Ool0<Goo00=l07ooOol0LGoo001hOol00g`0Oomoo`0aOol00g`0Oomoo`1aOol007Qoo`03O01oogoo
035oo`03O01oogoo075oo`00N7oo00=l07ooOol0<7oo00=l07ooOol0LWoo001gOol00g`0Oomoo`0a
Ool00g`0Oomoo`1bOol007Moo`03O01oogoo035oo`03O01oogoo079oo`00Mgoo00=l07ooOol0<Goo
00=l07ooOol0LWoo001gOol00g`0Oomoo`0aOol00g`0Oomoo`1bOol007Moo`03O01oogoo035oo`03
O01oogoo079oo`00Mgoo00=l07ooOol0<Goo00=l07ooOol0LWoo001gOol00g`0Oomoo`0`Ool00g`0
Oomoo`1cOol007Moo`03O01oogoo031oo`03O01oogoo07=oo`00Mgoo00=l07ooOol0<7oo00=l07oo
Ool0Lgoo001gOol00g`0Oomoo`0`Ool00g`0Oomoo`1cOol007Moo`03O01oogoo02moo`03O01oogoo
07Aoo`00Mgoo00=l07ooOol0;goo00=l07ooOol0M7oo001gOol00g`0Oomoo`0_Ool00g`0Oomoo`1d
Ool007Moo`03O01oogoo02moo`03O01oogoo07Aoo`00Mgoo00=l07ooOol0;goo00=l07ooOol0M7oo
001gOol00g`0Oomoo`0_Ool00g`0Oomoo`1dOol007Moo`03O01oogoo02moo`03O01oogoo07Aoo`00
Mgoo00=l07ooOol0;Woo00=l07ooOol0MGoo001gOol00g`0Oomoo`0^Ool00g`0Oomoo`1eOol007Mo
o`03O01oogoo02ioo`03O01oogoo07Eoo`00Mgoo00=l07ooOol0;Woo00=l07ooOol0MGoo001gOol0
0g`0Oomoo`0^Ool00g`0Oomoo`1eOol007Moo`03O01oogoo02ioo`03O01oogoo07Eoo`00Mgoo00=l
07ooOol0;Goo00=l07ooOol0MWoo001gOol00g`0Oomoo`0]Ool00g`0Oomoo`1fOol007Moo`03O01o
ogoo02eoo`03O01oogoo07Ioo`00Mgoo00=l07ooOol0;Goo00=l07ooOol0MWoo001gOol00g`0Oomo
o`0/Ool00g`0Oomoo`1gOol007Moo`03O01oogoo02aoo`03O01oogoo07Moo`00Mgoo00=l07ooOol0
;7oo00=l07ooOol0Mgoo001gOol00g`0Oomoo`0/Ool00g`0Oomoo`1gOol007Moo`03O01oogoo02]o
o`03O01oogoo07Qoo`00Mgoo00=l07ooOol0:goo00=l07ooOol0N7oo001gOol00g`0Oomoo`0[Ool0
0g`0Oomoo`1hOol007Moo`03O01oogoo02]oo`03O01oogoo07Qoo`00Mgoo00=l07ooOol0:Woo00=l
07ooOol0NGoo001gOol00g`0Oomoo`0ZOol00g`0Oomoo`1iOol007Moo`03O01oogoo02Yoo`03O01o
ogoo07Uoo`00Mgoo00=l07ooOol0:Woo00=l07ooOol0NGoo001gOol00g`0Oomoo`0YOol00g`0Oomo
o`1jOol007Moo`03O01oogoo02Uoo`03O01oogoo07Yoo`00Mgoo00=l07ooOol0:Goo00=l07ooOol0
NWoo001gOol00g`0Oomoo`0YOol00g`0Oomoo`1jOol007Moo`03O01oogoo02Qoo`03O01oogoo07]o
o`00Mgoo00=l07ooOol0:7oo00=l07ooOol0Ngoo001gOol00g`0Oomoo`0XOol00g`0Oomoo`1kOol0
07Qoo`03O01oogoo02Ioo`03O01oogoo07aoo`00N7oo00=l07ooOol09Woo00=l07ooOol0O7oo001h
Ool00g`0Oomoo`0UOol00g`0Oomoo`1mOol007Qoo`03O01oogoo02Eoo`03O01oogoo07eoo`00N7oo
00=l07ooOol097oo00=l07ooOol0OWoo001iOol00g`0Oomoo`0SOol00g`0Oomoo`1nOol007Uoo`03
O01oogoo02=oo`03O01oogoo07ioo`00NGoo00=l07ooOol08Woo00=l07ooOol0Ogoo001iOol00g`0
Oomoo`0ROol00g`0Oomoo`1oOol007Uoo`03O01oogoo029oo`03O01oogoo07moo`00NWoo00=l07oo
Ool08Goo00=l07ooOol0Ogoo001jOol00g`0Oomoo`0POol00g`0Oomoo`20Ool007Yoo`03O01oogoo
021oo`03O01oogoo081oo`00NWoo00=l07ooOol07goo00=l07ooOol0PGoo001jOol00g`0Oomoo`0O
Ool00g`0Oomoo`21Ool007]oo`03O01oogoo01eoo`03O01oogoo089oo`00Ngoo00=l07ooOol07Goo
00=l07ooOol0PWoo001kOol00g`0Oomoo`0LOol00g`0Oomoo`23Ool007]oo`03O01oogoo01aoo`03
O01oogoo08=oo`00Ngoo00=l07ooOol06goo00=l07ooOol0Q7oo001lOol00g`0Oomoo`0JOol00g`0
Oomoo`24Ool007aoo`03O01oogoo01Uoo`03O01oogoo08Eoo`00O7oo00=l07ooOol06Goo00=l07oo
Ool0QGoo001mOol00g`0Oomoo`0GOol00g`0Oomoo`26Ool007eoo`03O01oogoo01Ioo`03O01oogoo
08Moo`00OWoo00=l07ooOol05Goo00=l07ooOol0Qgoo001nOol00g`0Oomoo`0DOol00g`0Oomoo`28
Ool007ioo`03O01oogoo01=oo`03O01oogoo08Uoo`00Ogoo00=l07ooOol04Woo00=l07ooOol0RGoo
001oOol00g`0Oomoo`0AOol00g`0Oomoo`2:Ool0081oo`03O01oogoo011oo`03O01oogoo08Yoo`00
PGoo00=l07ooOol03Woo00=l07ooOol0Rgoo0022Ool00g`0Oomoo`0<Ool00g`0Oomoo`2<Ool0089o
o`03O01oogoo00]oo`03O01oogoo08eoo`00Pgoo00=l07ooOol02Goo00=l07ooOol0SWoo0024Ool2
O007Ool2O02AOol008Ioo`Ml09=oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.412 .48451 m
.41093 .5091 L
s
.41362 .46 m
.412 .48451 L
s
.41093 .5091 m
.41043 .53365 L
s
.4158 .43568 m
.41362 .46 L
s
.41043 .53365 m
.4105 .55806 L
s
.41852 .41167 m
.4158 .43568 L
s
.4105 .55806 m
.41114 .5822 L
s
.42179 .38808 m
.41852 .41167 L
s
.41114 .5822 m
.41235 .60596 L
s
.42558 .36503 m
.42179 .38808 L
s
.41235 .60596 m
.41414 .62922 L
s
.42988 .34264 m
.42558 .36503 L
s
.41414 .62922 m
.41649 .65186 L
s
.43469 .32103 m
.42988 .34264 L
s
.41649 .65186 m
.41942 .67376 L
s
.43998 .30032 m
.43469 .32103 L
s
.41942 .67376 m
.4229 .6948 L
s
.44575 .28064 m
.43998 .30032 L
s
.4229 .6948 m
.42695 .71485 L
s
.45196 .26212 m
.44575 .28064 L
s
.42695 .71485 m
.43154 .73378 L
s
.45859 .24489 m
.45196 .26212 L
s
.43154 .73378 m
.43667 .75146 L
s
.46563 .22907 m
.45859 .24489 L
s
.43667 .75146 m
.44232 .76775 L
s
.47303 .21479 m
.46563 .22907 L
s
.44232 .76775 m
.44846 .78253 L
s
.48076 .2022 m
.47303 .21479 L
s
.44846 .78253 m
.45509 .79566 L
s
.48879 .19142 m
.48076 .2022 L
s
.45509 .79566 m
.46217 .807 L
s
.49708 .18258 m
.48879 .19142 L
s
.46217 .807 m
.46967 .81642 L
s
.50557 .1758 m
.49708 .18258 L
s
.46967 .81642 m
.47755 .8238 L
s
.51421 .1712 m
.50557 .1758 L
s
.47755 .8238 m
.48578 .82902 L
s
.52296 .16889 m
.51421 .1712 L
s
.48578 .82902 m
.4943 .83195 L
s
.53173 .16896 m
.52296 .16889 L
s
.4943 .83195 m
.50306 .83251 L
s
.54048 .17151 m
.53173 .16896 L
s
.50306 .83251 m
.51201 .8306 L
s
.54913 .17659 m
.54048 .17151 L
s
.51201 .8306 m
.52107 .82615 L
s
.55759 .18426 m
.54913 .17659 L
s
.52107 .82615 m
.53018 .81911 L
s
.56581 .19453 m
.55759 .18426 L
s
.53018 .81911 m
.53926 .80945 L
s
.57369 .20741 m
.56581 .19453 L
s
.53926 .80945 m
.54823 .79716 L
s
.58116 .22286 m
.57369 .20741 L
s
.54823 .79716 m
.55701 .78228 L
s
.58812 .24082 m
.58116 .22286 L
s
.55701 .78228 m
.56551 .76486 L
s
.59451 .26119 m
.58812 .24082 L
s
.56551 .76486 m
.57364 .745 L
s
.60025 .28384 m
.59451 .26119 L
s
.57364 .745 m
.58131 .72282 L
s
.60525 .30859 m
.60025 .28384 L
s
.58131 .72282 m
.58844 .69848 L
s
.60947 .33526 m
.60525 .30859 L
s
.58844 .69848 m
.59494 .67218 L
s
.61283 .3636 m
.60947 .33526 L
s
.59494 .67218 m
.60073 .64415 L
s
.61529 .39336 m
.61283 .3636 L
s
.60073 .64415 m
.60575 .61465 L
s
.61681 .42423 m
.61529 .39336 L
s
.60575 .61465 m
.60993 .58397 L
s
.61737 .4559 m
.61681 .42423 L
s
.60993 .58397 m
.61321 .55243 L
s
.61695 .48805 m
.61737 .4559 L
s
.61321 .55243 m
.61556 .52034 L
s
.61556 .52034 m
.61695 .48805 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo002EOol5O026Ool009=oo`9l00Eoo`9l08Aoo`00TGoo0W`02Goo0W`0
PWoo002?Ool2O00=Ool2O020Ool008ioo`03O01oogoo00moo`03O01oogoo07eoo`00SGoo00=l07oo
Ool04Goo00=l07ooOol0O7oo002<Ool00g`0Oomoo`0BOol00g`0Oomoo`1lOol008]oo`03O01oogoo
01Aoo`03O01oogoo07]oo`00RWoo00=l07ooOol05Goo00=l07ooOol0Ngoo002:Ool00g`0Oomoo`0F
Ool00g`0Oomoo`1jOol008Uoo`03O01oogoo01Moo`03O01oogoo07Yoo`00R7oo00=l07ooOol06Goo
00=l07ooOol0NGoo0028Ool00g`0Oomoo`0IOol00g`0Oomoo`1iOol008Moo`03O01oogoo01]oo`03
O01oogoo07Qoo`00QWoo00=l07ooOol077oo00=l07ooOol0N7oo0026Ool00g`0Oomoo`0MOol00g`0
Oomoo`1gOol008Eoo`03O01oogoo01ioo`03O01oogoo07Moo`00QGoo00=l07ooOol07goo00=l07oo
Ool0MWoo0025Ool00g`0Oomoo`0OOol00g`0Oomoo`1fOol008Aoo`03O01oogoo021oo`03O01oogoo
07Ioo`00Q7oo00=l07ooOol08Goo00=l07ooOol0MGoo0023Ool00g`0Oomoo`0ROol00g`0Oomoo`1e
Ool008=oo`03O01oogoo029oo`03O01oogoo07Eoo`00Pgoo00=l07ooOol08goo00=l07ooOol0M7oo
0022Ool00g`0Oomoo`0TOol00g`0Oomoo`1dOol0089oo`03O01oogoo02Eoo`03O01oogoo07=oo`00
PGoo00=l07ooOol09Woo00=l07ooOol0Lgoo0021Ool00g`0Oomoo`0VOol00g`0Oomoo`1cOol0085o
o`03O01oogoo02Moo`03O01oogoo079oo`00P7oo00=l07ooOol0:7oo00=l07ooOol0LWoo0020Ool0
0g`0Oomoo`0XOol00g`0Oomoo`1bOol007moo`03O01oogoo02Uoo`03O01oogoo079oo`00Ogoo00=l
07ooOol0:Woo00=l07ooOol0LGoo001oOol00g`0Oomoo`0ZOol00g`0Oomoo`1aOol007moo`03O01o
ogoo02Yoo`03O01oogoo075oo`00OWoo00=l07ooOol0:goo00=l07ooOol0LGoo001nOol00g`0Oomo
o`0[Ool00g`0Oomoo`1aOol007ioo`03O01oogoo02aoo`03O01oogoo071oo`00OWoo00=l07ooOol0
;7oo00=l07ooOol0L7oo001nOol00g`0Oomoo`0/Ool00g`0Oomoo`1`Ool007eoo`03O01oogoo02eo
o`03O01oogoo071oo`00OGoo00=l07ooOol0;Goo00=l07ooOol0L7oo001mOol00g`0Oomoo`0]Ool0
0g`0Oomoo`1`Ool007aoo`03O01oogoo02ioo`03O01oogoo071oo`00O7oo00=l07ooOol0;Woo00=l
07ooOol0L7oo001lOol00g`0Oomoo`0_Ool00g`0Oomoo`1_Ool007aoo`03O01oogoo02moo`03O01o
ogoo06moo`00Ngoo00=l07ooOol0<7oo00=l07ooOol0Kgoo001kOol00g`0Oomoo`0`Ool00g`0Oomo
o`1_Ool007]oo`03O01oogoo031oo`03O01oogoo06moo`00Ngoo00=l07ooOol0<7oo00=l07ooOol0
Kgoo001kOol00g`0Oomoo`0`Ool00g`0Oomoo`1_Ool007]oo`03O01oogoo031oo`03O01oogoo06mo
o`00NWoo00=l07ooOol0<Woo00=l07ooOol0KWoo001jOol00g`0Oomoo`0bOol00g`0Oomoo`1^Ool0
07Yoo`03O01oogoo039oo`03O01oogoo06ioo`00NWoo00=l07ooOol0<Woo00=l07ooOol0KWoo001j
Ool00g`0Oomoo`0bOol00g`0Oomoo`1^Ool007Yoo`03O01oogoo039oo`03O01oogoo06ioo`00NWoo
00=l07ooOol0<Woo00=l07ooOol0KWoo001iOol00g`0Oomoo`0cOol00g`0Oomoo`1^Ool007Uoo`03
O01oogoo03Aoo`03O01oogoo06eoo`00NGoo00=l07ooOol0=7oo00=l07ooOol0KGoo001iOol00g`0
Oomoo`0dOol00g`0Oomoo`1]Ool007Uoo`03O01oogoo03Aoo`03O01oogoo06eoo`00NGoo00=l07oo
Ool0=7oo00=l07ooOol0KGoo001iOol00g`0Oomoo`0dOol00g`0Oomoo`1]Ool007Qoo`03O01oogoo
03Eoo`03O01oogoo06eoo`00N7oo00=l07ooOol0=Goo00=l07ooOol0KGoo001hOol00g`0Oomoo`0f
Ool00g`0Oomoo`1/Ool007Qoo`03O01oogoo03Ioo`03O01oogoo06aoo`00N7oo00=l07ooOol0=Woo
00=l07ooOol0K7oo001hOol00g`0Oomoo`0fOol00g`0Oomoo`1/Ool007Qoo`03O01oogoo03Ioo`03
O01oogoo06aoo`00Mgoo00=l07ooOol0=goo00=l07ooOol0K7oo001gOol00g`0Oomoo`0gOol00g`0
Oomoo`1/Ool007Moo`03O01oogoo03Moo`03O01oogoo06aoo`00Mgoo00=l07ooOol0=goo00=l07oo
Ool0K7oo001gOol00g`0Oomoo`0gOol00g`0Oomoo`1/Ool007Moo`03O01oogoo03Moo`03O01oogoo
06aoo`00Mgoo00=l07ooOol0=goo00=l07ooOol0K7oo001fOol00g`0Oomoo`0hOol00g`0Oomoo`1/
Ool007Ioo`03O01oogoo03Qoo`03O01oogoo06aoo`00MWoo00=l07ooOol0>7oo00=l07ooOol0K7oo
001fOol00g`0Oomoo`0hOol00g`0Oomoo`1/Ool007Ioo`03O01oogoo03Qoo`03O01oogoo06aoo`00
MWoo00=l07ooOol0>7oo00=l07ooOol0K7oo001fOol00g`0Oomoo`0hOol00g`0Oomoo`1/Ool007Io
o`03O01oogoo03Qoo`03O01oogoo06aoo`00MWoo00=l07ooOol0>7oo00=l07ooOol0K7oo001fOol0
0g`0Oomoo`0hOol00g`0Oomoo`1/Ool007Ioo`03O01oogoo03Qoo`03O01oogoo06aoo`00MWoo00=l
07ooOol0>7oo00=l07ooOol0K7oo001fOol00g`0Oomoo`0hOol00g`0Oomoo`1/Ool007Ioo`03O01o
ogoo03Qoo`03O01oogoo06aoo`00MGoo00=l07ooOol0>Goo00=l07ooOol0K7oo001eOol00g`0Oomo
o`0iOol00g`0Oomoo`1/Ool007Eoo`03O01oogoo03Qoo`03O01oogoo06eoo`00MGoo00=l07ooOol0
>7oo00=l07ooOol0KGoo001eOol00g`0Oomoo`0hOol00g`0Oomoo`1]Ool007Eoo`03O01oogoo03Qo
o`03O01oogoo06eoo`00MGoo00=l07ooOol0>7oo00=l07ooOol0KGoo001eOol00g`0Oomoo`0hOol0
0g`0Oomoo`1]Ool007Eoo`03O01oogoo03Qoo`03O01oogoo06eoo`00MGoo00=l07ooOol0>7oo00=l
07ooOol0KGoo001eOol00g`0Oomoo`0hOol00g`0Oomoo`1]Ool007Eoo`03O01oogoo03Moo`03O01o
ogoo06ioo`00MGoo00=l07ooOol0=goo00=l07ooOol0KWoo001eOol00g`0Oomoo`0gOol00g`0Oomo
o`1^Ool007Eoo`03O01oogoo03Moo`03O01oogoo06ioo`00MGoo00=l07ooOol0=goo00=l07ooOol0
KWoo001eOol00g`0Oomoo`0gOol00g`0Oomoo`1^Ool007Eoo`03O01oogoo03Moo`03O01oogoo06io
o`00MGoo00=l07ooOol0=goo00=l07ooOol0KWoo001eOol00g`0Oomoo`0gOol00g`0Oomoo`1^Ool0
07Eoo`03O01oogoo03Moo`03O01oogoo06ioo`00MGoo00=l07ooOol0=goo00=l07ooOol0KWoo001e
Ool00g`0Oomoo`0gOol00g`0Oomoo`1^Ool007Eoo`03O01oogoo03Moo`03O01oogoo06ioo`00MGoo
00=l07ooOol0=goo00=l07ooOol0KWoo001eOol00g`0Oomoo`0gOol00g`0Oomoo`1^Ool007Eoo`03
O01oogoo03Moo`03O01oogoo06ioo`00MGoo00=l07ooOol0=Woo00=l07ooOol0Kgoo001fOol00g`0
Oomoo`0eOol00g`0Oomoo`1_Ool007Ioo`03O01oogoo03Eoo`03O01oogoo06moo`00MWoo00=l07oo
Ool0=Goo00=l07ooOol0Kgoo001fOol00g`0Oomoo`0dOol00g`0Oomoo`1`Ool007Ioo`03O01oogoo
03Aoo`03O01oogoo071oo`00MWoo00=l07ooOol0=7oo00=l07ooOol0L7oo001fOol00g`0Oomoo`0d
Ool00g`0Oomoo`1`Ool007Ioo`03O01oogoo03Aoo`03O01oogoo071oo`00MWoo00=l07ooOol0=7oo
00=l07ooOol0L7oo001fOol00g`0Oomoo`0cOol00g`0Oomoo`1aOol007Ioo`03O01oogoo03=oo`03
O01oogoo075oo`00MWoo00=l07ooOol0<goo00=l07ooOol0LGoo001fOol00g`0Oomoo`0cOol00g`0
Oomoo`1aOol007Moo`03O01oogoo039oo`03O01oogoo075oo`00Mgoo00=l07ooOol0<Woo00=l07oo
Ool0LGoo001gOol00g`0Oomoo`0aOol00g`0Oomoo`1bOol007Moo`03O01oogoo035oo`03O01oogoo
079oo`00Mgoo00=l07ooOol0<Goo00=l07ooOol0LWoo001gOol00g`0Oomoo`0aOol00g`0Oomoo`1b
Ool007Moo`03O01oogoo031oo`03O01oogoo07=oo`00N7oo00=l07ooOol0;goo00=l07ooOol0Lgoo
001hOol00g`0Oomoo`0_Ool00g`0Oomoo`1cOol007Qoo`03O01oogoo02moo`03O01oogoo07=oo`00
N7oo00=l07ooOol0;Woo00=l07ooOol0M7oo001hOol00g`0Oomoo`0^Ool00g`0Oomoo`1dOol007Qo
o`03O01oogoo02ioo`03O01oogoo07Aoo`00NGoo00=l07ooOol0;Goo00=l07ooOol0M7oo001iOol0
0g`0Oomoo`0/Ool00g`0Oomoo`1eOol007Uoo`03O01oogoo02aoo`03O01oogoo07Eoo`00NGoo00=l
07ooOol0;7oo00=l07ooOol0MGoo001iOol00g`0Oomoo`0/Ool00g`0Oomoo`1eOol007Uoo`03O01o
ogoo02]oo`03O01oogoo07Ioo`00NWoo00=l07ooOol0:Woo00=l07ooOol0MWoo001jOol00g`0Oomo
o`0ZOol00g`0Oomoo`1fOol007Yoo`03O01oogoo02Yoo`03O01oogoo07Ioo`00NWoo00=l07ooOol0
:Goo00=l07ooOol0Mgoo001jOol00g`0Oomoo`0YOol00g`0Oomoo`1gOol007]oo`03O01oogoo02Qo
o`03O01oogoo07Moo`00Ngoo00=l07ooOol09goo00=l07ooOol0N7oo001kOol00g`0Oomoo`0WOol0
0g`0Oomoo`1hOol007]oo`03O01oogoo02Moo`03O01oogoo07Qoo`00O7oo00=l07ooOol09Goo00=l
07ooOol0NGoo001lOol00g`0Oomoo`0UOol00g`0Oomoo`1iOol007eoo`03O01oogoo02Aoo`03O01o
ogoo07Uoo`00OGoo00=l07ooOol08goo00=l07ooOol0NWoo001mOol00g`0Oomoo`0SOol00g`0Oomo
o`1jOol007eoo`03O01oogoo02=oo`03O01oogoo07Yoo`00OWoo00=l07ooOol08Goo00=l07ooOol0
Ngoo001nOol00g`0Oomoo`0QOol00g`0Oomoo`1kOol007ioo`03O01oogoo021oo`03O01oogoo07ao
o`00OWoo00=l07ooOol087oo00=l07ooOol0O7oo001oOol00g`0Oomoo`0NOol00g`0Oomoo`1mOol0
07moo`03O01oogoo01ioo`03O01oogoo07eoo`00P7oo00=l07ooOol077oo00=l07ooOol0OWoo0020
Ool00g`0Oomoo`0KOol00g`0Oomoo`1oOol0085oo`03O01oogoo01Yoo`03O01oogoo07moo`00PGoo
00=l07ooOol06Goo00=l07ooOol0P7oo0022Ool00g`0Oomoo`0HOol00g`0Oomoo`20Ool008=oo`03
O01oogoo01Ioo`03O01oogoo085oo`00Pgoo00=l07ooOol05Goo00=l07ooOol0PWoo0024Ool00g`0
Oomoo`0DOol00g`0Oomoo`22Ool008Eoo`03O01oogoo019oo`03O01oogoo08=oo`00QGoo00=l07oo
Ool04Goo00=l07ooOol0Q7oo0026Ool00g`0Oomoo`0@Ool00g`0Oomoo`24Ool008Moo`9l00moo`03
O01oogoo08Eoo`00RGoo00=l07ooOol02Woo0W`0R7oo002:Ool2O008Ool2O02:Ool008aoo`Ql08ao
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.40349 .51215 m
.40471 .53667 L
s
.40289 .48758 m
.40349 .51215 L
s
.4029 .46306 m
.40289 .48758 L
s
.40471 .53667 m
.40653 .561 L
s
.40353 .4387 m
.4029 .46306 L
s
.40653 .561 m
.40896 .58505 L
s
.40478 .41463 m
.40353 .4387 L
s
.40896 .58505 m
.41199 .6087 L
s
.40665 .39096 m
.40478 .41463 L
s
.41199 .6087 m
.4156 .63182 L
s
.40913 .3678 m
.40665 .39096 L
s
.4156 .63182 m
.41979 .65431 L
s
.41222 .34527 m
.40913 .3678 L
s
.41979 .65431 m
.42455 .67603 L
s
.41591 .3235 m
.41222 .34527 L
s
.42455 .67603 m
.42985 .69687 L
s
.42021 .30262 m
.41591 .3235 L
s
.42985 .69687 m
.4357 .7167 L
s
.42508 .28273 m
.42021 .30262 L
s
.4357 .7167 m
.44205 .73539 L
s
.43054 .26399 m
.42508 .28273 L
s
.44205 .73539 m
.4489 .75282 L
s
.43655 .24651 m
.43054 .26399 L
s
.4489 .75282 m
.45622 .76886 L
s
.44309 .23043 m
.43655 .24651 L
s
.45622 .76886 m
.46397 .78336 L
s
.45016 .21588 m
.44309 .23043 L
s
.46397 .78336 m
.47213 .7962 L
s
.4577 .203 m
.45016 .21588 L
s
.47213 .7962 m
.48065 .80725 L
s
.46571 .19192 m
.4577 .203 L
s
.48065 .80725 m
.48949 .81638 L
s
.47413 .18277 m
.46571 .19192 L
s
.48949 .81638 m
.49861 .82346 L
s
.48292 .17568 m
.47413 .18277 L
s
.49861 .82346 m
.50794 .82838 L
s
.49204 .17076 m
.48292 .17568 L
s
.50794 .82838 m
.51743 .83102 L
s
.50143 .16813 m
.49204 .17076 L
s
.51743 .83102 m
.52702 .83129 L
s
.51103 .16789 m
.50143 .16813 L
s
.52702 .83129 m
.53663 .82909 L
s
.52078 .17012 m
.51103 .16789 L
s
.53663 .82909 m
.54619 .82437 L
s
.53059 .1749 m
.52078 .17012 L
s
.54619 .82437 m
.55562 .81706 L
s
.5404 .18227 m
.53059 .1749 L
s
.55562 .81706 m
.56484 .80714 L
s
.55011 .19227 m
.5404 .18227 L
s
.56484 .80714 m
.57375 .79461 L
s
.55965 .20488 m
.55011 .19227 L
s
.57375 .79461 m
.58226 .7795 L
s
.56891 .22008 m
.55965 .20488 L
s
.58226 .7795 m
.5903 .76187 L
s
.5778 .23781 m
.56891 .22008 L
s
.5903 .76187 m
.59776 .74181 L
s
.58624 .25797 m
.5778 .23781 L
s
.59776 .74181 m
.60455 .71945 L
s
.59411 .28044 m
.58624 .25797 L
s
.60455 .71945 m
.61061 .69496 L
s
.60135 .30503 m
.59411 .28044 L
s
.61061 .69496 m
.61584 .66852 L
s
.60784 .33156 m
.60135 .30503 L
s
.61584 .66852 m
.62018 .64037 L
s
.61353 .35979 m
.60784 .33156 L
s
.62018 .64037 m
.62357 .61078 L
s
.61833 .38945 m
.61353 .35979 L
s
.62357 .61078 m
.62596 .58003 L
s
.62218 .42026 m
.61833 .38945 L
s
.62596 .58003 m
.62732 .54844 L
s
.62503 .45189 m
.62218 .42026 L
s
.62732 .54844 m
.62761 .51632 L
s
.62685 .48403 m
.62503 .45189 L
s
.62761 .51632 m
.62685 .48403 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo002?Ool7O02:Ool008aoo`=l00Moo`9l08Qoo`00RWoo0W`037oo00=l
07ooOol0QGoo0029Ool00g`0Oomoo`0=Ool2O025Ool008Qoo`03O01oogoo011oo`03O01oogoo089o
o`00Qgoo00=l07ooOol04Woo00=l07ooOol0PGoo0026Ool00g`0Oomoo`0COol00g`0Oomoo`21Ool0
08Eoo`03O01oogoo01Eoo`03O01oogoo081oo`00Q7oo00=l07ooOol05goo00=l07ooOol0Ogoo0024
Ool00g`0Oomoo`0HOol00g`0Oomoo`1nOol008=oo`03O01oogoo01Yoo`03O01oogoo07eoo`00PWoo
00=l07ooOol077oo00=l07ooOol0O7oo0022Ool00g`0Oomoo`0LOol00g`0Oomoo`1lOol0085oo`03
O01oogoo01ioo`03O01oogoo07]oo`00PGoo00=l07ooOol07Woo00=l07ooOol0Ngoo0020Ool00g`0
Oomoo`0POol00g`0Oomoo`1jOol0081oo`03O01oogoo021oo`03O01oogoo07Yoo`00Ogoo00=l07oo
Ool08Woo00=l07ooOol0NGoo001oOol00g`0Oomoo`0ROol00g`0Oomoo`1iOol007ioo`03O01oogoo
02Aoo`03O01oogoo07Qoo`00OWoo00=l07ooOol097oo00=l07ooOol0N7oo001mOol00g`0Oomoo`0U
Ool00g`0Oomoo`1hOol007eoo`03O01oogoo02Ioo`03O01oogoo07Moo`00OGoo00=l07ooOol09Woo
00=l07ooOol0Mgoo001lOol00g`0Oomoo`0XOol00g`0Oomoo`1fOol007aoo`03O01oogoo02Qoo`03
O01oogoo07Ioo`00Ngoo00=l07ooOol0:Woo00=l07ooOol0MGoo001kOol00g`0Oomoo`0ZOol00g`0
Oomoo`1eOol007]oo`03O01oogoo02]oo`03O01oogoo07Aoo`00Ngoo00=l07ooOol0:goo00=l07oo
Ool0M7oo001jOol00g`0Oomoo`0/Ool00g`0Oomoo`1dOol007Yoo`03O01oogoo02eoo`03O01oogoo
07=oo`00NWoo00=l07ooOol0;Goo00=l07ooOol0Lgoo001jOol00g`0Oomoo`0]Ool00g`0Oomoo`1c
Ool007Yoo`03O01oogoo02ioo`03O01oogoo079oo`00NGoo00=l07ooOol0;goo00=l07ooOol0LWoo
001iOol00g`0Oomoo`0_Ool00g`0Oomoo`1bOol007Qoo`03O01oogoo031oo`03O01oogoo079oo`00
N7oo00=l07ooOol0<Goo00=l07ooOol0LGoo001hOol00g`0Oomoo`0aOol00g`0Oomoo`1aOol007Qo
o`03O01oogoo035oo`03O01oogoo075oo`00Mgoo00=l07ooOol0<Woo00=l07ooOol0LGoo001gOol0
0g`0Oomoo`0cOol00g`0Oomoo`1`Ool007Moo`03O01oogoo03=oo`03O01oogoo071oo`00Mgoo00=l
07ooOol0<goo00=l07ooOol0L7oo001gOol00g`0Oomoo`0cOol00g`0Oomoo`1`Ool007Moo`03O01o
ogoo03Aoo`03O01oogoo06moo`00Mgoo00=l07ooOol0=7oo00=l07ooOol0Kgoo001fOol00g`0Oomo
o`0eOol00g`0Oomoo`1_Ool007Ioo`03O01oogoo03Eoo`03O01oogoo06moo`00MWoo00=l07ooOol0
=Woo00=l07ooOol0KWoo001fOol00g`0Oomoo`0fOol00g`0Oomoo`1^Ool007Ioo`03O01oogoo03Io
o`03O01oogoo06ioo`00MWoo00=l07ooOol0=Woo00=l07ooOol0KWoo001eOol00g`0Oomoo`0hOol0
0g`0Oomoo`1]Ool007Eoo`03O01oogoo03Qoo`03O01oogoo06eoo`00MGoo00=l07ooOol0>7oo00=l
07ooOol0KGoo001eOol00g`0Oomoo`0hOol00g`0Oomoo`1]Ool007Eoo`03O01oogoo03Qoo`03O01o
ogoo06eoo`00MGoo00=l07ooOol0>7oo00=l07ooOol0KGoo001eOol00g`0Oomoo`0iOol00g`0Oomo
o`1/Ool007Aoo`03O01oogoo03Yoo`03O01oogoo06aoo`00M7oo00=l07ooOol0>Woo00=l07ooOol0
K7oo001dOol00g`0Oomoo`0jOol00g`0Oomoo`1/Ool007Aoo`03O01oogoo03Yoo`03O01oogoo06ao
o`00M7oo00=l07ooOol0>Woo00=l07ooOol0K7oo001dOol00g`0Oomoo`0jOol00g`0Oomoo`1/Ool0
07Aoo`03O01oogoo03Yoo`03O01oogoo06aoo`00M7oo00=l07ooOol0>goo00=l07ooOol0Jgoo001d
Ool00g`0Oomoo`0kOol00g`0Oomoo`1[Ool007Aoo`03O01oogoo03]oo`03O01oogoo06]oo`00M7oo
00=l07ooOol0>goo00=l07ooOol0Jgoo001dOol00g`0Oomoo`0kOol00g`0Oomoo`1[Ool007Aoo`03
O01oogoo03]oo`03O01oogoo06]oo`00Lgoo00=l07ooOol0?7oo00=l07ooOol0Jgoo001cOol00g`0
Oomoo`0lOol00g`0Oomoo`1[Ool007=oo`03O01oogoo03aoo`03O01oogoo06]oo`00Lgoo00=l07oo
Ool0?Goo00=l07ooOol0JWoo001cOol00g`0Oomoo`0mOol00g`0Oomoo`1ZOol007=oo`03O01oogoo
03eoo`03O01oogoo06Yoo`00Lgoo00=l07ooOol0?Goo00=l07ooOol0JWoo001cOol00g`0Oomoo`0m
Ool00g`0Oomoo`1ZOol007=oo`03O01oogoo03eoo`03O01oogoo06Yoo`00Lgoo00=l07ooOol0?Goo
00=l07ooOol0JWoo001cOol00g`0Oomoo`0mOol00g`0Oomoo`1ZOol007=oo`03O01oogoo03eoo`03
O01oogoo06Yoo`00Lgoo00=l07ooOol0?Goo00=l07ooOol0JWoo001cOol00g`0Oomoo`0mOol00g`0
Oomoo`1ZOol007=oo`03O01oogoo03eoo`03O01oogoo06Yoo`00Lgoo00=l07ooOol0?Goo00=l07oo
Ool0JWoo001cOol00g`0Oomoo`0mOol00g`0Oomoo`1ZOol007=oo`03O01oogoo03eoo`03O01oogoo
06Yoo`00Lgoo00=l07ooOol0?Goo00=l07ooOol0JWoo001cOol00g`0Oomoo`0mOol00g`0Oomoo`1Z
Ool007=oo`03O01oogoo03eoo`03O01oogoo06Yoo`00Lgoo00=l07ooOol0?Goo00=l07ooOol0JWoo
001cOol00g`0Oomoo`0nOol00g`0Oomoo`1YOol007=oo`03O01oogoo03ioo`03O01oogoo06Uoo`00
Lgoo00=l07ooOol0?Woo00=l07ooOol0JGoo001cOol00g`0Oomoo`0nOol00g`0Oomoo`1YOol007=o
o`03O01oogoo03ioo`03O01oogoo06Uoo`00Lgoo00=l07ooOol0?Woo00=l07ooOol0JGoo001cOol0
0g`0Oomoo`0nOol00g`0Oomoo`1YOol007Aoo`03O01oogoo03eoo`03O01oogoo06Uoo`00M7oo00=l
07ooOol0?Goo00=l07ooOol0JGoo001dOol00g`0Oomoo`0mOol00g`0Oomoo`1YOol007Aoo`03O01o
ogoo03eoo`03O01oogoo06Uoo`00M7oo00=l07ooOol0?Goo00=l07ooOol0JGoo001dOol00g`0Oomo
o`0mOol00g`0Oomoo`1YOol007Aoo`03O01oogoo03eoo`03O01oogoo06Uoo`00M7oo00=l07ooOol0
?Goo00=l07ooOol0JGoo001dOol00g`0Oomoo`0mOol00g`0Oomoo`1YOol007Aoo`03O01oogoo03eo
o`03O01oogoo06Uoo`00M7oo00=l07ooOol0?Goo00=l07ooOol0JGoo001dOol00g`0Oomoo`0lOol0
0g`0Oomoo`1ZOol007Aoo`03O01oogoo03aoo`03O01oogoo06Yoo`00M7oo00=l07ooOol0?7oo00=l
07ooOol0JWoo001eOol00g`0Oomoo`0kOol00g`0Oomoo`1ZOol007Eoo`03O01oogoo03]oo`03O01o
ogoo06Yoo`00MGoo00=l07ooOol0>goo00=l07ooOol0JWoo001eOol00g`0Oomoo`0kOol00g`0Oomo
o`1ZOol007Eoo`03O01oogoo03]oo`03O01oogoo06Yoo`00MGoo00=l07ooOol0>goo00=l07ooOol0
JWoo001fOol00g`0Oomoo`0iOol00g`0Oomoo`1[Ool007Ioo`03O01oogoo03Uoo`03O01oogoo06]o
o`00MWoo00=l07ooOol0>Goo00=l07ooOol0Jgoo001fOol00g`0Oomoo`0iOol00g`0Oomoo`1[Ool0
07Ioo`03O01oogoo03Uoo`03O01oogoo06]oo`00MWoo00=l07ooOol0>Goo00=l07ooOol0Jgoo001f
Ool00g`0Oomoo`0iOol00g`0Oomoo`1[Ool007Moo`03O01oogoo03Qoo`03O01oogoo06]oo`00Mgoo
00=l07ooOol0=goo00=l07ooOol0K7oo001gOol00g`0Oomoo`0gOol00g`0Oomoo`1/Ool007Moo`03
O01oogoo03Moo`03O01oogoo06aoo`00Mgoo00=l07ooOol0=goo00=l07ooOol0K7oo001gOol00g`0
Oomoo`0gOol00g`0Oomoo`1/Ool007Moo`03O01oogoo03Moo`03O01oogoo06aoo`00N7oo00=l07oo
Ool0=Woo00=l07ooOol0K7oo001hOol00g`0Oomoo`0fOol00g`0Oomoo`1/Ool007Qoo`03O01oogoo
03Eoo`03O01oogoo06eoo`00N7oo00=l07ooOol0=Goo00=l07ooOol0KGoo001hOol00g`0Oomoo`0e
Ool00g`0Oomoo`1]Ool007Qoo`03O01oogoo03Eoo`03O01oogoo06eoo`00NGoo00=l07ooOol0=7oo
00=l07ooOol0KGoo001iOol00g`0Oomoo`0dOol00g`0Oomoo`1]Ool007Uoo`03O01oogoo03Aoo`03
O01oogoo06eoo`00NGoo00=l07ooOol0=7oo00=l07ooOol0KGoo001iOol00g`0Oomoo`0cOol00g`0
Oomoo`1^Ool007Yoo`03O01oogoo039oo`03O01oogoo06ioo`00NWoo00=l07ooOol0<Woo00=l07oo
Ool0KWoo001kOol00g`0Oomoo`0aOol00g`0Oomoo`1^Ool007]oo`03O01oogoo035oo`03O01oogoo
06ioo`00Ngoo00=l07ooOol0<Goo00=l07ooOol0KWoo001lOol00g`0Oomoo`0_Ool00g`0Oomoo`1_
Ool007aoo`03O01oogoo02moo`03O01oogoo06moo`00O7oo00=l07ooOol0;goo00=l07ooOol0Kgoo
001mOol00g`0Oomoo`0^Ool00g`0Oomoo`1_Ool007eoo`03O01oogoo02eoo`03O01oogoo071oo`00
OGoo00=l07ooOol0;Goo00=l07ooOol0L7oo001mOol00g`0Oomoo`0]Ool00g`0Oomoo`1`Ool007eo
o`03O01oogoo02aoo`03O01oogoo075oo`00OWoo00=l07ooOol0:goo00=l07ooOol0LGoo001nOol0
0g`0Oomoo`0[Ool00g`0Oomoo`1aOol007ioo`03O01oogoo02Yoo`03O01oogoo079oo`00OWoo00=l
07ooOol0:Woo00=l07ooOol0LWoo001oOol00g`0Oomoo`0YOol00g`0Oomoo`1bOol007moo`03O01o
ogoo02Qoo`03O01oogoo07=oo`00P7oo00=l07ooOol09goo00=l07ooOol0Lgoo0020Ool00g`0Oomo
o`0WOol00g`0Oomoo`1cOol0081oo`03O01oogoo02Ioo`03O01oogoo07Aoo`00PGoo00=l07ooOol0
9Goo00=l07ooOol0M7oo0021Ool00g`0Oomoo`0UOol00g`0Oomoo`1dOol0089oo`03O01oogoo02=o
o`03O01oogoo07Eoo`00Pgoo00=l07ooOol08Woo00=l07ooOol0MGoo0023Ool00g`0Oomoo`0QOol0
0g`0Oomoo`1fOol008Aoo`03O01oogoo021oo`03O01oogoo07Ioo`00QGoo00=l07ooOol07Woo00=l
07ooOol0Mgoo0025Ool00g`0Oomoo`0NOol00g`0Oomoo`1gOol008Ioo`03O01oogoo01aoo`03O01o
ogoo07Qoo`00QWoo00=l07ooOol077oo00=l07ooOol0N7oo0027Ool00g`0Oomoo`0JOol00g`0Oomo
o`1iOol008Qoo`03O01oogoo01Qoo`03O01oogoo07Yoo`00R7oo00=l07ooOol067oo00=l07ooOol0
NWoo0029Ool00g`0Oomoo`0FOol00g`0Oomoo`1kOol008Yoo`03O01oogoo01Aoo`03O01oogoo07ao
o`00Rgoo00=l07ooOol04Woo00=l07ooOol0OGoo002<Ool00g`0Oomoo`0@Ool00g`0Oomoo`1nOol0
08eoo`9l00ioo`9l085oo`00Sgoo00=l07ooOol02Woo00=l07ooOol0PGoo002@Ool3O006Ool3O024
Ool009=oo`Il08Moo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.39805 .51563 m
.40101 .53995 L
s
.39574 .49121 m
.39805 .51563 L
s
.39408 .46681 m
.39574 .49121 L
s
.40101 .53995 m
.40461 .56408 L
s
.3931 .44255 m
.39408 .46681 L
s
.40461 .56408 m
.40883 .58789 L
s
.39278 .41853 m
.3931 .44255 L
s
.40883 .58789 m
.41365 .61127 L
s
.39316 .39489 m
.39278 .41853 L
s
.41365 .61127 m
.41906 .63411 L
s
.39422 .37172 m
.39316 .39489 L
s
.41906 .63411 m
.42504 .65629 L
s
.39598 .34915 m
.39422 .37172 L
s
.42504 .65629 m
.43157 .67769 L
s
.39843 .32731 m
.39598 .34915 L
s
.43157 .67769 m
.43862 .69819 L
s
.40158 .30631 m
.39843 .32731 L
s
.43862 .69819 m
.44617 .71767 L
s
.40542 .28628 m
.40158 .30631 L
s
.44617 .71767 m
.4542 .736 L
s
.40996 .26736 m
.40542 .28628 L
s
.4542 .736 m
.46266 .75306 L
s
.41518 .24967 m
.40996 .26736 L
s
.46266 .75306 m
.47152 .76872 L
s
.42106 .23336 m
.41518 .24967 L
s
.47152 .76872 m
.48074 .78284 L
s
.4276 .21854 m
.42106 .23336 L
s
.48074 .78284 m
.49028 .79531 L
s
.43478 .20537 m
.4276 .21854 L
s
.49028 .79531 m
.50009 .80598 L
s
.44257 .19397 m
.43478 .20537 L
s
.50009 .80598 m
.51011 .81474 L
s
.45093 .18449 m
.44257 .19397 L
s
.51011 .81474 m
.52028 .82147 L
s
.45984 .17704 m
.45093 .18449 L
s
.52028 .82147 m
.53055 .82604 L
s
.46925 .17175 m
.45984 .17704 L
s
.53055 .82604 m
.54083 .82835 L
s
.4791 .16873 m
.46925 .17175 L
s
.54083 .82835 m
.55106 .8283 L
s
.48934 .1681 m
.4791 .16873 L
s
.55106 .8283 m
.56114 .82581 L
s
.4999 .16994 m
.48934 .1681 L
s
.56114 .82581 m
.57101 .8208 L
s
.51072 .17432 m
.4999 .16994 L
s
.57101 .8208 m
.58057 .81324 L
s
.5217 .1813 m
.51072 .17432 L
s
.58057 .81324 m
.58973 .80309 L
s
.53276 .1909 m
.5217 .1813 L
s
.58973 .80309 m
.59839 .79036 L
s
.54381 .20313 m
.53276 .1909 L
s
.59839 .79036 m
.60647 .77508 L
s
.55474 .21797 m
.54381 .20313 L
s
.60647 .77508 m
.61386 .7573 L
s
.56544 .23535 m
.55474 .21797 L
s
.61386 .7573 m
.62048 .73711 L
s
.57582 .25518 m
.56544 .23535 L
s
.62048 .73711 m
.62625 .71466 L
s
.58576 .27732 m
.57582 .25518 L
s
.62625 .71466 m
.63108 .69009 L
s
.59514 .30163 m
.58576 .27732 L
s
.63108 .69009 m
.63491 .66361 L
s
.60387 .32789 m
.59514 .30163 L
s
.63491 .66361 m
.63767 .63545 L
s
.61184 .35588 m
.60387 .32789 L
s
.63767 .63545 m
.63932 .60586 L
s
.61896 .38532 m
.61184 .35588 L
s
.63932 .60586 m
.63983 .57515 L
s
.62513 .41594 m
.61896 .38532 L
s
.63983 .57515 m
.63918 .54361 L
s
.6303 .44741 m
.62513 .41594 L
s
.63918 .54361 m
.63736 .51159 L
s
.63439 .4794 m
.6303 .44741 L
s
.63736 .51159 m
.63439 .4794 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0028Ool8O02@Ool008Eoo`=l00Qoo`9l08ioo`00Pgoo0W`03Goo00=l
07ooOol0Rgoo0022Ool00g`0Oomoo`0>Ool2O02;Ool0085oo`03O01oogoo015oo`03O01oogoo08Qo
o`00P7oo00=l07ooOol04goo0W`0R7oo0020Ool00g`0Oomoo`0EOol00g`0Oomoo`25Ool007moo`03
O01oogoo01Moo`03O01oogoo08Aoo`00OWoo00=l07ooOol06Goo00=l07ooOol0Pgoo001mOol00g`0
Oomoo`0KOol00g`0Oomoo`22Ool007aoo`03O01oogoo01eoo`03O01oogoo085oo`00Ngoo00=l07oo
Ool07goo00=l07ooOol0P7oo001kOol00g`0Oomoo`0OOol00g`0Oomoo`20Ool007Yoo`03O01oogoo
025oo`03O01oogoo07moo`00NWoo00=l07ooOol08Woo00=l07ooOol0OWoo001iOol00g`0Oomoo`0T
Ool00g`0Oomoo`1mOol007Uoo`03O01oogoo02Aoo`03O01oogoo07eoo`00N7oo00=l07ooOol09Woo
00=l07ooOol0O7oo001hOol00g`0Oomoo`0VOol00g`0Oomoo`1lOol007Qoo`03O01oogoo02Moo`03
O01oogoo07]oo`00N7oo00=l07ooOol09goo00=l07ooOol0Ngoo001gOol00g`0Oomoo`0YOol00g`0
Oomoo`1jOol007Moo`03O01oogoo02Uoo`03O01oogoo07Yoo`00Mgoo00=l07ooOol0:Woo00=l07oo
Ool0NGoo001gOol00g`0Oomoo`0ZOol00g`0Oomoo`1iOol007Ioo`03O01oogoo02aoo`03O01oogoo
07Qoo`00MWoo00=l07ooOol0;7oo00=l07ooOol0N7oo001eOol00g`0Oomoo`0^Ool00g`0Oomoo`1g
Ool007Eoo`03O01oogoo02ioo`03O01oogoo07Moo`00MGoo00=l07ooOol0;goo00=l07ooOol0MWoo
001eOol00g`0Oomoo`0_Ool00g`0Oomoo`1fOol007Aoo`03O01oogoo035oo`03O01oogoo07Eoo`00
M7oo00=l07ooOol0<Goo00=l07ooOol0MGoo001dOol00g`0Oomoo`0bOol00g`0Oomoo`1dOol007Ao
o`03O01oogoo039oo`03O01oogoo07Aoo`00M7oo00=l07ooOol0<Woo00=l07ooOol0M7oo001dOol0
0g`0Oomoo`0bOol00g`0Oomoo`1dOol007=oo`03O01oogoo03Aoo`03O01oogoo07=oo`00Lgoo00=l
07ooOol0=7oo00=l07ooOol0Lgoo001cOol00g`0Oomoo`0dOol00g`0Oomoo`1cOol007=oo`03O01o
ogoo03Eoo`03O01oogoo079oo`00Lgoo00=l07ooOol0=Goo00=l07ooOol0LWoo001bOol00g`0Oomo
o`0fOol00g`0Oomoo`1bOol0079oo`03O01oogoo03Moo`03O01oogoo075oo`00LWoo00=l07ooOol0
=goo00=l07ooOol0LGoo001bOol00g`0Oomoo`0hOol00g`0Oomoo`1`Ool0079oo`03O01oogoo03Qo
o`03O01oogoo071oo`00LWoo00=l07ooOol0>7oo00=l07ooOol0L7oo001bOol00g`0Oomoo`0hOol0
0g`0Oomoo`1`Ool0075oo`03O01oogoo03Yoo`03O01oogoo06moo`00LGoo00=l07ooOol0>Woo00=l
07ooOol0Kgoo001aOol00g`0Oomoo`0jOol00g`0Oomoo`1_Ool0075oo`03O01oogoo03Yoo`03O01o
ogoo06moo`00LGoo00=l07ooOol0>goo00=l07ooOol0KWoo001aOol00g`0Oomoo`0kOol00g`0Oomo
o`1^Ool0075oo`03O01oogoo03]oo`03O01oogoo06ioo`00LGoo00=l07ooOol0>goo00=l07ooOol0
KWoo001aOol00g`0Oomoo`0lOol00g`0Oomoo`1]Ool0075oo`03O01oogoo03aoo`03O01oogoo06eo
o`00LGoo00=l07ooOol0?7oo00=l07ooOol0KGoo001aOol00g`0Oomoo`0lOol00g`0Oomoo`1]Ool0
075oo`03O01oogoo03eoo`03O01oogoo06aoo`00L7oo00=l07ooOol0?Woo00=l07ooOol0K7oo001`
Ool00g`0Oomoo`0nOol00g`0Oomoo`1/Ool0071oo`03O01oogoo03ioo`03O01oogoo06aoo`00L7oo
00=l07ooOol0?goo00=l07ooOol0Jgoo001`Ool00g`0Oomoo`0oOol00g`0Oomoo`1[Ool0071oo`03
O01oogoo03moo`03O01oogoo06]oo`00L7oo00=l07ooOol0?goo00=l07ooOol0Jgoo001`Ool00g`0
Oomoo`10Ool00g`0Oomoo`1ZOol0071oo`03O01oogoo041oo`03O01oogoo06Yoo`00L7oo00=l07oo
Ool0@7oo00=l07ooOol0JWoo001`Ool00g`0Oomoo`10Ool00g`0Oomoo`1ZOol0071oo`03O01oogoo
041oo`03O01oogoo06Yoo`00L7oo00=l07ooOol0@7oo00=l07ooOol0JWoo001`Ool00g`0Oomoo`10
Ool00g`0Oomoo`1ZOol0071oo`03O01oogoo045oo`03O01oogoo06Uoo`00L7oo00=l07ooOol0@Goo
00=l07ooOol0JGoo001`Ool00g`0Oomoo`11Ool00g`0Oomoo`1YOol0071oo`03O01oogoo045oo`03
O01oogoo06Uoo`00L7oo00=l07ooOol0@Goo00=l07ooOol0JGoo001`Ool00g`0Oomoo`11Ool00g`0
Oomoo`1YOol0071oo`03O01oogoo045oo`03O01oogoo06Uoo`00LGoo00=l07ooOol0@Goo00=l07oo
Ool0J7oo001aOol00g`0Oomoo`11Ool00g`0Oomoo`1XOol0075oo`03O01oogoo045oo`03O01oogoo
06Qoo`00LGoo00=l07ooOol0@Goo00=l07ooOol0J7oo001aOol00g`0Oomoo`12Ool00g`0Oomoo`1W
Ool0075oo`03O01oogoo049oo`03O01oogoo06Moo`00LGoo00=l07ooOol0@Woo00=l07ooOol0Igoo
001aOol00g`0Oomoo`12Ool00g`0Oomoo`1WOol0075oo`03O01oogoo049oo`03O01oogoo06Moo`00
LGoo00=l07ooOol0@Woo00=l07ooOol0Igoo001aOol00g`0Oomoo`12Ool00g`0Oomoo`1WOol0075o
o`03O01oogoo049oo`03O01oogoo06Moo`00LGoo00=l07ooOol0@Woo00=l07ooOol0Igoo001bOol0
0g`0Oomoo`11Ool00g`0Oomoo`1WOol0079oo`03O01oogoo045oo`03O01oogoo06Moo`00LWoo00=l
07ooOol0@Goo00=l07ooOol0Igoo001bOol00g`0Oomoo`11Ool00g`0Oomoo`1WOol0079oo`03O01o
ogoo045oo`03O01oogoo06Moo`00LWoo00=l07ooOol0@Goo00=l07ooOol0Igoo001bOol00g`0Oomo
o`11Ool00g`0Oomoo`1WOol007=oo`03O01oogoo041oo`03O01oogoo06Moo`00Lgoo00=l07ooOol0
@Goo00=l07ooOol0IWoo001cOol00g`0Oomoo`11Ool00g`0Oomoo`1VOol007=oo`03O01oogoo045o
o`03O01oogoo06Ioo`00Lgoo00=l07ooOol0@Goo00=l07ooOol0IWoo001cOol00g`0Oomoo`11Ool0
0g`0Oomoo`1VOol007=oo`03O01oogoo045oo`03O01oogoo06Ioo`00M7oo00=l07ooOol0@7oo00=l
07ooOol0IWoo001dOol00g`0Oomoo`10Ool00g`0Oomoo`1VOol007Aoo`03O01oogoo041oo`03O01o
ogoo06Ioo`00M7oo00=l07ooOol0@7oo00=l07ooOol0IWoo001dOol00g`0Oomoo`10Ool00g`0Oomo
o`1VOol007Aoo`03O01oogoo041oo`03O01oogoo06Ioo`00M7oo00=l07ooOol0@7oo00=l07ooOol0
IWoo001eOol00g`0Oomoo`0oOol00g`0Oomoo`1VOol007Eoo`03O01oogoo03moo`03O01oogoo06Io
o`00MGoo00=l07ooOol0?goo00=l07ooOol0IWoo001eOol00g`0Oomoo`0oOol00g`0Oomoo`1VOol0
07Eoo`03O01oogoo03moo`03O01oogoo06Ioo`00MGoo00=l07ooOol0?goo00=l07ooOol0IWoo001e
Ool00g`0Oomoo`0oOol00g`0Oomoo`1VOol007Ioo`03O01oogoo03ioo`03O01oogoo06Ioo`00MWoo
00=l07ooOol0?Woo00=l07ooOol0IWoo001fOol00g`0Oomoo`0nOol00g`0Oomoo`1VOol007Ioo`03
O01oogoo03ioo`03O01oogoo06Ioo`00MWoo00=l07ooOol0?Woo00=l07ooOol0IWoo001gOol00g`0
Oomoo`0mOol00g`0Oomoo`1VOol007Moo`03O01oogoo03eoo`03O01oogoo06Ioo`00Mgoo00=l07oo
Ool0?Goo00=l07ooOol0IWoo001hOol00g`0Oomoo`0lOol00g`0Oomoo`1VOol007Qoo`03O01oogoo
03aoo`03O01oogoo06Ioo`00N7oo00=l07ooOol0?7oo00=l07ooOol0IWoo001hOol00g`0Oomoo`0l
Ool00g`0Oomoo`1VOol007Qoo`03O01oogoo03aoo`03O01oogoo06Ioo`00NGoo00=l07ooOol0>goo
00=l07ooOol0IWoo001iOol00g`0Oomoo`0jOol00g`0Oomoo`1WOol007Uoo`03O01oogoo03Yoo`03
O01oogoo06Moo`00NGoo00=l07ooOol0>Woo00=l07ooOol0Igoo001iOol00g`0Oomoo`0jOol00g`0
Oomoo`1WOol007Yoo`03O01oogoo03Uoo`03O01oogoo06Moo`00NWoo00=l07ooOol0>Goo00=l07oo
Ool0Igoo001jOol00g`0Oomoo`0iOol00g`0Oomoo`1WOol007]oo`03O01oogoo03Qoo`03O01oogoo
06Moo`00Ngoo00=l07ooOol0=goo00=l07ooOol0J7oo001kOol00g`0Oomoo`0gOol00g`0Oomoo`1X
Ool007aoo`03O01oogoo03Ioo`03O01oogoo06Qoo`00O7oo00=l07ooOol0=Woo00=l07ooOol0J7oo
001lOol00g`0Oomoo`0fOol00g`0Oomoo`1XOol007eoo`03O01oogoo03Eoo`03O01oogoo06Qoo`00
OGoo00=l07ooOol0=7oo00=l07ooOol0JGoo001nOol00g`0Oomoo`0cOol00g`0Oomoo`1YOol007io
o`03O01oogoo03=oo`03O01oogoo06Uoo`00Ogoo00=l07ooOol0<Woo00=l07ooOol0JGoo001oOol0
0g`0Oomoo`0aOol00g`0Oomoo`1ZOol0081oo`03O01oogoo031oo`03O01oogoo06Yoo`00P7oo00=l
07ooOol0<7oo00=l07ooOol0JWoo0021Ool00g`0Oomoo`0_Ool00g`0Oomoo`1ZOol0085oo`03O01o
ogoo02ioo`03O01oogoo06]oo`00PGoo00=l07ooOol0;Woo00=l07ooOol0Jgoo0022Ool00g`0Oomo
o`0]Ool00g`0Oomoo`1[Ool0089oo`03O01oogoo02eoo`03O01oogoo06]oo`00PWoo00=l07ooOol0
;Goo00=l07ooOol0Jgoo0023Ool00g`0Oomoo`0[Ool00g`0Oomoo`1/Ool008=oo`03O01oogoo02]o
o`03O01oogoo06aoo`00Q7oo00=l07ooOol0:Woo00=l07ooOol0K7oo0024Ool00g`0Oomoo`0YOol0
0g`0Oomoo`1]Ool008Eoo`03O01oogoo02Qoo`03O01oogoo06eoo`00QGoo00=l07ooOol0:7oo00=l
07ooOol0KGoo0026Ool00g`0Oomoo`0VOol00g`0Oomoo`1^Ool008Moo`03O01oogoo02Eoo`03O01o
ogoo06ioo`00Qgoo00=l07ooOol097oo00=l07ooOol0Kgoo0028Ool00g`0Oomoo`0SOol00g`0Oomo
o`1_Ool008Qoo`03O01oogoo029oo`03O01oogoo071oo`00RGoo00=l07ooOol087oo00=l07ooOol0
LGoo002:Ool00g`0Oomoo`0OOol00g`0Oomoo`1aOol008Yoo`03O01oogoo01ioo`03O01oogoo079o
o`00Rgoo00=l07ooOol077oo00=l07ooOol0Lgoo002<Ool00g`0Oomoo`0KOol00g`0Oomoo`1cOol0
08eoo`03O01oogoo01Uoo`03O01oogoo07Aoo`00SWoo00=l07ooOol067oo00=l07ooOol0M7oo002?
Ool00g`0Oomoo`0FOol00g`0Oomoo`1eOol0091oo`9l01Eoo`03O01oogoo07Ioo`00TWoo00=l07oo
Ool04Goo00=l07ooOol0Mgoo002COol2O00?Ool2O01jOol009Eoo`03O01oogoo00]oo`03O01oogoo
07Yoo`00UWoo0W`02Woo00=l07ooOol0Ngoo002HOol:O01nOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.39471 .51924 m
.39942 .54322 L
s
.39068 .49514 m
.39471 .51924 L
s
.38732 .47103 m
.39068 .49514 L
s
.39942 .54322 m
.40477 .56697 L
s
.38467 .44702 m
.38732 .47103 L
s
.40477 .56697 m
.41074 .59037 L
s
.38274 .42321 m
.38467 .44702 L
s
.41074 .59037 m
.41732 .61333 L
s
.38155 .39974 m
.38274 .42321 L
s
.41732 .61333 m
.42446 .63572 L
s
.38111 .3767 m
.38155 .39974 L
s
.42446 .63572 m
.43216 .65744 L
s
.38143 .35422 m
.38111 .3767 L
s
.43216 .65744 m
.44037 .67836 L
s
.38252 .33242 m
.38143 .35422 L
s
.44037 .67836 m
.44907 .69837 L
s
.3844 .31142 m
.38252 .33242 L
s
.44907 .69837 m
.45822 .71736 L
s
.38707 .29135 m
.3844 .31142 L
s
.45822 .71736 m
.46778 .7352 L
s
.39053 .27233 m
.38707 .29135 L
s
.46778 .7352 m
.47772 .75176 L
s
.39479 .25451 m
.39053 .27233 L
s
.47772 .75176 m
.48798 .76693 L
s
.39984 .23802 m
.39479 .25451 L
s
.48798 .76693 m
.49851 .78058 L
s
.40568 .22299 m
.39984 .23802 L
s
.49851 .78058 m
.50927 .79258 L
s
.4123 .20955 m
.40568 .22299 L
s
.50927 .79258 m
.52019 .80281 L
s
.41968 .19786 m
.4123 .20955 L
s
.52019 .80281 m
.53121 .81115 L
s
.42779 .18804 m
.41968 .19786 L
s
.53121 .81115 m
.54226 .81747 L
s
.43661 .18022 m
.42779 .18804 L
s
.54226 .81747 m
.55327 .82166 L
s
.4461 .17453 m
.43661 .18022 L
s
.55327 .82166 m
.56415 .82363 L
s
.45622 .1711 m
.4461 .17453 L
s
.56415 .82363 m
.57482 .82327 L
s
.4669 .17002 m
.45622 .1711 L
s
.57482 .82327 m
.5852 .82049 L
s
.47809 .1714 m
.4669 .17002 L
s
.5852 .82049 m
.59519 .81525 L
s
.48971 .1753 m
.47809 .1714 L
s
.59519 .81525 m
.60469 .80748 L
s
.50169 .18179 m
.48971 .1753 L
s
.60469 .80748 m
.61361 .79717 L
s
.51392 .19091 m
.50169 .18179 L
s
.61361 .79717 m
.62185 .78431 L
s
.52632 .20266 m
.51392 .19091 L
s
.62185 .78431 m
.62931 .76893 L
s
.53877 .21701 m
.52632 .20266 L
s
.62931 .76893 m
.63591 .7511 L
s
.55115 .23391 m
.53877 .21701 L
s
.63591 .7511 m
.64154 .7309 L
s
.56334 .25327 m
.55115 .23391 L
s
.64154 .7309 m
.64614 .70846 L
s
.57523 .27497 m
.56334 .25327 L
s
.64614 .70846 m
.64962 .68395 L
s
.58668 .29885 m
.57523 .27497 L
s
.64962 .68395 m
.65192 .65756 L
s
.59756 .3247 m
.58668 .29885 L
s
.65192 .65756 m
.653 .62951 L
s
.60776 .3523 m
.59756 .3247 L
s
.653 .62951 m
.65283 .60008 L
s
.61715 .38138 m
.60776 .3523 L
s
.65283 .60008 m
.65138 .56955 L
s
.62563 .41165 m
.61715 .38138 L
s
.65138 .56955 m
.64865 .53822 L
s
.6331 .44281 m
.62563 .41165 L
s
.64865 .53822 m
.64467 .50643 L
s
.63947 .47451 m
.6331 .44281 L
s
.64467 .50643 m
.63947 .47451 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0025Ool3O02HOol0089oo`=l00=oo`=l09Eoo`00Ogoo0g`02Goo0W`0
Tgoo001mOol2O00>Ool2O02AOol007]oo`9l019oo`03O01oogoo08ioo`00NWoo00=l07ooOol04goo
0W`0SWoo001iOol00g`0Oomoo`0FOol2O02<Ool007Uoo`03O01oogoo01Qoo`03O01oogoo08Uoo`00
N7oo00=l07ooOol06Woo00=l07ooOol0R7oo001gOol00g`0Oomoo`0LOol00g`0Oomoo`27Ool007Mo
o`03O01oogoo01eoo`03O01oogoo08Ioo`00MWoo00=l07ooOol07goo00=l07ooOol0QGoo001fOol0
0g`0Oomoo`0OOol00g`0Oomoo`25Ool007Eoo`03O01oogoo025oo`03O01oogoo08Aoo`00MGoo00=l
07ooOol08Woo00=l07ooOol0Pgoo001dOol00g`0Oomoo`0TOol00g`0Oomoo`22Ool007Aoo`03O01o
ogoo02Eoo`03O01oogoo085oo`00Lgoo00=l07ooOol09Woo00=l07ooOol0PGoo001cOol00g`0Oomo
o`0WOol00g`0Oomoo`20Ool0079oo`03O01oogoo02Uoo`03O01oogoo07moo`00LWoo00=l07ooOol0
:Woo00=l07ooOol0OWoo001bOol00g`0Oomoo`0ZOol00g`0Oomoo`1nOol0079oo`03O01oogoo02]o
o`03O01oogoo07eoo`00LGoo00=l07ooOol0;7oo00=l07ooOol0OGoo001aOol00g`0Oomoo`0]Ool0
0g`0Oomoo`1lOol0075oo`03O01oogoo02ioo`03O01oogoo07]oo`00LGoo00=l07ooOol0;Woo00=l
07ooOol0Ngoo001aOol00g`0Oomoo`0_Ool00g`0Oomoo`1jOol0071oo`03O01oogoo035oo`03O01o
ogoo07Uoo`00L7oo00=l07ooOol0<Goo00=l07ooOol0NGoo001`Ool00g`0Oomoo`0bOol00g`0Oomo
o`1hOol0071oo`03O01oogoo039oo`03O01oogoo07Qoo`00L7oo00=l07ooOol0<goo00=l07ooOol0
Mgoo001_Ool00g`0Oomoo`0dOol00g`0Oomoo`1gOol006moo`03O01oogoo03Eoo`03O01oogoo07Io
o`00Kgoo00=l07ooOol0=Goo00=l07ooOol0MWoo001_Ool00g`0Oomoo`0fOol00g`0Oomoo`1eOol0
06moo`03O01oogoo03Ioo`03O01oogoo07Eoo`00KWoo00=l07ooOol0=goo00=l07ooOol0MGoo001^
Ool00g`0Oomoo`0hOol00g`0Oomoo`1dOol006ioo`03O01oogoo03Qoo`03O01oogoo07Aoo`00KWoo
00=l07ooOol0>7oo00=l07ooOol0M7oo001^Ool00g`0Oomoo`0iOol00g`0Oomoo`1cOol006ioo`03
O01oogoo03Uoo`03O01oogoo07=oo`00KGoo00=l07ooOol0>goo00=l07ooOol0LWoo001]Ool00g`0
Oomoo`0kOol00g`0Oomoo`1bOol006eoo`03O01oogoo03]oo`03O01oogoo079oo`00KGoo00=l07oo
Ool0?7oo00=l07ooOol0LGoo001]Ool00g`0Oomoo`0lOol00g`0Oomoo`1aOol006eoo`03O01oogoo
03aoo`03O01oogoo075oo`00KGoo00=l07ooOol0?Goo00=l07ooOol0L7oo001]Ool00g`0Oomoo`0m
Ool00g`0Oomoo`1`Ool006eoo`03O01oogoo03ioo`03O01oogoo06moo`00KGoo00=l07ooOol0?Woo
00=l07ooOol0Kgoo001]Ool00g`0Oomoo`0nOol00g`0Oomoo`1_Ool006eoo`03O01oogoo03moo`03
O01oogoo06ioo`00KGoo00=l07ooOol0?goo00=l07ooOol0KWoo001]Ool00g`0Oomoo`0oOol00g`0
Oomoo`1^Ool006eoo`03O01oogoo041oo`03O01oogoo06eoo`00KGoo00=l07ooOol0@7oo00=l07oo
Ool0KGoo001]Ool00g`0Oomoo`11Ool00g`0Oomoo`1/Ool006eoo`03O01oogoo045oo`03O01oogoo
06aoo`00KGoo00=l07ooOol0@Goo00=l07ooOol0K7oo001]Ool00g`0Oomoo`11Ool00g`0Oomoo`1/
Ool006eoo`03O01oogoo049oo`03O01oogoo06]oo`00KGoo00=l07ooOol0@Woo00=l07ooOol0Jgoo
001]Ool00g`0Oomoo`12Ool00g`0Oomoo`1[Ool006eoo`03O01oogoo049oo`03O01oogoo06]oo`00
KGoo00=l07ooOol0@goo00=l07ooOol0JWoo001]Ool00g`0Oomoo`13Ool00g`0Oomoo`1ZOol006eo
o`03O01oogoo04=oo`03O01oogoo06Yoo`00KGoo00=l07ooOol0@goo00=l07ooOol0JWoo001]Ool0
0g`0Oomoo`13Ool00g`0Oomoo`1ZOol006eoo`03O01oogoo04Aoo`03O01oogoo06Uoo`00KGoo00=l
07ooOol0A7oo00=l07ooOol0JGoo001]Ool00g`0Oomoo`14Ool00g`0Oomoo`1YOol006eoo`03O01o
ogoo04Aoo`03O01oogoo06Uoo`00KWoo00=l07ooOol0A7oo00=l07ooOol0J7oo001^Ool00g`0Oomo
o`14Ool00g`0Oomoo`1XOol006ioo`03O01oogoo04Aoo`03O01oogoo06Qoo`00KWoo00=l07ooOol0
A7oo00=l07ooOol0J7oo001^Ool00g`0Oomoo`14Ool00g`0Oomoo`1XOol006ioo`03O01oogoo04Eo
o`03O01oogoo06Moo`00KWoo00=l07ooOol0AGoo00=l07ooOol0Igoo001_Ool00g`0Oomoo`14Ool0
0g`0Oomoo`1WOol006moo`03O01oogoo04Aoo`03O01oogoo06Moo`00Kgoo00=l07ooOol0AGoo00=l
07ooOol0IWoo001_Ool00g`0Oomoo`15Ool00g`0Oomoo`1VOol006moo`03O01oogoo04Eoo`03O01o
ogoo06Ioo`00Kgoo00=l07ooOol0AGoo00=l07ooOol0IWoo001_Ool00g`0Oomoo`15Ool00g`0Oomo
o`1VOol0071oo`03O01oogoo04Eoo`03O01oogoo06Eoo`00L7oo00=l07ooOol0AGoo00=l07ooOol0
IGoo001`Ool00g`0Oomoo`15Ool00g`0Oomoo`1UOol0071oo`03O01oogoo04Eoo`03O01oogoo06Eo
o`00L7oo00=l07ooOol0AWoo00=l07ooOol0I7oo001`Ool00g`0Oomoo`16Ool00g`0Oomoo`1TOol0
071oo`03O01oogoo04Ioo`03O01oogoo06Aoo`00LGoo00=l07ooOol0AGoo00=l07ooOol0I7oo001a
Ool00g`0Oomoo`15Ool00g`0Oomoo`1TOol0075oo`03O01oogoo04Eoo`03O01oogoo06Aoo`00LGoo
00=l07ooOol0AGoo00=l07ooOol0I7oo001aOol00g`0Oomoo`16Ool00g`0Oomoo`1SOol0075oo`03
O01oogoo04Ioo`03O01oogoo06=oo`00LGoo00=l07ooOol0AWoo00=l07ooOol0Hgoo001bOol00g`0
Oomoo`15Ool00g`0Oomoo`1SOol0079oo`03O01oogoo04Eoo`03O01oogoo06=oo`00LWoo00=l07oo
Ool0AGoo00=l07ooOol0Hgoo001bOol00g`0Oomoo`15Ool00g`0Oomoo`1SOol007=oo`03O01oogoo
04Aoo`03O01oogoo06=oo`00Lgoo00=l07ooOol0A7oo00=l07ooOol0Hgoo001cOol00g`0Oomoo`14
Ool00g`0Oomoo`1SOol007=oo`03O01oogoo04Aoo`03O01oogoo06=oo`00M7oo00=l07ooOol0@goo
00=l07ooOol0Hgoo001dOol00g`0Oomoo`13Ool00g`0Oomoo`1SOol007Aoo`03O01oogoo04=oo`03
O01oogoo06=oo`00M7oo00=l07ooOol0@goo00=l07ooOol0Hgoo001dOol00g`0Oomoo`13Ool00g`0
Oomoo`1SOol007Eoo`03O01oogoo049oo`03O01oogoo06=oo`00MGoo00=l07ooOol0@Woo00=l07oo
Ool0Hgoo001eOol00g`0Oomoo`13Ool00g`0Oomoo`1ROol007Eoo`03O01oogoo04=oo`03O01oogoo
069oo`00MGoo00=l07ooOol0@goo00=l07ooOol0HWoo001fOol00g`0Oomoo`12Ool00g`0Oomoo`1R
Ool007Ioo`03O01oogoo049oo`03O01oogoo069oo`00MWoo00=l07ooOol0@Woo00=l07ooOol0HWoo
001fOol00g`0Oomoo`12Ool00g`0Oomoo`1ROol007Moo`03O01oogoo045oo`03O01oogoo069oo`00
Mgoo00=l07ooOol0@Goo00=l07ooOol0HWoo001gOol00g`0Oomoo`11Ool00g`0Oomoo`1ROol007Qo
o`03O01oogoo041oo`03O01oogoo069oo`00N7oo00=l07ooOol0@7oo00=l07ooOol0HWoo001hOol0
0g`0Oomoo`10Ool00g`0Oomoo`1ROol007Uoo`03O01oogoo03moo`03O01oogoo069oo`00NGoo00=l
07ooOol0?goo00=l07ooOol0HWoo001iOol00g`0Oomoo`0oOol00g`0Oomoo`1ROol007Yoo`03O01o
ogoo03ioo`03O01oogoo069oo`00NWoo00=l07ooOol0?Woo00=l07ooOol0HWoo001kOol00g`0Oomo
o`0mOol00g`0Oomoo`1ROol007]oo`03O01oogoo03eoo`03O01oogoo069oo`00O7oo00=l07ooOol0
?7oo00=l07ooOol0HWoo001lOol00g`0Oomoo`0lOol00g`0Oomoo`1ROol007eoo`03O01oogoo03]o
o`03O01oogoo069oo`00OGoo00=l07ooOol0>goo00=l07ooOol0HWoo001mOol00g`0Oomoo`0jOol0
0g`0Oomoo`1SOol007ioo`03O01oogoo03Uoo`03O01oogoo06=oo`00OWoo00=l07ooOol0>Goo00=l
07ooOol0Hgoo001nOol00g`0Oomoo`0iOol00g`0Oomoo`1SOol007moo`03O01oogoo03Qoo`03O01o
ogoo06=oo`00Ogoo00=l07ooOol0>7oo00=l07ooOol0Hgoo001oOol00g`0Oomoo`0hOol00g`0Oomo
o`1SOol0081oo`03O01oogoo03Moo`03O01oogoo06=oo`00P7oo00=l07ooOol0=Woo00=l07ooOol0
I7oo0021Ool00g`0Oomoo`0eOol00g`0Oomoo`1TOol0085oo`03O01oogoo03Eoo`03O01oogoo06Ao
o`00PWoo00=l07ooOol0=7oo00=l07ooOol0I7oo0022Ool00g`0Oomoo`0dOol00g`0Oomoo`1TOol0
08=oo`03O01oogoo03=oo`03O01oogoo06Aoo`00Q7oo00=l07ooOol0<Goo00=l07ooOol0IGoo0024
Ool00g`0Oomoo`0aOol00g`0Oomoo`1UOol008Eoo`03O01oogoo031oo`03O01oogoo06Eoo`00QGoo
00=l07ooOol0<7oo00=l07ooOol0IGoo0026Ool00g`0Oomoo`0_Ool00g`0Oomoo`1UOol008Moo`03
O01oogoo02eoo`03O01oogoo06Ioo`00Qgoo00=l07ooOol0;Goo00=l07ooOol0IWoo0028Ool00g`0
Oomoo`0/Ool00g`0Oomoo`1VOol008Qoo`03O01oogoo02]oo`03O01oogoo06Moo`00RGoo00=l07oo
Ool0:Woo00=l07ooOol0Igoo002:Ool00g`0Oomoo`0YOol00g`0Oomoo`1WOol008Yoo`03O01oogoo
02Qoo`03O01oogoo06Qoo`00Rgoo00=l07ooOol09goo00=l07ooOol0J7oo002;Ool00g`0Oomoo`0V
Ool00g`0Oomoo`1YOol008aoo`03O01oogoo02Eoo`03O01oogoo06Uoo`00SGoo00=l07ooOol097oo
00=l07ooOol0JGoo002=Ool00g`0Oomoo`0SOol00g`0Oomoo`1ZOol008ioo`03O01oogoo029oo`03
O01oogoo06Yoo`00Sgoo00=l07ooOol087oo00=l07ooOol0Jgoo002@Ool00g`0Oomoo`0OOol00g`0
Oomoo`1[Ool0095oo`03O01oogoo01eoo`03O01oogoo06aoo`00TWoo00=l07ooOol077oo00=l07oo
Ool0K7oo002COol00g`0Oomoo`0JOol00g`0Oomoo`1]Ool009Aoo`03O01oogoo01Qoo`03O01oogoo
06ioo`00UGoo00=l07ooOol05Woo00=l07ooOol0Kgoo002FOol2O00EOol00g`0Oomoo`1`Ool009Qo
o`03O01oogoo011oo`9l07=oo`00VGoo0W`03goo00=l07ooOol0Lgoo002KOol2O00;Ool2O01fOol0
09eoo`=l00Ioo`9l07Qoo`00X7oo1W`0NWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.3934 .52273 m
.39982 .54621 L
s
.38764 .4991 m
.3934 .52273 L
s
.39982 .54621 m
.40688 .56943 L
s
.38259 .47543 m
.38764 .4991 L
s
.40688 .56943 m
.41455 .59228 L
s
.37826 .45181 m
.38259 .47543 L
s
.41455 .59228 m
.42281 .61466 L
s
.37467 .42837 m
.37826 .45181 L
s
.42281 .61466 m
.43161 .63646 L
s
.37186 .40521 m
.37467 .42837 L
s
.43161 .63646 m
.44093 .65758 L
s
.36985 .38244 m
.37186 .40521 L
s
.44093 .65758 m
.45072 .6779 L
s
.36865 .36017 m
.36985 .38244 L
s
.45072 .6779 m
.46094 .6973 L
s
.36829 .33854 m
.36865 .36017 L
s
.46094 .6973 m
.47156 .71569 L
s
.36879 .31765 m
.36829 .33854 L
s
.47156 .71569 m
.48252 .73293 L
s
.37016 .29765 m
.36879 .31765 L
s
.48252 .73293 m
.49379 .74891 L
s
.37242 .27864 m
.37016 .29765 L
s
.49379 .74891 m
.50529 .76351 L
s
.37557 .26077 m
.37242 .27864 L
s
.50529 .76351 m
.51698 .77662 L
s
.37963 .24417 m
.37557 .26077 L
s
.51698 .77662 m
.52879 .7881 L
s
.3846 .22898 m
.37963 .24417 L
s
.52879 .7881 m
.54065 .79784 L
s
.39049 .21534 m
.3846 .22898 L
s
.54065 .79784 m
.5525 .80572 L
s
.39727 .20339 m
.39049 .21534 L
s
.5525 .80572 m
.56425 .81162 L
s
.40494 .19325 m
.39727 .20339 L
s
.56425 .81162 m
.57582 .81544 L
s
.41347 .18508 m
.40494 .19325 L
s
.57582 .81544 m
.58712 .81708 L
s
.42285 .179 m
.41347 .18508 L
s
.58712 .81708 m
.59806 .81643 L
s
.43302 .17512 m
.42285 .179 L
s
.59806 .81643 m
.60855 .81342 L
s
.44395 .17357 m
.43302 .17512 L
s
.60855 .81342 m
.61849 .80798 L
s
.45557 .17445 m
.44395 .17357 L
s
.61849 .80798 m
.62777 .80008 L
s
.46781 .17783 m
.45557 .17445 L
s
.62777 .80008 m
.63629 .78967 L
s
.48059 .18378 m
.46781 .17783 L
s
.63629 .78967 m
.64396 .77678 L
s
.49383 .19233 m
.48059 .18378 L
s
.64396 .77678 m
.65067 .76141 L
s
.5074 .20351 m
.49383 .19233 L
s
.65067 .76141 m
.65633 .74363 L
s
.52121 .21729 m
.5074 .20351 L
s
.65633 .74363 m
.66085 .72353 L
s
.53512 .23362 m
.52121 .21729 L
s
.66085 .72353 m
.66416 .70124 L
s
.54901 .25241 m
.53512 .23362 L
s
.66416 .70124 m
.66618 .67691 L
s
.56273 .27356 m
.54901 .25241 L
s
.66618 .67691 m
.66688 .65074 L
s
.57614 .29689 m
.56273 .27356 L
s
.66688 .65074 m
.6662 .62295 L
s
.5891 .32221 m
.57614 .29689 L
s
.6662 .62295 m
.66413 .59381 L
s
.60146 .3493 m
.5891 .32221 L
s
.66413 .59381 m
.66067 .56359 L
s
.61307 .37789 m
.60146 .3493 L
s
.66067 .56359 m
.65583 .53261 L
s
.62382 .40769 m
.61307 .37789 L
s
.65583 .53261 m
.64966 .50119 L
s
.63357 .43839 m
.62382 .40769 L
s
.64966 .50119 m
.64221 .46967 L
s
.64221 .46967 m
.63357 .43839 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol007ioo`=l09moo`00Ngoo0g`00goo0g`0W7oo001iOol2
O009Ool4O02HOol007Moo`9l00moo`9l09Ioo`00MWoo00=l07ooOol04Goo00=l07ooOol0Tgoo001e
Ool00g`0Oomoo`0COol2O02COol007Aoo`03O01oogoo01Ioo`03O01oogoo091oo`00Lgoo00=l07oo
Ool067oo00=l07ooOol0Sgoo001cOol00g`0Oomoo`0IOol2O02?Ool0079oo`03O01oogoo01aoo`03
O01oogoo08aoo`00LGoo00=l07ooOol07Woo00=l07ooOol0Rgoo001aOol00g`0Oomoo`0OOol00g`0
Oomoo`2:Ool0071oo`03O01oogoo025oo`03O01oogoo08Uoo`00Kgoo00=l07ooOol08goo00=l07oo
Ool0R7oo001_Ool00g`0Oomoo`0TOol00g`0Oomoo`27Ool006ioo`03O01oogoo02Ioo`03O01oogoo
08Ioo`00KWoo00=l07ooOol09Woo00=l07ooOol0QWoo001^Ool00g`0Oomoo`0WOol00g`0Oomoo`25
Ool006eoo`03O01oogoo02Uoo`03O01oogoo08Aoo`00KGoo00=l07ooOol0:Woo00=l07ooOol0Pgoo
001/Ool00g`0Oomoo`0/Ool00g`0Oomoo`22Ool006aoo`03O01oogoo02aoo`03O01oogoo089oo`00
K7oo00=l07ooOol0;Goo00=l07ooOol0PGoo001[Ool00g`0Oomoo`0_Ool00g`0Oomoo`20Ool006]o
o`03O01oogoo031oo`03O01oogoo07moo`00Jgoo00=l07ooOol0<7oo00=l07ooOol0Ogoo001[Ool0
0g`0Oomoo`0aOol00g`0Oomoo`1nOol006]oo`03O01oogoo039oo`03O01oogoo07eoo`00JWoo00=l
07ooOol0<goo00=l07ooOol0OGoo001ZOol00g`0Oomoo`0dOol00g`0Oomoo`1lOol006Yoo`03O01o
ogoo03Eoo`03O01oogoo07]oo`00JWoo00=l07ooOol0=Goo00=l07ooOol0Ngoo001ZOol00g`0Oomo
o`0fOol00g`0Oomoo`1jOol006Yoo`03O01oogoo03Ioo`03O01oogoo07Yoo`00JWoo00=l07ooOol0
=goo00=l07ooOol0NGoo001ZOol00g`0Oomoo`0gOol00g`0Oomoo`1iOol006Yoo`03O01oogoo03Qo
o`03O01oogoo07Qoo`00JWoo00=l07ooOol0>Goo00=l07ooOol0Mgoo001ZOol00g`0Oomoo`0iOol0
0g`0Oomoo`1gOol006Uoo`03O01oogoo03]oo`03O01oogoo07Ioo`00JGoo00=l07ooOol0>goo00=l
07ooOol0MWoo001YOol00g`0Oomoo`0lOol00g`0Oomoo`1eOol006Uoo`03O01oogoo03aoo`03O01o
ogoo07Eoo`00JGoo00=l07ooOol0?Goo00=l07ooOol0M7oo001YOol00g`0Oomoo`0mOol00g`0Oomo
o`1dOol006Uoo`03O01oogoo03ioo`03O01oogoo07=oo`00JGoo00=l07ooOol0?Woo00=l07ooOol0
Lgoo001YOol00g`0Oomoo`0nOol00g`0Oomoo`1cOol006Uoo`03O01oogoo03moo`03O01oogoo079o
o`00JGoo00=l07ooOol0?goo00=l07ooOol0LWoo001YOol00g`0Oomoo`10Ool00g`0Oomoo`1aOol0
06Uoo`03O01oogoo041oo`03O01oogoo075oo`00JGoo00=l07ooOol0@7oo00=l07ooOol0LGoo001Y
Ool00g`0Oomoo`11Ool00g`0Oomoo`1`Ool006Uoo`03O01oogoo045oo`03O01oogoo071oo`00JGoo
00=l07ooOol0@Goo00=l07ooOol0L7oo001YOol00g`0Oomoo`12Ool00g`0Oomoo`1_Ool006Uoo`03
O01oogoo049oo`03O01oogoo06moo`00JWoo00=l07ooOol0@Woo00=l07ooOol0KWoo001ZOol00g`0
Oomoo`12Ool00g`0Oomoo`1^Ool006Yoo`03O01oogoo049oo`03O01oogoo06ioo`00JWoo00=l07oo
Ool0@goo00=l07ooOol0KGoo001ZOol00g`0Oomoo`13Ool00g`0Oomoo`1]Ool006Yoo`03O01oogoo
04Aoo`03O01oogoo06aoo`00JWoo00=l07ooOol0A7oo00=l07ooOol0K7oo001ZOol00g`0Oomoo`15
Ool00g`0Oomoo`1[Ool006Yoo`03O01oogoo04Eoo`03O01oogoo06]oo`00JWoo00=l07ooOol0AWoo
00=l07ooOol0JWoo001ZOol00g`0Oomoo`16Ool00g`0Oomoo`1ZOol006Yoo`03O01oogoo04Ioo`03
O01oogoo06Yoo`00JWoo00=l07ooOol0AWoo00=l07ooOol0JWoo001[Ool00g`0Oomoo`16Ool00g`0
Oomoo`1YOol006]oo`03O01oogoo04Ioo`03O01oogoo06Uoo`00Jgoo00=l07ooOol0AWoo00=l07oo
Ool0JGoo001[Ool00g`0Oomoo`16Ool00g`0Oomoo`1YOol006]oo`03O01oogoo04Moo`03O01oogoo
06Qoo`00Jgoo00=l07ooOol0Agoo00=l07ooOol0J7oo001/Ool00g`0Oomoo`16Ool00g`0Oomoo`1X
Ool006aoo`03O01oogoo04Moo`03O01oogoo06Moo`00K7oo00=l07ooOol0Agoo00=l07ooOol0Igoo
001/Ool00g`0Oomoo`17Ool00g`0Oomoo`1WOol006aoo`03O01oogoo04Qoo`03O01oogoo06Ioo`00
K7oo00=l07ooOol0B7oo00=l07ooOol0IWoo001/Ool00g`0Oomoo`18Ool00g`0Oomoo`1VOol006eo
o`03O01oogoo04Qoo`03O01oogoo06Eoo`00KGoo00=l07ooOol0B7oo00=l07ooOol0IGoo001]Ool0
0g`0Oomoo`18Ool00g`0Oomoo`1UOol006eoo`03O01oogoo04Qoo`03O01oogoo06Eoo`00KGoo00=l
07ooOol0BGoo00=l07ooOol0I7oo001^Ool00g`0Oomoo`18Ool00g`0Oomoo`1TOol006ioo`03O01o
ogoo04Qoo`03O01oogoo06Aoo`00KWoo00=l07ooOol0B7oo00=l07ooOol0I7oo001^Ool00g`0Oomo
o`19Ool00g`0Oomoo`1SOol006moo`03O01oogoo04Qoo`03O01oogoo06=oo`00Kgoo00=l07ooOol0
B7oo00=l07ooOol0Hgoo001_Ool00g`0Oomoo`18Ool00g`0Oomoo`1SOol006moo`03O01oogoo04Qo
o`03O01oogoo06=oo`00Kgoo00=l07ooOol0BGoo00=l07ooOol0HWoo001`Ool00g`0Oomoo`18Ool0
0g`0Oomoo`1ROol0071oo`03O01oogoo04Qoo`03O01oogoo069oo`00L7oo00=l07ooOol0B7oo00=l
07ooOol0HWoo001`Ool00g`0Oomoo`19Ool00g`0Oomoo`1QOol0071oo`03O01oogoo04Uoo`03O01o
ogoo065oo`00LGoo00=l07ooOol0B7oo00=l07ooOol0HGoo001aOol00g`0Oomoo`18Ool00g`0Oomo
o`1QOol0075oo`03O01oogoo04Qoo`03O01oogoo065oo`00LWoo00=l07ooOol0Agoo00=l07ooOol0
HGoo001bOol00g`0Oomoo`17Ool00g`0Oomoo`1QOol0079oo`03O01oogoo04Qoo`03O01oogoo061o
o`00Lgoo00=l07ooOol0Agoo00=l07ooOol0H7oo001cOol00g`0Oomoo`17Ool00g`0Oomoo`1POol0
07=oo`03O01oogoo04Moo`03O01oogoo061oo`00Lgoo00=l07ooOol0Agoo00=l07ooOol0H7oo001d
Ool00g`0Oomoo`16Ool00g`0Oomoo`1POol007Aoo`03O01oogoo04Ioo`03O01oogoo061oo`00M7oo
00=l07ooOol0AWoo00=l07ooOol0H7oo001eOol00g`0Oomoo`15Ool00g`0Oomoo`1POol007Eoo`03
O01oogoo04Ioo`03O01oogoo05moo`00MGoo00=l07ooOol0AWoo00=l07ooOol0Ggoo001fOol00g`0
Oomoo`15Ool00g`0Oomoo`1OOol007Ioo`03O01oogoo04Eoo`03O01oogoo05moo`00MWoo00=l07oo
Ool0AGoo00=l07ooOol0Ggoo001gOol00g`0Oomoo`14Ool00g`0Oomoo`1OOol007Moo`03O01oogoo
04Aoo`03O01oogoo05moo`00N7oo00=l07ooOol0@goo00=l07ooOol0Ggoo001hOol00g`0Oomoo`13
Ool00g`0Oomoo`1OOol007Uoo`03O01oogoo04=oo`03O01oogoo05ioo`00NGoo00=l07ooOol0@goo
00=l07ooOol0GWoo001iOol00g`0Oomoo`13Ool00g`0Oomoo`1NOol007Yoo`03O01oogoo049oo`03
O01oogoo05ioo`00NWoo00=l07ooOol0@Woo00=l07ooOol0GWoo001jOol00g`0Oomoo`12Ool00g`0
Oomoo`1NOol007]oo`03O01oogoo045oo`03O01oogoo05ioo`00Ngoo00=l07ooOol0@Goo00=l07oo
Ool0GWoo001kOol00g`0Oomoo`11Ool00g`0Oomoo`1NOol007aoo`03O01oogoo041oo`03O01oogoo
05ioo`00O7oo00=l07ooOol0@7oo00=l07ooOol0GWoo001mOol00g`0Oomoo`0oOol00g`0Oomoo`1N
Ool007eoo`03O01oogoo03moo`03O01oogoo05ioo`00OWoo00=l07ooOol0?Woo00=l07ooOol0GWoo
001nOol00g`0Oomoo`0nOol00g`0Oomoo`1NOol007moo`03O01oogoo03eoo`03O01oogoo05ioo`00
Ogoo00=l07ooOol0?Goo00=l07ooOol0GWoo0020Ool00g`0Oomoo`0lOol00g`0Oomoo`1NOol0081o
o`03O01oogoo03aoo`03O01oogoo05ioo`00PGoo00=l07ooOol0>goo00=l07ooOol0GWoo0021Ool0
0g`0Oomoo`0kOol00g`0Oomoo`1NOol0089oo`03O01oogoo03Yoo`03O01oogoo05ioo`00PWoo00=l
07ooOol0>Woo00=l07ooOol0GWoo0023Ool00g`0Oomoo`0hOol00g`0Oomoo`1OOol008=oo`03O01o
ogoo03Qoo`03O01oogoo05moo`00Q7oo00=l07ooOol0=goo00=l07ooOol0Ggoo0025Ool00g`0Oomo
o`0fOol00g`0Oomoo`1OOol008Eoo`03O01oogoo03Ioo`03O01oogoo05moo`00QWoo00=l07ooOol0
=Goo00=l07ooOol0Ggoo0026Ool00g`0Oomoo`0dOol00g`0Oomoo`1POol008Moo`03O01oogoo03=o
o`03O01oogoo061oo`00R7oo00=l07ooOol0<Woo00=l07ooOol0H7oo0028Ool00g`0Oomoo`0bOol0
0g`0Oomoo`1POol008Uoo`03O01oogoo035oo`03O01oogoo061oo`00RGoo00=l07ooOol0<Goo00=l
07ooOol0H7oo002:Ool00g`0Oomoo`0_Ool00g`0Oomoo`1QOol008]oo`03O01oogoo02ioo`03O01o
ogoo065oo`00Rgoo00=l07ooOol0;Woo00=l07ooOol0HGoo002<Ool00g`0Oomoo`0]Ool00g`0Oomo
o`1QOol008eoo`03O01oogoo02aoo`03O01oogoo065oo`00SWoo00=l07ooOol0:Woo00=l07ooOol0
HWoo002?Ool00g`0Oomoo`0YOol00g`0Oomoo`1ROol008moo`03O01oogoo02Qoo`03O01oogoo06=o
o`00T7oo00=l07ooOol09goo00=l07ooOol0Hgoo002AOol00g`0Oomoo`0UOol00g`0Oomoo`1TOol0
099oo`03O01oogoo02Aoo`03O01oogoo06Aoo`00Tgoo00=l07ooOol08Woo00=l07ooOol0IGoo002D
Ool00g`0Oomoo`0QOol00g`0Oomoo`1UOol009Eoo`03O01oogoo01moo`03O01oogoo06Ioo`00UGoo
00=l07ooOol07goo00=l07ooOol0IWoo002FOol00g`0Oomoo`0MOol00g`0Oomoo`1WOol009Moo`03
O01oogoo01aoo`03O01oogoo06Moo`00V7oo0W`06goo00=l07ooOol0J7oo002JOol2O00IOol00g`0
Oomoo`1XOol009aoo`03O01oogoo01Eoo`03O01oogoo06Uoo`00WGoo00=l07ooOol04Woo0W`0K7oo
002NOol2O00AOol00g`0Oomoo`1/Ool00:1oo`9l00eoo`9l06moo`00XWoo0W`02Goo0W`0LGoo002T
Ool9O01cOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.38667 .50281 m
.3941 .5258 L
s
.3941 .5258 m
.40218 .54861 L
s
.40218 .54861 m
.41088 .57114 L
s
.37994 .47974 m
.38667 .50281 L
s
.41088 .57114 m
.42018 .59328 L
s
.37394 .45669 m
.37994 .47974 L
s
.42018 .59328 m
.43001 .61494 L
s
.3687 .43377 m
.37394 .45669 L
s
.43001 .61494 m
.44036 .63602 L
s
.36425 .41109 m
.3687 .43377 L
s
.44036 .63602 m
.45117 .6564 L
s
.36062 .38874 m
.36425 .41109 L
s
.45117 .6564 m
.46241 .67599 L
s
.35785 .36686 m
.36062 .38874 L
s
.46241 .67599 m
.47402 .69467 L
s
.35597 .34554 m
.35785 .36686 L
s
.47402 .69467 m
.48596 .71235 L
s
.355 .32492 m
.35597 .34554 L
s
.48596 .71235 m
.49816 .7289 L
s
.35496 .30511 m
.355 .32492 L
s
.49816 .7289 m
.51058 .74422 L
s
.35589 .28624 m
.35496 .30511 L
s
.51058 .74422 m
.52316 .75819 L
s
.35781 .26845 m
.35589 .28624 L
s
.52316 .75819 m
.53583 .77069 L
s
.36073 .25185 m
.35781 .26845 L
s
.53583 .77069 m
.54851 .78161 L
s
.36467 .23661 m
.36073 .25185 L
s
.54851 .78161 m
.56114 .79084 L
s
.36964 .22284 m
.36467 .23661 L
s
.56114 .79084 m
.57363 .79826 L
s
.37565 .2107 m
.36964 .22284 L
s
.57363 .79826 m
.5859 .80375 L
s
.38268 .20031 m
.37565 .2107 L
s
.5859 .80375 m
.59785 .80722 L
s
.39074 .19183 m
.38268 .20031 L
s
.59785 .80722 m
.6094 .80855 L
s
.39979 .18538 m
.39074 .19183 L
s
.6094 .80855 m
.62045 .80767 L
s
.40982 .18109 m
.39979 .18538 L
s
.62045 .80767 m
.63088 .80449 L
s
.42078 .17907 m
.40982 .18109 L
s
.63088 .80449 m
.64061 .79895 L
s
.43261 .17943 m
.42078 .17907 L
s
.64061 .79895 m
.64951 .791 L
s
.44527 .18226 m
.43261 .17943 L
s
.64951 .791 m
.65749 .78062 L
s
.45866 .18762 m
.44527 .18226 L
s
.65749 .78062 m
.66445 .7678 L
s
.47269 .19556 m
.45866 .18762 L
s
.66445 .7678 m
.67027 .75257 L
s
.48726 .2061 m
.47269 .19556 L
s
.67027 .75257 m
.67488 .73499 L
s
.50225 .21923 m
.48726 .2061 L
s
.67488 .73499 m
.67819 .71514 L
s
.51753 .2349 m
.50225 .21923 L
s
.67819 .71514 m
.68011 .69314 L
s
.53296 .25304 m
.51753 .2349 L
s
.68011 .69314 m
.6806 .66916 L
s
.54838 .27352 m
.53296 .25304 L
s
.6806 .66916 m
.67961 .64337 L
s
.56363 .29619 m
.54838 .27352 L
s
.67961 .64337 m
.67711 .616 L
s
.57855 .32086 m
.56363 .29619 L
s
.67711 .616 m
.6731 .58731 L
s
.59297 .3473 m
.57855 .32086 L
s
.6731 .58731 m
.66759 .55758 L
s
.60674 .37526 m
.59297 .3473 L
s
.66759 .55758 m
.66063 .52711 L
s
.6197 .40445 m
.60674 .37526 L
s
.66063 .52711 m
.65226 .49623 L
s
.63169 .43456 m
.6197 .40445 L
s
.65226 .49623 m
.64258 .46526 L
s
.64258 .46526 m
.63169 .43456 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001eOol9O02ROol007=oo`9l
00Uoo`=l09moo`00LWoo00=l07ooOol037oo0g`0W7oo001aOol00g`0Oomoo`0@Ool00g`0Oomoo`2I
Ool0071oo`03O01oogoo019oo`9l09Uoo`00KWoo0W`05goo00=l07ooOol0UWoo001]Ool00g`0Oomo
o`0HOol00g`0Oomoo`2EOol006aoo`03O01oogoo01Yoo`9l09Eoo`00K7oo00=l07ooOol077oo00=l
07ooOol0TWoo001[Ool00g`0Oomoo`0NOol2O02BOol006]oo`03O01oogoo021oo`9l091oo`00JWoo
00=l07ooOol08goo00=l07ooOol0SGoo001ZOol00g`0Oomoo`0TOol00g`0Oomoo`2<Ool006Uoo`03
O01oogoo02Ioo`03O01oogoo08]oo`00JGoo00=l07ooOol09Woo00=l07ooOol0Rgoo001XOol00g`0
Oomoo`0XOol00g`0Oomoo`2:Ool006Qoo`03O01oogoo02Uoo`03O01oogoo08Uoo`00J7oo00=l07oo
Ool0:Woo00=l07ooOol0R7oo001XOol00g`0Oomoo`0[Ool00g`0Oomoo`27Ool006Moo`03O01oogoo
02aoo`03O01oogoo08Moo`00Igoo00=l07ooOol0;Goo00=l07ooOol0QWoo001WOol00g`0Oomoo`0^
Ool00g`0Oomoo`25Ool006Moo`03O01oogoo02moo`03O01oogoo08Aoo`00Igoo00=l07ooOol0<7oo
00=l07ooOol0Pgoo001VOol00g`0Oomoo`0aOol00g`0Oomoo`23Ool006Ioo`03O01oogoo039oo`03
O01oogoo089oo`00IWoo00=l07ooOol0<goo00=l07ooOol0PGoo001VOol00g`0Oomoo`0dOol00g`0
Oomoo`20Ool006Ioo`03O01oogoo03Eoo`03O01oogoo07moo`00IWoo00=l07ooOol0=Goo00=l07oo
Ool0Ogoo001VOol00g`0Oomoo`0fOol00g`0Oomoo`1nOol006Ioo`03O01oogoo03Ioo`03O01oogoo
07ioo`00IWoo00=l07ooOol0=goo00=l07ooOol0OGoo001VOol00g`0Oomoo`0gOol00g`0Oomoo`1m
Ool006Eoo`03O01oogoo03Uoo`03O01oogoo07aoo`00IGoo00=l07ooOol0>Woo00=l07ooOol0Ngoo
001UOol00g`0Oomoo`0jOol00g`0Oomoo`1kOol006Eoo`03O01oogoo03]oo`03O01oogoo07Yoo`00
IGoo00=l07ooOol0?7oo00=l07ooOol0NGoo001UOol00g`0Oomoo`0mOol00g`0Oomoo`1hOol006Eo
o`03O01oogoo03eoo`03O01oogoo07Qoo`00IGoo00=l07ooOol0?Woo00=l07ooOol0Mgoo001UOol0
0g`0Oomoo`0oOol00g`0Oomoo`1fOol006Eoo`03O01oogoo03moo`03O01oogoo07Ioo`00IGoo00=l
07ooOol0@7oo00=l07ooOol0MGoo001UOol00g`0Oomoo`10Ool00g`0Oomoo`1eOol006Ioo`03O01o
ogoo041oo`03O01oogoo07Aoo`00IWoo00=l07ooOol0@7oo00=l07ooOol0M7oo001VOol00g`0Oomo
o`11Ool00g`0Oomoo`1cOol006Ioo`03O01oogoo045oo`03O01oogoo07=oo`00IWoo00=l07ooOol0
@Woo00=l07ooOol0LWoo001VOol00g`0Oomoo`12Ool00g`0Oomoo`1bOol006Ioo`03O01oogoo04=o
o`03O01oogoo075oo`00IWoo00=l07ooOol0@goo00=l07ooOol0LGoo001VOol00g`0Oomoo`14Ool0
0g`0Oomoo`1`Ool006Ioo`03O01oogoo04Aoo`03O01oogoo071oo`00IWoo00=l07ooOol0AGoo00=l
07ooOol0Kgoo001VOol00g`0Oomoo`15Ool00g`0Oomoo`1_Ool006Moo`03O01oogoo04Eoo`03O01o
ogoo06ioo`00Igoo00=l07ooOol0AGoo00=l07ooOol0KWoo001WOol00g`0Oomoo`15Ool00g`0Oomo
o`1^Ool006Moo`03O01oogoo04Ioo`03O01oogoo06eoo`00Igoo00=l07ooOol0AWoo00=l07ooOol0
KGoo001WOol00g`0Oomoo`16Ool00g`0Oomoo`1]Ool006Qoo`03O01oogoo04Ioo`03O01oogoo06ao
o`00J7oo00=l07ooOol0AWoo00=l07ooOol0K7oo001XOol00g`0Oomoo`16Ool00g`0Oomoo`1/Ool0
06Qoo`03O01oogoo04Moo`03O01oogoo06]oo`00J7oo00=l07ooOol0Agoo00=l07ooOol0Jgoo001X
Ool00g`0Oomoo`18Ool00g`0Oomoo`1ZOol006Uoo`03O01oogoo04Moo`03O01oogoo06Yoo`00JGoo
00=l07ooOol0B7oo00=l07ooOol0JGoo001YOol00g`0Oomoo`18Ool00g`0Oomoo`1YOol006Uoo`03
O01oogoo04Uoo`03O01oogoo06Qoo`00JGoo00=l07ooOol0BGoo00=l07ooOol0J7oo001ZOol00g`0
Oomoo`19Ool00g`0Oomoo`1WOol006Yoo`03O01oogoo04Uoo`03O01oogoo06Moo`00JWoo00=l07oo
Ool0BGoo00=l07ooOol0Igoo001ZOol00g`0Oomoo`1:Ool00g`0Oomoo`1VOol006]oo`03O01oogoo
04Uoo`03O01oogoo06Ioo`00Jgoo00=l07ooOol0BGoo00=l07ooOol0IWoo001[Ool00g`0Oomoo`1:
Ool00g`0Oomoo`1UOol006aoo`03O01oogoo04Uoo`03O01oogoo06Eoo`00K7oo00=l07ooOol0BGoo
00=l07ooOol0IGoo001/Ool00g`0Oomoo`1:Ool00g`0Oomoo`1TOol006eoo`03O01oogoo04Uoo`03
O01oogoo06Aoo`00KGoo00=l07ooOol0BGoo00=l07ooOol0I7oo001]Ool00g`0Oomoo`1:Ool00g`0
Oomoo`1SOol006eoo`03O01oogoo04Yoo`03O01oogoo06=oo`00KGoo00=l07ooOol0BWoo00=l07oo
Ool0Hgoo001^Ool00g`0Oomoo`1:Ool00g`0Oomoo`1ROol006ioo`03O01oogoo04Yoo`03O01oogoo
069oo`00KWoo00=l07ooOol0BWoo00=l07ooOol0HWoo001^Ool00g`0Oomoo`1:Ool00g`0Oomoo`1R
Ool006ioo`03O01oogoo04]oo`03O01oogoo065oo`00Kgoo00=l07ooOol0BWoo00=l07ooOol0HGoo
001_Ool00g`0Oomoo`1:Ool00g`0Oomoo`1QOol0071oo`03O01oogoo04Uoo`03O01oogoo065oo`00
L7oo00=l07ooOol0BWoo00=l07ooOol0H7oo001aOol00g`0Oomoo`19Ool00g`0Oomoo`1POol0075o
o`03O01oogoo04Uoo`03O01oogoo061oo`00LWoo00=l07ooOol0B7oo00=l07ooOol0H7oo001bOol0
0g`0Oomoo`18Ool00g`0Oomoo`1POol0079oo`03O01oogoo04Uoo`03O01oogoo05moo`00LWoo00=l
07ooOol0BGoo00=l07ooOol0Ggoo001cOol00g`0Oomoo`18Ool00g`0Oomoo`1OOol007=oo`03O01o
ogoo04Qoo`03O01oogoo05moo`00Lgoo00=l07ooOol0BGoo00=l07ooOol0GWoo001dOol00g`0Oomo
o`18Ool00g`0Oomoo`1NOol007Aoo`03O01oogoo04Qoo`03O01oogoo05ioo`00M7oo00=l07ooOol0
B7oo00=l07ooOol0GWoo001eOol00g`0Oomoo`17Ool00g`0Oomoo`1NOol007Eoo`03O01oogoo04Qo
o`03O01oogoo05eoo`00MGoo00=l07ooOol0B7oo00=l07ooOol0GGoo001fOol00g`0Oomoo`17Ool0
0g`0Oomoo`1MOol007Ioo`03O01oogoo04Moo`03O01oogoo05eoo`00Mgoo00=l07ooOol0Agoo00=l
07ooOol0G7oo001gOol00g`0Oomoo`17Ool00g`0Oomoo`1LOol007Qoo`03O01oogoo04Ioo`03O01o
ogoo05aoo`00N7oo00=l07ooOol0AWoo00=l07ooOol0G7oo001hOol00g`0Oomoo`16Ool00g`0Oomo
o`1LOol007Uoo`03O01oogoo04Eoo`03O01oogoo05aoo`00NGoo00=l07ooOol0AWoo00=l07ooOol0
Fgoo001jOol00g`0Oomoo`15Ool00g`0Oomoo`1KOol007Yoo`03O01oogoo04Eoo`03O01oogoo05]o
o`00Ngoo00=l07ooOol0A7oo00=l07ooOol0Fgoo001kOol00g`0Oomoo`14Ool00g`0Oomoo`1KOol0
07aoo`03O01oogoo04=oo`03O01oogoo05]oo`00O7oo00=l07ooOol0@goo00=l07ooOol0Fgoo001m
Ool00g`0Oomoo`12Ool00g`0Oomoo`1KOol007eoo`03O01oogoo04=oo`03O01oogoo05Yoo`00OWoo
00=l07ooOol0@Woo00=l07ooOol0FWoo001nOol00g`0Oomoo`12Ool00g`0Oomoo`1JOol007moo`03
O01oogoo045oo`03O01oogoo05Yoo`00Ogoo00=l07ooOol0@Goo00=l07ooOol0FWoo0020Ool00g`0
Oomoo`10Ool00g`0Oomoo`1JOol0081oo`03O01oogoo041oo`03O01oogoo05Yoo`00PGoo00=l07oo
Ool0?goo00=l07ooOol0FWoo0021Ool00g`0Oomoo`0oOol00g`0Oomoo`1JOol0089oo`03O01oogoo
03ioo`03O01oogoo05Yoo`00PWoo00=l07ooOol0?Woo00=l07ooOol0FWoo0023Ool00g`0Oomoo`0m
Ool00g`0Oomoo`1JOol008=oo`03O01oogoo03eoo`03O01oogoo05Yoo`00Q7oo00=l07ooOol0?7oo
00=l07ooOol0FWoo0025Ool00g`0Oomoo`0kOol00g`0Oomoo`1JOol008Ioo`03O01oogoo03Yoo`03
O01oogoo05Yoo`00QWoo00=l07ooOol0>Woo00=l07ooOol0FWoo0027Ool00g`0Oomoo`0iOol00g`0
Oomoo`1JOol008Qoo`03O01oogoo03Qoo`03O01oogoo05Yoo`00RGoo00=l07ooOol0=goo00=l07oo
Ool0FWoo0029Ool00g`0Oomoo`0gOol00g`0Oomoo`1JOol008Yoo`03O01oogoo03Eoo`03O01oogoo
05]oo`00RWoo00=l07ooOol0=Goo00=l07ooOol0Fgoo002;Ool00g`0Oomoo`0dOol00g`0Oomoo`1K
Ool008aoo`03O01oogoo03=oo`03O01oogoo05]oo`00S7oo00=l07ooOol0<goo00=l07ooOol0Fgoo
002=Ool00g`0Oomoo`0bOol00g`0Oomoo`1KOol008eoo`03O01oogoo035oo`03O01oogoo05aoo`00
SWoo00=l07ooOol0<7oo00=l07ooOol0G7oo002?Ool00g`0Oomoo`0_Ool00g`0Oomoo`1LOol0091o
o`03O01oogoo02ioo`03O01oogoo05aoo`00TGoo00=l07ooOol0;Goo00=l07ooOol0G7oo002BOol0
0g`0Oomoo`0[Ool00g`0Oomoo`1MOol009=oo`03O01oogoo02Yoo`03O01oogoo05eoo`00U7oo00=l
07ooOol0:Goo00=l07ooOol0GGoo002EOol00g`0Oomoo`0XOol00g`0Oomoo`1MOol009Ioo`03O01o
ogoo02Ioo`03O01oogoo05ioo`00Ugoo00=l07ooOol09Goo00=l07ooOol0GWoo002GOol00g`0Oomo
o`0TOol00g`0Oomoo`1OOol009Qoo`03O01oogoo02=oo`03O01oogoo05moo`00VGoo00=l07ooOol0
8Goo00=l07ooOol0H7oo002JOol00g`0Oomoo`0POol00g`0Oomoo`1POol009]oo`9l01moo`03O01o
ogoo065oo`00WGoo00=l07ooOol077oo00=l07ooOol0HGoo002NOol2O00KOol00g`0Oomoo`1ROol0
0:1oo`9l01Uoo`03O01oogoo069oo`00XWoo00=l07ooOol05Goo00=l07ooOol0Hgoo002SOol00g`0
Oomoo`0BOol2O01VOol00:Aoo`9l015oo`03O01oogoo06Ioo`00YWoo17`02Woo0g`0JGoo002ZOol3
O004Ool3O01/Ool00:eoo`Al06moo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.40571 .55052 m
.41603 .57236 L
s
.39598 .52837 m
.40571 .55052 L
s
.38689 .50602 m
.39598 .52837 L
s
.41603 .57236 m
.42691 .5938 L
s
.37849 .48355 m
.38689 .50602 L
s
.42691 .5938 m
.4383 .61475 L
s
.37081 .46109 m
.37849 .48355 L
s
.4383 .61475 m
.45015 .63509 L
s
.3639 .43871 m
.37081 .46109 L
s
.45015 .63509 m
.46241 .65474 L
s
.3578 .41653 m
.3639 .43871 L
s
.46241 .65474 m
.47502 .67359 L
s
.35255 .39466 m
.3578 .41653 L
s
.47502 .67359 m
.48795 .69154 L
s
.34818 .37321 m
.35255 .39466 L
s
.48795 .69154 m
.50112 .70849 L
s
.34474 .35228 m
.34818 .37321 L
s
.50112 .70849 m
.51448 .72432 L
s
.34226 .332 m
.34474 .35228 L
s
.51448 .72432 m
.52796 .73894 L
s
.34078 .31248 m
.34226 .332 L
s
.52796 .73894 m
.5415 .75223 L
s
.34033 .29386 m
.34078 .31248 L
s
.5415 .75223 m
.55501 .76409 L
s
.34096 .27626 m
.34033 .29386 L
s
.55501 .76409 m
.56844 .77439 L
s
.34267 .25981 m
.34096 .27626 L
s
.56844 .77439 m
.58168 .78304 L
s
.34551 .24466 m
.34267 .25981 L
s
.58168 .78304 m
.59465 .78993 L
s
.34948 .23093 m
.34551 .24466 L
s
.59465 .78993 m
.60727 .79494 L
s
.35462 .21877 m
.34948 .23093 L
s
.60727 .79494 m
.61944 .79798 L
s
.36091 .20832 m
.35462 .21877 L
s
.61944 .79798 m
.63105 .79895 L
s
.36837 .19971 m
.36091 .20832 L
s
.63105 .79895 m
.64199 .79778 L
s
.37698 .19308 m
.36837 .19971 L
s
.64199 .79778 m
.65218 .79437 L
s
.38672 .18855 m
.37698 .19308 L
s
.65218 .79437 m
.66149 .78868 L
s
.39757 .18624 m
.38672 .18855 L
s
.66149 .78868 m
.66981 .78067 L
s
.40946 .18626 m
.39757 .18624 L
s
.66981 .78067 m
.67705 .7703 L
s
.42236 .18868 m
.40946 .18626 L
s
.67705 .7703 m
.68309 .75757 L
s
.43617 .1936 m
.42236 .18868 L
s
.68309 .75757 m
.68785 .74253 L
s
.45081 .20103 m
.43617 .1936 L
s
.68785 .74253 m
.69122 .72521 L
s
.46618 .21102 m
.45081 .20103 L
s
.69122 .72521 m
.69314 .7057 L
s
.48216 .22355 m
.46618 .21102 L
s
.69314 .7057 m
.69353 .68413 L
s
.4986 .23858 m
.48216 .22355 L
s
.69353 .68413 m
.69235 .66064 L
s
.51535 .25602 m
.4986 .23858 L
s
.69235 .66064 m
.68957 .63542 L
s
.53226 .27577 m
.51535 .25602 L
s
.68957 .63542 m
.68517 .60869 L
s
.54916 .29768 m
.53226 .27577 L
s
.68517 .60869 m
.67916 .58068 L
s
.56585 .32156 m
.54916 .29768 L
s
.67916 .58068 m
.67159 .55169 L
s
.58217 .34719 m
.56585 .32156 L
s
.67159 .55169 m
.6625 .52199 L
s
.59793 .37431 m
.58217 .34719 L
s
.6625 .52199 m
.65198 .49192 L
s
.61295 .40266 m
.59793 .37431 L
s
.65198 .49192 m
.64013 .46178 L
s
.62707 .43192 m
.61295 .40266 L
s
.64013 .46178 m
.62707 .43192 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
LGoo1W`0ZGoo001^Ool3O006Ool4O02UOol006aoo`9l00eoo`=l0:9oo`00JWoo0W`04Woo0W`0X7oo
001YOol00g`0Oomoo`0DOol2O02NOol006Qoo`03O01oogoo01Moo`03O01oogoo09]oo`00Igoo00=l
07ooOol06Goo0W`0Vgoo001VOol00g`0Oomoo`0LOol00g`0Oomoo`2HOol006Ioo`03O01oogoo01eo
o`03O01oogoo09Moo`00IGoo00=l07ooOol07goo0W`0Ugoo001UOol00g`0Oomoo`0QOol00g`0Oomo
o`2DOol006Aoo`03O01oogoo02=oo`03O01oogoo09=oo`00I7oo00=l07ooOol097oo00=l07ooOol0
TWoo001TOol00g`0Oomoo`0UOol2O02BOol006Aoo`03O01oogoo02Moo`03O01oogoo08moo`00Hgoo
00=l07ooOol0:Goo00=l07ooOol0SWoo001SOol00g`0Oomoo`0ZOol00g`0Oomoo`2=Ool006=oo`03
O01oogoo02]oo`03O01oogoo08aoo`00Hgoo00=l07ooOol0:goo00=l07ooOol0S7oo001ROol00g`0
Oomoo`0]Ool00g`0Oomoo`2;Ool0069oo`03O01oogoo02ioo`03O01oogoo08Yoo`00HWoo00=l07oo
Ool0;goo00=l07ooOol0RGoo001ROol00g`0Oomoo`0`Ool00g`0Oomoo`28Ool0069oo`03O01oogoo
031oo`03O01oogoo08Qoo`00HGoo00=l07ooOol0<Woo00=l07ooOol0Qgoo001QOol00g`0Oomoo`0c
Ool00g`0Oomoo`26Ool0065oo`03O01oogoo03Aoo`03O01oogoo08Eoo`00HGoo00=l07ooOol0=Goo
00=l07ooOol0Q7oo001QOol00g`0Oomoo`0fOol00g`0Oomoo`23Ool0065oo`03O01oogoo03Ioo`03
O01oogoo08=oo`00HGoo00=l07ooOol0=goo00=l07ooOol0PWoo001QOol00g`0Oomoo`0hOol00g`0
Oomoo`21Ool0065oo`03O01oogoo03Uoo`03O01oogoo081oo`00HGoo00=l07ooOol0>Woo00=l07oo
Ool0Ogoo001QOol00g`0Oomoo`0jOol00g`0Oomoo`1oOol0065oo`03O01oogoo03]oo`03O01oogoo
07ioo`00HGoo00=l07ooOol0?7oo00=l07ooOol0OGoo001QOol00g`0Oomoo`0mOol00g`0Oomoo`1l
Ool0065oo`03O01oogoo03eoo`03O01oogoo07aoo`00HGoo00=l07ooOol0?Woo00=l07ooOol0Ngoo
001ROol00g`0Oomoo`0nOol00g`0Oomoo`1jOol0069oo`03O01oogoo03ioo`03O01oogoo07Yoo`00
HWoo00=l07ooOol0?goo00=l07ooOol0NGoo001ROol00g`0Oomoo`10Ool00g`0Oomoo`1hOol0069o
o`03O01oogoo045oo`03O01oogoo07Moo`00HWoo00=l07ooOol0@Goo00=l07ooOol0Mgoo001ROol0
0g`0Oomoo`12Ool00g`0Oomoo`1fOol0069oo`03O01oogoo049oo`03O01oogoo07Ioo`00HWoo00=l
07ooOol0@goo00=l07ooOol0MGoo001ROol00g`0Oomoo`13Ool00g`0Oomoo`1eOol0069oo`03O01o
ogoo04Aoo`03O01oogoo07Aoo`00HWoo00=l07ooOol0A7oo00=l07ooOol0M7oo001SOol00g`0Oomo
o`14Ool00g`0Oomoo`1cOol006=oo`03O01oogoo04Aoo`03O01oogoo07=oo`00Hgoo00=l07ooOol0
AGoo00=l07ooOol0LWoo001SOol00g`0Oomoo`15Ool00g`0Oomoo`1bOol006Aoo`03O01oogoo04Eo
o`03O01oogoo075oo`00I7oo00=l07ooOol0AGoo00=l07ooOol0LGoo001TOol00g`0Oomoo`16Ool0
0g`0Oomoo`1`Ool006Eoo`03O01oogoo04Eoo`03O01oogoo071oo`00IGoo00=l07ooOol0AWoo00=l
07ooOol0Kgoo001UOol00g`0Oomoo`16Ool00g`0Oomoo`1_Ool006Eoo`03O01oogoo04Moo`03O01o
ogoo06ioo`00IGoo00=l07ooOol0Agoo00=l07ooOol0KWoo001VOol00g`0Oomoo`17Ool00g`0Oomo
o`1]Ool006Ioo`03O01oogoo04Moo`03O01oogoo06eoo`00IWoo00=l07ooOol0B7oo00=l07ooOol0
K7oo001VOol00g`0Oomoo`18Ool00g`0Oomoo`1/Ool006Moo`03O01oogoo04Qoo`03O01oogoo06]o
o`00Igoo00=l07ooOol0B7oo00=l07ooOol0Jgoo001WOol00g`0Oomoo`19Ool00g`0Oomoo`1ZOol0
06Qoo`03O01oogoo04Qoo`03O01oogoo06Yoo`00J7oo00=l07ooOol0BGoo00=l07ooOol0JGoo001X
Ool00g`0Oomoo`19Ool00g`0Oomoo`1YOol006Uoo`03O01oogoo04Uoo`03O01oogoo06Qoo`00JGoo
00=l07ooOol0BGoo00=l07ooOol0J7oo001YOol00g`0Oomoo`1:Ool00g`0Oomoo`1WOol006Uoo`03
O01oogoo04Yoo`03O01oogoo06Moo`00JWoo00=l07ooOol0BWoo00=l07ooOol0IWoo001ZOol00g`0
Oomoo`1:Ool00g`0Oomoo`1VOol006Yoo`03O01oogoo04Yoo`03O01oogoo06Ioo`00Jgoo00=l07oo
Ool0BWoo00=l07ooOol0IGoo001[Ool00g`0Oomoo`1:Ool00g`0Oomoo`1UOol006]oo`03O01oogoo
04]oo`03O01oogoo06Aoo`00K7oo00=l07ooOol0BWoo00=l07ooOol0I7oo001/Ool00g`0Oomoo`1;
Ool00g`0Oomoo`1SOol006aoo`03O01oogoo04]oo`03O01oogoo06=oo`00KGoo00=l07ooOol0Bgoo
00=l07ooOol0HWoo001]Ool00g`0Oomoo`1;Ool00g`0Oomoo`1ROol006ioo`03O01oogoo04Yoo`03
O01oogoo069oo`00KWoo00=l07ooOol0Bgoo00=l07ooOol0HGoo001_Ool00g`0Oomoo`1:Ool00g`0
Oomoo`1QOol006moo`03O01oogoo04Yoo`03O01oogoo065oo`00Kgoo00=l07ooOol0Bgoo00=l07oo
Ool0H7oo001`Ool00g`0Oomoo`1:Ool00g`0Oomoo`1POol0071oo`03O01oogoo04]oo`03O01oogoo
05moo`00L7oo00=l07ooOol0Bgoo00=l07ooOol0Ggoo001aOol00g`0Oomoo`1:Ool00g`0Oomoo`1O
Ool0075oo`03O01oogoo04Yoo`03O01oogoo05moo`00LGoo00=l07ooOol0Bgoo00=l07ooOol0GWoo
001bOol00g`0Oomoo`1:Ool00g`0Oomoo`1NOol0079oo`03O01oogoo04Yoo`03O01oogoo05ioo`00
Lgoo00=l07ooOol0BGoo00=l07ooOol0GWoo001cOol00g`0Oomoo`1:Ool00g`0Oomoo`1MOol007Ao
o`03O01oogoo04Uoo`03O01oogoo05eoo`00M7oo00=l07ooOol0BGoo00=l07ooOol0GGoo001eOol0
0g`0Oomoo`18Ool00g`0Oomoo`1MOol007Eoo`03O01oogoo04Qoo`03O01oogoo05eoo`00MWoo00=l
07ooOol0B7oo00=l07ooOol0G7oo001fOol00g`0Oomoo`18Ool00g`0Oomoo`1LOol007Moo`03O01o
ogoo04Moo`03O01oogoo05aoo`00Mgoo00=l07ooOol0Agoo00=l07ooOol0G7oo001gOol00g`0Oomo
o`18Ool00g`0Oomoo`1KOol007Qoo`03O01oogoo04Moo`03O01oogoo05]oo`00N7oo00=l07ooOol0
Agoo00=l07ooOol0Fgoo001iOol00g`0Oomoo`16Ool00g`0Oomoo`1KOol007Uoo`03O01oogoo04Mo
o`03O01oogoo05Yoo`00NWoo00=l07ooOol0AWoo00=l07ooOol0FWoo001jOol00g`0Oomoo`16Ool0
0g`0Oomoo`1JOol007]oo`03O01oogoo04Eoo`03O01oogoo05Yoo`00Ngoo00=l07ooOol0AWoo00=l
07ooOol0FGoo001lOol00g`0Oomoo`15Ool00g`0Oomoo`1IOol007aoo`03O01oogoo04Eoo`03O01o
ogoo05Uoo`00OGoo00=l07ooOol0A7oo00=l07ooOol0FGoo001nOol00g`0Oomoo`13Ool00g`0Oomo
o`1IOol007ioo`03O01oogoo04=oo`03O01oogoo05Uoo`00Ogoo00=l07ooOol0@goo00=l07ooOol0
F7oo0020Ool00g`0Oomoo`12Ool00g`0Oomoo`1HOol0081oo`03O01oogoo049oo`03O01oogoo05Qo
o`00PGoo00=l07ooOol0@Goo00=l07ooOol0F7oo0022Ool00g`0Oomoo`10Ool00g`0Oomoo`1HOol0
089oo`03O01oogoo041oo`03O01oogoo05Qoo`00Pgoo00=l07ooOol0?goo00=l07ooOol0F7oo0023
Ool00g`0Oomoo`10Ool00g`0Oomoo`1GOol008Aoo`03O01oogoo03moo`03O01oogoo05Moo`00QGoo
00=l07ooOol0?Woo00=l07ooOol0Egoo0025Ool00g`0Oomoo`0nOol00g`0Oomoo`1GOol008Ioo`03
O01oogoo03eoo`03O01oogoo05Moo`00Qgoo00=l07ooOol0?7oo00=l07ooOol0Egoo0027Ool00g`0
Oomoo`0lOol00g`0Oomoo`1GOol008Qoo`03O01oogoo03aoo`03O01oogoo05Ioo`00RGoo00=l07oo
Ool0>goo00=l07ooOol0EWoo002:Ool00g`0Oomoo`0jOol00g`0Oomoo`1FOol008Yoo`03O01oogoo
03Yoo`03O01oogoo05Ioo`00Rgoo00=l07ooOol0>Goo00=l07ooOol0EWoo002<Ool00g`0Oomoo`0h
Ool00g`0Oomoo`1FOol008eoo`03O01oogoo03Ioo`03O01oogoo05Moo`00SGoo00=l07ooOol0=Woo
00=l07ooOol0Egoo002>Ool00g`0Oomoo`0eOol00g`0Oomoo`1GOol008ioo`03O01oogoo03Eoo`03
O01oogoo05Moo`00Sgoo00=l07ooOol0=7oo00=l07ooOol0Egoo002@Ool00g`0Oomoo`0cOol00g`0
Oomoo`1GOol0095oo`03O01oogoo039oo`03O01oogoo05Moo`00TWoo00=l07ooOol0<Goo00=l07oo
Ool0Egoo002COol00g`0Oomoo`0`Ool00g`0Oomoo`1GOol009Aoo`03O01oogoo02moo`03O01oogoo
05Moo`00UGoo00=l07ooOol0;Woo00=l07ooOol0Egoo002EOol00g`0Oomoo`0^Ool00g`0Oomoo`1G
Ool009Ioo`03O01oogoo02aoo`03O01oogoo05Qoo`00Ugoo00=l07ooOol0:goo00=l07ooOol0F7oo
002HOol00g`0Oomoo`0ZOol00g`0Oomoo`1HOol009Uoo`9l02Yoo`03O01oogoo05Qoo`00Vgoo00=l
07ooOol09Woo00=l07ooOol0FGoo002LOol00g`0Oomoo`0UOol00g`0Oomoo`1IOol009eoo`03O01o
ogoo02Aoo`03O01oogoo05Uoo`00WWoo00=l07ooOol08Woo00=l07ooOol0FWoo002OOol00g`0Oomo
o`0QOol00g`0Oomoo`1JOol00:1oo`03O01oogoo01moo`03O01oogoo05]oo`00XGoo0W`07goo00=l
07ooOol0Fgoo002SOol00g`0Oomoo`0KOol00g`0Oomoo`1LOol00:Aoo`9l01]oo`03O01oogoo05ao
o`00YWoo00=l07ooOol05goo00=l07ooOol0GGoo002WOol2O00EOol2O01POol00:Uoo`9l019oo`03
O01oogoo061oo`00Zgoo0W`03Goo0g`0Hgoo002]Ool3O007Ool3O01VOol00;1oo`Ml06Uoo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.41033 .55171 m
.42226 .57288 L
s
.39897 .53022 m
.41033 .55171 L
s
.38822 .50851 m
.39897 .53022 L
s
.42226 .57288 m
.43471 .59363 L
s
.37814 .48666 m
.38822 .50851 L
s
.43471 .59363 m
.44762 .61387 L
s
.36878 .46479 m
.37814 .48666 L
s
.44762 .61387 m
.46093 .6335 L
s
.3602 .44299 m
.36878 .46479 L
s
.46093 .6335 m
.47459 .65243 L
s
.35243 .42136 m
.3602 .44299 L
s
.47459 .65243 m
.48854 .67055 L
s
.34553 .40001 m
.35243 .42136 L
s
.48854 .67055 m
.50271 .68777 L
s
.33954 .37905 m
.34553 .40001 L
s
.50271 .68777 m
.51705 .70399 L
s
.33452 .35858 m
.33954 .37905 L
s
.51705 .70399 m
.53147 .71911 L
s
.33051 .33874 m
.33452 .35858 L
s
.53147 .71911 m
.54591 .73302 L
s
.32756 .31963 m
.33051 .33874 L
s
.54591 .73302 m
.56029 .74561 L
s
.3257 .30138 m
.32756 .31963 L
s
.56029 .74561 m
.57454 .7568 L
s
.32499 .28412 m
.3257 .30138 L
s
.57454 .7568 m
.58856 .76646 L
s
.32546 .26798 m
.32499 .28412 L
s
.58856 .76646 m
.60226 .7745 L
s
.32715 .25309 m
.32546 .26798 L
s
.60226 .7745 m
.61556 .78082 L
s
.33007 .23959 m
.32715 .25309 L
s
.61556 .78082 m
.62835 .78532 L
s
.33427 .22761 m
.33007 .23959 L
s
.62835 .78532 m
.64054 .7879 L
s
.33976 .21729 m
.33427 .22761 L
s
.64054 .7879 m
.65201 .78848 L
s
.34654 .20876 m
.33976 .21729 L
s
.65201 .78848 m
.66266 .78698 L
s
.35461 .20216 m
.34654 .20876 L
s
.66266 .78698 m
.67238 .78333 L
s
.36396 .1976 m
.35461 .20216 L
s
.67238 .78333 m
.68106 .77748 L
s
.37457 .1952 m
.36396 .1976 L
s
.68106 .77748 m
.6886 .7694 L
s
.3864 .19506 m
.37457 .1952 L
s
.6886 .7694 m
.69488 .75906 L
s
.39939 .19726 m
.3864 .19506 L
s
.69488 .75906 m
.69981 .74647 L
s
.41347 .20187 m
.39939 .19726 L
s
.69981 .74647 m
.7033 .73167 L
s
.42855 .20893 m
.41347 .20187 L
s
.7033 .73167 m
.70526 .7147 L
s
.44453 .21847 m
.42855 .20893 L
s
.70526 .7147 m
.70563 .69565 L
s
.46129 .23046 m
.44453 .21847 L
s
.70563 .69565 m
.70435 .67463 L
s
.47868 .24487 m
.46129 .23046 L
s
.70435 .67463 m
.70138 .65181 L
s
.49656 .26161 m
.47868 .24487 L
s
.70138 .65181 m
.69672 .62734 L
s
.51474 .28059 m
.49656 .26161 L
s
.69672 .62734 m
.69036 .60144 L
s
.53306 .30165 m
.51474 .28059 L
s
.69036 .60144 m
.68233 .57436 L
s
.55132 .32462 m
.53306 .30165 L
s
.68233 .57436 m
.6727 .54634 L
s
.56933 .34927 m
.55132 .32462 L
s
.6727 .54634 m
.66152 .51768 L
s
.58689 .37538 m
.56933 .34927 L
s
.66152 .51768 m
.64891 .48867 L
s
.60381 .40267 m
.58689 .37538 L
s
.64891 .48867 m
.63499 .45962 L
s
.61991 .43085 m
.60381 .40267 L
s
.63499 .45962 m
.61991 .43085 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol006eoo`=l0;1oo`00J7oo1G`00goo17`0[7oo001VOol2O00<Ool3O02YOol0
06Eoo`03O01oogoo00moo`9l0:Moo`00Hgoo0W`057oo0W`0YGoo001ROol00g`0Oomoo`0FOol2O02S
Ool0069oo`03O01oogoo01Qoo`9l0:5oo`00HGoo00=l07ooOol06goo00=l07ooOol0WWoo001POol0
0g`0Oomoo`0MOol00g`0Oomoo`2MOol0061oo`03O01oogoo01ioo`9l09eoo`00Ggoo00=l07ooOol0
8Goo00=l07ooOol0VWoo001OOol00g`0Oomoo`0ROol00g`0Oomoo`2IOol005ioo`03O01oogoo02Ao
o`03O01oogoo09Qoo`00GWoo00=l07ooOol09Goo0W`0V7oo001NOol00g`0Oomoo`0WOol00g`0Oomo
o`2EOol005eoo`03O01oogoo02Uoo`03O01oogoo09Aoo`00GGoo00=l07ooOol0:Woo00=l07ooOol0
Tgoo001MOol00g`0Oomoo`0[Ool00g`0Oomoo`2BOol005eoo`03O01oogoo02aoo`03O01oogoo095o
o`00GGoo00=l07ooOol0;Goo00=l07ooOol0T7oo001MOol00g`0Oomoo`0^Ool00g`0Oomoo`2?Ool0
05eoo`03O01oogoo02moo`03O01oogoo08ioo`00GGoo00=l07ooOol0<7oo00=l07ooOol0SGoo001M
Ool00g`0Oomoo`0aOol00g`0Oomoo`2<Ool005eoo`03O01oogoo039oo`03O01oogoo08]oo`00GGoo
00=l07ooOol0<goo00=l07ooOol0RWoo001MOol00g`0Oomoo`0dOol00g`0Oomoo`29Ool005eoo`03
O01oogoo03Eoo`03O01oogoo08Qoo`00GGoo00=l07ooOol0=Goo00=l07ooOol0R7oo001MOol00g`0
Oomoo`0fOol00g`0Oomoo`27Ool005eoo`03O01oogoo03Moo`03O01oogoo08Ioo`00GGoo00=l07oo
Ool0>7oo00=l07ooOol0QGoo001MOol00g`0Oomoo`0iOol00g`0Oomoo`24Ool005eoo`03O01oogoo
03Yoo`03O01oogoo08=oo`00GWoo00=l07ooOol0>Woo00=l07ooOol0PWoo001NOol00g`0Oomoo`0j
Ool00g`0Oomoo`22Ool005ioo`03O01oogoo03]oo`03O01oogoo085oo`00GWoo00=l07ooOol0?7oo
00=l07ooOol0P7oo001NOol00g`0Oomoo`0mOol00g`0Oomoo`1oOol005ioo`03O01oogoo03ioo`03
O01oogoo07ioo`00GWoo00=l07ooOol0?Woo00=l07ooOol0OWoo001NOol00g`0Oomoo`0oOol00g`0
Oomoo`1mOol005ioo`03O01oogoo041oo`03O01oogoo07aoo`00GWoo00=l07ooOol0@Goo00=l07oo
Ool0Ngoo001OOol00g`0Oomoo`10Ool00g`0Oomoo`1kOol005moo`03O01oogoo045oo`03O01oogoo
07Yoo`00H7oo00=l07ooOol0@Goo00=l07ooOol0NGoo001POol00g`0Oomoo`11Ool00g`0Oomoo`1i
Ool0061oo`03O01oogoo049oo`03O01oogoo07Qoo`00H7oo00=l07ooOol0@goo00=l07ooOol0Mgoo
001POol00g`0Oomoo`14Ool00g`0Oomoo`1fOol0065oo`03O01oogoo04=oo`03O01oogoo07Ioo`00
HGoo00=l07ooOol0A7oo00=l07ooOol0MGoo001QOol00g`0Oomoo`15Ool00g`0Oomoo`1dOol0065o
o`03O01oogoo04Eoo`03O01oogoo07Aoo`00HWoo00=l07ooOol0AGoo00=l07ooOol0Lgoo001ROol0
0g`0Oomoo`15Ool00g`0Oomoo`1cOol0069oo`03O01oogoo04Ioo`03O01oogoo079oo`00Hgoo00=l
07ooOol0AWoo00=l07ooOol0LGoo001SOol00g`0Oomoo`16Ool00g`0Oomoo`1aOol006=oo`03O01o
ogoo04Moo`03O01oogoo071oo`00I7oo00=l07ooOol0AWoo00=l07ooOol0L7oo001TOol00g`0Oomo
o`17Ool00g`0Oomoo`1_Ool006Aoo`03O01oogoo04Moo`03O01oogoo06moo`00IGoo00=l07ooOol0
Agoo00=l07ooOol0KWoo001UOol00g`0Oomoo`17Ool00g`0Oomoo`1^Ool006Eoo`03O01oogoo04Qo
o`03O01oogoo06eoo`00IWoo00=l07ooOol0Agoo00=l07ooOol0KGoo001VOol00g`0Oomoo`18Ool0
0g`0Oomoo`1/Ool006Ioo`03O01oogoo04Uoo`03O01oogoo06]oo`00IWoo00=l07ooOol0BGoo00=l
07ooOol0Jgoo001WOol00g`0Oomoo`19Ool00g`0Oomoo`1ZOol006Moo`03O01oogoo04Uoo`03O01o
ogoo06Yoo`00Igoo00=l07ooOol0BWoo00=l07ooOol0JGoo001XOol00g`0Oomoo`1:Ool00g`0Oomo
o`1XOol006Qoo`03O01oogoo04Yoo`03O01oogoo06Qoo`00J7oo00=l07ooOol0Bgoo00=l07ooOol0
Igoo001YOol00g`0Oomoo`1:Ool00g`0Oomoo`1WOol006Uoo`03O01oogoo04]oo`03O01oogoo06Io
o`00JGoo00=l07ooOol0Bgoo00=l07ooOol0IWoo001ZOol00g`0Oomoo`1;Ool00g`0Oomoo`1UOol0
06Yoo`03O01oogoo04]oo`03O01oogoo06Eoo`00Jgoo00=l07ooOol0Bgoo00=l07ooOol0I7oo001[
Ool00g`0Oomoo`1;Ool00g`0Oomoo`1TOol006aoo`03O01oogoo04]oo`03O01oogoo06=oo`00K7oo
00=l07ooOol0Bgoo00=l07ooOol0Hgoo001]Ool00g`0Oomoo`1:Ool00g`0Oomoo`1SOol006eoo`03
O01oogoo04]oo`03O01oogoo069oo`00KWoo00=l07ooOol0BWoo00=l07ooOol0HWoo001^Ool00g`0
Oomoo`1:Ool00g`0Oomoo`1ROol006moo`03O01oogoo04Yoo`03O01oogoo065oo`00Kgoo00=l07oo
Ool0BWoo00=l07ooOol0HGoo001`Ool00g`0Oomoo`1:Ool00g`0Oomoo`1POol0071oo`03O01oogoo
04Yoo`03O01oogoo061oo`00LGoo00=l07ooOol0BGoo00=l07ooOol0H7oo001aOol00g`0Oomoo`1:
Ool00g`0Oomoo`1OOol0079oo`03O01oogoo04Uoo`03O01oogoo05moo`00LWoo00=l07ooOol0BWoo
00=l07ooOol0GWoo001bOol00g`0Oomoo`1:Ool00g`0Oomoo`1NOol007=oo`03O01oogoo04Yoo`03
O01oogoo05eoo`00Lgoo00=l07ooOol0BWoo00=l07ooOol0GGoo001dOol00g`0Oomoo`1:Ool00g`0
Oomoo`1LOol007Aoo`03O01oogoo04Yoo`03O01oogoo05aoo`00MGoo00=l07ooOol0BGoo00=l07oo
Ool0G7oo001fOol00g`0Oomoo`19Ool00g`0Oomoo`1KOol007Ioo`03O01oogoo04Uoo`03O01oogoo
05]oo`00Mgoo00=l07ooOol0B7oo00=l07ooOol0Fgoo001hOol00g`0Oomoo`17Ool00g`0Oomoo`1K
Ool007Qoo`03O01oogoo04Qoo`03O01oogoo05Yoo`00NGoo00=l07ooOol0Agoo00=l07ooOol0FWoo
001iOol00g`0Oomoo`17Ool00g`0Oomoo`1JOol007Yoo`03O01oogoo04Moo`03O01oogoo05Uoo`00
NWoo00=l07ooOol0Agoo00=l07ooOol0FGoo001kOol00g`0Oomoo`16Ool00g`0Oomoo`1IOol007]o
o`03O01oogoo04Moo`03O01oogoo05Qoo`00O7oo00=l07ooOol0AWoo00=l07ooOol0F7oo001mOol0
0g`0Oomoo`16Ool00g`0Oomoo`1GOol007eoo`03O01oogoo04Ioo`03O01oogoo05Moo`00OWoo00=l
07ooOol0AGoo00=l07ooOol0Egoo001oOol00g`0Oomoo`14Ool00g`0Oomoo`1GOol007moo`03O01o
ogoo04Aoo`03O01oogoo05Moo`00P7oo00=l07ooOol0@goo00=l07ooOol0Egoo0021Ool00g`0Oomo
o`13Ool00g`0Oomoo`1FOol0089oo`03O01oogoo049oo`03O01oogoo05Ioo`00PWoo00=l07ooOol0
@Woo00=l07ooOol0EWoo0023Ool00g`0Oomoo`11Ool00g`0Oomoo`1FOol008Aoo`03O01oogoo041o
o`03O01oogoo05Ioo`00QGoo00=l07ooOol0@7oo00=l07ooOol0EGoo0025Ool00g`0Oomoo`10Ool0
0g`0Oomoo`1EOol008Ioo`03O01oogoo03moo`03O01oogoo05Eoo`00Qgoo00=l07ooOol0?Woo00=l
07ooOol0EGoo0027Ool00g`0Oomoo`0oOol00g`0Oomoo`1DOol008Qoo`03O01oogoo03ioo`03O01o
ogoo05Aoo`00RGoo00=l07ooOol0?Goo00=l07ooOol0E7oo002:Ool00g`0Oomoo`0lOol00g`0Oomo
o`1DOol008Yoo`03O01oogoo03aoo`03O01oogoo05Aoo`00Rgoo00=l07ooOol0?7oo00=l07ooOol0
Dgoo002<Ool00g`0Oomoo`0kOol00g`0Oomoo`1COol008eoo`03O01oogoo03Yoo`03O01oogoo05=o
o`00SWoo00=l07ooOol0>Goo00=l07ooOol0Dgoo002>Ool00g`0Oomoo`0iOol00g`0Oomoo`1COol0
08moo`03O01oogoo03Qoo`03O01oogoo05=oo`00T7oo00=l07ooOol0=goo00=l07ooOol0Dgoo002A
Ool00g`0Oomoo`0fOol00g`0Oomoo`1COol0099oo`03O01oogoo03Eoo`03O01oogoo05=oo`00TWoo
00=l07ooOol0=Goo00=l07ooOol0Dgoo002COol00g`0Oomoo`0dOol00g`0Oomoo`1COol009Aoo`03
O01oogoo03=oo`03O01oogoo05=oo`00UGoo00=l07ooOol0<Woo00=l07ooOol0Dgoo002FOol00g`0
Oomoo`0aOol00g`0Oomoo`1COol009Moo`03O01oogoo031oo`03O01oogoo05=oo`00V7oo00=l07oo
Ool0;goo00=l07ooOol0Dgoo002IOol00g`0Oomoo`0]Ool00g`0Oomoo`1DOol009Yoo`03O01oogoo
02aoo`03O01oogoo05Aoo`00Vgoo00=l07ooOol0:goo00=l07ooOol0E7oo002LOol00g`0Oomoo`0Z
Ool00g`0Oomoo`1DOol009eoo`03O01oogoo02Uoo`03O01oogoo05Aoo`00WWoo0W`0:7oo00=l07oo
Ool0EGoo002POol00g`0Oomoo`0UOol00g`0Oomoo`1EOol00:5oo`03O01oogoo02Aoo`03O01oogoo
05Eoo`00XWoo00=l07ooOol08goo00=l07ooOol0EGoo002SOol00g`0Oomoo`0QOol00g`0Oomoo`1F
Ool00:Aoo`03O01oogoo021oo`03O01oogoo05Ioo`00YGoo0W`07goo00=l07ooOol0Egoo002WOol2
O00MOol00g`0Oomoo`1GOol00:Uoo`03O01oogoo01Uoo`03O01oogoo05Qoo`00ZWoo0W`067oo00=l
07ooOol0FGoo002/Ool00g`0Oomoo`0EOol00g`0Oomoo`1IOol00:eoo`9l01=oo`9l05aoo`00[goo
0g`03Woo0W`0GWoo002bOol4O007Ool3O01POol00;Ioo`Ml06=oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.4166 .55161 m
.43004 .57198 L
s
.40368 .53092 m
.4166 .55161 L
s
.43004 .57198 m
.44394 .59192 L
s
.39135 .50999 m
.40368 .53092 L
s
.44394 .59192 m
.45825 .61135 L
s
.37966 .48892 m
.39135 .50999 L
s
.45825 .61135 m
.4729 .63018 L
s
.36867 .4678 m
.37966 .48892 L
s
.4729 .63018 m
.48782 .6483 L
s
.35845 .44674 m
.36867 .4678 L
s
.48782 .6483 m
.50295 .66563 L
s
.34904 .42583 m
.35845 .44674 L
s
.50295 .66563 m
.51822 .68208 L
s
.3405 .40518 m
.34904 .42583 L
s
.51822 .68208 m
.53355 .69754 L
s
.3329 .38489 m
.3405 .40518 L
s
.53355 .69754 m
.54887 .71191 L
s
.32628 .36508 m
.3329 .38489 L
s
.54887 .71191 m
.5641 .72511 L
s
.32071 .34585 m
.32628 .36508 L
s
.5641 .72511 m
.57916 .73703 L
s
.31623 .32733 m
.32071 .34585 L
s
.57916 .73703 m
.59395 .74758 L
s
.31291 .30963 m
.31623 .32733 L
s
.59395 .74758 m
.60839 .75665 L
s
.3108 .29288 m
.31291 .30963 L
s
.60839 .75665 m
.62239 .76415 L
s
.30993 .2772 m
.3108 .29288 L
s
.62239 .76415 m
.63583 .76998 L
s
.31037 .26274 m
.30993 .2772 L
s
.63583 .76998 m
.64862 .77406 L
s
.31214 .24961 m
.31037 .26274 L
s
.64862 .77406 m
.66066 .77629 L
s
.31528 .23795 m
.31214 .24961 L
s
.66066 .77629 m
.67183 .7766 L
s
.31983 .22789 m
.31528 .23795 L
s
.67183 .7766 m
.68203 .77491 L
s
.32578 .21957 m
.31983 .22789 L
s
.68203 .77491 m
.69114 .77116 L
s
.33317 .2131 m
.32578 .21957 L
s
.69114 .77116 m
.69905 .76531 L
s
.34197 .20861 m
.33317 .2131 L
s
.69905 .76531 m
.70567 .75733 L
s
.35218 .20619 m
.34197 .20861 L
s
.70567 .75733 m
.71088 .74719 L
s
.36376 .20596 m
.35218 .20619 L
s
.71088 .74719 m
.71459 .73492 L
s
.37667 .20798 m
.36376 .20596 L
s
.71459 .73492 m
.71672 .72053 L
s
.39083 .21233 m
.37667 .20798 L
s
.71672 .72053 m
.7172 .70409 L
s
.40617 .21904 m
.39083 .21233 L
s
.7172 .70409 m
.71596 .68568 L
s
.42258 .22812 m
.40617 .21904 L
s
.71596 .68568 m
.71297 .6654 L
s
.43994 .23957 m
.42258 .22812 L
s
.71297 .6654 m
.70819 .64341 L
s
.4581 .25334 m
.43994 .23957 L
s
.70819 .64341 m
.70164 .61987 L
s
.47692 .26936 m
.4581 .25334 L
s
.70164 .61987 m
.69332 .59498 L
s
.49621 .28752 m
.47692 .26936 L
s
.69332 .59498 m
.6833 .56897 L
s
.51579 .30768 m
.49621 .28752 L
s
.6833 .56897 m
.67163 .54208 L
s
.53546 .32966 m
.51579 .30768 L
s
.67163 .54208 m
.65843 .51459 L
s
.55501 .35327 m
.53546 .32966 L
s
.65843 .51459 m
.6438 .48678 L
s
.57424 .37826 m
.55501 .35327 L
s
.6438 .48678 m
.6279 .45895 L
s
.59293 .40439 m
.57424 .37826 L
s
.6279 .45895 m
.61088 .43138 L
s
.61088 .43138 m
.59293 .40439 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00HWoo37`0/Woo001P
Ool2O00<Ool3O02_Ool005moo`03O01oogoo00moo`9l0:eoo`00GWoo00=l07ooOol04Woo0W`0Zgoo
001MOol00g`0Oomoo`0EOol2O02YOol005aoo`03O01oogoo01Qoo`9l0:Moo`00Fgoo00=l07ooOol0
6goo00=l07ooOol0Y7oo001KOol00g`0Oomoo`0LOol2O02TOol005Yoo`03O01oogoo01moo`9l0:9o
o`00FWoo00=l07ooOol08Goo00=l07ooOol0Wgoo001JOol00g`0Oomoo`0ROol00g`0Oomoo`2NOol0
05Uoo`03O01oogoo02Aoo`9l09ioo`00FGoo00=l07ooOol09Woo00=l07ooOol0Vgoo001IOol00g`0
Oomoo`0WOol00g`0Oomoo`2JOol005Uoo`03O01oogoo02Qoo`03O01oogoo09Uoo`00FGoo00=l07oo
Ool0:Goo00=l07ooOol0V7oo001IOol00g`0Oomoo`0ZOol00g`0Oomoo`2GOol005Uoo`03O01oogoo
02]oo`03O01oogoo09Ioo`00F7oo00=l07ooOol0;Goo00=l07ooOol0UGoo001HOol00g`0Oomoo`0^
Ool00g`0Oomoo`2DOol005Qoo`03O01oogoo02moo`03O01oogoo09=oo`00F7oo00=l07ooOol0<7oo
0W`0Tgoo001HOol00g`0Oomoo`0bOol00g`0Oomoo`2@Ool005Uoo`03O01oogoo039oo`03O01oogoo
08moo`00FGoo00=l07ooOol0<goo00=l07ooOol0SWoo001IOol00g`0Oomoo`0dOol00g`0Oomoo`2=
Ool005Uoo`03O01oogoo03Eoo`03O01oogoo08aoo`00FGoo00=l07ooOol0=Woo00=l07ooOol0Rgoo
001IOol00g`0Oomoo`0gOol00g`0Oomoo`2:Ool005Uoo`03O01oogoo03Qoo`03O01oogoo08Uoo`00
FGoo00=l07ooOol0>Goo00=l07ooOol0R7oo001IOol00g`0Oomoo`0jOol00g`0Oomoo`27Ool005Yo
o`03O01oogoo03Uoo`03O01oogoo08Moo`00FWoo00=l07ooOol0>Woo00=l07ooOol0QWoo001JOol0
0g`0Oomoo`0kOol00g`0Oomoo`25Ool005Yoo`03O01oogoo03aoo`03O01oogoo08Aoo`00Fgoo00=l
07ooOol0?7oo00=l07ooOol0Pgoo001KOol00g`0Oomoo`0mOol00g`0Oomoo`22Ool005]oo`03O01o
ogoo03ioo`03O01oogoo085oo`00G7oo00=l07ooOol0?Goo00=l07ooOol0PGoo001LOol00g`0Oomo
o`0nOol00g`0Oomoo`20Ool005aoo`03O01oogoo03moo`03O01oogoo07moo`00G7oo00=l07ooOol0
@7oo00=l07ooOol0OWoo001MOol00g`0Oomoo`10Ool00g`0Oomoo`1mOol005eoo`03O01oogoo041o
o`03O01oogoo07eoo`00GGoo00=l07ooOol0@Goo00=l07ooOol0O7oo001MOol00g`0Oomoo`12Ool0
0g`0Oomoo`1kOol005ioo`03O01oogoo049oo`03O01oogoo07Yoo`00GWoo00=l07ooOol0@Woo00=l
07ooOol0NWoo001NOol00g`0Oomoo`13Ool00g`0Oomoo`1iOol005moo`03O01oogoo04=oo`03O01o
ogoo07Qoo`00Ggoo00=l07ooOol0@goo00=l07ooOol0N7oo001OOol00g`0Oomoo`14Ool00g`0Oomo
o`1gOol0061oo`03O01oogoo04Aoo`03O01oogoo07Ioo`00H7oo00=l07ooOol0AGoo00=l07ooOol0
MGoo001POol00g`0Oomoo`15Ool00g`0Oomoo`1eOol0065oo`03O01oogoo04Eoo`03O01oogoo07Ao
o`00HGoo00=l07ooOol0AWoo00=l07ooOol0Lgoo001QOol00g`0Oomoo`17Ool00g`0Oomoo`1bOol0
069oo`03O01oogoo04Ioo`03O01oogoo079oo`00HWoo00=l07ooOol0Agoo00=l07ooOol0LGoo001S
Ool00g`0Oomoo`17Ool00g`0Oomoo`1`Ool006=oo`03O01oogoo04Qoo`03O01oogoo06moo`00I7oo
00=l07ooOol0Agoo00=l07ooOol0Kgoo001TOol00g`0Oomoo`18Ool00g`0Oomoo`1^Ool006Eoo`03
O01oogoo04Qoo`03O01oogoo06eoo`00IGoo00=l07ooOol0B7oo00=l07ooOol0KGoo001UOol00g`0
Oomoo`19Ool00g`0Oomoo`1/Ool006Ioo`03O01oogoo04Qoo`03O01oogoo06aoo`00IWoo00=l07oo
Ool0BGoo00=l07ooOol0Jgoo001VOol00g`0Oomoo`1:Ool00g`0Oomoo`1ZOol006Moo`03O01oogoo
04Uoo`03O01oogoo06Yoo`00Igoo00=l07ooOol0BWoo00=l07ooOol0JGoo001XOol00g`0Oomoo`19
Ool00g`0Oomoo`1YOol006Qoo`03O01oogoo04Yoo`03O01oogoo06Qoo`00JGoo00=l07ooOol0BGoo
00=l07ooOol0J7oo001YOol00g`0Oomoo`1:Ool00g`0Oomoo`1WOol006Yoo`03O01oogoo04Uoo`03
O01oogoo06Moo`00JWoo00=l07ooOol0BWoo00=l07ooOol0IWoo001[Ool00g`0Oomoo`19Ool00g`0
Oomoo`1VOol006]oo`03O01oogoo04Yoo`03O01oogoo06Eoo`00K7oo00=l07ooOol0BGoo00=l07oo
Ool0IGoo001]Ool00g`0Oomoo`19Ool00g`0Oomoo`1TOol006eoo`03O01oogoo04Uoo`03O01oogoo
06Aoo`00KWoo00=l07ooOol0BGoo00=l07ooOol0Hgoo001_Ool00g`0Oomoo`18Ool00g`0Oomoo`1S
Ool006moo`03O01oogoo04Uoo`03O01oogoo069oo`00L7oo00=l07ooOol0B7oo00=l07ooOol0HWoo
001`Ool00g`0Oomoo`19Ool00g`0Oomoo`1QOol0075oo`03O01oogoo04Qoo`03O01oogoo065oo`00
LGoo00=l07ooOol0BGoo00=l07ooOol0H7oo001bOol00g`0Oomoo`18Ool00g`0Oomoo`1POol0079o
o`03O01oogoo04Uoo`03O01oogoo05moo`00Lgoo00=l07ooOol0B7oo00=l07ooOol0Ggoo001dOol0
0g`0Oomoo`18Ool00g`0Oomoo`1NOol007Aoo`03O01oogoo04Qoo`03O01oogoo05ioo`00MGoo00=l
07ooOol0B7oo00=l07ooOol0GGoo001fOol00g`0Oomoo`17Ool00g`0Oomoo`1MOol007Ioo`03O01o
ogoo04Qoo`03O01oogoo05aoo`00Mgoo00=l07ooOol0Agoo00=l07ooOol0G7oo001hOol00g`0Oomo
o`17Ool00g`0Oomoo`1KOol007Qoo`03O01oogoo04Moo`03O01oogoo05]oo`00NGoo00=l07ooOol0
Agoo00=l07ooOol0FWoo001jOol00g`0Oomoo`16Ool00g`0Oomoo`1JOol007Yoo`03O01oogoo04Mo
o`03O01oogoo05Uoo`00Ngoo00=l07ooOol0AWoo00=l07ooOol0FGoo001lOol00g`0Oomoo`16Ool0
0g`0Oomoo`1HOol007eoo`03O01oogoo04Eoo`03O01oogoo05Qoo`00OGoo00=l07ooOol0AGoo00=l
07ooOol0F7oo001nOol00g`0Oomoo`14Ool00g`0Oomoo`1HOol007moo`03O01oogoo04Aoo`03O01o
ogoo05Moo`00P7oo00=l07ooOol0@goo00=l07ooOol0Egoo0020Ool00g`0Oomoo`13Ool00g`0Oomo
o`1GOol0085oo`03O01oogoo04=oo`03O01oogoo05Ioo`00PWoo00=l07ooOol0@Woo00=l07ooOol0
EWoo0022Ool00g`0Oomoo`13Ool00g`0Oomoo`1EOol008=oo`03O01oogoo049oo`03O01oogoo05Eo
o`00Q7oo00=l07ooOol0@Woo00=l07ooOol0E7oo0025Ool00g`0Oomoo`11Ool00g`0Oomoo`1DOol0
08Eoo`03O01oogoo045oo`03O01oogoo05Aoo`00QWoo00=l07ooOol0@Goo00=l07ooOol0Dgoo0027
Ool00g`0Oomoo`10Ool00g`0Oomoo`1COol008Qoo`03O01oogoo03moo`03O01oogoo05=oo`00RGoo
00=l07ooOol0?Woo00=l07ooOol0Dgoo0029Ool00g`0Oomoo`0oOol00g`0Oomoo`1BOol008Yoo`03
O01oogoo03ioo`03O01oogoo059oo`00Rgoo00=l07ooOol0?Goo00=l07ooOol0DWoo002<Ool00g`0
Oomoo`0lOol00g`0Oomoo`1BOol008eoo`03O01oogoo03]oo`03O01oogoo059oo`00SWoo00=l07oo
Ool0>goo00=l07ooOol0DGoo002>Ool00g`0Oomoo`0kOol00g`0Oomoo`1AOol008moo`03O01oogoo
03Yoo`03O01oogoo055oo`00T7oo00=l07ooOol0>Goo00=l07ooOol0DGoo002AOol00g`0Oomoo`0h
Ool00g`0Oomoo`1AOol0099oo`03O01oogoo03Moo`03O01oogoo055oo`00Tgoo00=l07ooOol0=goo
00=l07ooOol0D7oo002DOol00g`0Oomoo`0fOol00g`0Oomoo`1@Ool009Eoo`03O01oogoo03Eoo`03
O01oogoo051oo`00UWoo00=l07ooOol0=7oo00=l07ooOol0D7oo002GOol00g`0Oomoo`0cOol00g`0
Oomoo`1@Ool009Qoo`03O01oogoo039oo`03O01oogoo051oo`00VGoo00=l07ooOol0<Goo00=l07oo
Ool0D7oo002JOol00g`0Oomoo`0`Ool00g`0Oomoo`1@Ool009]oo`03O01oogoo02moo`03O01oogoo
051oo`00W7oo00=l07ooOol0;Woo00=l07ooOol0D7oo002MOol00g`0Oomoo`0]Ool00g`0Oomoo`1@
Ool009ioo`03O01oogoo02aoo`03O01oogoo051oo`00Wgoo00=l07ooOol0:goo00=l07ooOol0D7oo
002POol00g`0Oomoo`0ZOol00g`0Oomoo`1@Ool00:5oo`03O01oogoo02Uoo`03O01oogoo051oo`00
XWoo0W`0:Goo00=l07ooOol0D7oo002TOol2O00WOol00g`0Oomoo`1@Ool00:Ioo`03O01oogoo02Ao
o`03O01oogoo051oo`00Ygoo00=l07ooOol08Woo00=l07ooOol0DGoo002XOol2O00ROol00g`0Oomo
o`1AOol00:Yoo`03O01oogoo01moo`03O01oogoo055oo`00Zgoo00=l07ooOol07Goo00=l07ooOol0
DWoo002/Ool2O00MOol00g`0Oomoo`1BOol00:ioo`03O01oogoo01Uoo`03O01oogoo05=oo`00[goo
0W`067oo00=l07ooOol0E7oo002aOol3O00DOol00g`0Oomoo`1EOol00;Aoo`=l011oo`03O01oogoo
05Ioo`00]goo0W`037oo0W`0FGoo002iOol<O01KOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.42428 .55004 m
.43912 .56951 L
s
.40991 .53024 m
.42428 .55004 L
s
.43912 .56951 m
.45437 .58857 L
s
.39609 .51021 m
.40991 .53024 L
s
.45437 .58857 m
.46995 .60712 L
s
.38286 .49004 m
.39609 .51021 L
s
.46995 .60712 m
.4858 .62508 L
s
.37031 .46982 m
.38286 .49004 L
s
.4858 .62508 m
.50185 .64237 L
s
.3585 .44964 m
.37031 .46982 L
s
.50185 .64237 m
.51802 .65888 L
s
.34749 .4296 m
.3585 .44964 L
s
.51802 .65888 m
.53423 .67453 L
s
.33735 .4098 m
.34749 .4296 L
s
.53423 .67453 m
.55041 .68924 L
s
.32814 .39035 m
.33735 .4098 L
s
.55041 .68924 m
.56647 .70289 L
s
.31993 .37134 m
.32814 .39035 L
s
.56647 .70289 m
.58233 .71542 L
s
.31279 .3529 m
.31993 .37134 L
s
.58233 .71542 m
.5979 .72671 L
s
.30677 .33513 m
.31279 .3529 L
s
.5979 .72671 m
.61308 .73668 L
s
.30195 .31814 m
.30677 .33513 L
s
.61308 .73668 m
.62778 .74524 L
s
.29838 .30207 m
.30195 .31814 L
s
.62778 .74524 m
.6419 .75229 L
s
.29612 .28703 m
.29838 .30207 L
s
.6419 .75229 m
.65534 .75775 L
s
.29523 .27314 m
.29612 .28703 L
s
.65534 .75775 m
.66799 .76153 L
s
.29575 .26054 m
.29523 .27314 L
s
.66799 .76153 m
.67973 .76354 L
s
.29774 .24935 m
.29575 .26054 L
s
.67973 .76354 m
.69046 .76372 L
s
.30123 .2397 m
.29774 .24935 L
s
.69046 .76372 m
.70007 .762 L
s
.30624 .23171 m
.30123 .2397 L
s
.70007 .762 m
.70845 .75832 L
s
.3128 .2255 m
.30624 .23171 L
s
.70845 .75832 m
.71548 .75263 L
s
.32091 .22118 m
.3128 .2255 L
s
.71548 .75263 m
.72108 .74492 L
s
.33057 .21886 m
.32091 .22118 L
s
.72108 .74492 m
.72513 .73517 L
s
.34174 .21863 m
.33057 .21886 L
s
.72513 .73517 m
.72754 .72338 L
s
.3544 .22056 m
.34174 .21863 L
s
.72754 .72338 m
.72825 .70959 L
s
.36848 .22471 m
.3544 .22056 L
s
.72825 .70959 m
.72719 .69385 L
s
.38389 .23112 m
.36848 .22471 L
s
.72719 .69385 m
.7243 .67625 L
s
.40056 .2398 m
.38389 .23112 L
s
.7243 .67625 m
.71957 .65688 L
s
.41834 .25074 m
.40056 .2398 L
s
.71957 .65688 m
.71297 .63588 L
s
.43711 .26389 m
.41834 .25074 L
s
.71297 .63588 m
.70453 .61342 L
s
.4567 .27919 m
.43711 .26389 L
s
.70453 .61342 m
.69428 .58968 L
s
.47693 .29653 m
.4567 .27919 L
s
.69428 .58968 m
.68229 .56488 L
s
.49761 .31577 m
.47693 .29653 L
s
.68229 .56488 m
.66865 .53925 L
s
.51853 .33674 m
.49761 .31577 L
s
.66865 .53925 m
.65348 .51305 L
s
.53948 .35926 m
.51853 .33674 L
s
.65348 .51305 m
.63691 .48654 L
s
.56023 .3831 m
.53948 .35926 L
s
.63691 .48654 m
.61911 .46001 L
s
.58057 .40801 m
.56023 .3831 L
s
.61911 .46001 m
.60026 .43374 L
s
.60026 .43374 m
.58057 .40801 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00GWoo1W`0_7oo001KOol3O006Ool3O02iOol005Uoo`9l00aoo`Al0;Eoo`00F7oo
00=l07ooOol047oo0W`0/goo001GOol00g`0Oomoo`0COol2O02aOol005Ioo`03O01oogoo01Ioo`9l
0:moo`00EWoo00=l07ooOol067oo0W`0[Goo001FOol00g`0Oomoo`0JOol2O02[Ool005Eoo`03O01o
ogoo01eoo`9l0:Uoo`00EGoo00=l07ooOol07goo0W`0Ygoo001EOol00g`0Oomoo`0QOol00g`0Oomo
o`2TOol005Aoo`03O01oogoo02=oo`9l0:Aoo`00E7oo00=l07ooOol09Goo00=l07ooOol0XGoo001D
Ool00g`0Oomoo`0VOol00g`0Oomoo`2POol005Aoo`03O01oogoo02Moo`03O01oogoo09moo`00E7oo
00=l07ooOol0:7oo00=l07ooOol0WWoo001DOol00g`0Oomoo`0YOol2O02NOol005Aoo`03O01oogoo
02]oo`03O01oogoo09]oo`00E7oo00=l07ooOol0;7oo00=l07ooOol0VWoo001DOol00g`0Oomoo`0]
Ool00g`0Oomoo`2IOol005Aoo`03O01oogoo02ioo`03O01oogoo09Qoo`00E7oo00=l07ooOol0;goo
00=l07ooOol0Ugoo001DOol00g`0Oomoo`0`Ool00g`0Oomoo`2FOol005Eoo`03O01oogoo031oo`03
O01oogoo09Eoo`00EGoo00=l07ooOol0<Goo00=l07ooOol0U7oo001EOol00g`0Oomoo`0bOol00g`0
Oomoo`2COol005Eoo`03O01oogoo03=oo`9l09=oo`00EWoo00=l07ooOol0=7oo00=l07ooOol0T7oo
001FOol00g`0Oomoo`0eOol00g`0Oomoo`2?Ool005Ioo`03O01oogoo03Ioo`03O01oogoo08ioo`00
EWoo00=l07ooOol0=goo00=l07ooOol0SGoo001GOol00g`0Oomoo`0gOol00g`0Oomoo`2<Ool005Mo
o`03O01oogoo03Qoo`03O01oogoo08]oo`00F7oo00=l07ooOol0>7oo00=l07ooOol0RWoo001HOol0
0g`0Oomoo`0iOol00g`0Oomoo`29Ool005Qoo`03O01oogoo03Yoo`03O01oogoo08Qoo`00F7oo00=l
07ooOol0>goo00=l07ooOol0Qgoo001IOol00g`0Oomoo`0kOol00g`0Oomoo`26Ool005Uoo`03O01o
ogoo03]oo`03O01oogoo08Ioo`00FGoo00=l07ooOol0?7oo00=l07ooOol0QGoo001IOol00g`0Oomo
o`0mOol00g`0Oomoo`24Ool005Yoo`03O01oogoo03eoo`03O01oogoo08=oo`00FWoo00=l07ooOol0
?Woo00=l07ooOol0PWoo001KOol00g`0Oomoo`0nOol00g`0Oomoo`21Ool005]oo`03O01oogoo03mo
o`03O01oogoo081oo`00Fgoo00=l07ooOol0@7oo00=l07ooOol0Ogoo001LOol00g`0Oomoo`10Ool0
0g`0Oomoo`1nOol005aoo`03O01oogoo045oo`03O01oogoo07eoo`00GGoo00=l07ooOol0@Goo00=l
07ooOol0O7oo001MOol00g`0Oomoo`11Ool00g`0Oomoo`1lOol005ioo`03O01oogoo045oo`03O01o
ogoo07]oo`00GWoo00=l07ooOol0@Woo00=l07ooOol0NWoo001OOol00g`0Oomoo`12Ool00g`0Oomo
o`1iOol005moo`03O01oogoo049oo`03O01oogoo07Uoo`00H7oo00=l07ooOol0@Woo00=l07ooOol0
N7oo001POol00g`0Oomoo`13Ool00g`0Oomoo`1gOol0061oo`03O01oogoo04Aoo`03O01oogoo07Io
o`00HGoo00=l07ooOol0A7oo00=l07ooOol0MGoo001QOol00g`0Oomoo`15Ool00g`0Oomoo`1dOol0
069oo`03O01oogoo04Aoo`03O01oogoo07Aoo`00HWoo00=l07ooOol0AGoo00=l07ooOol0Lgoo001S
Ool00g`0Oomoo`15Ool00g`0Oomoo`1bOol006=oo`03O01oogoo04Ioo`03O01oogoo075oo`00I7oo
00=l07ooOol0AWoo00=l07ooOol0L7oo001TOol00g`0Oomoo`16Ool00g`0Oomoo`1`Ool006Eoo`03
O01oogoo04Ioo`03O01oogoo06moo`00IGoo00=l07ooOol0AWoo00=l07ooOol0Kgoo001VOol00g`0
Oomoo`16Ool00g`0Oomoo`1^Ool006Moo`03O01oogoo04Ioo`03O01oogoo06eoo`00J7oo00=l07oo
Ool0AGoo00=l07ooOol0KGoo001XOol00g`0Oomoo`16Ool00g`0Oomoo`1/Ool006Uoo`03O01oogoo
04Ioo`03O01oogoo06]oo`00JWoo00=l07ooOol0AGoo00=l07ooOol0Jgoo001ZOol00g`0Oomoo`16
Ool00g`0Oomoo`1ZOol006]oo`03O01oogoo04Ioo`03O01oogoo06Uoo`00Jgoo00=l07ooOol0Agoo
00=l07ooOol0J7oo001/Ool00g`0Oomoo`16Ool00g`0Oomoo`1XOol006aoo`03O01oogoo04Moo`03
O01oogoo06Moo`00KGoo00=l07ooOol0Agoo00=l07ooOol0IWoo001^Ool00g`0Oomoo`16Ool00g`0
Oomoo`1VOol006ioo`03O01oogoo04Moo`03O01oogoo06Eoo`00Kgoo00=l07ooOol0AWoo00=l07oo
Ool0IGoo001`Ool00g`0Oomoo`16Ool00g`0Oomoo`1TOol0071oo`03O01oogoo04Moo`03O01oogoo
06=oo`00LGoo00=l07ooOol0AWoo00=l07ooOol0Hgoo001bOol00g`0Oomoo`16Ool00g`0Oomoo`1R
Ool0079oo`03O01oogoo04Moo`03O01oogoo065oo`00Lgoo00=l07ooOol0AWoo00=l07ooOol0HGoo
001dOol00g`0Oomoo`16Ool00g`0Oomoo`1POol007Aoo`03O01oogoo04Ioo`03O01oogoo061oo`00
MGoo00=l07ooOol0AWoo00=l07ooOol0Ggoo001fOol00g`0Oomoo`15Ool00g`0Oomoo`1OOol007Mo
o`03O01oogoo04Eoo`03O01oogoo05ioo`00Mgoo00=l07ooOol0AGoo00=l07ooOol0GWoo001hOol0
0g`0Oomoo`15Ool00g`0Oomoo`1MOol007Uoo`03O01oogoo04Aoo`03O01oogoo05eoo`00NWoo00=l
07ooOol0A7oo00=l07ooOol0G7oo001kOol00g`0Oomoo`13Ool00g`0Oomoo`1LOol007]oo`03O01o
ogoo04Aoo`03O01oogoo05]oo`00O7oo00=l07ooOol0@goo00=l07ooOol0Fgoo001mOol00g`0Oomo
o`13Ool00g`0Oomoo`1JOol007ioo`03O01oogoo04=oo`03O01oogoo05Uoo`00Ogoo00=l07ooOol0
@Woo00=l07ooOol0FGoo0020Ool00g`0Oomoo`12Ool00g`0Oomoo`1HOol0081oo`03O01oogoo049o
o`03O01oogoo05Qoo`00PGoo00=l07ooOol0@Woo00=l07ooOol0Egoo0022Ool00g`0Oomoo`11Ool0
0g`0Oomoo`1GOol008=oo`03O01oogoo045oo`03O01oogoo05Ioo`00Pgoo00=l07ooOol0@Goo00=l
07ooOol0EWoo0024Ool00g`0Oomoo`11Ool00g`0Oomoo`1EOol008Eoo`03O01oogoo041oo`03O01o
ogoo05Eoo`00QGoo00=l07ooOol0@Goo00=l07ooOol0E7oo0026Ool00g`0Oomoo`10Ool00g`0Oomo
o`1DOol008Moo`03O01oogoo041oo`03O01oogoo05=oo`00R7oo00=l07ooOol0?goo00=l07ooOol0
Dgoo0029Ool00g`0Oomoo`0nOol00g`0Oomoo`1COol008Yoo`03O01oogoo03ioo`03O01oogoo059o
o`00Rgoo00=l07ooOol0?Goo00=l07ooOol0DWoo002<Ool00g`0Oomoo`0lOol00g`0Oomoo`1BOol0
08eoo`03O01oogoo03aoo`03O01oogoo055oo`00SWoo00=l07ooOol0>goo00=l07ooOol0DGoo002?
Ool00g`0Oomoo`0jOol00g`0Oomoo`1AOol0091oo`03O01oogoo03Yoo`03O01oogoo051oo`00TGoo
00=l07ooOol0>Goo00=l07ooOol0D7oo002BOol00g`0Oomoo`0hOol00g`0Oomoo`1@Ool0099oo`03
O01oogoo03Uoo`03O01oogoo04moo`00Tgoo00=l07ooOol0>7oo00=l07ooOol0Cgoo002DOol00g`0
Oomoo`0gOol00g`0Oomoo`1?Ool009Eoo`03O01oogoo03Ioo`03O01oogoo04moo`00UWoo0W`0=Woo
00=l07ooOol0Cgoo002HOol00g`0Oomoo`0dOol00g`0Oomoo`1>Ool009Uoo`03O01oogoo03=oo`03
O01oogoo04ioo`00VWoo00=l07ooOol0<Woo00=l07ooOol0CWoo002KOol00g`0Oomoo`0aOol00g`0
Oomoo`1>Ool009aoo`03O01oogoo031oo`03O01oogoo04ioo`00WGoo00=l07ooOol0<7oo00=l07oo
Ool0CGoo002NOol00g`0Oomoo`0_Ool00g`0Oomoo`1=Ool009moo`9l02moo`03O01oogoo04eoo`00
XGoo00=l07ooOol0;7oo00=l07ooOol0CGoo002ROol00g`0Oomoo`0[Ool00g`0Oomoo`1=Ool00:=o
o`03O01oogoo02]oo`03O01oogoo04aoo`00Y7oo0W`0:goo00=l07ooOol0C7oo002VOol00g`0Oomo
o`0XOol00g`0Oomoo`1<Ool00:Moo`03O01oogoo02Ioo`03O01oogoo04eoo`00Z7oo00=l07ooOol0
9Goo00=l07ooOol0CGoo002YOol2O00UOol00g`0Oomoo`1=Ool00:]oo`03O01oogoo029oo`03O01o
ogoo04eoo`00[7oo00=l07ooOol08Goo00=l07ooOol0CGoo002]Ool2O00QOol00g`0Oomoo`1=Ool0
0:moo`9l01ioo`03O01oogoo04ioo`00/Goo0W`077oo00=l07ooOol0CWoo002cOol2O00IOol00g`0
Oomoo`1?Ool00;Eoo`9l01Moo`03O01oogoo04moo`00]goo0W`057oo00=l07ooOol0D7oo002iOol2
O00BOol00g`0Oomoo`1@Ool00;]oo`=l00aoo`=l05=oo`00_Woo0g`01goo0W`0EWoo0031Ool7O01H
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.43325 .5468 m
.44936 .56529 L
s
.41755 .528 m
.43325 .5468 L
s
.44936 .56529 m
.4658 .58339 L
s
.40234 .50898 m
.41755 .528 L
s
.4658 .58339 m
.48252 .60102 L
s
.38769 .48982 m
.40234 .50898 L
s
.48252 .60102 m
.49942 .61808 L
s
.37367 .47061 m
.38769 .48982 L
s
.49942 .61808 m
.51644 .6345 L
s
.36035 .45145 m
.37367 .47061 L
s
.51644 .6345 m
.53348 .65018 L
s
.34781 .43243 m
.36035 .45145 L
s
.53348 .65018 m
.55048 .66505 L
s
.33612 .41364 m
.34781 .43243 L
s
.55048 .66505 m
.56734 .67902 L
s
.32536 .39518 m
.33612 .41364 L
s
.56734 .67902 m
.58398 .692 L
s
.31559 .37715 m
.32536 .39518 L
s
.58398 .692 m
.60031 .7039 L
s
.30689 .35966 m
.31559 .37715 L
s
.60031 .7039 m
.61622 .71464 L
s
.29934 .34281 m
.30689 .35966 L
s
.61622 .71464 m
.63164 .72412 L
s
.293 .32671 m
.29934 .34281 L
s
.63164 .72412 m
.64644 .73226 L
s
.28795 .31149 m
.293 .32671 L
s
.64644 .73226 m
.66054 .73898 L
s
.28425 .29725 m
.28795 .31149 L
s
.66054 .73898 m
.67382 .74418 L
s
.28198 .28412 m
.28425 .29725 L
s
.67382 .74418 m
.68617 .7478 L
s
.28119 .27222 m
.28198 .28412 L
s
.68617 .7478 m
.69749 .74974 L
s
.28193 .26167 m
.28119 .27222 L
s
.69749 .74974 m
.70766 .74995 L
s
.28426 .25258 m
.28193 .26167 L
s
.70766 .74995 m
.71656 .74837 L
s
.28822 .24508 m
.28426 .25258 L
s
.71656 .74837 m
.7241 .74492 L
s
.29383 .23927 m
.28822 .24508 L
s
.7241 .74492 m
.73016 .73959 L
s
.30111 .23527 m
.29383 .23927 L
s
.73016 .73959 m
.73464 .73234 L
s
.31006 .23317 m
.30111 .23527 L
s
.73464 .73234 m
.73746 .72315 L
s
.32067 .23306 m
.31006 .23317 L
s
.73746 .72315 m
.73852 .71204 L
s
.33291 .235 m
.32067 .23306 L
s
.73852 .71204 m
.73776 .69904 L
s
.34673 .23905 m
.33291 .235 L
s
.73776 .69904 m
.73513 .68419 L
s
.36205 .24524 m
.34673 .23905 L
s
.73513 .68419 m
.73058 .66758 L
s
.37878 .25359 m
.36205 .24524 L
s
.73058 .66758 m
.7241 .64929 L
s
.39681 .26408 m
.37878 .25359 L
s
.7241 .64929 m
.71569 .62946 L
s
.41599 .27666 m
.39681 .26408 L
s
.71569 .62946 m
.70539 .60824 L
s
.43616 .29126 m
.41599 .27666 L
s
.70539 .60824 m
.69325 .5858 L
s
.45715 .30779 m
.43616 .29126 L
s
.69325 .5858 m
.67935 .56235 L
s
.47875 .32612 m
.45715 .30779 L
s
.67935 .56235 m
.6638 .5381 L
s
.50075 .34607 m
.47875 .32612 L
s
.6638 .5381 m
.64674 .5133 L
s
.52293 .36748 m
.50075 .34607 L
s
.64674 .5133 m
.62833 .48821 L
s
.54506 .39012 m
.52293 .36748 L
s
.62833 .48821 m
.60875 .46307 L
s
.56689 .41377 m
.54506 .39012 L
s
.60875 .46307 m
.58819 .43817 L
s
.58819 .43817 m
.56689 .41377 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001HOol6O032Ool005Ioo`9l
00Ioo`=l0;moo`00E7oo0W`02goo0g`0_7oo001COol00g`0Oomoo`0>Ool2O02jOol0059oo`03O01o
ogoo015oo`=l0;Moo`00DGoo00=l07ooOol05Goo0W`0]Goo001AOol00g`0Oomoo`0GOol2O02cOol0
055oo`03O01oogoo01Uoo`9l0;5oo`00D7oo00=l07ooOol077oo0W`0[goo001@Ool00g`0Oomoo`0N
Ool00g`0Oomoo`2/Ool0051oo`03O01oogoo01moo`9l0:aoo`00D7oo00=l07ooOol08Goo00=l07oo
Ool0ZGoo001@Ool00g`0Oomoo`0ROol2O02YOol0051oo`03O01oogoo02Aoo`03O01oogoo0:Ioo`00
D7oo00=l07ooOol09Goo0W`0YWoo001@Ool00g`0Oomoo`0WOol00g`0Oomoo`2SOol0051oo`03O01o
ogoo02Qoo`9l0:=oo`00D7oo00=l07ooOol0:Woo00=l07ooOol0X7oo001AOol00g`0Oomoo`0ZOol0
0g`0Oomoo`2OOol0055oo`03O01oogoo02]oo`03O01oogoo09ioo`00DGoo00=l07ooOol0;7oo0W`0
WWoo001AOol00g`0Oomoo`0^Ool00g`0Oomoo`2KOol0059oo`03O01oogoo02ioo`03O01oogoo09Yo
o`00DWoo00=l07ooOol0;goo00=l07ooOol0VGoo001BOol00g`0Oomoo`0`Ool00g`0Oomoo`2HOol0
05=oo`03O01oogoo031oo`9l09Qoo`00Dgoo00=l07ooOol0<Woo00=l07ooOol0UGoo001DOol00g`0
Oomoo`0bOol00g`0Oomoo`2DOol005Aoo`03O01oogoo03=oo`03O01oogoo09=oo`00E7oo00=l07oo
Ool0=7oo00=l07ooOol0TWoo001EOol00g`0Oomoo`0dOol00g`0Oomoo`2AOol005Eoo`03O01oogoo
03Eoo`03O01oogoo091oo`00EGoo00=l07ooOol0=Woo00=l07ooOol0Sgoo001FOol00g`0Oomoo`0f
Ool00g`0Oomoo`2>Ool005Ioo`03O01oogoo03Moo`03O01oogoo08eoo`00Egoo00=l07ooOol0=goo
00=l07ooOol0S7oo001GOol00g`0Oomoo`0hOol2O02<Ool005Qoo`03O01oogoo03Uoo`03O01oogoo
08Uoo`00F7oo00=l07ooOol0>Woo00=l07ooOol0R7oo001IOol00g`0Oomoo`0jOol00g`0Oomoo`27
Ool005Uoo`03O01oogoo03]oo`03O01oogoo08Ioo`00FWoo00=l07ooOol0>goo00=l07ooOol0QGoo
001JOol00g`0Oomoo`0lOol00g`0Oomoo`24Ool005]oo`03O01oogoo03aoo`03O01oogoo08=oo`00
Fgoo00=l07ooOol0?Goo00=l07ooOol0PWoo001LOol00g`0Oomoo`0mOol00g`0Oomoo`21Ool005ao
o`03O01oogoo03ioo`03O01oogoo081oo`00GGoo00=l07ooOol0?Woo00=l07ooOol0Ogoo001NOol0
0g`0Oomoo`0nOol00g`0Oomoo`1nOol005ioo`03O01oogoo03ioo`03O01oogoo07ioo`00Ggoo00=l
07ooOol0?Woo00=l07ooOol0OGoo001OOol00g`0Oomoo`0oOol00g`0Oomoo`1lOol0061oo`03O01o
ogoo03moo`03O01oogoo07]oo`00H7oo00=l07ooOol0@7oo00=l07ooOol0NWoo001QOol00g`0Oomo
o`10Ool00g`0Oomoo`1iOol0065oo`03O01oogoo045oo`03O01oogoo07Qoo`00HWoo00=l07ooOol0
@7oo00=l07ooOol0N7oo001ROol00g`0Oomoo`11Ool00g`0Oomoo`1gOol006=oo`03O01oogoo045o
o`03O01oogoo07Ioo`00I7oo00=l07ooOol0@Goo00=l07ooOol0MGoo001UOol00g`0Oomoo`11Ool0
0g`0Oomoo`1dOol006Eoo`03O01oogoo049oo`03O01oogoo07=oo`00IWoo00=l07ooOol0@Woo00=l
07ooOol0LWoo001WOol00g`0Oomoo`11Ool00g`0Oomoo`1bOol006Qoo`03O01oogoo045oo`03O01o
ogoo075oo`00J7oo00=l07ooOol0@Woo00=l07ooOol0L7oo001YOol00g`0Oomoo`12Ool00g`0Oomo
o`1_Ool006Yoo`03O01oogoo049oo`03O01oogoo06ioo`00JWoo00=l07ooOol0@Woo00=l07ooOol0
KWoo001[Ool00g`0Oomoo`12Ool00g`0Oomoo`1]Ool006aoo`03O01oogoo049oo`03O01oogoo06ao
o`00KGoo00=l07ooOol0@Woo00=l07ooOol0Jgoo001]Ool00g`0Oomoo`12Ool00g`0Oomoo`1[Ool0
06ioo`03O01oogoo049oo`03O01oogoo06Yoo`00Kgoo00=l07ooOol0@Woo00=l07ooOol0JGoo001`
Ool00g`0Oomoo`12Ool00g`0Oomoo`1XOol0071oo`03O01oogoo049oo`03O01oogoo06Qoo`00LGoo
00=l07ooOol0@Woo00=l07ooOol0Igoo001bOol00g`0Oomoo`12Ool00g`0Oomoo`1VOol0079oo`03
O01oogoo04=oo`03O01oogoo06Eoo`00Lgoo00=l07ooOol0@Woo00=l07ooOol0IGoo001dOol00g`0
Oomoo`12Ool00g`0Oomoo`1TOol007Eoo`03O01oogoo049oo`03O01oogoo06=oo`00MGoo00=l07oo
Ool0@Woo00=l07ooOol0Hgoo001fOol00g`0Oomoo`12Ool00g`0Oomoo`1ROol007Moo`03O01oogoo
049oo`03O01oogoo065oo`00N7oo00=l07ooOol0@Woo00=l07ooOol0H7oo001iOol00g`0Oomoo`11
Ool00g`0Oomoo`1POol007Yoo`03O01oogoo045oo`03O01oogoo05moo`00Ngoo00=l07ooOol0@Goo
00=l07ooOol0GWoo001lOol00g`0Oomoo`10Ool00g`0Oomoo`1NOol007eoo`03O01oogoo041oo`03
O01oogoo05eoo`00OGoo00=l07ooOol0@7oo00=l07ooOol0GGoo001nOol00g`0Oomoo`10Ool00g`0
Oomoo`1LOol007moo`03O01oogoo03moo`03O01oogoo05aoo`00Ogoo00=l07ooOol0@7oo00=l07oo
Ool0Fgoo0020Ool00g`0Oomoo`10Ool00g`0Oomoo`1JOol0085oo`03O01oogoo03moo`03O01oogoo
05Yoo`00PWoo00=l07ooOol0?goo00=l07ooOol0FGoo0023Ool00g`0Oomoo`0nOol00g`0Oomoo`1I
Ool008Aoo`03O01oogoo03ioo`03O01oogoo05Qoo`00QGoo00=l07ooOol0?Goo00=l07ooOol0F7oo
0026Ool00g`0Oomoo`0mOol00g`0Oomoo`1GOol008Moo`03O01oogoo03eoo`03O01oogoo05Ioo`00
R7oo00=l07ooOol0?7oo00=l07ooOol0EWoo0029Ool00g`0Oomoo`0lOol00g`0Oomoo`1EOol008Yo
o`03O01oogoo03aoo`03O01oogoo05Aoo`00Rgoo00=l07ooOol0>goo00=l07ooOol0E7oo002<Ool0
0g`0Oomoo`0kOol00g`0Oomoo`1COol008eoo`03O01oogoo03Yoo`03O01oogoo05=oo`00SWoo00=l
07ooOol0>Woo00=l07ooOol0DWoo002?Ool00g`0Oomoo`0iOol00g`0Oomoo`1BOol0091oo`03O01o
ogoo03Uoo`03O01oogoo055oo`00TGoo00=l07ooOol0>7oo00=l07ooOol0DGoo002BOol00g`0Oomo
o`0hOol00g`0Oomoo`1@Ool009=oo`03O01oogoo03Moo`03O01oogoo051oo`00U7oo00=l07ooOol0
=goo00=l07ooOol0Cgoo002EOol00g`0Oomoo`0fOol00g`0Oomoo`1?Ool009Ioo`9l03Ioo`03O01o
ogoo04moo`00V7oo00=l07ooOol0=7oo00=l07ooOol0CWoo002IOol00g`0Oomoo`0cOol00g`0Oomo
o`1>Ool009Yoo`03O01oogoo039oo`03O01oogoo04ioo`00Vgoo00=l07ooOol0<Woo00=l07ooOol0
CGoo002LOol00g`0Oomoo`0aOol00g`0Oomoo`1=Ool009eoo`03O01oogoo035oo`03O01oogoo04ao
o`00WWoo00=l07ooOol0<7oo00=l07ooOol0C7oo002OOol2O00`Ool00g`0Oomoo`1<Ool00:5oo`03
O01oogoo02eoo`03O01oogoo04aoo`00XWoo00=l07ooOol0;Goo00=l07ooOol0Bgoo002SOol00g`0
Oomoo`0/Ool00g`0Oomoo`1;Ool00:Aoo`9l02aoo`03O01oogoo04]oo`00YWoo00=l07ooOol0:Goo
00=l07ooOol0Bgoo002WOol00g`0Oomoo`0XOol00g`0Oomoo`1;Ool00:Qoo`03O01oogoo02Qoo`03
O01oogoo04Yoo`00ZGoo0W`0:7oo00=l07ooOol0BWoo002[Ool00g`0Oomoo`0UOol00g`0Oomoo`1:
Ool00:aoo`03O01oogoo02Aoo`03O01oogoo04Yoo`00[Goo00=l07ooOol08goo00=l07ooOol0BWoo
002^Ool2O00SOol00g`0Oomoo`1:Ool00;1oo`9l025oo`03O01oogoo04Yoo`00/Woo0W`07goo00=l
07ooOol0BWoo002dOol2O00MOol00g`0Oomoo`1:Ool00;Ioo`03O01oogoo01Yoo`03O01oogoo04Yo
o`00]goo0W`06Goo00=l07ooOol0Bgoo002iOol00g`0Oomoo`0FOol00g`0Oomoo`1;Ool00;Yoo`9l
01Eoo`03O01oogoo04aoo`00_7oo0g`04Woo00=l07ooOol0C7oo002oOol4O00<Ool2O01?Ool00<=o
o`=l00Moo`9l055oo`00aWoo1g`0Dgoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.44323 .54182 m
.46048 .5593 L
s
.42633 .52407 m
.44323 .54182 L
s
.46048 .5593 m
.478 .57642 L
s
.40985 .50612 m
.42633 .52407 L
s
.478 .57642 m
.49571 .5931 L
s
.39388 .48805 m
.40985 .50612 L
s
.49571 .5931 m
.51352 .60926 L
s
.37849 .46996 m
.39388 .48805 L
s
.51352 .60926 m
.53136 .62483 L
s
.36376 .45192 m
.37849 .46996 L
s
.53136 .62483 m
.54914 .63972 L
s
.34977 .43402 m
.36376 .45192 L
s
.54914 .63972 m
.56677 .65385 L
s
.33661 .41635 m
.34977 .43402 L
s
.56677 .65385 m
.58417 .66714 L
s
.32434 .39901 m
.33661 .41635 L
s
.58417 .66714 m
.60124 .67951 L
s
.31306 .3821 m
.32434 .39901 L
s
.60124 .67951 m
.61789 .69087 L
s
.30285 .3657 m
.31306 .3821 L
s
.61789 .69087 m
.63401 .70114 L
s
.29377 .34992 m
.30285 .3657 L
s
.63401 .70114 m
.64952 .71025 L
s
.28593 .33487 m
.29377 .34992 L
s
.64952 .71025 m
.66429 .7181 L
s
.27939 .32065 m
.28593 .33487 L
s
.66429 .7181 m
.67824 .72461 L
s
.27424 .30738 m
.27939 .32065 L
s
.67824 .72461 m
.69124 .72971 L
s
.27055 .29517 m
.27424 .30738 L
s
.69124 .72971 m
.70318 .73332 L
s
.26839 .28413 m
.27055 .29517 L
s
.70318 .73332 m
.71396 .73536 L
s
.26783 .27438 m
.26839 .28413 L
s
.71396 .73536 m
.72346 .73577 L
s
.26893 .26602 m
.26783 .27438 L
s
.72346 .73577 m
.73157 .73449 L
s
.27174 .25916 m
.26893 .26602 L
s
.73157 .73449 m
.73819 .73147 L
s
.27629 .25392 m
.27174 .25916 L
s
.73819 .73147 m
.7432 .72667 L
s
.28263 .25039 m
.27629 .25392 L
s
.7432 .72667 m
.74651 .72006 L
s
.29075 .24865 m
.28263 .25039 L
s
.74651 .72006 m
.74804 .71163 L
s
.30066 .2488 m
.29075 .24865 L
s
.74804 .71163 m
.74771 .70138 L
s
.31234 .25088 m
.30066 .2488 L
s
.74771 .70138 m
.74545 .68934 L
s
.32574 .25496 m
.31234 .25088 L
s
.74545 .68934 m
.74123 .67556 L
s
.3408 .26105 m
.32574 .25496 L
s
.74123 .67556 m
.73501 .66009 L
s
.35743 .26917 m
.3408 .26105 L
s
.73501 .66009 m
.7268 .64304 L
s
.37552 .2793 m
.35743 .26917 L
s
.7268 .64304 m
.7166 .62453 L
s
.39494 .29139 m
.37552 .2793 L
s
.7166 .62453 m
.70447 .60468 L
s
.41553 .30538 m
.39494 .29139 L
s
.70447 .60468 m
.69049 .58366 L
s
.4371 .32116 m
.41553 .30538 L
s
.69049 .58366 m
.67474 .56167 L
s
.45945 .33861 m
.4371 .32116 L
s
.67474 .56167 m
.65736 .5389 L
s
.48238 .35759 m
.45945 .33861 L
s
.65736 .5389 m
.6385 .51559 L
s
.50563 .3779 m
.48238 .35759 L
s
.6385 .51559 m
.61834 .49197 L
s
.52898 .39936 m
.50563 .3779 L
s
.61834 .49197 m
.59709 .46828 L
s
.55216 .42173 m
.52898 .39936 L
s
.59709 .46828 m
.57495 .44479 L
s
.57495 .44479 m
.55216 .42173 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00DGoo1g`0b7oo001?Ool2O007Ool3O035Ool004ioo`03O01o
ogoo00Yoo`Al0<5oo`00CGoo00=l07ooOol03goo0g`0_Woo001=Ool00g`0Oomoo`0BOol2O02lOol0
04eoo`03O01oogoo01Aoo`9l0;Yoo`00C7oo00=l07ooOol05goo00=l07ooOol0]goo001<Ool00g`0
Oomoo`0HOol2O02gOol004aoo`03O01oogoo01Yoo`9l0;Eoo`00CGoo00=l07ooOol06goo00=l07oo
Ool0/Woo001=Ool00g`0Oomoo`0LOol2O02bOol004eoo`03O01oogoo01ioo`9l0;1oo`00CGoo00=l
07ooOol087oo0W`0[Woo001=Ool00g`0Oomoo`0ROol2O02/Ool004eoo`03O01oogoo02Aoo`03O01o
ogoo0:Uoo`00CGoo00=l07ooOol09Goo0W`0ZGoo001>Ool00g`0Oomoo`0VOol00g`0Oomoo`2VOol0
04ioo`03O01oogoo02Moo`03O01oogoo0:Eoo`00CWoo00=l07ooOol0:7oo00=l07ooOol0Y7oo001?
Ool00g`0Oomoo`0XOol2O02TOol004moo`03O01oogoo02Yoo`03O01oogoo0:5oo`00D7oo00=l07oo
Ool0:Woo00=l07ooOol0X7oo001@Ool00g`0Oomoo`0[Ool00g`0Oomoo`2OOol0055oo`03O01oogoo
02]oo`03O01oogoo09ioo`00DGoo00=l07ooOol0;7oo0W`0WWoo001BOol00g`0Oomoo`0]Ool00g`0
Oomoo`2KOol0059oo`03O01oogoo02ioo`03O01oogoo09Yoo`00Dgoo00=l07ooOol0;Woo0W`0VWoo
001COol00g`0Oomoo`0`Ool00g`0Oomoo`2GOol005Aoo`03O01oogoo031oo`03O01oogoo09Ioo`00
E7oo00=l07ooOol0<Goo0W`0UWoo001EOol00g`0Oomoo`0bOol00g`0Oomoo`2COol005Eoo`03O01o
ogoo03=oo`03O01oogoo099oo`00EWoo00=l07ooOol0<goo00=l07ooOol0TGoo001GOol00g`0Oomo
o`0cOol2O02AOol005Moo`03O01oogoo03Eoo`03O01oogoo08ioo`00F7oo00=l07ooOol0=Goo00=l
07ooOol0SGoo001HOol00g`0Oomoo`0fOol00g`0Oomoo`2<Ool005Uoo`03O01oogoo03Ioo`03O01o
ogoo08]oo`00FWoo00=l07ooOol0=Woo00=l07ooOol0RWoo001KOol00g`0Oomoo`0fOol00g`0Oomo
o`29Ool005]oo`03O01oogoo03Moo`03O01oogoo08Qoo`00G7oo00=l07ooOol0=goo00=l07ooOol0
Qgoo001MOol00g`0Oomoo`0gOol00g`0Oomoo`26Ool005ioo`03O01oogoo03Moo`03O01oogoo08Eo
o`00GWoo00=l07ooOol0>7oo00=l07ooOol0Q7oo001OOol00g`0Oomoo`0hOol00g`0Oomoo`23Ool0
05moo`03O01oogoo03Uoo`03O01oogoo089oo`00H7oo00=l07ooOol0>Goo00=l07ooOol0PGoo001Q
Ool00g`0Oomoo`0iOol00g`0Oomoo`20Ool0069oo`03O01oogoo03Uoo`03O01oogoo07moo`00HWoo
00=l07ooOol0>Woo00=l07ooOol0OWoo001SOol00g`0Oomoo`0jOol00g`0Oomoo`1mOol006Aoo`03
O01oogoo03Yoo`9l07eoo`00IGoo00=l07ooOol0>goo00=l07ooOol0NWoo001VOol00g`0Oomoo`0k
Ool00g`0Oomoo`1iOol006Ioo`03O01oogoo03aoo`03O01oogoo07Qoo`00Igoo00=l07ooOol0?7oo
00=l07ooOol0Mgoo001XOol00g`0Oomoo`0lOol00g`0Oomoo`1fOol006Uoo`03O01oogoo03aoo`03
O01oogoo07Eoo`00JWoo00=l07ooOol0>goo00=l07ooOol0MGoo001ZOol00g`0Oomoo`0lOol00g`0
Oomoo`1dOol006]oo`03O01oogoo03aoo`03O01oogoo07=oo`00K7oo00=l07ooOol0?7oo00=l07oo
Ool0LWoo001]Ool00g`0Oomoo`0lOol00g`0Oomoo`1aOol006ioo`03O01oogoo03aoo`03O01oogoo
071oo`00KWoo00=l07ooOol0?Goo00=l07ooOol0Kgoo001_Ool00g`0Oomoo`0lOol00g`0Oomoo`1_
Ool0071oo`03O01oogoo03aoo`03O01oogoo06ioo`00LGoo00=l07ooOol0?7oo00=l07ooOol0KGoo
001bOol00g`0Oomoo`0lOol00g`0Oomoo`1/Ool007=oo`03O01oogoo03aoo`03O01oogoo06]oo`00
Lgoo00=l07ooOol0?Goo00=l07ooOol0JWoo001dOol00g`0Oomoo`0mOol00g`0Oomoo`1YOol007Eo
o`03O01oogoo03eoo`03O01oogoo06Qoo`00MWoo00=l07ooOol0?Goo00=l07ooOol0Igoo001gOol0
0g`0Oomoo`0mOol00g`0Oomoo`1VOol007Qoo`03O01oogoo03eoo`03O01oogoo06Eoo`00NGoo00=l
07ooOol0?7oo00=l07ooOol0IGoo001jOol00g`0Oomoo`0lOol00g`0Oomoo`1TOol007]oo`03O01o
ogoo03aoo`03O01oogoo06=oo`00O7oo00=l07ooOol0?7oo00=l07ooOol0HWoo001mOol00g`0Oomo
o`0kOol00g`0Oomoo`1ROol007ioo`03O01oogoo03]oo`03O01oogoo065oo`00Ogoo00=l07ooOol0
>goo00=l07ooOol0H7oo0020Ool00g`0Oomoo`0jOol00g`0Oomoo`1POol0085oo`03O01oogoo03Yo
o`03O01oogoo05moo`00PWoo00=l07ooOol0>Woo00=l07ooOol0GWoo0023Ool00g`0Oomoo`0jOol0
0g`0Oomoo`1MOol008Aoo`03O01oogoo03Uoo`03O01oogoo05eoo`00QGoo00=l07ooOol0>Goo00=l
07ooOol0G7oo0026Ool00g`0Oomoo`0iOol00g`0Oomoo`1KOol008Moo`03O01oogoo03Uoo`03O01o
ogoo05Yoo`00R7oo00=l07ooOol0>7oo00=l07ooOol0FWoo0029Ool00g`0Oomoo`0hOol00g`0Oomo
o`1IOol008Yoo`03O01oogoo03Qoo`03O01oogoo05Qoo`00Rgoo00=l07ooOol0>7oo00=l07ooOol0
Egoo002<Ool00g`0Oomoo`0hOol00g`0Oomoo`1FOol008eoo`03O01oogoo03Moo`03O01oogoo05Io
o`00SWoo00=l07ooOol0=goo00=l07ooOol0EGoo002?Ool00g`0Oomoo`0gOol00g`0Oomoo`1DOol0
091oo`9l03Moo`03O01oogoo05Aoo`00TWoo00=l07ooOol0=Goo00=l07ooOol0Dgoo002COol00g`0
Oomoo`0dOol00g`0Oomoo`1COol009Aoo`03O01oogoo03Aoo`03O01oogoo059oo`00UGoo00=l07oo
Ool0<goo00=l07ooOol0DWoo002FOol00g`0Oomoo`0cOol00g`0Oomoo`1AOol009Moo`03O01oogoo
039oo`03O01oogoo055oo`00V7oo00=l07ooOol0<Woo00=l07ooOol0D7oo002IOol00g`0Oomoo`0b
Ool00g`0Oomoo`1?Ool009Yoo`9l039oo`03O01oogoo04moo`00W7oo00=l07ooOol0<7oo00=l07oo
Ool0CWoo002MOol00g`0Oomoo`0_Ool00g`0Oomoo`1>Ool009ioo`03O01oogoo02moo`03O01oogoo
04eoo`00Wgoo0W`0;goo00=l07ooOol0CGoo002QOol00g`0Oomoo`0]Ool00g`0Oomoo`1<Ool00:9o
o`03O01oogoo02aoo`03O01oogoo04aoo`00Xgoo00=l07ooOol0;7oo00=l07ooOol0Bgoo002TOol2
O00/Ool00g`0Oomoo`1;Ool00:Ioo`03O01oogoo02Uoo`03O01oogoo04]oo`00Ygoo00=l07ooOol0
:Goo00=l07ooOol0BWoo002XOol00g`0Oomoo`0XOol00g`0Oomoo`1:Ool00:Uoo`9l02Uoo`03O01o
ogoo04Uoo`00Zgoo00=l07ooOol09Woo00=l07ooOol0BGoo002/Ool00g`0Oomoo`0UOol00g`0Oomo
o`19Ool00:eoo`9l02Ioo`03O01oogoo04Qoo`00[goo0W`097oo00=l07ooOol0B7oo002aOol00g`0
Oomoo`0QOol00g`0Oomoo`18Ool00;9oo`03O01oogoo021oo`03O01oogoo04Qoo`00/goo0W`08Goo
00=l07ooOol0Agoo002eOol2O00OOol00g`0Oomoo`17Ool00;Moo`9l01eoo`03O01oogoo04Moo`00
^Goo0W`06goo00=l07ooOol0Agoo002kOol00g`0Oomoo`0HOol00g`0Oomoo`17Ool00;aoo`9l01Qo
o`03O01oogoo04Moo`00_Woo0W`05Woo00=l07ooOol0Agoo0030Ool3O00BOol00g`0Oomoo`18Ool0
0<=oo`9l011oo`03O01oogoo04Qoo`00aGoo0g`02goo0W`0Bgoo0038Ool3O006Ool2O01=Ool00<]o
o`Il04moo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.45406 .53503 m
.47231 .55147 L
s
.43609 .51836 m
.45406 .53503 L
s
.47231 .55147 m
.49075 .5676 L
s
.41848 .50153 m
.43609 .51836 L
s
.49075 .5676 m
.5093 .58334 L
s
.40131 .48462 m
.41848 .50153 L
s
.5093 .58334 m
.52787 .59862 L
s
.38468 .46771 m
.40131 .48462 L
s
.52787 .59862 m
.54638 .61337 L
s
.36865 .45087 m
.38468 .46771 L
s
.54638 .61337 m
.56474 .6275 L
s
.35332 .4342 m
.36865 .45087 L
s
.56474 .6275 m
.58286 .64095 L
s
.33877 .41776 m
.35332 .4342 L
s
.58286 .64095 m
.60065 .65364 L
s
.32509 .40166 m
.33877 .41776 L
s
.60065 .65364 m
.618 .66548 L
s
.31237 .38598 m
.32509 .40166 L
s
.618 .66548 m
.63482 .67641 L
s
.30069 .37081 m
.31237 .38598 L
s
.63482 .67641 m
.65102 .68633 L
s
.29015 .35624 m
.30069 .37081 L
s
.65102 .68633 m
.66648 .69518 L
s
.28084 .34238 m
.29015 .35624 L
s
.66648 .69518 m
.6811 .70287 L
s
.27283 .32933 m
.28084 .34238 L
s
.6811 .70287 m
.69476 .70933 L
s
.26623 .31719 m
.27283 .32933 L
s
.69476 .70933 m
.70737 .71448 L
s
.26111 .30606 m
.26623 .31719 L
s
.70737 .71448 m
.7188 .71824 L
s
.25756 .29604 m
.26111 .30606 L
s
.7188 .71824 m
.72894 .72055 L
s
.25565 .28725 m
.25756 .29604 L
s
.72894 .72055 m
.73769 .72135 L
s
.25546 .27979 m
.25565 .28725 L
s
.73769 .72135 m
.74493 .72056 L
s
.25705 .27375 m
.25546 .27979 L
s
.74493 .72056 m
.75055 .71814 L
s
.26046 .26924 m
.25705 .27375 L
s
.75055 .71814 m
.75445 .71406 L
s
.26574 .26634 m
.26046 .26924 L
s
.75445 .71406 m
.75655 .70828 L
s
.27292 .26513 m
.26574 .26634 L
s
.75655 .70828 m
.75676 .70079 L
s
.282 .26569 m
.27292 .26513 L
s
.75676 .70079 m
.75501 .69158 L
s
.29297 .26807 m
.282 .26569 L
s
.75501 .69158 m
.75125 .68069 L
s
.3058 .27231 m
.29297 .26807 L
s
.75125 .68069 m
.74544 .66814 L
s
.32044 .27844 m
.3058 .27231 L
s
.74544 .66814 m
.73757 .654 L
s
.3368 .28646 m
.32044 .27844 L
s
.73757 .654 m
.72764 .63834 L
s
.35478 .29635 m
.3368 .28646 L
s
.72764 .63834 m
.7157 .62128 L
s
.37426 .30806 m
.35478 .29635 L
s
.7157 .62128 m
.70181 .60293 L
s
.39508 .32152 m
.37426 .30806 L
s
.70181 .60293 m
.68604 .58346 L
s
.41705 .33665 m
.39508 .32152 L
s
.68604 .58346 m
.66852 .56303 L
s
.43998 .3533 m
.41705 .33665 L
s
.66852 .56303 m
.64941 .54183 L
s
.46364 .37135 m
.43998 .3533 L
s
.64941 .54183 m
.62886 .52008 L
s
.48779 .39061 m
.46364 .37135 L
s
.62886 .52008 m
.60707 .49799 L
s
.51219 .4109 m
.48779 .39061 L
s
.60707 .49799 m
.58427 .47579 L
s
.53658 .43201 m
.51219 .4109 L
s
.58427 .47579 m
.56069 .45372 L
s
.56069 .45372 m
.53658 .43201 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool004aoo`Ul0<]oo`00BWoo0W`02Goo0W`0bGoo0019Ool00g`0Oomoo`0;Ool2O037Ool004Uoo`03
O01oogoo00eoo`=l0<Aoo`00BGoo00=l07ooOol047oo0W`0`Woo0019Ool00g`0Oomoo`0BOol2O030
Ool004Uoo`03O01oogoo01Aoo`03O01oogoo0;eoo`00BGoo00=l07ooOol05Goo0W`0_Goo0019Ool0
0g`0Oomoo`0GOol2O02kOol004Uoo`03O01oogoo01Uoo`03O01oogoo0;Qoo`00BWoo00=l07ooOol0
6Goo0W`0^7oo001:Ool00g`0Oomoo`0KOol2O02fOol004Yoo`03O01oogoo01eoo`9l0;Aoo`00Bgoo
00=l07ooOol07Woo0W`0/Woo001;Ool00g`0Oomoo`0POol00g`0Oomoo`2_Ool004aoo`03O01oogoo
021oo`9l0:moo`00CGoo00=l07ooOol08Goo00=l07ooOol0[7oo001=Ool00g`0Oomoo`0ROol2O02/
Ool004ioo`03O01oogoo02=oo`03O01oogoo0:Uoo`00CWoo00=l07ooOol097oo0W`0ZGoo001?Ool0
0g`0Oomoo`0UOol00g`0Oomoo`2VOol004moo`03O01oogoo02Ioo`9l0:Ioo`00D7oo00=l07ooOol0
9goo00=l07ooOol0Xgoo001AOol00g`0Oomoo`0WOol00g`0Oomoo`2ROol0055oo`03O01oogoo02Qo
o`9l0:9oo`00DWoo00=l07ooOol0:Goo00=l07ooOol0Wgoo001COol00g`0Oomoo`0YOol2O02OOol0
05Aoo`03O01oogoo02Yoo`03O01oogoo09aoo`00E7oo00=l07ooOol0:goo00=l07ooOol0Vgoo001E
Ool00g`0Oomoo`0[Ool2O02KOol005Ioo`03O01oogoo02aoo`03O01oogoo09Qoo`00Egoo00=l07oo
Ool0;7oo00=l07ooOol0Ugoo001GOol00g`0Oomoo`0]Ool00g`0Oomoo`2FOol005Qoo`03O01oogoo
02eoo`03O01oogoo09Eoo`00FGoo00=l07ooOol0;Goo00=l07ooOol0U7oo001JOol00g`0Oomoo`0]
Ool00g`0Oomoo`2COol005]oo`03O01oogoo02eoo`03O01oogoo099oo`00Fgoo00=l07ooOol0;Woo
0W`0TWoo001LOol00g`0Oomoo`0_Ool00g`0Oomoo`2?Ool005eoo`03O01oogoo02moo`9l08moo`00
GWoo00=l07ooOol0<7oo0W`0SGoo001OOol00g`0Oomoo`0aOol00g`0Oomoo`2:Ool0061oo`03O01o
ogoo035oo`03O01oogoo08Uoo`00HGoo00=l07ooOol0<Goo00=l07ooOol0R7oo001ROol00g`0Oomo
o`0aOol2O028Ool006=oo`03O01oogoo039oo`03O01oogoo08Eoo`00Hgoo00=l07ooOol0<goo00=l
07ooOol0Q7oo001TOol00g`0Oomoo`0cOol00g`0Oomoo`23Ool006Eoo`03O01oogoo03=oo`03O01o
ogoo089oo`00IWoo00=l07ooOol0<goo00=l07ooOol0PGoo001WOol00g`0Oomoo`0cOol00g`0Oomo
o`20Ool006Moo`03O01oogoo03=oo`03O01oogoo081oo`00J7oo00=l07ooOol0<goo00=l07ooOol0
Ogoo001YOol00g`0Oomoo`0cOol00g`0Oomoo`1nOol006Yoo`03O01oogoo03=oo`03O01oogoo07eo
o`00Jgoo00=l07ooOol0<goo00=l07ooOol0O7oo001/Ool00g`0Oomoo`0cOol00g`0Oomoo`1kOol0
06eoo`03O01oogoo03=oo`9l07]oo`00KWoo00=l07ooOol0=7oo00=l07ooOol0N7oo001_Ool00g`0
Oomoo`0dOol00g`0Oomoo`1gOol0071oo`03O01oogoo03Aoo`03O01oogoo07Ioo`00LGoo00=l07oo
Ool0=7oo00=l07ooOol0MGoo001bOol00g`0Oomoo`0dOol00g`0Oomoo`1dOol007=oo`03O01oogoo
03Aoo`9l07Aoo`00M7oo00=l07ooOol0=Goo00=l07ooOol0LGoo001eOol2O00fOol00g`0Oomoo`1`
Ool007Moo`03O01oogoo03Aoo`03O01oogoo06moo`00N7oo00=l07ooOol0=7oo00=l07ooOol0KWoo
001iOol00g`0Oomoo`0dOol00g`0Oomoo`1]Ool007Yoo`03O01oogoo03Aoo`03O01oogoo06aoo`00
Ngoo00=l07ooOol0<goo00=l07ooOol0K7oo001lOol00g`0Oomoo`0cOol00g`0Oomoo`1[Ool007eo
o`03O01oogoo03=oo`03O01oogoo06Yoo`00OWoo00=l07ooOol0<goo00=l07ooOol0JGoo001oOol0
0g`0Oomoo`0cOol00g`0Oomoo`1XOol0081oo`03O01oogoo03=oo`03O01oogoo06Moo`00PGoo00=l
07ooOol0<goo00=l07ooOol0IWoo0022Ool00g`0Oomoo`0cOol00g`0Oomoo`1UOol008=oo`03O01o
ogoo03=oo`03O01oogoo06Aoo`00Q7oo00=l07ooOol0<goo00=l07ooOol0Hgoo0025Ool00g`0Oomo
o`0cOol00g`0Oomoo`1ROol008Ioo`03O01oogoo03=oo`03O01oogoo065oo`00Qgoo00=l07ooOol0
<Woo00=l07ooOol0HGoo0028Ool00g`0Oomoo`0bOol00g`0Oomoo`1POol008Uoo`9l03=oo`03O01o
ogoo05moo`00Rgoo00=l07ooOol0<Goo00=l07ooOol0GWoo002<Ool00g`0Oomoo`0aOol00g`0Oomo
o`1MOol008eoo`03O01oogoo035oo`03O01oogoo05aoo`00SWoo00=l07ooOol0<7oo00=l07ooOol0
G7oo002?Ool2O00aOol00g`0Oomoo`1KOol0095oo`03O01oogoo02moo`03O01oogoo05Yoo`00TWoo
00=l07ooOol0;goo00=l07ooOol0FGoo002COol00g`0Oomoo`0_Ool00g`0Oomoo`1HOol009Aoo`9l
031oo`03O01oogoo05Moo`00UWoo00=l07ooOol0;Goo00=l07ooOol0Egoo002GOol00g`0Oomoo`0]
Ool00g`0Oomoo`1FOol009Qoo`03O01oogoo02eoo`03O01oogoo05Eoo`00VGoo00=l07ooOol0;Goo
00=l07ooOol0E7oo002JOol00g`0Oomoo`0]Ool00g`0Oomoo`1COol009]oo`03O01oogoo02eoo`03
O01oogoo059oo`00W7oo00=l07ooOol0;7oo00=l07ooOol0DWoo002MOol2O00]Ool00g`0Oomoo`1A
Ool009moo`03O01oogoo02]oo`03O01oogoo051oo`00X7oo0W`0;7oo00=l07ooOol0Cgoo002ROol0
0g`0Oomoo`0YOol00g`0Oomoo`1?Ool00:=oo`9l02Yoo`03O01oogoo04ioo`00YGoo0W`0:7oo00=l
07ooOol0CWoo002WOol00g`0Oomoo`0VOol00g`0Oomoo`1=Ool00:Qoo`03O01oogoo02Ioo`03O01o
ogoo04aoo`00ZGoo0W`09Woo00=l07ooOol0C7oo002[Ool00g`0Oomoo`0TOol00g`0Oomoo`1;Ool0
0:aoo`03O01oogoo02Aoo`03O01oogoo04Yoo`00[Goo0W`097oo00=l07ooOol0BWoo002_Ool2O00S
Ool00g`0Oomoo`19Ool00;5oo`03O01oogoo021oo`03O01oogoo04Uoo`00/Woo00=l07ooOol087oo
00=l07ooOol0B7oo002cOol2O00POol00g`0Oomoo`18Ool00;Eoo`03O01oogoo01ioo`03O01oogoo
04Moo`00]Woo00=l07ooOol07Goo00=l07ooOol0Agoo002gOol2O00NOol00g`0Oomoo`16Ool00;Uo
o`9l01aoo`03O01oogoo04Ioo`00^goo0W`06goo00=l07ooOol0AGoo002mOol2O00IOol00g`0Oomo
o`15Ool00;moo`03O01oogoo01Ioo`03O01oogoo04Eoo`00`7oo0W`05goo00=l07ooOol0A7oo0032
Ool2O00EOol00g`0Oomoo`14Ool00<Aoo`9l01=oo`03O01oogoo04Aoo`00aWoo0W`04Goo00=l07oo
Ool0A7oo0038Ool2O00>Ool00g`0Oomoo`15Ool00<Yoo`=l00Yoo`03O01oogoo04Ioo`00cGoo1G`0
0goo0g`0B7oo003BOol3O01;Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig3B\  = \ 
        Show[Array[p, {Steps}], ViewPoint \[Rule] {0, 0, 2}];\)\)], "Input",
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.50625 .49375 m
.49375 .50625 L
s
.51873 .48127 m
.50625 .49375 L
s
.49375 .50625 m
.48127 .51873 L
s
.49375 .48446 m
.48129 .49701 L
s
.50626 .47199 m
.49375 .48446 L
s
.48129 .49701 m
.46891 .50959 L
s
.53115 .46885 m
.51873 .48127 L
s
.48127 .51873 m
.46885 .53115 L
s
.51878 .45964 m
.50626 .47199 L
s
.48126 .4753 m
.46891 .48799 L
s
.49373 .46275 m
.48126 .4753 L
s
.46891 .50959 m
.45666 .52218 L
s
.46891 .48799 m
.45671 .50078 L
s
.50628 .45036 m
.49373 .46275 L
s
.45671 .50078 m
.4447 .51363 L
s
.54348 .45652 m
.53115 .46885 L
s
.46885 .53115 m
.45652 .54348 L
s
.53128 .44743 m
.51878 .45964 L
s
.46884 .46645 m
.45667 .47938 L
s
.48119 .45371 m
.46884 .46645 L
s
.45667 .47938 m
.44472 .49245 L
s
.45666 .52218 m
.44457 .53474 L
s
.4937 .4412 m
.48119 .45371 L
s
.51888 .43818 m
.50628 .45036 L
s
.44472 .49245 m
.43303 .50564 L
s
.4447 .51363 m
.43292 .52649 L
s
.50632 .42895 m
.4937 .4412 L
s
.45653 .45806 m
.44462 .47132 L
s
.4687 .44505 m
.45653 .45806 L
s
.54372 .43541 m
.53128 .44743 L
s
.55569 .44431 m
.54348 .45652 L
s
.45652 .54348 m
.44431 .55569 L
s
.44462 .47132 m
.433 .48477 L
s
.48109 .43232 m
.4687 .44505 L
s
.53148 .42625 m
.51888 .43818 L
s
.44457 .53474 m
.43267 .54722 L
s
.43303 .50564 m
.42164 .51891 L
s
.433 .48477 m
.42171 .49838 L
s
.49366 .41991 m
.48109 .43232 L
s
.51902 .41701 m
.50632 .42895 L
s
.43292 .52649 m
.42141 .53934 L
s
.4444 .45031 m
.43282 .46396 L
s
.4563 .43694 m
.4444 .45031 L
s
.43282 .46396 m
.42161 .47786 L
s
.46849 .42391 m
.4563 .43694 L
s
.55606 .42363 m
.54372 .43541 L
s
.42171 .49838 m
.41079 .51212 L
s
.56772 .43228 m
.55569 .44431 L
s
.44431 .55569 m
.43228 .56772 L
s
.54405 .41462 m
.53148 .42625 L
s
.50637 .40787 m
.49366 .41991 L
s
.42164 .51891 m
.41059 .5322 L
s
.42161 .47786 m
.4108 .49197 L
s
.43267 .54722 m
.42102 .55959 L
s
.48094 .41125 m
.46849 .42391 L
s
.53175 .40542 m
.51902 .41701 L
s
.42141 .53934 m
.41021 .55213 L
s
.43251 .44333 m
.42136 .45745 L
s
.44406 .42954 m
.43251 .44333 L
s
.42136 .45745 m
.41064 .47186 L
s
.4108 .49197 m
.40044 .50623 L
s
.45598 .41612 m
.44406 .42954 L
s
.41079 .51212 m
.40027 .52593 L
s
.4936 .399 m
.48094 .41125 L
s
.5192 .39623 m
.50637 .40787 L
s
.41064 .47186 m
.4004 .48651 L
s
.46822 .40312 m
.45598 .41612 L
s
.56825 .41211 m
.55606 .42363 L
s
.41059 .5322 m
.39991 .54549 L
s
.57954 .42046 m
.56772 .43228 L
s
.43228 .56772 m
.42046 .57954 L
s
.55655 .40331 m
.54405 .41462 L
s
.42102 .55959 m
.40965 .5718 L
s
.40044 .50623 m
.39055 .52061 L
s
.54448 .39423 m
.53175 .40542 L
s
.4004 .48651 m
.39067 .50135 L
s
.42094 .43725 m
.4103 .45189 L
s
.43205 .42297 m
.42094 .43725 L
s
.50644 .38722 m
.4936 .399 L
s
.4103 .45189 m
.40016 .46685 L
s
.48075 .39059 m
.46822 .40312 L
s
.44361 .4091 m
.43205 .42297 L
s
.40027 .52593 m
.39021 .53977 L
s
.41021 .55213 m
.39936 .56482 L
s
.40016 .46685 m
.39058 .48208 L
s
.53209 .38505 m
.5192 .39623 L
s
.45556 .3957 m
.44361 .4091 L
s
.39067 .50135 m
.38148 .51633 L
s
.39991 .54549 m
.38967 .55872 L
s
.39058 .48208 m
.38157 .49752 L
s
.49353 .37858 m
.48075 .39059 L
s
.58026 .40092 m
.56825 .41211 L
s
.39055 .52061 m
.38118 .53506 L
s
.56893 .39238 m
.55655 .40331 L
s
.5911 .4089 m
.57954 .42046 L
s
.42046 .57954 m
.4089 .5911 L
s
.40977 .43216 m
.39973 .44736 L
s
.42036 .41735 m
.40977 .43216 L
s
.51942 .37596 m
.50644 .38722 L
s
.39973 .44736 m
.39027 .4629 L
s
.46787 .38281 m
.45556 .3957 L
s
.55716 .38348 m
.54448 .39423 L
s
.43146 .40299 m
.42036 .41735 L
s
.40965 .5718 m
.3986 .58381 L
s
.39027 .4629 m
.38143 .47872 L
s
.39021 .53977 m
.38065 .5536 L
s
.38157 .49752 m
.37318 .51313 L
s
.44303 .38912 m
.43146 .40299 L
s
.545 .37437 m
.53209 .38505 L
s
.38148 .51633 m
.3729 .53142 L
s
.39936 .56482 m
.38891 .57736 L
s
.38143 .47872 m
.37323 .49478 L
s
.48051 .37048 m
.46787 .38281 L
s
.50652 .36714 m
.49353 .37858 L
s
.38976 .44391 m
.38106 .46003 L
s
.3991 .42814 m
.38976 .44391 L
s
.40907 .41278 m
.3991 .42814 L
s
.38118 .53506 m
.37238 .54953 L
s
.45504 .3758 m
.44303 .38912 L
s
.38967 .55872 m
.37989 .57185 L
s
.38106 .46003 m
.37305 .47645 L
s
.53249 .36525 m
.51942 .37596 L
s
.41962 .39788 m
.40907 .41278 L
s
.37323 .49478 m
.36572 .51101 L
s
.37318 .51313 m
.36545 .52886 L
s
.59203 .39009 m
.58026 .40092 L
s
.58114 .38189 m
.56893 .39238 L
s
.60235 .39765 m
.5911 .4089 L
s
.4089 .5911 m
.39765 .60235 L
s
.37305 .47645 m
.36575 .49311 L
s
.56974 .37322 m
.55716 .38348 L
s
.43072 .3835 m
.41962 .39788 L
s
.38065 .5536 m
.37162 .56737 L
s
.3729 .53142 m
.36494 .54655 L
s
.49344 .35877 m
.48051 .37048 L
s
.3986 .58381 m
.38794 .59557 L
s
.46746 .36308 m
.45504 .3758 L
s
.51968 .35631 m
.50652 .36714 L
s
.38047 .44156 m
.37263 .45825 L
s
.38903 .42522 m
.38047 .44156 L
s
.55789 .36425 m
.545 .37437 L
s
.39827 .4093 m
.38903 .42522 L
s
.37263 .45825 m
.36554 .47523 L
s
.36575 .49311 m
.35921 .50994 L
s
.36572 .51101 m
.35894 .52737 L
s
.38891 .57736 m
.37891 .5897 L
s
.44233 .36971 m
.43072 .3835 L
s
.40818 .39386 m
.39827 .4093 L
s
.36554 .47523 m
.35923 .49245 L
s
.37238 .54953 m
.36419 .56397 L
s
.36545 .52886 m
.35843 .54465 L
s
.54562 .35517 m
.53249 .36525 L
s
.37989 .57185 m
.37064 .58482 L
s
.41871 .37895 m
.40818 .39386 L
s
.48024 .35103 m
.46746 .36308 L
s
.35923 .49245 m
.35372 .50984 L
s
.35921 .50994 m
.35345 .5269 L
s
.37198 .44028 m
.36508 .4575 L
s
.37965 .42341 m
.37198 .44028 L
s
.50661 .34774 m
.49344 .35877 L
s
.36508 .4575 m
.35899 .47501 L
s
.45443 .35655 m
.44233 .36971 L
s
.38809 .40694 m
.37965 .42341 L
s
.36494 .54655 m
.35767 .56167 L
s
.35899 .47501 m
.35374 .49273 L
s
.59313 .37187 m
.58114 .38189 L
s
.60351 .37968 m
.59203 .39009 L
s
.35894 .52737 m
.35293 .5438 L
s
.58218 .36351 m
.56974 .37322 L
s
.61325 .38675 m
.60235 .39765 L
s
.39765 .60235 m
.38675 .61325 L
s
.37162 .56737 m
.36319 .58102 L
s
.53297 .34617 m
.51968 .35631 L
s
.39725 .39096 m
.38809 .40694 L
s
.42983 .36464 m
.41871 .37895 L
s
.35374 .49273 m
.34935 .5106 L
s
.35372 .50984 m
.34906 .52734 L
s
.38794 .59557 m
.37771 .60703 L
s
.5707 .35474 m
.55789 .36425 L
s
.35852 .4577 m
.35351 .47565 L
s
.36438 .44001 m
.35852 .4577 L
s
.37109 .42265 m
.36438 .44001 L
s
.35843 .54465 m
.35215 .56044 L
s
.35351 .47565 m
.34938 .4938 L
s
.35345 .5269 m
.34852 .54391 L
s
.40711 .37551 m
.39725 .39096 L
s
.36419 .56397 m
.35667 .57832 L
s
.49334 .33971 m
.48024 .35103 L
s
.37861 .40568 m
.37109 .42265 L
s
.46698 .34409 m
.45443 .35655 L
s
.37891 .5897 m
.36942 .60178 L
s
.34938 .4938 m
.34615 .51206 L
s
.34935 .5106 m
.34584 .52855 L
s
.55874 .34577 m
.54562 .35517 L
s
.51999 .33744 m
.50661 .34774 L
s
.44152 .35099 m
.42983 .36464 L
s
.34916 .47703 m
.34621 .4955 L
s
.35302 .45872 m
.34916 .47703 L
s
.35779 .44064 m
.35302 .45872 L
s
.34906 .52734 m
.34527 .54487 L
s
.35293 .5438 m
.34772 .56022 L
s
.38693 .38919 m
.37861 .40568 L
s
.34621 .4955 m
.3442 .51405 L
s
.36345 .42287 m
.35779 .44064 L
s
.34615 .51206 m
.34385 .53038 L
s
.37064 .58482 m
.36196 .59758 L
s
.35767 .56167 m
.35113 .57671 L
s
.41764 .36068 m
.40711 .37551 L
s
.34601 .47896 m
.34429 .49764 L
s
.34868 .4604 m
.34601 .47896 L
s
.34429 .49764 m
.34352 .51636 L
s
.35229 .44204 m
.34868 .4604 L
s
.3442 .51405 m
.34313 .53262 L
s
.34584 .52855 m
.34324 .54652 L
s
.36997 .40546 m
.36345 .42287 L
s
.54633 .33677 m
.53297 .34617 L
s
.34352 .51636 m
.3437 .53505 L
s
.34852 .54391 m
.34444 .56092 L
s
.39602 .37323 m
.38693 .38919 L
s
.60486 .3624 m
.59313 .37187 L
s
.35682 .42394 m
.35229 .44204 L
s
.61464 .36974 m
.60351 .37968 L
s
.36319 .58102 m
.35541 .59449 L
s
.34385 .53038 m
.34249 .54867 L
s
.59443 .3544 m
.58218 .36351 L
s
.47992 .3324 m
.46698 .34409 L
s
.35215 .56044 m
.34667 .57617 L
s
.45373 .33808 m
.44152 .35099 L
s
.62372 .37628 m
.61325 .38675 L
s
.38675 .61325 m
.37628 .62372 L
s
.3437 .53505 m
.34485 .55363 L
s
.34313 .53262 m
.34302 .55112 L
s
.50672 .32917 m
.49334 .33971 L
s
.37735 .38851 m
.36997 .40546 L
s
.34527 .54487 m
.34238 .56238 L
s
.5834 .34591 m
.5707 .35474 L
s
.42881 .34653 m
.41764 .36068 L
s
.36227 .40618 m
.35682 .42394 L
s
.37771 .60703 m
.36796 .61812 L
s
.35667 .57832 m
.34986 .59252 L
s
.34324 .54652 m
.34159 .56443 L
s
.34772 .56022 m
.34336 .57658 L
s
.53351 .32795 m
.51999 .33744 L
s
.40585 .35788 m
.39602 .37323 L
s
.34485 .55363 m
.34697 .57204 L
s
.34249 .54867 m
.34209 .56688 L
s
.57181 .3371 m
.55874 .34577 L
s
.34302 .55112 m
.34389 .56949 L
s
.36942 .60178 m
.36048 .61355 L
s
.38557 .37208 m
.37735 .38851 L
s
.36862 .38884 m
.36227 .40618 L
s
.34444 .56092 m
.34127 .57784 L
s
.35113 .57671 m
.34537 .59163 L
s
.46642 .32597 m
.45373 .33808 L
s
.49323 .32155 m
.47992 .3324 L
s
.36196 .59758 m
.35392 .61008 L
s
.34697 .57204 m
.35006 .59018 L
s
.44058 .33313 m
.42881 .34653 L
s
.34238 .56238 m
.34043 .57978 L
s
.55971 .32817 m
.54633 .33677 L
s
.4164 .34322 m
.40585 .35788 L
s
.34389 .56949 m
.34574 .58764 L
s
.52034 .31949 m
.50672 .32917 L
s
.34159 .56443 m
.3409 .58221 L
s
.34667 .57617 m
.34203 .59176 L
s
.34209 .56688 m
.34267 .5849 L
s
.39459 .35624 m
.38557 .37208 L
s
.37586 .372 m
.36862 .38884 L
s
.35541 .59449 m
.34834 .60773 L
s
.61625 .35353 m
.60486 .3624 L
s
.62537 .36035 m
.61464 .36974 L
s
.60641 .34596 m
.59443 .3544 L
s
.34336 .57658 m
.3399 .59281 L
s
.35006 .59018 m
.35414 .60798 L
s
.63372 .36628 m
.62372 .37628 L
s
.37628 .62372 m
.36628 .63372 L
s
.5959 .33781 m
.5834 .34591 L
s
.54714 .31932 m
.53351 .32795 L
s
.34986 .59252 m
.34382 .6065 L
s
.34127 .57784 m
.33903 .59462 L
s
.45293 .32055 m
.44058 .33313 L
s
.36796 .61812 m
.35877 .62879 L
s
.47956 .31474 m
.46642 .32597 L
s
.34574 .58764 m
.34858 .60549 L
s
.42763 .32932 m
.4164 .34322 L
s
.58477 .32924 m
.57181 .3371 L
s
.40441 .34109 m
.39459 .35624 L
s
.38399 .35574 m
.37586 .372 L
s
.34043 .57978 m
.33946 .59701 L
s
.50685 .3116 m
.49323 .32155 L
s
.34267 .5849 m
.34425 .60267 L
s
.3409 .58221 m
.3412 .59977 L
s
.34537 .59163 m
.34045 .60634 L
s
.36048 .61355 m
.35218 .62494 L
s
.35414 .60798 m
.35919 .62536 L
s
.53413 .31074 m
.52034 .31949 L
s
.57306 .32044 m
.55971 .32817 L
s
.34203 .59176 m
.33828 .60716 L
s
.35392 .61008 m
.34657 .62223 L
s
.34858 .60549 m
.35243 .62296 L
s
.3399 .59281 m
.33737 .60882 L
s
.39297 .34015 m
.38399 .35574 L
s
.43952 .31626 m
.42763 .32932 L
s
.415 .32671 m
.40441 .34109 L
s
.4658 .30889 m
.45293 .32055 L
s
.34834 .60773 m
.34203 .62066 L
s
.4931 .30445 m
.47956 .31474 L
s
.34425 .60267 m
.34685 .6201 L
s
.33903 .59462 m
.33776 .61116 L
s
.5608 .31163 m
.54714 .31932 L
s
.62725 .34533 m
.61625 .35353 L
s
.61807 .33826 m
.60641 .34596 L
s
.3412 .59977 m
.34252 .61703 L
s
.33946 .59701 m
.33948 .61397 L
s
.63563 .35156 m
.62537 .36035 L
s
.60816 .33051 m
.5959 .33781 L
s
.52073 .30264 m
.50685 .3116 L
s
.35919 .62536 m
.36522 .64221 L
s
.34382 .6065 m
.33862 .6202 L
s
.64317 .35683 m
.63372 .36628 L
s
.36628 .63372 m
.35683 .64317 L
s
.59756 .32224 m
.58477 .32924 L
s
.35877 .62879 m
.3502 .63897 L
s
.34045 .60634 m
.33641 .62077 L
s
.35243 .62296 m
.35729 .63995 L
s
.54804 .30299 m
.53413 .31074 L
s
.40279 .32531 m
.39297 .34015 L
s
.42632 .31317 m
.415 .32671 L
s
.45203 .30413 m
.43952 .31626 L
s
.35218 .62494 m
.34456 .63589 L
s
.58631 .31366 m
.57306 .32044 L
s
.33828 .60716 m
.33547 .62227 L
s
.47916 .29821 m
.4658 .30889 L
s
.34685 .6201 m
.35049 .6371 L
s
.50698 .2952 m
.4931 .30445 L
s
.33737 .60882 m
.33583 .62454 L
s
.36522 .64221 m
.37223 .65846 L
s
.34657 .62223 m
.33999 .63397 L
s
.34252 .61703 m
.34488 .6339 L
s
.33776 .61116 m
.33752 .62738 L
s
.33948 .61397 m
.34054 .63058 L
s
.57445 .30494 m
.5608 .31163 L
s
.53481 .29473 m
.52073 .30264 L
s
.34203 .62066 m
.33654 .6332 L
s
.35729 .63995 m
.36318 .65637 L
s
.41344 .31131 m
.40279 .32531 L
s
.62933 .33136 m
.61807 .33826 L
s
.63777 .33786 m
.62725 .34533 L
s
.43834 .30057 m
.42632 .31317 L
s
.62009 .32408 m
.60816 .33051 L
s
.64535 .34344 m
.63563 .35156 L
s
.33862 .6202 m
.3343 .63353 L
s
.46511 .29302 m
.45203 .30413 L
s
.65201 .34799 m
.64317 .35683 L
s
.35683 .64317 m
.34799 .65201 L
s
.6101 .3162 m
.59756 .32224 L
s
.56202 .29631 m
.54804 .30299 L
s
.35049 .6371 m
.35517 .65357 L
s
.49296 .2886 m
.47916 .29821 L
s
.33641 .62077 m
.33332 .63484 L
s
.37223 .65846 m
.3802 .67401 L
s
.3502 .63897 m
.34232 .64858 L
s
.34488 .6339 m
.34831 .65029 L
s
.52116 .28705 m
.50698 .2952 L
s
.33547 .62227 m
.33365 .63702 L
s
.59939 .30789 m
.58631 .31366 L
s
.33583 .62454 m
.33532 .63987 L
s
.34054 .63058 m
.34267 .64674 L
s
.33752 .62738 m
.33833 .64319 L
s
.34456 .63589 m
.33771 .64632 L
s
.42486 .29826 m
.41344 .31131 L
s
.36318 .65637 m
.37008 .67212 L
s
.54904 .28796 m
.53481 .29473 L
s
.33999 .63397 m
.33424 .64523 L
s
.45103 .28901 m
.43834 .30057 L
s
.58801 .29935 m
.57445 .30494 L
s
.47871 .28301 m
.46511 .29302 L
s
.33654 .6332 m
.33196 .64528 L
s
.35517 .65357 m
.36092 .66942 L
s
.3802 .67401 m
.38914 .68875 L
s
.50713 .28015 m
.49296 .2886 L
s
.64013 .32534 m
.62933 .33136 L
s
.64775 .33121 m
.63777 .33786 L
s
.3343 .63353 m
.33095 .6464 L
s
.57598 .29078 m
.56202 .29631 L
s
.63163 .31861 m
.62009 .32408 L
s
.34831 .65029 m
.35282 .66609 L
s
.65445 .33608 m
.64535 .34344 L
s
.53557 .28011 m
.52116 .28705 L
s
.62232 .31117 m
.6101 .3162 L
s
.33332 .63484 m
.33124 .64847 L
s
.66015 .33985 m
.65201 .34799 L
s
.34799 .65201 m
.33985 .66015 L
s
.34267 .64674 m
.3459 .66236 L
s
.43705 .28624 m
.42486 .29826 L
s
.33365 .63702 m
.33289 .6513 L
s
.37008 .67212 m
.37801 .6871 L
s
.33833 .64319 m
.34024 .65849 L
s
.33532 .63987 m
.33589 .65472 L
s
.61223 .30321 m
.59939 .30789 L
s
.46435 .27857 m
.45103 .28901 L
s
.34232 .64858 m
.33521 .65754 L
s
.56334 .28241 m
.54904 .28796 L
s
.4928 .2742 m
.47871 .28301 L
s
.33771 .64632 m
.3317 .65613 L
s
.38914 .68875 m
.39903 .70258 L
s
.6014 .29492 m
.58801 .29935 L
s
.36092 .66942 m
.36773 .68452 L
s
.52163 .27295 m
.50713 .28015 L
s
.33424 .64523 m
.32939 .65591 L
s
.35282 .66609 m
.35844 .68119 L
s
.33196 .64528 m
.32835 .65681 L
s
.58986 .28649 m
.57598 .29078 L
s
.55013 .27444 m
.53557 .28011 L
s
.44995 .27537 m
.43705 .28624 L
s
.37801 .6871 m
.38694 .7012 L
s
.33095 .6464 m
.32861 .65874 L
s
.3459 .66236 m
.35025 .67733 L
s
.65037 .32029 m
.64013 .32534 L
s
.64269 .31417 m
.63163 .31861 L
s
.47823 .26936 m
.46435 .27857 L
s
.6571 .32545 m
.64775 .33121 L
s
.33124 .64847 m
.33023 .66154 L
s
.63413 .30725 m
.62232 .31117 L
s
.34024 .65849 m
.34328 .67317 L
s
.66283 .32955 m
.65445 .33608 L
s
.33289 .6513 m
.33323 .66503 L
s
.33589 .65472 m
.33758 .66899 L
s
.5073 .26668 m
.4928 .2742 L
s
.39903 .70258 m
.40983 .71538 L
s
.66751 .33249 m
.66015 .33985 L
s
.33985 .66015 m
.33249 .66751 L
s
.62474 .29971 m
.61223 .30321 L
s
.57765 .27816 m
.56334 .28241 L
s
.36773 .68452 m
.37561 .69878 L
s
.33521 .65754 m
.32895 .66577 L
s
.53639 .26708 m
.52163 .27295 L
s
.61454 .29173 m
.6014 .29492 L
s
.3317 .65613 m
.32661 .66526 L
s
.35844 .68119 m
.36517 .69549 L
s
.46352 .26574 m
.44995 .27537 L
s
.38694 .7012 m
.39688 .7143 L
s
.56479 .27014 m
.55013 .27444 L
s
.32939 .65591 m
.32554 .66593 L
s
.60357 .28352 m
.58986 .28649 L
s
.49263 .26147 m
.47823 .26936 L
s
.35025 .67733 m
.35576 .69152 L
s
.32835 .65681 m
.32578 .66769 L
s
.52215 .26055 m
.5073 .26668 L
s
.40983 .71538 m
.42154 .72706 L
s
.34328 .67317 m
.34748 .68713 L
s
.32861 .65874 m
.32737 .67043 L
s
.65318 .31084 m
.64269 .31417 L
s
.65996 .31627 m
.65037 .32029 L
s
.33023 .66154 m
.33035 .67396 L
s
.33758 .66899 m
.34044 .68256 L
s
.37561 .69878 m
.38457 .71208 L
s
.33323 .66503 m
.33472 .67809 L
s
.64546 .30451 m
.63413 .30725 L
s
.66573 .32068 m
.6571 .32545 L
s
.59186 .27531 m
.57765 .27816 L
s
.67043 .32395 m
.66283 .32955 L
s
.55132 .26265 m
.53639 .26708 L
s
.63683 .29746 m
.62474 .29971 L
s
.674 .326 m
.66751 .33249 L
s
.33249 .66751 m
.326 .674 L
s
.47771 .25746 m
.46352 .26574 L
s
.36517 .69549 m
.37303 .70886 L
s
.62734 .28988 m
.61454 .29173 L
s
.39688 .7143 m
.40781 .72629 L
s
.32895 .66577 m
.32363 .67318 L
s
.50748 .25501 m
.49263 .26147 L
s
.57944 .2673 m
.56479 .27014 L
s
.32661 .66526 m
.32253 .67359 L
s
.35576 .69152 m
.36243 .70483 L
s
.61702 .28196 m
.60357 .28352 L
s
.42154 .72706 m
.43412 .73748 L
s
.53727 .25589 m
.52215 .26055 L
s
.32554 .66593 m
.32274 .67518 L
s
.34748 .68713 m
.35288 .70024 L
s
.38457 .71208 m
.39458 .72429 L
s
.32578 .66769 m
.32432 .67782 L
s
.34044 .68256 m
.34452 .69532 L
s
.32737 .67043 m
.32729 .68137 L
s
.6059 .27392 m
.59186 .27531 L
s
.56634 .25973 m
.55132 .26265 L
s
.33472 .67809 m
.33742 .69036 L
s
.33035 .67396 m
.33167 .68563 L
s
.66301 .3087 m
.65318 .31084 L
s
.49244 .25064 m
.47771 .25746 L
s
.66881 .31339 m
.65996 .31627 L
s
.65619 .30304 m
.64546 .30451 L
s
.67354 .31697 m
.66573 .32068 L
s
.40781 .72629 m
.41969 .73704 L
s
.37303 .70886 m
.38202 .72117 L
s
.64841 .29655 m
.63683 .29746 L
s
.67713 .31935 m
.67043 .32395 L
s
.5227 .25008 m
.50748 .25501 L
s
.63971 .28943 m
.62734 .28988 L
s
.59401 .266 m
.57944 .2673 L
s
.67953 .32047 m
.674 .326 L
s
.326 .674 m
.32047 .67953 L
s
.43412 .73748 m
.44751 .74654 L
s
.36243 .70483 m
.37028 .71713 L
s
.55258 .25282 m
.53727 .25589 L
s
.32363 .67318 m
.31934 .67967 L
s
.63012 .28187 m
.61702 .28196 L
s
.39458 .72429 m
.40564 .73528 L
s
.32253 .67359 m
.31953 .68104 L
s
.35288 .70024 m
.35951 .71237 L
s
.32274 .67518 m
.3211 .68355 L
s
.58136 .25842 m
.56634 .25973 L
s
.50767 .24538 m
.49244 .25064 L
s
.34452 .69532 m
.34984 .70715 L
s
.61967 .2741 m
.6059 .27392 L
s
.32432 .67782 m
.32406 .68708 L
s
.41969 .73704 m
.43249 .74643 L
s
.33742 .69036 m
.34138 .70173 L
s
.32729 .68137 m
.32844 .69144 L
s
.33167 .68563 m
.33422 .69641 L
s
.38202 .72117 m
.39213 .7323 L
s
.53821 .24677 m
.5227 .25008 L
s
.67206 .30785 m
.66301 .3087 L
s
.66623 .30291 m
.65619 .30304 L
s
.67681 .31172 m
.66881 .31339 L
s
.65937 .29706 m
.64841 .29655 L
s
.44751 .74654 m
.46168 .75411 L
s
.60838 .26633 m
.59401 .266 L
s
.68043 .31442 m
.67354 .31697 L
s
.65153 .29048 m
.63971 .28943 L
s
.56799 .25141 m
.55258 .25282 L
s
.37028 .71713 m
.37932 .72827 L
s
.68284 .31586 m
.67713 .31935 L
s
.40564 .73528 m
.41772 .74493 L
s
.684 .316 m
.67953 .32047 L
s
.32047 .67953 m
.316 .684 L
s
.64274 .28335 m
.63012 .28187 L
s
.35951 .71237 m
.36737 .72339 L
s
.52329 .2418 m
.50767 .24538 L
s
.31934 .67967 m
.31618 .68513 L
s
.59629 .25881 m
.58136 .25842 L
s
.43249 .74643 m
.44617 .75433 L
s
.31953 .68104 m
.31772 .68749 L
s
.63305 .27591 m
.61967 .2741 L
s
.34984 .70715 m
.35643 .7179 L
s
.55393 .24519 m
.53821 .24677 L
s
.39213 .7323 m
.40334 .74212 L
s
.3211 .68355 m
.32068 .69095 L
s
.34138 .70173 m
.34663 .71206 L
s
.32406 .68708 m
.32506 .69536 L
s
.46168 .75411 m
.47655 .76006 L
s
.33422 .69641 m
.33809 .70618 L
s
.32844 .69144 m
.33088 .70052 L
s
.62246 .26836 m
.60838 .26633 L
s
.58339 .25176 m
.56799 .25141 L
s
.67545 .30422 m
.66623 .30291 L
s
.68023 .30836 m
.67206 .30785 L
s
.66959 .29907 m
.65937 .29706 L
s
.37932 .72827 m
.38954 .73814 L
s
.68386 .31136 m
.67681 .31172 L
s
.41772 .74493 m
.43077 .7531 L
s
.66269 .2931 m
.65153 .29048 L
s
.68629 .31312 m
.68043 .31442 L
s
.53921 .23999 m
.52329 .2418 L
s
.65479 .28647 m
.64274 .28335 L
s
.68746 .31357 m
.68284 .31586 L
s
.61099 .26097 m
.59629 .25881 L
s
.36737 .72339 m
.37648 .73317 L
s
.44617 .75433 m
.46067 .76062 L
s
.6873 .3127 m
.684 .316 L
s
.316 .684 m
.3127 .6873 L
s
.56974 .24543 m
.55393 .24519 L
s
.64592 .27943 m
.63305 .27591 L
s
.40334 .74212 m
.41564 .75048 L
s
.31618 .68513 m
.31423 .68946 L
s
.35643 .7179 m
.36433 .72744 L
s
.47655 .76006 m
.49204 .76429 L
s
.31772 .68749 m
.31718 .69282 L
s
.34663 .71206 m
.35322 .72123 L
s
.59868 .25396 m
.58339 .25176 L
s
.32068 .69095 m
.32157 .69725 L
s
.63611 .27218 m
.62246 .26836 L
s
.33809 .70618 m
.3433 .71481 L
s
.32506 .69536 m
.32741 .70254 L
s
.33088 .70052 m
.33467 .70849 L
s
.43077 .7531 m
.44476 .75967 L
s
.38954 .73814 m
.40094 .74658 L
s
.68375 .30704 m
.67545 .30422 L
s
.67896 .30266 m
.66959 .29907 L
s
.55534 .24004 m
.53921 .23999 L
s
.6874 .31032 m
.68023 .30836 L
s
.67307 .29735 m
.66269 .2931 L
s
.68984 .31239 m
.68386 .31136 L
s
.62537 .26498 m
.61099 .26097 L
s
.46067 .76062 m
.47592 .76517 L
s
.66613 .2913 m
.65479 .28647 L
s
.37648 .73317 m
.38684 .74156 L
s
.69102 .31316 m
.68629 .31312 L
s
.58552 .24757 m
.56974 .24543 L
s
.41564 .75048 m
.42897 .75726 L
s
.69087 .31258 m
.68746 .31357 L
s
.49204 .76429 m
.50808 .76669 L
s
.65817 .28472 m
.64592 .27943 L
s
.36433 .72744 m
.37353 .73564 L
s
.68935 .31065 m
.6873 .3127 L
s
.3127 .6873 m
.31065 .68935 L
s
.61371 .25806 m
.59868 .25396 L
s
.31423 .68946 m
.3136 .69256 L
s
.64921 .27784 m
.63611 .27218 L
s
.44476 .75967 m
.45962 .7645 L
s
.35322 .72123 m
.36117 .72908 L
s
.31718 .69282 m
.318 .69694 L
s
.40094 .74658 m
.41347 .75346 L
s
.57156 .24205 m
.55534 .24004 L
s
.3433 .71481 m
.34991 .72217 L
s
.32157 .69725 m
.32386 .70232 L
s
.33467 .70849 m
.33987 .7152 L
s
.32741 .70254 m
.33116 .70849 L
s
.47592 .76517 m
.49183 .76786 L
s
.63928 .2709 m
.62537 .26498 L
s
.68735 .30788 m
.67896 .30266 L
s
.691 .31143 m
.68375 .30704 L
s
.68255 .30331 m
.67307 .29735 L
s
.60116 .25169 m
.58552 .24757 L
s
.69344 .31381 m
.6874 .31032 L
s
.38684 .74156 m
.39844 .74842 L
s
.67664 .29789 m
.66613 .2913 L
s
.50808 .76669 m
.52456 .76713 L
s
.42897 .75726 m
.44329 .76231 L
s
.69463 .3149 m
.68984 .31239 L
s
.66965 .29185 m
.65817 .28472 L
s
.69449 .31463 m
.69102 .31316 L
s
.62838 .26414 m
.61371 .25806 L
s
.37353 .73564 m
.38405 .74234 L
s
.69297 .31298 m
.69087 .31258 L
s
.45962 .7645 m
.47526 .76747 L
s
.66163 .28539 m
.64921 .27784 L
s
.58773 .2461 m
.57156 .24205 L
s
.69003 .30997 m
.68935 .31065 L
s
.31065 .68935 m
.30997 .69003 L
s
.41347 .75346 m
.4271 .75863 L
s
.36117 .72908 m
.3705 .73548 L
s
.49183 .76786 m
.5083 .76859 L
s
.3136 .69256 m
.31437 .6943 L
s
.34991 .72217 m
.35794 .72811 L
s
.65258 .27877 m
.63928 .2709 L
s
.61652 .25784 m
.60116 .25169 L
s
.318 .69694 m
.32025 .69971 L
s
.33987 .7152 m
.34652 .72054 L
s
.32386 .70232 m
.3276 .70605 L
s
.52456 .76713 m
.54135 .76554 L
s
.33116 .70849 m
.33638 .71309 L
s
.69463 .3148 m
.68735 .30788 L
s
.69098 .31102 m
.68255 .30331 L
s
.44329 .76231 m
.45852 .7655 L
s
.39844 .74842 m
.41123 .75361 L
s
.69707 .31747 m
.691 .31143 L
s
.68617 .3063 m
.67664 .29789 L
s
.69825 .31889 m
.69344 .31381 L
s
.64252 .27225 m
.62838 .26414 L
s
.68024 .30084 m
.66965 .29185 L
s
.69811 .31896 m
.69463 .3149 L
s
.47526 .76747 m
.4916 .76847 L
s
.60372 .25223 m
.58773 .2461 L
s
.38405 .74234 m
.39587 .74741 L
s
.67322 .29487 m
.66163 .28539 L
s
.69659 .31761 m
.69449 .31463 L
s
.4271 .75863 m
.44177 .76198 L
s
.5083 .76859 m
.52523 .76725 L
s
.69365 .31486 m
.69297 .31298 L
s
.63145 .26607 m
.61652 .25784 L
s
.3705 .73548 m
.3812 .74028 L
s
.66513 .28864 m
.65258 .27877 L
s
.54135 .76554 m
.55834 .76183 L
s
.68925 .31075 m
.69003 .30997 L
s
.30997 .69003 m
.31075 .68925 L
s
.35794 .72811 m
.36741 .7325 L
s
.45852 .7655 m
.47459 .76672 L
s
.31437 .6943 m
.31665 .6946 L
s
.41123 .75361 m
.42518 .75699 L
s
.32025 .69971 m
.32403 .70103 L
s
.34652 .72054 m
.35467 .72436 L
s
.69824 .32052 m
.69098 .31102 L
s
.65599 .28239 m
.64252 .27225 L
s
.69459 .31654 m
.68617 .3063 L
s
.70067 .32346 m
.69463 .3148 L
s
.3276 .70605 m
.33287 .70831 L
s
.33638 .71309 m
.34311 .71619 L
s
.70183 .32521 m
.69707 .31747 L
s
.68979 .31173 m
.68024 .30084 L
s
.61938 .2605 m
.60372 .25223 L
s
.4916 .76847 m
.50853 .76738 L
s
.70169 .32562 m
.69825 .31889 L
s
.68384 .3063 m
.67322 .29487 L
s
.52523 .76725 m
.54247 .76376 L
s
.39587 .74741 m
.40895 .75072 L
s
.70017 .32463 m
.69811 .31896 L
s
.44177 .76198 m
.45741 .76336 L
s
.64579 .2764 m
.63145 .26607 L
s
.55834 .76183 m
.57537 .75593 L
s
.67679 .3005 m
.66513 .28864 L
s
.69723 .32218 m
.69659 .31761 L
s
.3812 .74028 m
.39326 .74336 L
s
.47459 .76672 m
.49137 .76586 L
s
.69281 .31831 m
.69365 .31486 L
s
.66864 .29459 m
.65599 .28239 L
s
.42518 .75699 m
.44023 .75844 L
s
.36741 .7325 m
.37832 .7352 L
s
.68691 .31309 m
.68925 .31075 L
s
.31075 .68925 m
.31309 .68691 L
s
.63455 .27092 m
.61938 .2605 L
s
.50853 .76738 m
.52591 .76413 L
s
.70177 .32863 m
.69459 .31654 L
s
.70418 .33182 m
.69824 .32052 L
s
.31665 .6946 m
.3205 .69334 L
s
.69814 .3245 m
.68979 .31173 L
s
.35467 .72436 m
.36431 .72653 L
s
.70533 .33388 m
.70067 .32346 L
s
.32403 .70103 m
.32939 .70079 L
s
.54247 .76376 m
.55989 .75806 L
s
.34311 .71619 m
.35139 .71768 L
s
.33287 .70831 m
.33972 .709 L
s
.69334 .31966 m
.68384 .3063 L
s
.70517 .33467 m
.70183 .32521 L
s
.65939 .28883 m
.64579 .2764 L
s
.57537 .75593 m
.59229 .74781 L
s
.45741 .76336 m
.4739 .76267 L
s
.40895 .75072 m
.42324 .75212 L
s
.70364 .33405 m
.70169 .32562 L
s
.68739 .31435 m
.67679 .3005 L
s
.70069 .33197 m
.70017 .32463 L
s
.49137 .76586 m
.50876 .76282 L
s
.6803 .30881 m
.66864 .29459 L
s
.39326 .74336 m
.40665 .74458 L
s
.64906 .28349 m
.63455 .27092 L
s
.69628 .3284 m
.69723 .32218 L
s
.52591 .76413 m
.5436 .75863 L
s
.44023 .75844 m
.45627 .75784 L
s
.69036 .3234 m
.69281 .31831 L
s
.55989 .75806 m
.57732 .75009 L
s
.37832 .7352 m
.39066 .73608 L
s
.70756 .34255 m
.70177 .32863 L
s
.70517 .33915 m
.69814 .3245 L
s
.67209 .30333 m
.65939 .28883 L
s
.70868 .34492 m
.70418 .33182 L
s
.59229 .74781 m
.60894 .73745 L
s
.70157 .33493 m
.69334 .31966 L
s
.68293 .31707 m
.68691 .31309 L
s
.31309 .68691 m
.31707 .68293 L
s
.70849 .34608 m
.70533 .33388 L
s
.36431 .72653 m
.37546 .72693 L
s
.4739 .76267 m
.49114 .75981 L
s
.3205 .69334 m
.326 .69044 L
s
.69678 .33014 m
.68739 .31435 L
s
.35139 .71768 m
.36124 .71745 L
s
.42324 .75212 m
.43867 .7515 L
s
.70695 .34587 m
.70517 .33467 L
s
.32939 .70079 m
.33639 .69888 L
s
.33972 .709 m
.34817 .70799 L
s
.50876 .76282 m
.5266 .75754 L
s
.66274 .29817 m
.64906 .28349 L
s
.69082 .32502 m
.6803 .30881 L
s
.70399 .3442 m
.70364 .33405 L
s
.5436 .75863 m
.56144 .75086 L
s
.40665 .74458 m
.4213 .74382 L
s
.57732 .75009 m
.59459 .73985 L
s
.69957 .34101 m
.70069 .33197 L
s
.45627 .75784 m
.47321 .75509 L
s
.6837 .31985 m
.67209 .30333 L
s
.60894 .73745 m
.62512 .72486 L
s
.69365 .33632 m
.69628 .3284 L
s
.71074 .35561 m
.70517 .33915 L
s
.70839 .35204 m
.70157 .33493 L
s
.71182 .35826 m
.70756 .34255 L
s
.39066 .73608 m
.40437 .73504 L
s
.71161 .35979 m
.70868 .34492 L
s
.49114 .75981 m
.50899 .7547 L
s
.70482 .34779 m
.69678 .33014 L
s
.68621 .33018 m
.69036 .3234 L
s
.67543 .3149 m
.66274 .29817 L
s
.71004 .36001 m
.70849 .34608 L
s
.5266 .75754 m
.54473 .74996 L
s
.70005 .34312 m
.69082 .32502 L
s
.43867 .7515 m
.45514 .74877 L
s
.37546 .72693 m
.38808 .72545 L
s
.67726 .32274 m
.68293 .31707 L
s
.31707 .68293 m
.32274 .67726 L
s
.56144 .75086 m
.57925 .74078 L
s
.70707 .3588 m
.70695 .34587 L
s
.326 .69044 m
.33319 .68581 L
s
.36124 .71745 m
.37265 .71538 L
s
.59459 .73985 m
.61152 .72735 L
s
.33639 .69888 m
.34506 .69522 L
s
.34817 .70799 m
.35826 .70519 L
s
.62512 .72486 m
.64066 .71008 L
s
.69409 .33829 m
.6837 .31985 L
s
.70264 .35606 m
.70399 .3442 L
s
.47321 .75509 m
.49091 .75012 L
s
.4213 .74382 m
.43713 .74098 L
s
.71366 .3709 m
.70839 .35204 L
s
.7147 .3738 m
.71074 .35561 L
s
.71136 .36721 m
.70482 .34779 L
s
.69672 .35177 m
.69957 .34101 L
s
.68694 .33358 m
.67543 .3149 L
s
.71444 .37569 m
.71182 .35826 L
s
.50899 .7547 m
.52728 .74731 L
s
.70783 .363 m
.70005 .34312 L
s
.54473 .74996 m
.56298 .74007 L
s
.71285 .37636 m
.71161 .35979 L
s
.40437 .73504 m
.41939 .73196 L
s
.68928 .34595 m
.69365 .33632 L
s
.57925 .74078 m
.59685 .72842 L
s
.61152 .72735 m
.62791 .71264 L
s
.64066 .71008 m
.65537 .69319 L
s
.45514 .74877 m
.47253 .74383 L
s
.70308 .35852 m
.69409 .33829 L
s
.70985 .37565 m
.71004 .36001 L
s
.68031 .3387 m
.68621 .33018 L
s
.38808 .72545 m
.40214 .72199 L
s
.66983 .33017 m
.67726 .32274 L
s
.32274 .67726 m
.33017 .66983 L
s
.70542 .37342 m
.70707 .3588 L
s
.69712 .35407 m
.68694 .33358 L
s
.49091 .75012 m
.50922 .74286 L
s
.37265 .71538 m
.38559 .71139 L
s
.33319 .68581 m
.34211 .6794 L
s
.71726 .39137 m
.71366 .3709 L
s
.71627 .38826 m
.71136 .36721 L
s
.35826 .70519 m
.36996 .70052 L
s
.34506 .69522 m
.35541 .68974 L
s
.43713 .74098 m
.45403 .73599 L
s
.71695 .39361 m
.7147 .3738 L
s
.71402 .38451 m
.70783 .363 L
s
.52728 .74731 m
.54584 .7376 L
s
.6995 .36962 m
.70264 .35606 L
s
.56298 .74007 m
.58115 .72789 L
s
.62791 .71264 m
.64356 .6958 L
s
.59685 .72842 m
.61402 .71384 L
s
.65537 .69319 m
.66905 .67431 L
s
.71531 .39473 m
.71444 .37569 L
s
.71053 .3804 m
.70308 .35852 L
s
.69206 .36423 m
.69672 .35177 L
s
.7123 .39454 m
.71285 .37636 L
s
.41939 .73196 m
.43563 .72679 L
s
.47253 .74383 m
.49069 .73666 L
s
.70581 .37621 m
.69712 .35407 L
s
.68309 .3573 m
.68928 .34595 L
s
.70785 .39289 m
.70985 .37565 L
s
.71943 .41075 m
.71627 .38826 L
s
.7185 .40746 m
.71402 .38451 L
s
.50922 .74286 m
.52795 .73332 L
s
.71907 .4133 m
.71726 .39137 L
s
.66905 .67431 m
.68154 .6536 L
s
.64356 .6958 m
.65829 .67695 L
s
.40214 .72199 m
.41755 .71649 L
s
.61402 .71384 m
.63057 .69711 L
s
.71631 .40372 m
.71053 .3804 L
s
.54584 .7376 m
.56447 .72561 L
s
.67259 .34895 m
.68031 .3387 L
s
.58115 .72789 m
.59903 .71347 L
s
.71739 .41487 m
.71695 .39361 L
s
.70193 .38966 m
.70542 .37342 L
s
.45403 .73599 m
.47187 .7288 L
s
.38559 .71139 m
.40001 .70542 L
s
.66062 .33938 m
.66983 .33017 L
s
.33017 .66983 m
.33938 .66062 L
s
.71287 .39979 m
.70581 .37621 L
s
.71434 .41523 m
.71531 .39473 L
s
.36996 .70052 m
.38323 .69393 L
s
.34211 .6794 m
.35275 .67117 L
s
.35541 .68974 m
.36742 .68239 L
s
.6945 .38481 m
.6995 .36962 L
s
.68154 .6536 m
.69265 .63123 L
s
.65829 .67695 m
.67189 .65626 L
s
.72118 .43165 m
.7185 .40746 L
s
.70988 .4142 m
.7123 .39454 L
s
.72076 .43448 m
.71943 .41075 L
s
.49069 .73666 m
.50944 .72721 L
s
.72032 .42825 m
.71631 .40372 L
s
.63057 .69711 m
.64629 .67836 L
s
.43563 .72679 m
.45297 .71946 L
s
.71902 .43648 m
.71907 .4133 L
s
.59903 .71347 m
.61641 .6969 L
s
.71819 .42457 m
.71287 .39979 L
s
.68554 .37834 m
.69206 .36423 L
s
.52795 .73332 m
.54692 .72149 L
s
.56447 .72561 m
.58296 .71138 L
s
.70397 .41163 m
.70785 .39289 L
s
.71594 .4374 m
.71739 .41487 L
s
.69265 .63123 m
.70224 .60744 L
s
.67189 .65626 m
.68419 .63391 L
s
.67505 .37033 m
.68309 .3573 L
s
.72246 .45375 m
.72032 .42825 L
s
.41755 .71649 m
.4342 .7089 L
s
.72197 .45682 m
.72118 .43165 L
s
.72167 .45029 m
.71819 .42457 L
s
.64629 .67836 m
.66098 .65777 L
s
.47187 .7288 m
.49047 .71938 L
s
.71146 .43703 m
.71434 .41523 L
s
.72018 .45922 m
.72076 .43448 L
s
.69655 .40742 m
.70193 .38966 L
s
.66306 .36093 m
.67259 .34895 L
s
.70224 .60744 m
.71015 .58246 L
s
.61641 .6969 m
.63307 .67832 L
s
.40001 .70542 m
.41581 .69742 L
s
.71705 .46069 m
.71902 .43648 L
s
.68419 .63391 m
.69501 .61015 L
s
.50944 .72721 m
.52859 .71553 L
s
.72268 .47992 m
.72246 .45375 L
s
.72324 .47666 m
.72167 .45029 L
s
.64964 .35036 m
.66062 .33938 L
s
.33938 .66062 m
.35036 .64964 L
s
.58296 .71138 m
.60109 .69501 L
s
.70555 .43517 m
.70988 .4142 L
s
.54692 .72149 m
.5659 .70745 L
s
.38323 .69393 m
.39802 .68538 L
s
.72082 .48269 m
.72197 .45682 L
s
.68761 .40155 m
.6945 .38481 L
s
.35275 .67117 m
.36511 .66111 L
s
.71015 .58246 m
.71628 .5566 L
s
.36742 .68239 m
.38105 .67315 L
s
.66098 .65777 m
.67444 .63554 L
s
.71255 .46099 m
.71594 .4374 L
s
.72287 .50338 m
.72324 .47666 L
s
.45297 .71946 m
.47124 .70997 L
s
.69501 .61015 m
.70421 .58523 L
s
.71765 .48469 m
.72018 .45922 L
s
.72094 .50647 m
.72268 .47992 L
s
.71628 .5566 m
.72054 .53013 L
s
.72054 .53013 m
.72287 .50338 L
s
.63307 .67832 m
.64879 .6579 L
s
.69815 .43171 m
.70397 .41163 L
s
.67714 .39403 m
.68554 .37834 L
s
.71772 .50897 m
.72082 .48269 L
s
.70421 .58523 m
.71166 .55944 L
s
.71726 .53308 m
.72094 .50647 L
s
.67444 .63554 m
.68649 .6119 L
s
.70664 .4599 m
.71146 .43703 L
s
.71312 .48566 m
.71705 .46069 L
s
.71166 .55944 m
.71726 .53308 L
s
.60109 .69501 m
.61862 .67663 L
s
.49047 .71938 m
.50965 .70776 L
s
.4342 .7089 m
.45196 .69921 L
s
.71316 .5106 m
.71765 .48469 L
s
.71267 .53535 m
.71772 .50897 L
s
.66517 .38499 m
.67505 .37033 L
s
.5659 .70745 m
.58466 .69129 L
s
.68649 .6119 m
.69696 .58712 L
s
.52859 .71553 m
.54793 .70165 L
s
.68924 .42655 m
.69655 .40742 L
s
.64879 .6579 m
.66338 .63585 L
s
.70721 .48537 m
.71255 .46099 L
s
.70572 .5615 m
.71267 .53535 L
s
.69926 .45726 m
.70555 .43517 L
s
.69696 .58712 m
.70572 .5615 L
s
.41581 .69742 m
.43288 .68739 L
s
.65173 .37458 m
.66306 .36093 L
s
.70724 .51111 m
.71312 .48566 L
s
.70674 .53665 m
.71316 .5106 L
s
.61862 .67663 m
.63533 .65644 L
s
.66338 .63585 m
.67663 .61241 L
s
.47124 .70997 m
.49027 .69833 L
s
.67881 .4197 m
.68761 .40155 L
s
.63693 .36307 m
.64964 .35036 L
s
.35036 .64964 m
.36307 .63693 L
s
.39802 .68538 m
.41422 .67488 L
s
.69986 .48361 m
.70664 .4599 L
s
.36511 .66111 m
.37911 .64926 L
s
.38105 .67315 m
.39622 .66203 L
s
.69845 .56251 m
.70674 .53665 L
s
.6904 .45294 m
.69815 .43171 L
s
.67663 .61241 m
.68837 .58787 L
s
.58466 .69129 m
.60298 .67315 L
s
.68837 .58787 m
.69845 .56251 L
s
.50965 .70776 m
.52919 .694 L
s
.69992 .51027 m
.70721 .48537 L
s
.69945 .53673 m
.70724 .51111 L
s
.54793 .70165 m
.56721 .68569 L
s
.63533 .65644 m
.651 .63463 L
s
.66687 .41119 m
.67714 .39403 L
s
.45196 .69921 m
.47066 .68744 L
s
.69104 .48022 m
.69926 .45726 L
s
.68002 .44688 m
.68924 .42655 L
s
.6898 .56221 m
.69945 .53673 L
s
.651 .63463 m
.66543 .61147 L
s
.60298 .67315 m
.6206 .65321 L
s
.65346 .40116 m
.66517 .38499 L
s
.69115 .50788 m
.69986 .48361 L
s
.69074 .53538 m
.69992 .51027 L
s
.67842 .58723 m
.6898 .56221 L
s
.66543 .61147 m
.67842 .58723 L
s
.43288 .68739 m
.45105 .67537 L
s
.49027 .69833 m
.50984 .68461 L
s
.56721 .68569 m
.58621 .66779 L
s
.63865 .38982 m
.65173 .37458 L
s
.52919 .694 m
.54885 .6782 L
s
.68073 .47509 m
.6904 .45294 L
s
.66813 .43909 m
.67881 .4197 L
s
.6206 .65321 m
.63731 .6317 L
s
.41422 .67488 m
.43168 .66246 L
s
.67975 .5604 m
.69074 .53538 L
s
.36307 .63693 m
.37744 .62256 L
s
.62256 .37744 m
.63693 .36307 L
s
.39622 .66203 m
.41281 .64909 L
s
.37911 .64926 m
.39465 .63566 L
s
.68092 .50379 m
.69104 .48022 L
s
.68059 .53241 m
.69115 .50788 L
s
.63731 .6317 m
.65287 .60887 L
s
.47066 .68744 m
.49008 .67366 L
s
.66707 .585 m
.67975 .5604 L
s
.65477 .42966 m
.66687 .41119 L
s
.58621 .66779 m
.60466 .64813 L
s
.66892 .46819 m
.68002 .44688 L
s
.65287 .60887 m
.66707 .585 L
s
.50984 .68461 m
.52973 .66892 L
s
.54885 .6782 m
.5684 .66052 L
s
.66827 .5569 m
.68059 .53241 L
s
.63999 .41872 m
.65346 .40116 L
s
.66921 .49791 m
.68073 .47509 L
s
.45105 .67537 m
.47014 .66142 L
s
.60466 .64813 m
.62232 .62694 L
s
.66899 .52768 m
.68092 .50379 L
s
.65564 .45954 m
.66813 .43909 L
s
.65434 .58103 m
.66827 .5569 L
s
.6239 .40652 m
.63865 .38982 L
s
.62232 .62694 m
.63895 .60447 L
s
.43168 .66246 m
.45024 .64821 L
s
.5684 .66052 m
.58756 .64113 L
s
.63895 .60447 m
.65434 .58103 L
s
.49008 .67366 m
.51001 .65799 L
s
.37744 .62256 m
.39336 .60664 L
s
.60664 .39336 m
.62256 .37744 L
s
.41281 .64909 m
.43065 .63441 L
s
.65603 .49023 m
.66892 .46819 L
s
.39465 .63566 m
.41161 .62042 L
s
.52973 .66892 m
.54967 .6514 L
s
.65537 .55159 m
.66899 .52768 L
s
.64093 .44924 m
.65477 .42966 L
s
.65594 .52113 m
.66921 .49791 L
s
.58756 .64113 m
.60608 .62027 L
s
.47014 .66142 m
.48992 .64567 L
s
.64022 .5752 m
.65537 .55159 L
s
.62488 .43748 m
.63999 .41872 L
s
.64142 .48079 m
.65564 .45954 L
s
.60608 .62027 m
.62371 .5982 L
s
.54967 .6514 m
.56941 .63225 L
s
.62371 .5982 m
.64022 .5752 L
s
.51001 .65799 m
.53019 .64058 L
s
.64106 .54442 m
.65594 .52113 L
s
.45024 .64821 m
.46969 .63226 L
s
.64147 .51274 m
.65603 .49023 L
s
.60762 .42452 m
.6239 .40652 L
s
.43065 .63441 m
.44957 .61813 L
s
.39336 .60664 m
.41068 .58932 L
s
.58932 .41068 m
.60664 .39336 L
s
.62547 .46973 m
.64093 .44924 L
s
.41161 .62042 m
.42982 .60368 L
s
.56941 .63225 m
.58868 .61171 L
s
.62475 .56749 m
.64106 .54442 L
s
.48992 .64567 m
.51016 .62827 L
s
.53019 .64058 m
.55036 .62162 L
s
.62564 .5026 m
.64142 .48079 L
s
.58868 .61171 m
.60721 .59002 L
s
.6254 .53541 m
.64147 .51274 L
s
.60721 .59002 m
.62475 .56749 L
s
.60827 .45724 m
.62488 .43748 L
s
.46969 .63226 m
.48979 .61476 L
s
.55036 .62162 m
.57024 .60134 L
s
.58998 .44361 m
.60762 .42452 L
s
.60802 .55794 m
.6254 .53541 L
s
.60855 .49085 m
.62547 .46973 L
s
.51016 .62827 m
.53058 .60941 L
s
.44957 .61813 m
.46933 .60041 L
s
.41068 .58932 m
.4292 .5708 L
s
.5708 .4292 m
.58932 .41068 L
s
.60847 .52466 m
.62564 .5026 L
s
.42982 .60368 m
.44905 .58562 L
s
.57024 .60134 m
.58954 .58002 L
s
.58954 .58002 m
.60802 .55794 L
s
.59034 .47774 m
.60827 .45724 L
s
.48979 .61476 m
.51027 .59592 L
s
.53058 .60941 m
.5509 .58935 L
s
.59012 .54667 m
.60847 .52466 L
s
.59039 .51234 m
.60855 .49085 L
s
.57119 .46357 m
.58998 .44361 L
s
.46933 .60041 m
.48969 .58147 L
s
.5509 .58935 m
.57084 .56834 L
s
.57084 .56834 m
.59012 .54667 L
s
.4292 .5708 m
.4487 .5513 L
s
.5513 .4487 m
.5708 .4292 L
s
.44905 .58562 m
.46908 .56645 L
s
.51027 .59592 m
.53086 .57598 L
s
.57132 .49871 m
.59034 .47774 L
s
.5712 .53389 m
.59039 .51234 L
s
.48969 .58147 m
.51036 .56155 L
s
.53086 .57598 m
.55127 .5552 L
s
.55148 .48411 m
.57119 .46357 L
s
.55127 .5552 m
.5712 .53389 L
s
.46908 .56645 m
.48962 .54644 L
s
.53108 .46892 m
.5513 .4487 L
s
.4487 .5513 m
.46892 .53108 L
s
.55147 .51987 m
.57132 .49871 L
s
.51036 .56155 m
.53105 .54092 L
s
.53105 .54092 m
.55147 .51987 L
s
.53112 .50497 m
.55148 .48411 L
s
.48962 .54644 m
.5104 .52585 L
s
.46892 .53108 m
.48959 .51041 L
s
.51041 .48959 m
.53108 .46892 L
s
.5104 .52585 m
.53112 .50497 L
s
.48959 .51041 m
.51041 .48959 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
VGoo2G`0OWoo002DOol5O009Ool4O01jOol0091oo`Al00Eooa5l07Ioo`00SGoo0g`01Goo17`03Goo
1W`0M7oo002;Ool2O006Ool2O008OolAO01bOol008Uoo`9l00Ioo`9l00Eoo`El011oo`Al06moo`00
R7oo00=l07ooOol017oo0W`017oo0g`02Goo4W`0KGoo0026Ool2O005Ool2O004Ool2O007Ool5O00?
Ool5O01[Ool008Eoo`03O01oogoo00=oo`9l00Aoo`9l00Ioo`=l00Uoo`]l009oo`Al06Yoo`00Q7oo
00=l07ooOol00Woo0W`017oo0W`01Woo0W`01goo1G`02goo17`000Aoog`0O01l06Qoo`00PWoo0W`0
0goo0W`017oo0W`01Woo0W`01Woo0g`037oo1g`000=oog`0O0000g`0Igoo0021Ool017`0Oomoogoo
0W`01Goo00=l07ooOol017oo0W`01Woo0W`027oo1g`01goo17`000Aoog`0O01l06Eoo`00P7oo00El
07ooOomoog`000Eoo`9l00Eoo`9l00Ioo`9l00Qoo`9l00]oo`Il0003Ooml07`000Al06=oo`00OWoo
0W`00Woo0W`01Goo00=l07ooOol00goo0W`01Woo0W`01goo0g`02Goo17`01Woo27`0HWoo001mOol0
1G`0OomoogooO0001Woo00=l07ooOol00Woo0W`01Woo0W`01Woo0g`027oo17`03Woo1G`0HGoo001l
Ool01G`0OomoogooO0001Goo0W`017oo00=l07ooOol017oo0W`01Woo0W`027oo0g`01goo4W`0Ggoo
001jOol2O003Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool2O005Ool2O006Ool2O008Ool2O006Ool4
O00=Ool6O01NOol007Uoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo
00Aoo`03O01oogoo00Aoo`9l00Moo`=l00Eoo`=l00Yoo`il05eoo`00N7oo00=l07ooOol00Woo00=l
07ooOol00Woo0W`017oo00=l07ooOol00goo0W`01Goo0W`01Woo0g`01Woo0W`02Woo0g`01Woo1G`0
00Aoog`0O01l05aoo`00Mgoo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo0W`01Goo
00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol01Goo0W`027oo17`01Woo0g`017oo1W`0Fgoo
001gOol01G`0OomoogooO00017oo00=l07ooOol00Woo00=l07ooOol017oo00=l07ooOol00goo0W`0
1Woo0W`01Woo0W`027oo0W`01Woo17`01Goo2W`0FGoo001fOol01G`0OomoogooO00017oo00=l07oo
Ool00Woo00=l07ooOol00goo0W`01Goo00=l07ooOol01Goo00=l07ooOol017oo0W`027oo0W`01Goo
0g`01Woo0g`00Woo27`0FGoo001eOol01G`0OomoogooO00017oo00Al07ooOomoo`9l00Eoo`03O01o
ogoo00Aoo`03O01oogoo00Aoo`9l00Eoo`9l00Moo`=l00Eoo`9l00Ioo`=l009oo`=l009oo`Ml05Qo
o`00M7oo00El07ooOomoog`000Aoo`05O01oogooOoml0006Ool00g`0Oomoo`03Ool2O005Ool2O006
Ool00g`0Oomoo`04Ool3O006Ool2O006Ool2O003Ool2O004Ool00g`0Ooml0006O01GOol007Aoo`05
O01oogooOoml0003Ool01G`0OomoogooO0001Goo0W`01Goo00=l07ooOol017oo00=l07ooOol01Goo
00=l07ooOol017oo00=l07ooOol01Goo0W`01Woo0W`00goo0W`017oo37`0EWoo001cOol01G`0Oomo
ogooO0000goo00El07ooOomoog`000Eoo`03O01oogoo00Aoo`03O01oogoo00=oo`9l00Ioo`9l00Eo
o`9l00Ioo`9l00Eoo`=l00Aoo`03O01oogoo009oo`9l0007Ooml07ooO01oog`0Ool01G`0EWoo001b
Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00goo0W`01Goo
00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol017oo0W`01Goo0W`01Goo0W`00goo0W`00Woo
00=l07ooO0000goo1g`0EGoo001aOol01G`0OomoogooO0000goo00=l07ooOol00Woo00=l07ooOol0
0Woo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo0W`01Goo0W`01Goo0W`01Goo0W`0
1Woo00=l07ooOol00Woo00=l07ooOol00W`000=oog`0Ool00goo1g`0EGoo001aOol01G`0Oomoogoo
O0000Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo0W`01Goo
0W`01Goo0W`01Woo00=l07ooOol017oo00=l07ooOol017oo0W`00goo0W`00Woo00Al07ooOoml00Ao
o`03O01oog`000El05Eoo`00L7oo00El07ooOomoog`000=oo`05O01oogooOoml0005Ool00g`0Oomo
o`02Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`05Ool00g`0Oomo
o`04Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00=l07ooOol00goo00=l
07ooOol01W`0E7oo001`Ool017`0Oomoog`00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07oo
Ool00Woo00=l07ooOol00goo00=l07ooOol00goo0W`01Goo0W`01Woo0W`01Goo0W`01Goo0W`017oo
00El07ooOomoog`0009oo`03O01oogoo00=oo`04O01oogooOol6O01DOol006moo`05O01oogooOoml
0002Ool00g`0Oomoo`02Ool017`0Oomoogoo0W`017oo00=l07ooOol00Woo0W`01Goo00=l07ooOol0
17oo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol0
0W`00Woo00=l07ooOol017oo00El07ooOoml07oo009l0003Ooml07`005Aoo`00Kgoo00Al07ooOoml
009oo`03O01oogoo009oo`05O01oogooOoml0005Ool00g`0Oomoo`02Ool00g`0Oomoo`04Ool00g`0
Oomoo`04Ool00g`0Oomoo`04Ool2O005Ool2O005Ool2O004Ool2O002Ool01G`0OomoogooO0001Woo
00Il07ooOomoog`0Ool5O01DOol006ioo`05O01oogooOoml0002Ool01G`0OomoogooO0000goo00=l
07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo0W`01Woo00=l07ooOol00goo0W`01Goo0W`0
1Goo0W`017oo0W`00goo00El07ooOomoog`000Ioo`05O01oogooOoml0002Ool6O01COol006ioo`04
O01oogooO002Ool01G`0OomoogooO0000goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol0
0goo00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol0
0goo00=l07ooOol00Woo00El07ooOomoog`000Ioo`03O01oogoo009oo`04O01oog`0Ool5O01COol0
06eoo`04O01oogooO002Ool01G`0OomoogooO00017oo00=l07ooOol00Woo00=l07ooOol00goo00=l
07ooOol00Woo00=l07ooOol01Goo00=l07ooOol00Woo0W`01Woo00=l07ooOol017oo00=l07ooOol0
0goo00=l07ooOol00Woo00El07ooOomoog`000Ioo`03O01oogoo009oo`04O01oogooO002Ool4O01C
Ool006aoo`04O01oogooO003Ool017`0Oomoog`017oo00=l07ooOol00Woo00=l07ooOol00goo00=l
07ooOol00Woo00=l07ooOol017oo0W`017oo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol0
0goo00=l07ooOol00Woo00El07ooOomoog`000Ioo`03O01oogoo009oo`06O01oogooOoml07oo1G`0
Dgoo001/Ool017`0Oomoog`00Woo00Al07ooOoml00Aoo`03O01oogoo009oo`03O01oogoo00=oo`03
O01oogoo009oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Eoo`03O01oogoo00Aoo`03
O01oogoo009oo`9l00Aoo`05O01oogooOoml0006Ool00g`0Oomoo`03Ool017`0Oomoog`00Woo1W`0
DWoo001[Ool017`0Oomoog`00goo00Al07ooOoml00=oo`03O01oogoo009oo`03O01oogoo009oo`9l
00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`9l00Eoo`9l00Aoo`03O01oogoo
00=oo`05O01oogooOoml0007Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00=l07ooO0000g`0
DWoo001[Ool017`0Oomoog`00Woo00Al07ooOoml00Aoo`05O01oogooOoml0004Ool00g`0Oomoo`03
Ool00g`0Oomoo`03Ool2O005Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0
Oomoo`02Ool2O003Ool00g`0Oomoo`05Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00=l07oo
O0000g`0DWoo001ZOol017`0Oomoog`00Woo00El07ooOomoog`000=oo`05O01oogooOoml0004Ool0
0g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool0
0g`0Oomoo`02Ool2O004Ool00g`0Oomoo`02Ool00g`0Oomoo`05Ool00g`0Oomoo`02Ool00g`0Oomo
o`02Ool017`0Oomoog`00Woo17`0DWoo001ZOol017`0Oomoog`00Woo00Al07ooOoml00=oo`03O01o
ogoo009oo`05O01oogooOoml0005Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool2
O005Ool2O004Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`05Ool00g`0Oomoo`03Ool0
0g`0Oomoo`02Ool01g`0Oomoog`0Ooml07oo00=l059oo`00JGoo00Al07ooOoml009oo`05O01oogoo
Ooml0003Ool01G`0OomoogooO00017oo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol017oo
00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo0W`017oo00=l07oo
Ool01Goo00=l07ooOol00goo00=l07ooOol00Woo00Ql07ooOomoog`0Ooml07oo0g`0DWoo001YOol0
17`0Oomoog`00Woo00Al07ooOoml00=oo`05O01oogooOoml0004Ool00g`0Oomoo`02Ool00g`0Oomo
o`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomo
o`02Ool00g`0Oomoo`03Ool00g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool027`0Oomo
ogooO01oog`0Ool3O01BOol006Uoo`06O01oogooO01oog`00goo00El07ooOomoog`0009oo`03O01o
ogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01o
ogoo00Aoo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Eoo`03O01o
ogoo00Aoo`03O01oogoo009oo`05O01oogooOoml0002Ool00g`0Ooml0002O01BOol006Qoo`04O01o
ogooO002Ool017`0Oomoog`00goo00El07ooOomoog`000=oo`03O01oogoo009oo`03O01oogoo00=o
o`03O01oogoo00=oo`9l00Eoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo009oo`03O01o
ogoo00=oo`03O01oogoo00Eoo`03O01oogoo00Aoo`03O01oogoo00=oo`07O01oogooOoml07ooO000
0Woo0g`0DWoo001XOol01W`0Oomoog`0Ooml009oo`05O01oogooOoml0003Ool01G`0OomoogooO000
17oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol0
0Woo0W`01Goo00=l07ooOol00Woo00=l07ooOol01Woo00=l07ooOol017oo00=l07ooOol00Woo00El
07ooOomoog`0009oo`03O01oogoo00=l059oo`00Igoo00Al07ooOoml009oo`04O01oogooO002Ool0
1G`0OomoogooO0000goo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol0
17oo00=l07ooOol00goo0W`017oo00=l07ooOol017oo00=l07ooOol00Woo00=l07ooOol01Woo00=l
07ooOol017oo00=l07ooOol00goo00Ml07ooOomoog`0Ooml0002Ool00g`0Ooml0002O01AOol006Mo
o`06O01oogooO01oog`00Woo00El07ooOomoog`0009oo`05O01oogooOoml0005Ool00g`0Oomoo`02
Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04
Ool00g`0Oomoo`02Ool00g`0Oomoo`06Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool01G`0Oomoogoo
O0000Woo00=l07ooOol00W`000=oog`0O000DGoo001WOol027`0Oomoog`0Ooml07ooO003Ool01G`0
OomoogooO0000Woo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol017oo00=l07ooOol00goo
00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00Woo00=l07ooOol01Woo
00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`0009oo`03O01oogoo009l0003Ooml07`0
055oo`00Igoo00El07ooO01oog`0009oo`04O01oogooO003Ool01G`0OomoogooO00017oo00=l07oo
Ool00Woo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo0W`01Goo00=l07ooOol017oo
00=l07ooOol00Woo00=l07ooOol01Woo00=l07ooOol01Goo00=l07ooOol00goo00El07ooOomoog`0
009oo`04O01oogooOol2O0000gooO01l001AOol006Ioo`08O01oogooO01oog`0Ooml00=oo`04O01o
ogooO003Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool2O004
Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool00g`0Oomoo`06Ool00g`0Oomoo`05
Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool017`0Oomoog`00goo0W`000=oog`0O000DGoo001VOol0
1G`0Ooml07ooO0000Woo00Al07ooOoml009oo`05O01oogooOoml0005Ool01G`0OomoogooO0001Goo
0W`017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo0W`017oo00=l07ooOol01Woo
00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol00Woo00El07ooOomoog`0009oo`04O01oog`0
Ool2O01AOol006Ioo`07O01oog`0Ooml07ooO0000goo00Al07ooOoml00=oo`03O01oogoo009oo`05
O01oogooOoml0005Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03
Ool00g`0Oomoo`03Ool00g`0Oomoo`06Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool01G`0Oomoogoo
O0000goo00Al07ooOomoo`9l009oo`9l055oo`00IWoo00Ml07ooO01oog`0Ooml0002Ool017`0Oomo
og`00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07oo
Ool017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol01Woo00=l07oo
Ool01Goo00=l07ooOol017oo00=l07ooOol00Woo00El07ooOomoog`0009oo`04O01oog`0Ool3O01A
Ool006Ioo`9l0004Ooml07ooO002Ool017`0Oomoog`017oo00El07ooOomoog`000Aoo`03O01oogoo
009oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo
00=oo`03O01oogoo00Ioo`03O01oogoo00Ioo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo
009oo`07O01oogooO01oog`0Ool00g`0DGoo001UOol01g`0Ooml07ooO01oog`0009oo`04O01oogoo
O003Ool01G`0OomoogooO00017oo00=l07ooOol00Woo00=l07ooOol017oo00=l07ooOol00goo00=l
07ooOol00Woo0W`01Goo00=l07ooOol00goo00=l07ooOol01Woo00=l07ooOol01Woo00=l07ooOol0
0goo00=l07ooOol00goo00El07ooOomoog`000=oo`04O01oog`0Ool3O01AOol006Eoo`9l0004Ooml
07ooO002Ool017`0Oomoog`00goo00El07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo00Ao
o`03O01oogoo009oo`9l00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Moo`03O01o
ogoo00Eoo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`04O01oogooO002Ool00g`0
Ooml0002O01AOol006Eoo`9l0004Ooml07ooO002Ool017`0Oomoog`00Woo00El07ooOomoog`000Eo
o`05O01oogooOoml0005Ool2O004Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool0
0g`0Oomoo`07Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool0
1W`0Oomoog`0Ooml009oo`Al051oo`00IGoo0W`000Ioog`0Ooml07ooO002Ool01G`0OomoogooO000
0Woo00=l07ooOol00goo00El07ooOomoog`000Eoo`03O01oogoo00=oo`03O01oogoo00=oo`03O01o
ogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Moo`03O01oogoo00Eoo`03O01oogoo00Aoo`03O01o
ogoo00=oo`03O01oogoo009oo`0:O01oogooOoml07ooO01oog`0Ool3O01@Ool006Eoo`=l0005Ooml
07ooOoml0002Ool017`0Oomoog`00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo
00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol01goo
00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00Woo00Al07ooOoml009o
o`04O01oog`0Ool3O01@Ool006Aoo`9l0006Ooml07ooO01oog`00Woo00Al07ooOoml00=oo`03O01o
ogoo009oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01o
ogoo00=oo`03O01oogoo00=oo`03O01oogoo00Moo`03O01oogoo00Ioo`03O01oogoo00=oo`03O01o
ogoo00Aoo`03O01oogoo009oo`05O01oogooOoml0002Ool00g`0Ooml0004O01@Ool006Aoo`=l0005
Ooml07ooOoml0002Ool017`0Oomoog`00Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol0
0goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo0W`01Goo00=l07ooOol01goo00=l
07ooOol01Woo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00Woo00Yl07ooOomoog`0Ooml
07ooO01oo`Al051oo`00I7oo0g`000Aoog`0Ooml009oo`04O01oogooO002Ool00g`0Oomoo`02Ool0
0g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool2O004Ool00g`0Oomo
o`04Ool00g`0Oomoo`07Ool00g`0Oomoo`06Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomo
o`02Ool01G`0OomoogooO0000Woo00Al07ooO01oo`Al051oo`00I7oo0g`000Aoog`0Ooml009oo`04
O01oogooO002Ool01G`0OomoogooO0001Goo00=l07ooOol00Woo00=l07ooOol00Woo0W`017oo00=l
07ooOol00goo00=l07ooOol017oo00=l07ooOol01goo00=l07ooOol01Woo00=l07ooOol017oo00=l
07ooOol017oo00=l07ooOol00Woo00=l07ooOol00Woo00Ml07ooOoml07ooO01oo`04O01@Ool006Ao
o`=l0003Ooml07`0009oo`04O01oogooO002Ool01G`0OomoogooO0001Goo00=l07ooOol00Woo00=l
07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol01goo00=l
07ooOol01Woo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol00Woo00El07ooOomoog`0009o
o`03O01oog`0009oo`Al051oo`00I7oo0W`000Aoog`0Ooml009oo`04O01oogooO002Ool01G`0Oomo
ogooO00017oo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol017oo00=l
07ooOol00goo00=l07ooOol01goo00=l07ooOol01Woo00=l07ooOol01Goo00=l07ooOol017oo00=l
07ooOol00Woo00=l07ooOol00Woo00Ul07ooOoml07ooO01oog`0Ool00g`0D7oo001SOol3O0000goo
O01l0002Ool017`0Oomoog`00Woo00El07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo009o
o`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Moo`03O01oogoo00Mo
o`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo009oo`03O01oogoo009oo`0:O01oogooOoml
07ooO01oog`0Ool3O01@Ool006=oo`=l0003Ooml07`0009oo`04O01oogooO002Ool017`0Oomoog`0
1Goo00El07ooOomoog`000Eoo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01o
ogoo00Moo`03O01oogoo00Moo`03O01oogoo00Aoo`03O01oogoo00Eoo`03O01oogoo009oo`03O01o
ogoo009oo`04O01oogooO002Ool00g`0Ooml0004O01@Ool006=oo`=l0005Ooml07`0Ooml0002Ool0
17`0Oomoog`00Woo00=l07ooOol00goo00El07ooOomoog`000Eoo`03O01oogoo00=oo`03O01oogoo
00=oo`03O01oogoo00=oo`03O01oogoo00Moo`03O01oogoo00Moo`03O01oogoo00Aoo`03O01oogoo
00Eoo`03O01oogoo009oo`03O01oogoo009oo`07O01oogooOoml07ooO0000Woo1G`0D7oo001SOol4
O0001WooO01oog`0Ooml00=oo`04O01oogooO004Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0
Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0
Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool02W`0OomoogooO01oog`0
Ooml07oo17`0D7oo001SOol2O0001GooO01l07ooO0000Woo00Al07ooOoml009oo`03O01oogoo009o
o`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=o
o`03O01oogoo00Moo`03O01oogoo00Moo`03O01oogoo00Eoo`03O01oogoo00Eoo`03O01oogoo009o
o`03O01oogoo009oo`05O01oogooOoml0002Ool017`0Ooml07oo17`0D7oo001ROol4O0001WooO01o
og`0Ooml009oo`04O01oogooO004Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool0
0g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`05Ool0
0g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01g`0OomoogooO01oog`0009oo`03O01o
og`000=l051oo`00HWoo17`000=oog`0O0000Woo00Al07ooOoml009oo`05O01oogooOoml0004Ool0
0g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`07Ool0
0g`0Oomoo`07Ool00g`0Oomoo`05Ool00g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool0
1G`0OomoogooO0000Woo00Il07ooO01oog`0Ool3O01@Ool0069oo`Al0005Ooml07`0Ooml0002Ool0
17`0Oomoog`00goo00=l07ooOol00goo00El07ooOomoog`000Eoo`03O01oogoo00=oo`03O01oogoo
00=oo`03O01oogoo00Moo`03O01oogoo00Moo`03O01oogoo00Ioo`03O01oogoo00Aoo`03O01oogoo
00Aoo`03O01oogoo009oo`05O01oogooOoml0002Ool01W`0Ooml07ooO01oo`=l051oo`00HWoo1G`0
00Aoog`0Ooml009oo`04O01oogooO002Ool00g`0Oomoo`03Ool01G`0OomoogooO0001Goo00=l07oo
Ool00goo00=l07ooOol00goo00=l07ooOol01goo00=l07ooOol01goo00=l07ooOol01Woo00=l07oo
Ool01Goo00=l07ooOol00goo00=l07ooOol00Woo00El07ooOomoog`000=oo`04O01oog`0Ool5O01@
Ool0069oo`=l0005Ooml07`0Ooml0002Ool017`0Oomoog`00goo00=l07ooOol00Woo00=l07ooOol0
0Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol01goo00=l07ooOol0
1goo00=l07ooOol01Woo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol00Woo00El07ooOomo
og`0009oo`05O01oogooO01oo`05O01@Ool0069oo`Al0004Ooml07ooO002Ool017`0Oomoog`00Woo
00Al07ooOomoo`9l00Aoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo
00Moo`03O01oogoo00Moo`03O01oogoo00Ioo`03O01oogoo00Eoo`03O01oogoo00Aoo`03O01oogoo
009oo`03O01oogoo009oo`09O01oogooO01oog`0Ooml07oo00Al051oo`00HWoo17`000=oog`0O000
0Woo00Al07ooOoml009oo`05O01oogooOoml0005Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0
Oomoo`03Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`04Ool00g`0
Oomoo`05Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00Il07ooO01oog`0Ool4O01@Ool0069o
o`Al0003Ooml07`0009oo`04O01oogooO002Ool017`0Oomoog`01Goo00=l07ooOol00Woo00=l07oo
Ool00goo00=l07ooOol00goo00=l07ooOol01goo00=l07ooOol027oo00=l07ooOol01Woo00=l07oo
Ool017oo00=l07ooOol01Goo00=l07ooOol00Woo00=l07ooOol00Woo00Al07ooOoml009oo`04O01o
og`0Ool4O01@Ool0069oo`El0004Ooml07ooO002Ool017`0Oomoog`00Woo00=l07ooOol00goo00=l
07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol01goo00=l07ooOol027oo00=l
07ooOol01Woo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol00goo00El07ooOomoog`000=o
o`08O01oog`0Ooml07ooO01oo`9l055oo`00HWoo0g`000Eoog`0O01oog`0009oo`05O01oogooOoml
0002Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomo
o`07Ool00g`0Oomoo`08Ool00g`0Oomoo`06Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomo
o`03Ool00g`0Oomoo`02Ool017`0Oomoog`00Woo00Il07ooO01oog`0Ool2O01AOol0069oo`Al0004
Ooml07ooO002Ool017`0Oomoog`00Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol00Woo
00=l07ooOol00goo00=l07ooOol01goo00=l07ooOol027oo00=l07ooOol01Woo00=l07ooOol01Goo
00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00El07ooOomoog`0009oo`04O01oog`0
Ool4O01AOol0069oo`Al0003Ooml07`0009oo`04O01oogooO002Ool00g`0Oomoo`02Ool00g`0Oomo
o`03Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`07Ool00g`0Oomoo`08Ool00g`0Oomo
o`06Ool00g`0Oomoo`05Ool00g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool017`0Oomo
og`00goo00Al07ooO01oo`Al055oo`00HWoo17`000=oog`0O0000Woo00Il07ooOoml07ooO004Ool0
0g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`07Ool00g`0Oomoo`08Ool0
0g`0Oomoo`06Ool00g`0Oomoo`05Ool00g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool0
1G`0OomoogooO0000Woo00Il07ooO01oog`0Ool3O01AOol0069oo`Il009oo`04O01oogooO002Ool0
1G`0OomoogooO00017oo0W`017oo00=l07ooOol00goo00=l07ooOol01goo00=l07ooOol027oo00=l
07ooOol01Woo00=l07ooOol01Goo00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol00goo00Al
07ooOoml00=oo`06O01oog`0Ooml07oo0g`0DGoo001ROol3O0001GooO01l07ooO0000Woo00Al07oo
Ooml00=oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Moo`03O01o
ogoo00Qoo`03O01oogoo00Ioo`03O01oogoo00Ioo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01o
ogoo00=oo`05O01oogooOoml0003Ool01W`0Ooml07ooO01oo`=l055oo`00HWoo1G`00Woo00=l07oo
O0000Woo00=l07ooOol00Woo00El07ooOomoog`000Eoo`03O01oogoo00=oo`03O01oogoo00Moo`03
O01oogoo00Qoo`03O01oogoo00Ioo`03O01oogoo00Ioo`03O01oogoo00Eoo`03O01oogoo00=oo`03
O01oogoo00=oo`04O01oogooO003Ool01G`0Oomoog`0Ool00W`000=oog`0O000DGoo001ROol5O000
1GooO01oogooO0000Woo00El07ooOomoog`000=oo`03O01oogoo00Aoo`03O01oogoo009oo`03O01o
ogoo00Moo`03O01oogoo00Qoo`03O01oogoo00Ioo`03O01oogoo00Ioo`03O01oogoo00Eoo`03O01o
ogoo00=oo`03O01oogoo00=oo`05O01oogooOoml0003Ool01W`0Ooml07ooO01oo`=l059oo`00HWoo
0g`000Ioog`0Ooml07ooO002Ool01G`0OomoogooO00017oo00=l07ooOol00goo00=l07ooOol00Woo
00=l07ooOol01goo00=l07ooOol027oo00=l07ooOol01goo00=l07ooOol01Goo00=l07ooOol01Goo
00=l07ooOol00goo00=l07ooOol017oo00Al07ooOoml00=oo`07O01oogooO01oog`0Ool00g`0DWoo
001ROol4O00017ooO01oog`00goo00Al07ooOoml00Aoo`03O01oogoo00=oo`03O01oogoo009oo`03
O01oogoo00Moo`03O01oogoo00Qoo`03O01oogoo00Moo`03O01oogoo00Eoo`03O01oogoo00Eoo`03
O01oogoo00Aoo`03O01oogoo00=oo`05O01oogooOoml0003Ool00g`0Ooml0002Ool00g`0Ooml0002
O01BOol0069oo`9l0006Ooml07ooO01oog`00Woo00El07ooOomoog`000=oo`03O01oogoo009oo`9l
00Aoo`03O01oogoo00Moo`03O01oogoo00Qoo`03O01oogoo00Moo`03O01oogoo00Eoo`03O01oogoo
00Ioo`03O01oogoo00=oo`03O01oogoo00=oo`05O01oogooOoml0003Ool017`0Oomoog`00Woo0W`0
00=oog`0O000DWoo001ROol2O0001GooO01l07ooO0000Woo00El07ooOomoog`000=oo`03O01oogoo
009oo`03O01oogoo00=oo`03O01oogoo00Moo`03O01oogoo00Qoo`03O01oogoo00Moo`03O01oogoo
00Ioo`03O01oogoo00Eoo`03O01oogoo00=oo`03O01oogoo00Aoo`04O01oogooO004Ool00g`0Ooml
0002Ool017`0Ooml07oo0W`0DWoo001ROol2O0001GooO01l07ooO0000Woo00Al07ooOoml00Aoo`05
O01oogooOoml0005Ool00g`0Oomoo`07Ool00g`0Oomoo`08Ool00g`0Oomoo`07Ool00g`0Oomoo`06
Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool01G`0OomoogooO0000goo00Al07oo
Ooml009oo`05O01oog`0Ooml001COol0069oo`Al0005Ooml07ooOoml0003Ool01G`0OomoogooO000
0goo00=l07ooOol00goo00=l07ooOol01goo00=l07ooOol027oo00=l07ooOol01goo00=l07ooOol0
1Woo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol00goo00El07ooOomoog`000Aoo`04O01o
ogooO002Ool00g`0Ooml0002O01COol0065oo`El0004Ooml07ooO003Ool01G`0OomoogooO00017oo
00=l07ooOol00Woo00=l07ooOol01goo00=l07ooOol027oo00=l07ooOol01goo00=l07ooOol01Woo
00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00El07ooOomoog`0
009oo`07O01oogooO01oog`0Ool00W`0Dgoo001QOol4O0001GooO01oogooO0000goo00Al07ooOoml
00Aoo`03O01oogoo009oo`03O01oogoo00Moo`03O01oogoo00Moo`9l00Uoo`03O01oogoo00Ioo`03
O01oogoo00Ioo`03O01oogoo00Aoo`03O01oogoo00=oo`05O01oogooOoml0004Ool017`0Oomoog`0
0Woo00Al07ooO01oo`9l05=oo`00HGoo17`000Aoog`0Ooml00=oo`04O01oogooO004Ool00g`0Oomo
o`02Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`08Ool00g`0Oomoo`06Ool00g`0Oomo
o`06Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00Al
07ooOoml009oo`03O01oog`005Aoo`00HGoo17`000Aoog`0Ooml009oo`04O01oogooO004Ool00g`0
Oomoo`02Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`08Ool00g`0Oomoo`06Ool00g`0
Oomoo`06Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool017`0
Oomoog`00Woo00=l07ooOol00g`0E7oo001QOol5O0001GooO01oogooO0000Woo00=l07ooOol00Woo
00=l07ooOol00Woo00=l07ooOol01goo00=l07ooOol01goo00=l07ooOol027oo00=l07ooOol01goo
00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol017oo00El07ooOomoog`000Aoo`04O01oogoo
O002Ool01G`0Oomoog`0Ool00W`0E7oo001QOol5O00017ooO01oog`00goo00El07ooOomoog`000Ao
o`03O01oogoo00Moo`03O01oogoo00Moo`03O01oogoo00Qoo`03O01oogoo00Moo`03O01oogoo00Eo
o`03O01oogoo00Eoo`03O01oogoo00=oo`03O01oogoo009oo`05O01oogooOoml0003Ool017`0Oomo
og`00Woo00Al07ooO01l05Aoo`00HGoo17`000Aoog`0Ooml00=oo`05O01oogooOoml0004Ool00g`0
Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`08Ool00g`0Oomoo`07Ool00g`0Oomoo`05Ool00g`0
Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool017`0Oomoog`00goo00=l
07ooOol00g`0EGoo001QOol4O00017ooO01oog`00Woo00El07ooOomoog`000Aoo`03O01oogoo00Mo
o`03O01oogoo00Moo`03O01oogoo00Qoo`03O01oogoo00Moo`03O01oogoo00Eoo`03O01oogoo00Eo
o`03O01oogoo00Aoo`03O01oogoo009oo`05O01oogooOoml0003Ool017`0Oomoog`00Woo00Al07oo
O01l05Eoo`00HGoo1G`000=oog`0Ool00Woo00Al07ooOoml00Aoo`03O01oogoo00Moo`03O01oogoo
00Moo`03O01oogoo00Qoo`03O01oogoo00Moo`03O01oogoo00Eoo`03O01oogoo00Eoo`03O01oogoo
00Aoo`03O01oogoo009oo`03O01oogoo009oo`04O01oogooO003Ool00g`0Oomoo`02O0000gooO01o
o`1DOol0061oo`Ml00=oo`04O01oogooO004Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomo
o`08Ool00g`0Oomoo`06Ool2O007Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool0
1G`0OomoogooO0000goo00Al07ooOoml009oo`05O01oog`0Ooml001EOol0061oo`=l0004Ooml07`0
O002Ool01G`0OomoogooO0000goo00=l07ooOol01goo00=l07ooOol01goo00=l07ooOol027oo00=l
07ooOol01Woo00=l07ooOol01Woo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol00goo00=l
07ooOol00Woo00Al07ooOoml00=oo`05O01oogooO01oo`02O01FOol0061oo`Il009oo`05O01oogoo
Ooml0003Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool2O008Ool00g`0Oomoo`06
Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0Oomoogoo
O0000Woo00Ql07ooOoml07ooO01oog`0EWoo001POol6O002Ool017`0Oomoog`00goo00=l07ooOol0
1goo00=l07ooOol01goo00=l07ooOol01goo00=l07ooOol01goo00=l07ooOol01Woo00=l07ooOol0
1Goo00=l07ooOol01Goo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`000=oo`08O01o
ogooO01oog`0Ooml05Ioo`00H7oo27`00Woo00El07ooOomoog`000Uoo`03O01oogoo00Moo`03O01o
ogoo00Moo`03O01oogoo00Moo`03O01oogoo00Ioo`03O01oogoo00Eoo`03O01oogoo00Eoo`03O01o
ogoo009oo`03O01oogoo00=oo`04O01oogooO003Ool027`0Oomoog`0Ooml07ooO01GOol0061oo`Ml
009oo`05O01oogooOoml0009Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0
Oomoo`06Ool00g`0Oomoo`05Ool00g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0
OomoogooO0000goo00Ql07ooOoml07ooO01oog`0Egoo001POol4O0000gooO01l0002O003Ool00g`0
Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0Oomoo`06Ool00g`0
Oomoo`05Ool00g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo
00Ql07ooOoml07ooO01oog`0F7oo001POol4O00017ooO01oog`00goo00=l07ooOol01goo00=l07oo
Ool01goo00=l07ooOol01Woo0W`02Goo00=l07ooOol01Woo00=l07ooOol01Woo00=l07ooOol017oo
00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`0009oo`05O01oog`0
Ooml001HOol005moo`Al0003Ooml07`0009l009oo`03O01oogoo00Ioo`9l00Qoo`9l00Qoo`03O01o
ogoo00Qoo`03O01oogoo00Ioo`03O01oogoo00Ioo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01o
ogoo00=oo`05O01oogooOoml0003Ool027`0Oomoog`0Ooml07ooO01IOol005moo`Ul0003Ooml07oo
00Moo`03O01oogoo00Moo`03O01oogoo00Moo`03O01oogoo00Qoo`03O01oogoo00Ioo`03O01oogoo
00Ioo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo009oo`03O01oogoo009oo`05O01oogoo
Ooml0002Ool01G`0Ooml07ooO000FGoo001OOol4O0001WooO01l07`0Ooml00Qoo`03O01oogoo00Mo
o`03O01oogoo00Moo`03O01oogoo00Qoo`03O01oogoo00Ioo`03O01oogoo00Ioo`03O01oogoo00Eo
o`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`05O01oogooOoml0002Ool01G`0Ooml
07ooO000FWoo001NOol5O0000gooO01oo`03O007Ool00g`0Oomoo`07Ool00g`0Oomoo`07Ool00g`0
Oomoo`07Ool2O008Ool00g`0Oomoo`06Ool00g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`03
Ool01G`0OomoogooO0000goo00Al07ooOoml009oo`03O01oog`005Yoo`00GWoo1g`000Aoog`0Ooml
00Eoo`9l00Qoo`9l00Uoo`03O01oogoo00Moo`03O01oogoo00Moo`03O01oogoo00Eoo`9l00Moo`03
O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`05O01oogooOoml0002Ool01G`0Ooml07oo
O000Fgoo001NOol6O0000gooO01oo`02O004Ool00g`0Oomoo`07Ool00g`0Oomoo`08Ool00g`0Oomo
o`07Ool00g`0Oomoo`07Ool00g`0Oomoo`05Ool00g`0Oomoo`06Ool00g`0Oomoo`04Ool00g`0Oomo
o`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00Il07ooOoml07ooO01KOol005ioo`Ql0004
Ooml07ooO002Ool00g`0Oomoo`07Ool00g`0Oomoo`08Ool00g`0Oomoo`06Ool2O008Ool2O007Ool0
0g`0Oomoo`06Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool01G`0OomoogooO0000goo00Al07ooOoml
009oo`03O01oog`005aoo`00GWoo1W`000Aoog`0Oomoo`9l0003Ooml07oo00Qoo`03O01oogoo00Mo
o`9l00Qoo`03O01oogoo00Moo`03O01oogoo00Ioo`03O01oogoo00Ioo`03O01oogoo00Aoo`03O01o
ogoo00=oo`03O01oogoo009oo`05O01oogooOoml0002Ool01W`0Oomoog`0Ooml05aoo`00GWoo27`0
0Woo0g`027oo0W`02Goo00=l07ooOol01Woo0W`02Goo00=l07ooOol01Woo00=l07ooOol01Woo00=l
07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00El07ooOomoog`0009oo`06O01oogooO01o
og`0GGoo001NOol4O0001gooO01l07ooO01oog`0009oo`03O01oogoo00Aoo`03O01oogoo00Moo`9l
00Qoo`03O01oogoo00Qoo`03O01oogoo00Ioo`03O01oogoo00Ioo`03O01oogoo00Aoo`03O01oogoo
00=oo`03O01oogoo009oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo00=l07ooOol0Fgoo001M
Ool5O0000gooO01oo`03O00017ooO01oog`01Goo00=l07ooOol01goo00=l07ooOol01goo00=l07oo
Ool027oo00=l07ooOol01Woo00=l07ooOol01Woo00=l07ooOol017oo00=l07ooOol00goo00=l07oo
Ool00Woo00El07ooOomoog`000=oo`06O01oogooO01oog`0GWoo001MOol4O00017ooO01l07oo0g`0
00Eoog`0Oomoog`000=oo`03O01oogoo00Ioo`9l00Qoo`9l00Uoo`9l00Qoo`03O01oogoo00Ioo`03
O01oogoo00Aoo`03O01oogoo00Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000Woo00Al07oo
Ooml05ioo`00G7oo1G`000Moog`0O01oog`0Ooml0002Ool017`0Ooml07oo0W`01goo0W`02Goo00=l
07ooOol027oo00=l07ooOol01goo00=l07ooOol01Goo0W`01Woo00=l07ooOol017oo00=l07ooOol0
0Woo00El07ooOomoog`0009oo`04O01oogooO002Ool00g`0Oomoo`1MOol005aoo`=l0003Ooml07oo
00Al0005Ooml07ooOoml0002Ool00g`0Oomoo`06Ool00g`0Oomoo`08Ool00g`0Oomoo`08Ool00g`0
Oomoo`07Ool00g`0Oomoo`05Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool01G`0
OomoogooO0000goo00Al07ooOoml009oo`03O01oogoo05eoo`00Fgoo17`000Yoog`0O01l07ooO01o
og`0Ooml009oo`=l00Moo`03O01oogoo00Qoo`03O01oogoo00Qoo`03O01oogoo00Ioo`9l00Moo`03
O01oogoo00Aoo`9l00Ioo`03O01oogoo009oo`05O01oogooOoml0003Ool017`0Oomoog`00Woo00=l
07ooOol0GWoo001KOol3O0000gooO01l0002O0001GooO01oog`0Ool017`00Woo00=l07ooOol00Woo
0W`02Goo0W`02Goo0W`027oo00=l07ooOol01Woo00=l07ooOol017oo00=l07ooOol01Goo00=l07oo
Ool00Woo00El07ooOomoog`000=oo`04O01oogooO002Ool00g`0Oomoo`1OOol005Yoo`Al0007Ooml
07`0O01oog`0Ool01G`00Woo00=l07ooO0000goo00=l07ooOol027oo00=l07ooOol027oo00=l07oo
Ool01goo00=l07ooOol01Woo00=l07ooOol017oo00=l07ooOol017oo0W`017oo00El07ooOomoog`0
00=oo`04O01oogooO003Ool00g`0Oomoo`1OOol005Uoo`Ul0003Ooml07oo00=l0005Ooml07ooOoml
0002Ool3O00:Ool00g`0Oomoo`08Ool00g`0Oomoo`06Ool2O007Ool2O006Ool00g`0Oomoo`04Ool0
0g`0Oomoo`03Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`03O01oogoo061oo`00F7oo
00=l07ooO0001W`000=oog`0Ool017`00Woo00=l07ooOol017`02Goo0W`02Goo0W`027oo00=l07oo
Ool01Woo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00El07oo
Oomoog`0009oo`04O01oogooO01SOol005Yoo`Ml000:Ooml07`0O01oog`0Ooml07ooO002Ool017`0
Oomoog`01goo0W`02Goo0W`027oo0W`027oo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol0
0goo00=l07ooOol00Woo00El07ooOomoog`0009oo`04O01oogooO01TOol005]oo`Al000<Ooml07`0
Ooml07ooO01oog`0Ooml07oo0W`000Eoog`0Oomoog`000Aoo`9l00Uoo`9l00Uoo`03O01oogoo00Mo
o`03O01oogoo00Eoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo009oo`05O01oogooOoml
0002Ool017`0Oomoog`0IGoo001LOol6O0001gooO01oog`0Ooml07oo009l0005Ooml07ooOoml0002
Ool017`0Ooml07`02Goo0W`02Goo0W`027oo0W`01goo00=l07ooOol017oo00=l07ooOol00goo00=l
07ooOol00Woo00El07ooOomoog`0009oo`04O01oogooO01VOol005eoo`=l0004Ooml07`0Ool5O000
17ooO01oog`00Woo00=l07ooOol00W`02Goo0W`02Goo0W`02Goo00=l07ooOol01Goo0W`01Woo00=l
07ooOol00goo00Al07ooOomoo`9l00=oo`07O01oogooOoml07ooO000Igoo001OOol6O0002GooO01o
ogooO01oog`0Ooml0002Ool2O0000gooO01oo`06Ool2O00:Ool00g`0Oomoo`08Ool00g`0Oomoo`05
Ool00g`0Oomoo`05Ool00g`0Oomoo`03Ool01G`0OomoogooO00017oo00Ml07ooOomoog`0Ooml001X
Ool0061oo`0:O01oog`0O01oog`0Ooml07ooO002Ool5O003Ool00g`0Oomoo`02Ool2O00:Ool2O009
Ool2O006Ool2O006Ool2O005Ool01G`0OomoogooO00017oo00Ml07ooOomoog`0Ooml001YOol0065o
o`al009oo`03O01oog`000=oo`04O01oog`0O00:Ool2O009Ool2O007Ool00g`0Oomoo`05Ool00g`0
Oomoo`04Ool01G`0OomoogooO00017oo00Ml07ooOomoog`0Ooml001ZOol0069oo`9l0007Ooml07`0
Ooml07ooO0000Woo00Il07ooOoml07ooO002Ool2O00:Ool2O009Ool2O007Ool2O006Ool2O005Ool2
O002Ool2O004Ool00g`0Oomoo`02O002Ool00g`0Oomoo`1XOol006Aoo`Al0004Ooml07ooO002Ool0
0g`0Oomoo`04O002Ool00g`0Oomoo`05Ool2O009Ool2O007Ool2O007Ool00g`0Oomoo`04Ool01G`0
OomoogooO0001Goo00Al07ooOoml00=oo`03O01oogoo06Uoo`00IGoo3W`00Woo00Al07ooOoml00=o
o`=l00Uoo`9l00Qoo`03O01oogoo00Eoo`9l00Ioo`05O01oogooOoml0005Ool017`0Oomoog`00goo
00=l07ooOol0JWoo001WOol3O0000gooO01l0002Ool017`0Oomoog`00goo00=l07ooOol00g`02Woo
0W`027oo0W`01Woo0W`01Woo0W`00goo00=l07ooOol00goo00Al07ooOoml009oo`9l06eoo`00J7oo
1g`000Aoog`0Oomoo`Ul00Qoo`9l00Qoo`9l00Moo`03O01oogoo00Aoo`9l00=oo`9l00Aoo`9l0004
Ooml07`0Ool2O01_Ool006Yoo`9l0003Ooml07`000Al0003Ooml07oo009oo`05O01oogooOoml0003
Ool4O007Ool3O007Ool2O005Ool2O004Ool00g`0Oomoo`02Ool2O002Ool017`0Oomoog`0LGoo001/
Ool5O002Ool017`0Ooml07`00Woo00=l07ooO00017`02Goo0W`027oo0W`01Goo0W`01Goo00=l07oo
Ool00Woo00Il07ooOomoog`0Ool2O01bOol006ioo`il009oo`9l00Eoo`Al00Qoo`9l00Eoo`9l00Eo
o`9l00=oo`9l009oo`Al07Aoo`00L7oo17`000Eoog`0O01oog`000=oo`04O01oogooOol5O009Ool3
O005Ool2O005Ool2O003Ool2O002Ool2O0000gooO01oo`1eOol007=oo`el0003Ooml07`000Moo`Al
00Ioo`9l00Eoo`9l00=oo`9l009oo`9l0003Ooml07`007Moo`00MGoo1G`000=oog`0Ool00Woo0W`0
0Woo1g`01goo0g`01Goo0W`00goo0W`00Woo1G`0NGoo001hOol?O007Ool3O004Ool4O002Ool3O000
0gooO01l0003O01lOol007aoo`El009oo`]l009oo`El00=oo`=l009oo`El07ioo`00PGoo3g`017oo
17`000=oog`0O0000g`0PWoo0026OolCO027Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {359.625, 130.25}} -> {-0.399192, \
0.567848, 0.00348777, 0.00348777}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig3C = Show[Fig3A, \ Fig3B];\)\)], "Input",
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.50625 .49375 m
.49375 .50625 L
s
.51873 .48127 m
.50625 .49375 L
s
0 0 1 r
.49375 .49375 m
.50625 .50625 L
s
.48127 .48127 m
.49375 .49375 L
s
1 0 0 r
.49375 .50625 m
.48127 .51873 L
s
0 0 1 r
.50625 .50625 m
.51873 .51873 L
s
1 0 0 r
.49375 .48446 m
.48129 .49701 L
s
.50626 .47199 m
.49375 .48446 L
s
0 0 1 r
.50625 .48446 m
.51871 .49701 L
s
.49374 .47199 m
.50625 .48446 L
s
1 0 0 r
.48129 .49701 m
.46891 .50959 L
s
0 0 1 r
.51871 .49701 m
.53109 .50959 L
s
1 0 0 r
.53115 .46885 m
.51873 .48127 L
s
0 0 1 r
.46885 .46885 m
.48127 .48127 L
s
1 0 0 r
.48127 .51873 m
.46885 .53115 L
s
0 0 1 r
.51873 .51873 m
.53115 .53115 L
s
1 0 0 r
.51878 .45964 m
.50626 .47199 L
s
0 0 1 r
.48122 .45964 m
.49374 .47199 L
s
1 0 0 r
.48126 .4753 m
.46891 .48799 L
s
.49373 .46275 m
.48126 .4753 L
s
0 0 1 r
.51874 .4753 m
.53109 .48799 L
s
.50627 .46275 m
.51874 .4753 L
s
1 0 0 r
.46891 .50959 m
.45666 .52218 L
s
0 0 1 r
.53109 .50959 m
.54334 .52218 L
s
1 0 0 r
.46891 .48799 m
.45671 .50078 L
s
0 0 1 r
.53109 .48799 m
.54329 .50078 L
s
1 0 0 r
.50628 .45036 m
.49373 .46275 L
s
0 0 1 r
.49372 .45036 m
.50627 .46275 L
s
1 0 0 r
.45671 .50078 m
.4447 .51363 L
s
0 0 1 r
.54329 .50078 m
.5553 .51363 L
s
1 0 0 r
.54348 .45652 m
.53115 .46885 L
s
0 0 1 r
.45652 .45652 m
.46885 .46885 L
s
1 0 0 r
.46885 .53115 m
.45652 .54348 L
s
0 0 1 r
.53115 .53115 m
.54348 .54348 L
s
1 0 0 r
.53128 .44743 m
.51878 .45964 L
s
0 0 1 r
.46872 .44743 m
.48122 .45964 L
s
1 0 0 r
.46884 .46645 m
.45667 .47938 L
s
.48119 .45371 m
.46884 .46645 L
s
0 0 1 r
.53116 .46645 m
.54333 .47938 L
s
.51881 .45371 m
.53116 .46645 L
s
1 0 0 r
.45667 .47938 m
.44472 .49245 L
s
0 0 1 r
.54333 .47938 m
.55528 .49245 L
s
1 0 0 r
.45666 .52218 m
.44457 .53474 L
s
0 0 1 r
.54334 .52218 m
.55543 .53474 L
s
1 0 0 r
.4937 .4412 m
.48119 .45371 L
s
0 0 1 r
.5063 .4412 m
.51881 .45371 L
s
1 0 0 r
.51888 .43818 m
.50628 .45036 L
s
0 0 1 r
.48112 .43818 m
.49372 .45036 L
s
1 0 0 r
.44472 .49245 m
.43303 .50564 L
s
0 0 1 r
.55528 .49245 m
.56697 .50564 L
s
1 0 0 r
.4447 .51363 m
.43292 .52649 L
s
0 0 1 r
.5553 .51363 m
.56708 .52649 L
s
1 0 0 r
.50632 .42895 m
.4937 .4412 L
s
0 0 1 r
.49368 .42895 m
.5063 .4412 L
s
1 0 0 r
.45653 .45806 m
.44462 .47132 L
s
.4687 .44505 m
.45653 .45806 L
s
0 0 1 r
.54347 .45806 m
.55538 .47132 L
s
.5313 .44505 m
.54347 .45806 L
s
1 0 0 r
.54372 .43541 m
.53128 .44743 L
s
0 0 1 r
.45628 .43541 m
.46872 .44743 L
s
1 0 0 r
.55569 .44431 m
.54348 .45652 L
s
0 0 1 r
.44431 .44431 m
.45652 .45652 L
s
1 0 0 r
.45652 .54348 m
.44431 .55569 L
s
0 0 1 r
.54348 .54348 m
.55569 .55569 L
s
1 0 0 r
.44462 .47132 m
.433 .48477 L
s
0 0 1 r
.55538 .47132 m
.567 .48477 L
s
1 0 0 r
.48109 .43232 m
.4687 .44505 L
s
0 0 1 r
.51891 .43232 m
.5313 .44505 L
s
1 0 0 r
.53148 .42625 m
.51888 .43818 L
s
0 0 1 r
.46852 .42625 m
.48112 .43818 L
s
1 0 0 r
.44457 .53474 m
.43267 .54722 L
s
0 0 1 r
.55543 .53474 m
.56733 .54722 L
s
1 0 0 r
.43303 .50564 m
.42164 .51891 L
s
0 0 1 r
.56697 .50564 m
.57836 .51891 L
s
1 0 0 r
.433 .48477 m
.42171 .49838 L
s
0 0 1 r
.567 .48477 m
.57829 .49838 L
s
1 0 0 r
.49366 .41991 m
.48109 .43232 L
s
0 0 1 r
.50634 .41991 m
.51891 .43232 L
s
1 0 0 r
.51902 .41701 m
.50632 .42895 L
s
0 0 1 r
.48098 .41701 m
.49368 .42895 L
s
1 0 0 r
.43292 .52649 m
.42141 .53934 L
s
0 0 1 r
.56708 .52649 m
.57859 .53934 L
s
1 0 0 r
.4444 .45031 m
.43282 .46396 L
s
.4563 .43694 m
.4444 .45031 L
s
0 0 1 r
.5556 .45031 m
.56718 .46396 L
s
.5437 .43694 m
.5556 .45031 L
s
1 0 0 r
.43282 .46396 m
.42161 .47786 L
s
0 0 1 r
.56718 .46396 m
.57839 .47786 L
s
1 0 0 r
.46849 .42391 m
.4563 .43694 L
s
0 0 1 r
.53151 .42391 m
.5437 .43694 L
s
1 0 0 r
.55606 .42363 m
.54372 .43541 L
s
0 0 1 r
.44394 .42363 m
.45628 .43541 L
s
1 0 0 r
.42171 .49838 m
.41079 .51212 L
s
0 0 1 r
.57829 .49838 m
.58921 .51212 L
s
1 0 0 r
.56772 .43228 m
.55569 .44431 L
s
0 0 1 r
.43228 .43228 m
.44431 .44431 L
s
1 0 0 r
.44431 .55569 m
.43228 .56772 L
s
0 0 1 r
.55569 .55569 m
.56772 .56772 L
s
1 0 0 r
.54405 .41462 m
.53148 .42625 L
s
0 0 1 r
.45595 .41462 m
.46852 .42625 L
s
1 0 0 r
.50637 .40787 m
.49366 .41991 L
s
0 0 1 r
.49363 .40787 m
.50634 .41991 L
s
1 0 0 r
.42164 .51891 m
.41059 .5322 L
s
0 0 1 r
.57836 .51891 m
.58941 .5322 L
s
1 0 0 r
.42161 .47786 m
.4108 .49197 L
s
0 0 1 r
.57839 .47786 m
.5892 .49197 L
s
1 0 0 r
.43267 .54722 m
.42102 .55959 L
s
0 0 1 r
.56733 .54722 m
.57898 .55959 L
s
1 0 0 r
.48094 .41125 m
.46849 .42391 L
s
0 0 1 r
.51906 .41125 m
.53151 .42391 L
s
1 0 0 r
.53175 .40542 m
.51902 .41701 L
s
0 0 1 r
.46825 .40542 m
.48098 .41701 L
s
1 0 0 r
.42141 .53934 m
.41021 .55213 L
s
0 0 1 r
.57859 .53934 m
.58979 .55213 L
s
1 0 0 r
.43251 .44333 m
.42136 .45745 L
s
.44406 .42954 m
.43251 .44333 L
s
0 0 1 r
.56749 .44333 m
.57864 .45745 L
s
.55594 .42954 m
.56749 .44333 L
s
1 0 0 r
.42136 .45745 m
.41064 .47186 L
s
0 0 1 r
.57864 .45745 m
.58936 .47186 L
s
1 0 0 r
.4108 .49197 m
.40044 .50623 L
s
0 0 1 r
.5892 .49197 m
.59956 .50623 L
s
1 0 0 r
.45598 .41612 m
.44406 .42954 L
s
0 0 1 r
.54402 .41612 m
.55594 .42954 L
s
1 0 0 r
.41079 .51212 m
.40027 .52593 L
s
0 0 1 r
.58921 .51212 m
.59973 .52593 L
s
1 0 0 r
.4936 .399 m
.48094 .41125 L
s
0 0 1 r
.5064 .399 m
.51906 .41125 L
s
1 0 0 r
.5192 .39623 m
.50637 .40787 L
s
0 0 1 r
.4808 .39623 m
.49363 .40787 L
s
1 0 0 r
.41064 .47186 m
.4004 .48651 L
s
0 0 1 r
.58936 .47186 m
.5996 .48651 L
s
1 0 0 r
.46822 .40312 m
.45598 .41612 L
s
0 0 1 r
.53178 .40312 m
.54402 .41612 L
s
1 0 0 r
.56825 .41211 m
.55606 .42363 L
s
0 0 1 r
.43175 .41211 m
.44394 .42363 L
s
1 0 0 r
.41059 .5322 m
.39991 .54549 L
s
0 0 1 r
.58941 .5322 m
.60009 .54549 L
s
1 0 0 r
.57954 .42046 m
.56772 .43228 L
s
0 0 1 r
.42046 .42046 m
.43228 .43228 L
s
1 0 0 r
.43228 .56772 m
.42046 .57954 L
s
0 0 1 r
.56772 .56772 m
.57954 .57954 L
s
1 0 0 r
.55655 .40331 m
.54405 .41462 L
s
0 0 1 r
.44345 .40331 m
.45595 .41462 L
s
1 0 0 r
.42102 .55959 m
.40965 .5718 L
s
0 0 1 r
.57898 .55959 m
.59035 .5718 L
s
1 0 0 r
.40044 .50623 m
.39055 .52061 L
s
0 0 1 r
.59956 .50623 m
.60945 .52061 L
s
1 0 0 r
.54448 .39423 m
.53175 .40542 L
s
0 0 1 r
.45552 .39423 m
.46825 .40542 L
s
1 0 0 r
.4004 .48651 m
.39067 .50135 L
s
0 0 1 r
.5996 .48651 m
.60933 .50135 L
s
1 0 0 r
.42094 .43725 m
.4103 .45189 L
s
.43205 .42297 m
.42094 .43725 L
s
0 0 1 r
.57906 .43725 m
.5897 .45189 L
s
.56795 .42297 m
.57906 .43725 L
s
1 0 0 r
.50644 .38722 m
.4936 .399 L
s
0 0 1 r
.49356 .38722 m
.5064 .399 L
s
1 0 0 r
.4103 .45189 m
.40016 .46685 L
s
0 0 1 r
.5897 .45189 m
.59984 .46685 L
s
1 0 0 r
.48075 .39059 m
.46822 .40312 L
s
0 0 1 r
.51925 .39059 m
.53178 .40312 L
s
1 0 0 r
.44361 .4091 m
.43205 .42297 L
s
0 0 1 r
.55639 .4091 m
.56795 .42297 L
s
1 0 0 r
.40027 .52593 m
.39021 .53977 L
s
0 0 1 r
.59973 .52593 m
.60979 .53977 L
s
1 0 0 r
.41021 .55213 m
.39936 .56482 L
s
0 0 1 r
.58979 .55213 m
.60064 .56482 L
s
1 0 0 r
.40016 .46685 m
.39058 .48208 L
s
0 0 1 r
.59984 .46685 m
.60942 .48208 L
s
1 0 0 r
.53209 .38505 m
.5192 .39623 L
s
0 0 1 r
.46791 .38505 m
.4808 .39623 L
s
1 0 0 r
.45556 .3957 m
.44361 .4091 L
s
0 0 1 r
.54444 .3957 m
.55639 .4091 L
s
1 0 0 r
.39067 .50135 m
.38148 .51633 L
s
0 0 1 r
.60933 .50135 m
.61852 .51633 L
s
1 0 0 r
.39991 .54549 m
.38967 .55872 L
s
0 0 1 r
.60009 .54549 m
.61033 .55872 L
s
1 0 0 r
.39058 .48208 m
.38157 .49752 L
s
0 0 1 r
.60942 .48208 m
.61843 .49752 L
s
1 0 0 r
.49353 .37858 m
.48075 .39059 L
s
0 0 1 r
.50647 .37858 m
.51925 .39059 L
s
1 0 0 r
.58026 .40092 m
.56825 .41211 L
s
0 0 1 r
.41974 .40092 m
.43175 .41211 L
s
1 0 0 r
.39055 .52061 m
.38118 .53506 L
s
0 0 1 r
.60945 .52061 m
.61882 .53506 L
s
1 0 0 r
.56893 .39238 m
.55655 .40331 L
s
0 0 1 r
.43107 .39238 m
.44345 .40331 L
s
1 0 0 r
.5911 .4089 m
.57954 .42046 L
s
0 0 1 r
.4089 .4089 m
.42046 .42046 L
s
1 0 0 r
.42046 .57954 m
.4089 .5911 L
s
0 0 1 r
.57954 .57954 m
.5911 .5911 L
s
1 0 0 r
.40977 .43216 m
.39973 .44736 L
s
.42036 .41735 m
.40977 .43216 L
s
0 0 1 r
.59023 .43216 m
.60027 .44736 L
s
.57964 .41735 m
.59023 .43216 L
s
1 0 0 r
.51942 .37596 m
.50644 .38722 L
s
0 0 1 r
.48058 .37596 m
.49356 .38722 L
s
1 0 0 r
.39973 .44736 m
.39027 .4629 L
s
0 0 1 r
.60027 .44736 m
.60973 .4629 L
s
1 0 0 r
.46787 .38281 m
.45556 .3957 L
s
0 0 1 r
.53213 .38281 m
.54444 .3957 L
s
1 0 0 r
.55716 .38348 m
.54448 .39423 L
s
0 0 1 r
.44284 .38348 m
.45552 .39423 L
s
1 0 0 r
.43146 .40299 m
.42036 .41735 L
s
0 0 1 r
.56854 .40299 m
.57964 .41735 L
s
1 0 0 r
.40965 .5718 m
.3986 .58381 L
s
0 0 1 r
.59035 .5718 m
.6014 .58381 L
s
1 0 0 r
.39027 .4629 m
.38143 .47872 L
s
0 0 1 r
.60973 .4629 m
.61857 .47872 L
s
1 0 0 r
.39021 .53977 m
.38065 .5536 L
s
0 0 1 r
.60979 .53977 m
.61935 .5536 L
s
1 0 0 r
.38157 .49752 m
.37318 .51313 L
s
0 0 1 r
.61843 .49752 m
.62682 .51313 L
s
1 0 0 r
.44303 .38912 m
.43146 .40299 L
s
0 0 1 r
.55697 .38912 m
.56854 .40299 L
s
1 0 0 r
.545 .37437 m
.53209 .38505 L
s
0 0 1 r
.455 .37437 m
.46791 .38505 L
s
1 0 0 r
.38148 .51633 m
.3729 .53142 L
s
0 0 1 r
.61852 .51633 m
.6271 .53142 L
s
1 0 0 r
.39936 .56482 m
.38891 .57736 L
s
0 0 1 r
.60064 .56482 m
.61109 .57736 L
s
1 0 0 r
.38143 .47872 m
.37323 .49478 L
s
0 0 1 r
.61857 .47872 m
.62677 .49478 L
s
1 0 0 r
.48051 .37048 m
.46787 .38281 L
s
0 0 1 r
.51949 .37048 m
.53213 .38281 L
s
1 0 0 r
.50652 .36714 m
.49353 .37858 L
s
0 0 1 r
.49348 .36714 m
.50647 .37858 L
s
1 0 0 r
.38976 .44391 m
.38106 .46003 L
s
.3991 .42814 m
.38976 .44391 L
s
0 0 1 r
.61024 .44391 m
.61894 .46003 L
s
.6009 .42814 m
.61024 .44391 L
s
1 0 0 r
.40907 .41278 m
.3991 .42814 L
s
0 0 1 r
.59093 .41278 m
.6009 .42814 L
s
1 0 0 r
.38118 .53506 m
.37238 .54953 L
s
0 0 1 r
.61882 .53506 m
.62762 .54953 L
s
1 0 0 r
.45504 .3758 m
.44303 .38912 L
s
0 0 1 r
.54496 .3758 m
.55697 .38912 L
s
1 0 0 r
.38967 .55872 m
.37989 .57185 L
s
0 0 1 r
.61033 .55872 m
.62011 .57185 L
s
1 0 0 r
.38106 .46003 m
.37305 .47645 L
s
0 0 1 r
.61894 .46003 m
.62695 .47645 L
s
1 0 0 r
.53249 .36525 m
.51942 .37596 L
s
0 0 1 r
.46751 .36525 m
.48058 .37596 L
s
1 0 0 r
.41962 .39788 m
.40907 .41278 L
s
0 0 1 r
.58038 .39788 m
.59093 .41278 L
s
1 0 0 r
.37323 .49478 m
.36572 .51101 L
s
0 0 1 r
.62677 .49478 m
.63428 .51101 L
s
1 0 0 r
.37318 .51313 m
.36545 .52886 L
s
0 0 1 r
.62682 .51313 m
.63455 .52886 L
s
1 0 0 r
.59203 .39009 m
.58026 .40092 L
s
0 0 1 r
.40797 .39009 m
.41974 .40092 L
s
1 0 0 r
.58114 .38189 m
.56893 .39238 L
s
0 0 1 r
.41886 .38189 m
.43107 .39238 L
s
1 0 0 r
.60235 .39765 m
.5911 .4089 L
s
0 0 1 r
.39765 .39765 m
.4089 .4089 L
s
1 0 0 r
.4089 .5911 m
.39765 .60235 L
s
0 0 1 r
.5911 .5911 m
.60235 .60235 L
s
1 0 0 r
.37305 .47645 m
.36575 .49311 L
s
0 0 1 r
.62695 .47645 m
.63425 .49311 L
s
1 0 0 r
.56974 .37322 m
.55716 .38348 L
s
0 0 1 r
.43026 .37322 m
.44284 .38348 L
s
1 0 0 r
.43072 .3835 m
.41962 .39788 L
s
0 0 1 r
.56928 .3835 m
.58038 .39788 L
s
1 0 0 r
.38065 .5536 m
.37162 .56737 L
s
0 0 1 r
.61935 .5536 m
.62838 .56737 L
s
1 0 0 r
.3729 .53142 m
.36494 .54655 L
s
0 0 1 r
.6271 .53142 m
.63506 .54655 L
s
1 0 0 r
.49344 .35877 m
.48051 .37048 L
s
0 0 1 r
.50656 .35877 m
.51949 .37048 L
s
1 0 0 r
.3986 .58381 m
.38794 .59557 L
s
0 0 1 r
.6014 .58381 m
.61206 .59557 L
s
1 0 0 r
.46746 .36308 m
.45504 .3758 L
s
0 0 1 r
.53254 .36308 m
.54496 .3758 L
s
1 0 0 r
.51968 .35631 m
.50652 .36714 L
s
0 0 1 r
.48032 .35631 m
.49348 .36714 L
s
1 0 0 r
.38047 .44156 m
.37263 .45825 L
s
.38903 .42522 m
.38047 .44156 L
s
0 0 1 r
.61953 .44156 m
.62737 .45825 L
s
.61097 .42522 m
.61953 .44156 L
s
1 0 0 r
.55789 .36425 m
.545 .37437 L
s
0 0 1 r
.44211 .36425 m
.455 .37437 L
s
1 0 0 r
.39827 .4093 m
.38903 .42522 L
s
0 0 1 r
.60173 .4093 m
.61097 .42522 L
s
1 0 0 r
.37263 .45825 m
.36554 .47523 L
s
0 0 1 r
.62737 .45825 m
.63446 .47523 L
s
1 0 0 r
.36575 .49311 m
.35921 .50994 L
s
0 0 1 r
.63425 .49311 m
.64079 .50994 L
s
1 0 0 r
.36572 .51101 m
.35894 .52737 L
s
0 0 1 r
.63428 .51101 m
.64106 .52737 L
s
1 0 0 r
.38891 .57736 m
.37891 .5897 L
s
0 0 1 r
.61109 .57736 m
.62109 .5897 L
s
1 0 0 r
.44233 .36971 m
.43072 .3835 L
s
0 0 1 r
.55767 .36971 m
.56928 .3835 L
s
1 0 0 r
.40818 .39386 m
.39827 .4093 L
s
0 0 1 r
.59182 .39386 m
.60173 .4093 L
s
1 0 0 r
.36554 .47523 m
.35923 .49245 L
s
0 0 1 r
.63446 .47523 m
.64077 .49245 L
s
1 0 0 r
.37238 .54953 m
.36419 .56397 L
s
0 0 1 r
.62762 .54953 m
.63581 .56397 L
s
1 0 0 r
.36545 .52886 m
.35843 .54465 L
s
0 0 1 r
.63455 .52886 m
.64157 .54465 L
s
1 0 0 r
.54562 .35517 m
.53249 .36525 L
s
0 0 1 r
.45438 .35517 m
.46751 .36525 L
s
1 0 0 r
.37989 .57185 m
.37064 .58482 L
s
0 0 1 r
.62011 .57185 m
.62936 .58482 L
s
1 0 0 r
.41871 .37895 m
.40818 .39386 L
s
0 0 1 r
.58129 .37895 m
.59182 .39386 L
s
1 0 0 r
.48024 .35103 m
.46746 .36308 L
s
0 0 1 r
.51976 .35103 m
.53254 .36308 L
s
1 0 0 r
.35923 .49245 m
.35372 .50984 L
s
0 0 1 r
.64077 .49245 m
.64628 .50984 L
s
1 0 0 r
.35921 .50994 m
.35345 .5269 L
s
0 0 1 r
.64079 .50994 m
.64655 .5269 L
s
1 0 0 r
.37198 .44028 m
.36508 .4575 L
s
.37965 .42341 m
.37198 .44028 L
s
0 0 1 r
.62802 .44028 m
.63492 .4575 L
s
.62035 .42341 m
.62802 .44028 L
s
1 0 0 r
.50661 .34774 m
.49344 .35877 L
s
0 0 1 r
.49339 .34774 m
.50656 .35877 L
s
1 0 0 r
.36508 .4575 m
.35899 .47501 L
s
0 0 1 r
.63492 .4575 m
.64101 .47501 L
s
1 0 0 r
.45443 .35655 m
.44233 .36971 L
s
0 0 1 r
.54557 .35655 m
.55767 .36971 L
s
1 0 0 r
.38809 .40694 m
.37965 .42341 L
s
0 0 1 r
.61191 .40694 m
.62035 .42341 L
s
1 0 0 r
.36494 .54655 m
.35767 .56167 L
s
0 0 1 r
.63506 .54655 m
.64233 .56167 L
s
1 0 0 r
.35899 .47501 m
.35374 .49273 L
s
0 0 1 r
.64101 .47501 m
.64626 .49273 L
s
1 0 0 r
.59313 .37187 m
.58114 .38189 L
s
0 0 1 r
.40687 .37187 m
.41886 .38189 L
s
1 0 0 r
.60351 .37968 m
.59203 .39009 L
s
0 0 1 r
.39649 .37968 m
.40797 .39009 L
s
1 0 0 r
.35894 .52737 m
.35293 .5438 L
s
0 0 1 r
.64106 .52737 m
.64707 .5438 L
s
1 0 0 r
.58218 .36351 m
.56974 .37322 L
s
0 0 1 r
.41782 .36351 m
.43026 .37322 L
s
1 0 0 r
.61325 .38675 m
.60235 .39765 L
s
0 0 1 r
.38675 .38675 m
.39765 .39765 L
s
1 0 0 r
.39765 .60235 m
.38675 .61325 L
s
0 0 1 r
.60235 .60235 m
.61325 .61325 L
s
1 0 0 r
.37162 .56737 m
.36319 .58102 L
s
0 0 1 r
.62838 .56737 m
.63681 .58102 L
s
1 0 0 r
.53297 .34617 m
.51968 .35631 L
s
0 0 1 r
.46703 .34617 m
.48032 .35631 L
s
1 0 0 r
.39725 .39096 m
.38809 .40694 L
s
0 0 1 r
.60275 .39096 m
.61191 .40694 L
s
1 0 0 r
.42983 .36464 m
.41871 .37895 L
s
0 0 1 r
.57017 .36464 m
.58129 .37895 L
s
1 0 0 r
.35374 .49273 m
.34935 .5106 L
s
0 0 1 r
.64626 .49273 m
.65065 .5106 L
s
1 0 0 r
.35372 .50984 m
.34906 .52734 L
s
0 0 1 r
.64628 .50984 m
.65094 .52734 L
s
1 0 0 r
.38794 .59557 m
.37771 .60703 L
s
0 0 1 r
.61206 .59557 m
.62229 .60703 L
s
1 0 0 r
.5707 .35474 m
.55789 .36425 L
s
0 0 1 r
.4293 .35474 m
.44211 .36425 L
s
1 0 0 r
.35852 .4577 m
.35351 .47565 L
s
.36438 .44001 m
.35852 .4577 L
s
0 0 1 r
.64148 .4577 m
.64649 .47565 L
s
.63562 .44001 m
.64148 .4577 L
s
1 0 0 r
.37109 .42265 m
.36438 .44001 L
s
0 0 1 r
.62891 .42265 m
.63562 .44001 L
s
1 0 0 r
.35843 .54465 m
.35215 .56044 L
s
0 0 1 r
.64157 .54465 m
.64785 .56044 L
s
1 0 0 r
.35351 .47565 m
.34938 .4938 L
s
0 0 1 r
.64649 .47565 m
.65062 .4938 L
s
1 0 0 r
.35345 .5269 m
.34852 .54391 L
s
0 0 1 r
.64655 .5269 m
.65148 .54391 L
s
1 0 0 r
.40711 .37551 m
.39725 .39096 L
s
0 0 1 r
.59289 .37551 m
.60275 .39096 L
s
1 0 0 r
.36419 .56397 m
.35667 .57832 L
s
0 0 1 r
.63581 .56397 m
.64333 .57832 L
s
1 0 0 r
.49334 .33971 m
.48024 .35103 L
s
0 0 1 r
.50666 .33971 m
.51976 .35103 L
s
1 0 0 r
.37861 .40568 m
.37109 .42265 L
s
0 0 1 r
.62139 .40568 m
.62891 .42265 L
s
1 0 0 r
.46698 .34409 m
.45443 .35655 L
s
0 0 1 r
.53302 .34409 m
.54557 .35655 L
s
1 0 0 r
.37891 .5897 m
.36942 .60178 L
s
0 0 1 r
.62109 .5897 m
.63058 .60178 L
s
1 0 0 r
.34938 .4938 m
.34615 .51206 L
s
0 0 1 r
.65062 .4938 m
.65385 .51206 L
s
1 0 0 r
.34935 .5106 m
.34584 .52855 L
s
0 0 1 r
.65065 .5106 m
.65416 .52855 L
s
1 0 0 r
.55874 .34577 m
.54562 .35517 L
s
0 0 1 r
.44126 .34577 m
.45438 .35517 L
s
1 0 0 r
.51999 .33744 m
.50661 .34774 L
s
0 0 1 r
.48001 .33744 m
.49339 .34774 L
s
1 0 0 r
.44152 .35099 m
.42983 .36464 L
s
0 0 1 r
.55848 .35099 m
.57017 .36464 L
s
1 0 0 r
.34916 .47703 m
.34621 .4955 L
s
.35302 .45872 m
.34916 .47703 L
s
0 0 1 r
.65084 .47703 m
.65379 .4955 L
s
.64698 .45872 m
.65084 .47703 L
s
1 0 0 r
.35779 .44064 m
.35302 .45872 L
s
0 0 1 r
.64221 .44064 m
.64698 .45872 L
s
1 0 0 r
.34906 .52734 m
.34527 .54487 L
s
0 0 1 r
.65094 .52734 m
.65473 .54487 L
s
1 0 0 r
.35293 .5438 m
.34772 .56022 L
s
0 0 1 r
.64707 .5438 m
.65228 .56022 L
s
1 0 0 r
.38693 .38919 m
.37861 .40568 L
s
0 0 1 r
.61307 .38919 m
.62139 .40568 L
s
1 0 0 r
.34621 .4955 m
.3442 .51405 L
s
0 0 1 r
.65379 .4955 m
.6558 .51405 L
s
1 0 0 r
.36345 .42287 m
.35779 .44064 L
s
0 0 1 r
.63655 .42287 m
.64221 .44064 L
s
1 0 0 r
.34615 .51206 m
.34385 .53038 L
s
0 0 1 r
.65385 .51206 m
.65615 .53038 L
s
1 0 0 r
.37064 .58482 m
.36196 .59758 L
s
0 0 1 r
.62936 .58482 m
.63804 .59758 L
s
1 0 0 r
.35767 .56167 m
.35113 .57671 L
s
0 0 1 r
.64233 .56167 m
.64887 .57671 L
s
1 0 0 r
.41764 .36068 m
.40711 .37551 L
s
0 0 1 r
.58236 .36068 m
.59289 .37551 L
s
1 0 0 r
.34601 .47896 m
.34429 .49764 L
s
.34868 .4604 m
.34601 .47896 L
s
0 0 1 r
.65399 .47896 m
.65571 .49764 L
s
.65132 .4604 m
.65399 .47896 L
s
1 0 0 r
.34429 .49764 m
.34352 .51636 L
s
0 0 1 r
.65571 .49764 m
.65648 .51636 L
s
1 0 0 r
.35229 .44204 m
.34868 .4604 L
s
0 0 1 r
.64771 .44204 m
.65132 .4604 L
s
1 0 0 r
.3442 .51405 m
.34313 .53262 L
s
0 0 1 r
.6558 .51405 m
.65687 .53262 L
s
1 0 0 r
.34584 .52855 m
.34324 .54652 L
s
0 0 1 r
.65416 .52855 m
.65676 .54652 L
s
1 0 0 r
.36997 .40546 m
.36345 .42287 L
s
0 0 1 r
.63003 .40546 m
.63655 .42287 L
s
1 0 0 r
.54633 .33677 m
.53297 .34617 L
s
0 0 1 r
.45367 .33677 m
.46703 .34617 L
s
1 0 0 r
.34352 .51636 m
.3437 .53505 L
s
0 0 1 r
.65648 .51636 m
.6563 .53505 L
s
1 0 0 r
.34852 .54391 m
.34444 .56092 L
s
0 0 1 r
.65148 .54391 m
.65556 .56092 L
s
1 0 0 r
.39602 .37323 m
.38693 .38919 L
s
0 0 1 r
.60398 .37323 m
.61307 .38919 L
s
1 0 0 r
.60486 .3624 m
.59313 .37187 L
s
0 0 1 r
.39514 .3624 m
.40687 .37187 L
s
1 0 0 r
.35682 .42394 m
.35229 .44204 L
s
0 0 1 r
.64318 .42394 m
.64771 .44204 L
s
1 0 0 r
.61464 .36974 m
.60351 .37968 L
s
0 0 1 r
.38536 .36974 m
.39649 .37968 L
s
1 0 0 r
.36319 .58102 m
.35541 .59449 L
s
0 0 1 r
.63681 .58102 m
.64459 .59449 L
s
1 0 0 r
.34385 .53038 m
.34249 .54867 L
s
0 0 1 r
.65615 .53038 m
.65751 .54867 L
s
1 0 0 r
.59443 .3544 m
.58218 .36351 L
s
0 0 1 r
.40557 .3544 m
.41782 .36351 L
s
1 0 0 r
.47992 .3324 m
.46698 .34409 L
s
0 0 1 r
.52008 .3324 m
.53302 .34409 L
s
1 0 0 r
.35215 .56044 m
.34667 .57617 L
s
0 0 1 r
.64785 .56044 m
.65333 .57617 L
s
1 0 0 r
.45373 .33808 m
.44152 .35099 L
s
0 0 1 r
.54627 .33808 m
.55848 .35099 L
s
1 0 0 r
.62372 .37628 m
.61325 .38675 L
s
0 0 1 r
.37628 .37628 m
.38675 .38675 L
s
1 0 0 r
.38675 .61325 m
.37628 .62372 L
s
0 0 1 r
.61325 .61325 m
.62372 .62372 L
s
1 0 0 r
.3437 .53505 m
.34485 .55363 L
s
0 0 1 r
.6563 .53505 m
.65515 .55363 L
s
1 0 0 r
.34313 .53262 m
.34302 .55112 L
s
0 0 1 r
.65687 .53262 m
.65698 .55112 L
s
1 0 0 r
.50672 .32917 m
.49334 .33971 L
s
0 0 1 r
.49328 .32917 m
.50666 .33971 L
s
1 0 0 r
.37735 .38851 m
.36997 .40546 L
s
0 0 1 r
.62265 .38851 m
.63003 .40546 L
s
1 0 0 r
.34527 .54487 m
.34238 .56238 L
s
0 0 1 r
.65473 .54487 m
.65762 .56238 L
s
1 0 0 r
.5834 .34591 m
.5707 .35474 L
s
0 0 1 r
.4166 .34591 m
.4293 .35474 L
s
1 0 0 r
.42881 .34653 m
.41764 .36068 L
s
0 0 1 r
.57119 .34653 m
.58236 .36068 L
s
1 0 0 r
.36227 .40618 m
.35682 .42394 L
s
0 0 1 r
.63773 .40618 m
.64318 .42394 L
s
1 0 0 r
.37771 .60703 m
.36796 .61812 L
s
0 0 1 r
.62229 .60703 m
.63204 .61812 L
s
1 0 0 r
.35667 .57832 m
.34986 .59252 L
s
0 0 1 r
.64333 .57832 m
.65014 .59252 L
s
1 0 0 r
.34324 .54652 m
.34159 .56443 L
s
0 0 1 r
.65676 .54652 m
.65841 .56443 L
s
1 0 0 r
.34772 .56022 m
.34336 .57658 L
s
0 0 1 r
.65228 .56022 m
.65664 .57658 L
s
1 0 0 r
.53351 .32795 m
.51999 .33744 L
s
0 0 1 r
.46649 .32795 m
.48001 .33744 L
s
1 0 0 r
.40585 .35788 m
.39602 .37323 L
s
0 0 1 r
.59415 .35788 m
.60398 .37323 L
s
1 0 0 r
.34485 .55363 m
.34697 .57204 L
s
0 0 1 r
.65515 .55363 m
.65303 .57204 L
s
1 0 0 r
.34249 .54867 m
.34209 .56688 L
s
0 0 1 r
.65751 .54867 m
.65791 .56688 L
s
1 0 0 r
.57181 .3371 m
.55874 .34577 L
s
0 0 1 r
.42819 .3371 m
.44126 .34577 L
s
1 0 0 r
.34302 .55112 m
.34389 .56949 L
s
0 0 1 r
.65698 .55112 m
.65611 .56949 L
s
1 0 0 r
.36942 .60178 m
.36048 .61355 L
s
0 0 1 r
.63058 .60178 m
.63952 .61355 L
s
1 0 0 r
.38557 .37208 m
.37735 .38851 L
s
0 0 1 r
.61443 .37208 m
.62265 .38851 L
s
1 0 0 r
.36862 .38884 m
.36227 .40618 L
s
0 0 1 r
.63138 .38884 m
.63773 .40618 L
s
1 0 0 r
.34444 .56092 m
.34127 .57784 L
s
0 0 1 r
.65556 .56092 m
.65873 .57784 L
s
1 0 0 r
.35113 .57671 m
.34537 .59163 L
s
0 0 1 r
.64887 .57671 m
.65463 .59163 L
s
1 0 0 r
.46642 .32597 m
.45373 .33808 L
s
0 0 1 r
.53358 .32597 m
.54627 .33808 L
s
1 0 0 r
.49323 .32155 m
.47992 .3324 L
s
0 0 1 r
.50677 .32155 m
.52008 .3324 L
s
1 0 0 r
.36196 .59758 m
.35392 .61008 L
s
0 0 1 r
.63804 .59758 m
.64608 .61008 L
s
1 0 0 r
.34697 .57204 m
.35006 .59018 L
s
0 0 1 r
.65303 .57204 m
.64994 .59018 L
s
1 0 0 r
.44058 .33313 m
.42881 .34653 L
s
0 0 1 r
.55942 .33313 m
.57119 .34653 L
s
1 0 0 r
.34238 .56238 m
.34043 .57978 L
s
0 0 1 r
.65762 .56238 m
.65957 .57978 L
s
1 0 0 r
.55971 .32817 m
.54633 .33677 L
s
0 0 1 r
.44029 .32817 m
.45367 .33677 L
s
1 0 0 r
.4164 .34322 m
.40585 .35788 L
s
0 0 1 r
.5836 .34322 m
.59415 .35788 L
s
1 0 0 r
.34389 .56949 m
.34574 .58764 L
s
0 0 1 r
.65611 .56949 m
.65426 .58764 L
s
1 0 0 r
.52034 .31949 m
.50672 .32917 L
s
0 0 1 r
.47966 .31949 m
.49328 .32917 L
s
1 0 0 r
.34159 .56443 m
.3409 .58221 L
s
0 0 1 r
.65841 .56443 m
.6591 .58221 L
s
1 0 0 r
.34667 .57617 m
.34203 .59176 L
s
0 0 1 r
.65333 .57617 m
.65797 .59176 L
s
1 0 0 r
.34209 .56688 m
.34267 .5849 L
s
0 0 1 r
.65791 .56688 m
.65733 .5849 L
s
1 0 0 r
.39459 .35624 m
.38557 .37208 L
s
0 0 1 r
.60541 .35624 m
.61443 .37208 L
s
1 0 0 r
.37586 .372 m
.36862 .38884 L
s
0 0 1 r
.62414 .372 m
.63138 .38884 L
s
1 0 0 r
.35541 .59449 m
.34834 .60773 L
s
0 0 1 r
.64459 .59449 m
.65166 .60773 L
s
1 0 0 r
.61625 .35353 m
.60486 .3624 L
s
0 0 1 r
.38375 .35353 m
.39514 .3624 L
s
1 0 0 r
.62537 .36035 m
.61464 .36974 L
s
0 0 1 r
.37463 .36035 m
.38536 .36974 L
s
1 0 0 r
.60641 .34596 m
.59443 .3544 L
s
0 0 1 r
.39359 .34596 m
.40557 .3544 L
s
1 0 0 r
.34336 .57658 m
.3399 .59281 L
s
0 0 1 r
.65664 .57658 m
.6601 .59281 L
s
1 0 0 r
.35006 .59018 m
.35414 .60798 L
s
0 0 1 r
.64994 .59018 m
.64586 .60798 L
s
1 0 0 r
.63372 .36628 m
.62372 .37628 L
s
0 0 1 r
.36628 .36628 m
.37628 .37628 L
s
1 0 0 r
.37628 .62372 m
.36628 .63372 L
s
0 0 1 r
.62372 .62372 m
.63372 .63372 L
s
1 0 0 r
.5959 .33781 m
.5834 .34591 L
s
0 0 1 r
.4041 .33781 m
.4166 .34591 L
s
1 0 0 r
.54714 .31932 m
.53351 .32795 L
s
0 0 1 r
.45286 .31932 m
.46649 .32795 L
s
1 0 0 r
.34986 .59252 m
.34382 .6065 L
s
0 0 1 r
.65014 .59252 m
.65618 .6065 L
s
1 0 0 r
.34127 .57784 m
.33903 .59462 L
s
0 0 1 r
.65873 .57784 m
.66097 .59462 L
s
1 0 0 r
.45293 .32055 m
.44058 .33313 L
s
0 0 1 r
.54707 .32055 m
.55942 .33313 L
s
1 0 0 r
.36796 .61812 m
.35877 .62879 L
s
0 0 1 r
.63204 .61812 m
.64123 .62879 L
s
1 0 0 r
.47956 .31474 m
.46642 .32597 L
s
0 0 1 r
.52044 .31474 m
.53358 .32597 L
s
1 0 0 r
.34574 .58764 m
.34858 .60549 L
s
0 0 1 r
.65426 .58764 m
.65142 .60549 L
s
1 0 0 r
.42763 .32932 m
.4164 .34322 L
s
0 0 1 r
.57237 .32932 m
.5836 .34322 L
s
1 0 0 r
.58477 .32924 m
.57181 .3371 L
s
0 0 1 r
.41523 .32924 m
.42819 .3371 L
s
1 0 0 r
.40441 .34109 m
.39459 .35624 L
s
0 0 1 r
.59559 .34109 m
.60541 .35624 L
s
1 0 0 r
.38399 .35574 m
.37586 .372 L
s
0 0 1 r
.61601 .35574 m
.62414 .372 L
s
1 0 0 r
.34043 .57978 m
.33946 .59701 L
s
0 0 1 r
.65957 .57978 m
.66054 .59701 L
s
1 0 0 r
.50685 .3116 m
.49323 .32155 L
s
0 0 1 r
.49315 .3116 m
.50677 .32155 L
s
1 0 0 r
.34267 .5849 m
.34425 .60267 L
s
0 0 1 r
.65733 .5849 m
.65575 .60267 L
s
1 0 0 r
.3409 .58221 m
.3412 .59977 L
s
0 0 1 r
.6591 .58221 m
.6588 .59977 L
s
1 0 0 r
.34537 .59163 m
.34045 .60634 L
s
0 0 1 r
.65463 .59163 m
.65955 .60634 L
s
1 0 0 r
.36048 .61355 m
.35218 .62494 L
s
0 0 1 r
.63952 .61355 m
.64782 .62494 L
s
1 0 0 r
.35414 .60798 m
.35919 .62536 L
s
0 0 1 r
.64586 .60798 m
.64081 .62536 L
s
1 0 0 r
.53413 .31074 m
.52034 .31949 L
s
0 0 1 r
.46587 .31074 m
.47966 .31949 L
s
1 0 0 r
.57306 .32044 m
.55971 .32817 L
s
0 0 1 r
.42694 .32044 m
.44029 .32817 L
s
1 0 0 r
.34203 .59176 m
.33828 .60716 L
s
0 0 1 r
.65797 .59176 m
.66172 .60716 L
s
1 0 0 r
.35392 .61008 m
.34657 .62223 L
s
0 0 1 r
.64608 .61008 m
.65343 .62223 L
s
1 0 0 r
.34858 .60549 m
.35243 .62296 L
s
0 0 1 r
.65142 .60549 m
.64757 .62296 L
s
1 0 0 r
.3399 .59281 m
.33737 .60882 L
s
0 0 1 r
.6601 .59281 m
.66263 .60882 L
s
1 0 0 r
.39297 .34015 m
.38399 .35574 L
s
0 0 1 r
.60703 .34015 m
.61601 .35574 L
s
1 0 0 r
.43952 .31626 m
.42763 .32932 L
s
0 0 1 r
.56048 .31626 m
.57237 .32932 L
s
1 0 0 r
.415 .32671 m
.40441 .34109 L
s
0 0 1 r
.585 .32671 m
.59559 .34109 L
s
1 0 0 r
.4658 .30889 m
.45293 .32055 L
s
0 0 1 r
.5342 .30889 m
.54707 .32055 L
s
1 0 0 r
.34834 .60773 m
.34203 .62066 L
s
0 0 1 r
.65166 .60773 m
.65797 .62066 L
s
1 0 0 r
.4931 .30445 m
.47956 .31474 L
s
0 0 1 r
.5069 .30445 m
.52044 .31474 L
s
1 0 0 r
.34425 .60267 m
.34685 .6201 L
s
0 0 1 r
.65575 .60267 m
.65315 .6201 L
s
1 0 0 r
.33903 .59462 m
.33776 .61116 L
s
0 0 1 r
.66097 .59462 m
.66224 .61116 L
s
1 0 0 r
.5608 .31163 m
.54714 .31932 L
s
0 0 1 r
.4392 .31163 m
.45286 .31932 L
s
1 0 0 r
.62725 .34533 m
.61625 .35353 L
s
0 0 1 r
.37275 .34533 m
.38375 .35353 L
s
1 0 0 r
.61807 .33826 m
.60641 .34596 L
s
0 0 1 r
.38193 .33826 m
.39359 .34596 L
s
1 0 0 r
.3412 .59977 m
.34252 .61703 L
s
0 0 1 r
.6588 .59977 m
.65748 .61703 L
s
1 0 0 r
.33946 .59701 m
.33948 .61397 L
s
0 0 1 r
.66054 .59701 m
.66052 .61397 L
s
1 0 0 r
.63563 .35156 m
.62537 .36035 L
s
0 0 1 r
.36437 .35156 m
.37463 .36035 L
s
1 0 0 r
.60816 .33051 m
.5959 .33781 L
s
0 0 1 r
.39184 .33051 m
.4041 .33781 L
s
1 0 0 r
.52073 .30264 m
.50685 .3116 L
s
0 0 1 r
.47927 .30264 m
.49315 .3116 L
s
1 0 0 r
.35919 .62536 m
.36522 .64221 L
s
0 0 1 r
.64081 .62536 m
.63478 .64221 L
s
1 0 0 r
.34382 .6065 m
.33862 .6202 L
s
0 0 1 r
.65618 .6065 m
.66138 .6202 L
s
1 0 0 r
.64317 .35683 m
.63372 .36628 L
s
0 0 1 r
.35683 .35683 m
.36628 .36628 L
s
1 0 0 r
.36628 .63372 m
.35683 .64317 L
s
0 0 1 r
.63372 .63372 m
.64317 .64317 L
s
1 0 0 r
.59756 .32224 m
.58477 .32924 L
s
0 0 1 r
.40244 .32224 m
.41523 .32924 L
s
1 0 0 r
.35877 .62879 m
.3502 .63897 L
s
0 0 1 r
.64123 .62879 m
.6498 .63897 L
s
1 0 0 r
.34045 .60634 m
.33641 .62077 L
s
0 0 1 r
.65955 .60634 m
.66359 .62077 L
s
1 0 0 r
.35243 .62296 m
.35729 .63995 L
s
0 0 1 r
.64757 .62296 m
.64271 .63995 L
s
1 0 0 r
.54804 .30299 m
.53413 .31074 L
s
0 0 1 r
.45196 .30299 m
.46587 .31074 L
s
1 0 0 r
.40279 .32531 m
.39297 .34015 L
s
0 0 1 r
.59721 .32531 m
.60703 .34015 L
s
1 0 0 r
.42632 .31317 m
.415 .32671 L
s
0 0 1 r
.57368 .31317 m
.585 .32671 L
s
1 0 0 r
.45203 .30413 m
.43952 .31626 L
s
0 0 1 r
.54797 .30413 m
.56048 .31626 L
s
1 0 0 r
.35218 .62494 m
.34456 .63589 L
s
0 0 1 r
.64782 .62494 m
.65544 .63589 L
s
1 0 0 r
.58631 .31366 m
.57306 .32044 L
s
0 0 1 r
.41369 .31366 m
.42694 .32044 L
s
1 0 0 r
.33828 .60716 m
.33547 .62227 L
s
0 0 1 r
.66172 .60716 m
.66453 .62227 L
s
1 0 0 r
.47916 .29821 m
.4658 .30889 L
s
0 0 1 r
.52084 .29821 m
.5342 .30889 L
s
1 0 0 r
.34685 .6201 m
.35049 .6371 L
s
0 0 1 r
.65315 .6201 m
.64951 .6371 L
s
1 0 0 r
.50698 .2952 m
.4931 .30445 L
s
0 0 1 r
.49302 .2952 m
.5069 .30445 L
s
1 0 0 r
.33737 .60882 m
.33583 .62454 L
s
0 0 1 r
.66263 .60882 m
.66417 .62454 L
s
1 0 0 r
.36522 .64221 m
.37223 .65846 L
s
0 0 1 r
.63478 .64221 m
.62777 .65846 L
s
1 0 0 r
.34657 .62223 m
.33999 .63397 L
s
0 0 1 r
.65343 .62223 m
.66001 .63397 L
s
1 0 0 r
.34252 .61703 m
.34488 .6339 L
s
0 0 1 r
.65748 .61703 m
.65512 .6339 L
s
1 0 0 r
.33776 .61116 m
.33752 .62738 L
s
0 0 1 r
.66224 .61116 m
.66248 .62738 L
s
1 0 0 r
.33948 .61397 m
.34054 .63058 L
s
0 0 1 r
.66052 .61397 m
.65946 .63058 L
s
1 0 0 r
.57445 .30494 m
.5608 .31163 L
s
0 0 1 r
.42555 .30494 m
.4392 .31163 L
s
1 0 0 r
.53481 .29473 m
.52073 .30264 L
s
0 0 1 r
.46519 .29473 m
.47927 .30264 L
s
1 0 0 r
.34203 .62066 m
.33654 .6332 L
s
0 0 1 r
.65797 .62066 m
.66346 .6332 L
s
1 0 0 r
.35729 .63995 m
.36318 .65637 L
s
0 0 1 r
.64271 .63995 m
.63682 .65637 L
s
1 0 0 r
.41344 .31131 m
.40279 .32531 L
s
0 0 1 r
.58656 .31131 m
.59721 .32531 L
s
1 0 0 r
.62933 .33136 m
.61807 .33826 L
s
0 0 1 r
.37067 .33136 m
.38193 .33826 L
s
1 0 0 r
.63777 .33786 m
.62725 .34533 L
s
0 0 1 r
.36223 .33786 m
.37275 .34533 L
s
1 0 0 r
.43834 .30057 m
.42632 .31317 L
s
0 0 1 r
.56166 .30057 m
.57368 .31317 L
s
1 0 0 r
.62009 .32408 m
.60816 .33051 L
s
0 0 1 r
.37991 .32408 m
.39184 .33051 L
s
1 0 0 r
.64535 .34344 m
.63563 .35156 L
s
0 0 1 r
.35465 .34344 m
.36437 .35156 L
s
1 0 0 r
.33862 .6202 m
.3343 .63353 L
s
0 0 1 r
.66138 .6202 m
.6657 .63353 L
s
1 0 0 r
.46511 .29302 m
.45203 .30413 L
s
0 0 1 r
.53489 .29302 m
.54797 .30413 L
s
1 0 0 r
.65201 .34799 m
.64317 .35683 L
s
0 0 1 r
.34799 .34799 m
.35683 .35683 L
s
1 0 0 r
.35683 .64317 m
.34799 .65201 L
s
0 0 1 r
.64317 .64317 m
.65201 .65201 L
s
1 0 0 r
.6101 .3162 m
.59756 .32224 L
s
0 0 1 r
.3899 .3162 m
.40244 .32224 L
s
1 0 0 r
.56202 .29631 m
.54804 .30299 L
s
0 0 1 r
.43798 .29631 m
.45196 .30299 L
s
1 0 0 r
.35049 .6371 m
.35517 .65357 L
s
0 0 1 r
.64951 .6371 m
.64483 .65357 L
s
1 0 0 r
.49296 .2886 m
.47916 .29821 L
s
0 0 1 r
.50704 .2886 m
.52084 .29821 L
s
1 0 0 r
.33641 .62077 m
.33332 .63484 L
s
0 0 1 r
.66359 .62077 m
.66668 .63484 L
s
1 0 0 r
.37223 .65846 m
.3802 .67401 L
s
0 0 1 r
.62777 .65846 m
.6198 .67401 L
s
1 0 0 r
.3502 .63897 m
.34232 .64858 L
s
0 0 1 r
.6498 .63897 m
.65768 .64858 L
s
1 0 0 r
.34488 .6339 m
.34831 .65029 L
s
0 0 1 r
.65512 .6339 m
.65169 .65029 L
s
1 0 0 r
.52116 .28705 m
.50698 .2952 L
s
0 0 1 r
.47884 .28705 m
.49302 .2952 L
s
1 0 0 r
.33547 .62227 m
.33365 .63702 L
s
0 0 1 r
.66453 .62227 m
.66635 .63702 L
s
1 0 0 r
.59939 .30789 m
.58631 .31366 L
s
0 0 1 r
.40061 .30789 m
.41369 .31366 L
s
1 0 0 r
.33583 .62454 m
.33532 .63987 L
s
0 0 1 r
.66417 .62454 m
.66468 .63987 L
s
1 0 0 r
.34054 .63058 m
.34267 .64674 L
s
0 0 1 r
.65946 .63058 m
.65733 .64674 L
s
1 0 0 r
.33752 .62738 m
.33833 .64319 L
s
0 0 1 r
.66248 .62738 m
.66167 .64319 L
s
1 0 0 r
.34456 .63589 m
.33771 .64632 L
s
0 0 1 r
.65544 .63589 m
.66229 .64632 L
s
1 0 0 r
.42486 .29826 m
.41344 .31131 L
s
0 0 1 r
.57514 .29826 m
.58656 .31131 L
s
1 0 0 r
.36318 .65637 m
.37008 .67212 L
s
0 0 1 r
.63682 .65637 m
.62992 .67212 L
s
1 0 0 r
.54904 .28796 m
.53481 .29473 L
s
0 0 1 r
.45096 .28796 m
.46519 .29473 L
s
1 0 0 r
.33999 .63397 m
.33424 .64523 L
s
0 0 1 r
.66001 .63397 m
.66576 .64523 L
s
1 0 0 r
.45103 .28901 m
.43834 .30057 L
s
0 0 1 r
.54897 .28901 m
.56166 .30057 L
s
1 0 0 r
.58801 .29935 m
.57445 .30494 L
s
0 0 1 r
.41199 .29935 m
.42555 .30494 L
s
1 0 0 r
.47871 .28301 m
.46511 .29302 L
s
0 0 1 r
.52129 .28301 m
.53489 .29302 L
s
1 0 0 r
.33654 .6332 m
.33196 .64528 L
s
0 0 1 r
.66346 .6332 m
.66804 .64528 L
s
1 0 0 r
.35517 .65357 m
.36092 .66942 L
s
0 0 1 r
.64483 .65357 m
.63908 .66942 L
s
1 0 0 r
.3802 .67401 m
.38914 .68875 L
s
0 0 1 r
.6198 .67401 m
.61086 .68875 L
s
1 0 0 r
.50713 .28015 m
.49296 .2886 L
s
0 0 1 r
.49287 .28015 m
.50704 .2886 L
s
1 0 0 r
.64013 .32534 m
.62933 .33136 L
s
0 0 1 r
.35987 .32534 m
.37067 .33136 L
s
1 0 0 r
.64775 .33121 m
.63777 .33786 L
s
0 0 1 r
.35225 .33121 m
.36223 .33786 L
s
1 0 0 r
.3343 .63353 m
.33095 .6464 L
s
0 0 1 r
.6657 .63353 m
.66905 .6464 L
s
1 0 0 r
.57598 .29078 m
.56202 .29631 L
s
0 0 1 r
.42402 .29078 m
.43798 .29631 L
s
1 0 0 r
.63163 .31861 m
.62009 .32408 L
s
0 0 1 r
.36837 .31861 m
.37991 .32408 L
s
1 0 0 r
.34831 .65029 m
.35282 .66609 L
s
0 0 1 r
.65169 .65029 m
.64718 .66609 L
s
1 0 0 r
.65445 .33608 m
.64535 .34344 L
s
0 0 1 r
.34555 .33608 m
.35465 .34344 L
s
1 0 0 r
.53557 .28011 m
.52116 .28705 L
s
0 0 1 r
.46443 .28011 m
.47884 .28705 L
s
1 0 0 r
.62232 .31117 m
.6101 .3162 L
s
0 0 1 r
.37768 .31117 m
.3899 .3162 L
s
1 0 0 r
.33332 .63484 m
.33124 .64847 L
s
0 0 1 r
.66668 .63484 m
.66876 .64847 L
s
1 0 0 r
.66015 .33985 m
.65201 .34799 L
s
0 0 1 r
.33985 .33985 m
.34799 .34799 L
s
1 0 0 r
.34799 .65201 m
.33985 .66015 L
s
0 0 1 r
.65201 .65201 m
.66015 .66015 L
s
1 0 0 r
.34267 .64674 m
.3459 .66236 L
s
0 0 1 r
.65733 .64674 m
.6541 .66236 L
s
1 0 0 r
.43705 .28624 m
.42486 .29826 L
s
0 0 1 r
.56295 .28624 m
.57514 .29826 L
s
1 0 0 r
.33365 .63702 m
.33289 .6513 L
s
0 0 1 r
.66635 .63702 m
.66711 .6513 L
s
1 0 0 r
.37008 .67212 m
.37801 .6871 L
s
0 0 1 r
.62992 .67212 m
.62199 .6871 L
s
1 0 0 r
.33833 .64319 m
.34024 .65849 L
s
0 0 1 r
.66167 .64319 m
.65976 .65849 L
s
1 0 0 r
.33532 .63987 m
.33589 .65472 L
s
0 0 1 r
.66468 .63987 m
.66411 .65472 L
s
1 0 0 r
.61223 .30321 m
.59939 .30789 L
s
0 0 1 r
.38777 .30321 m
.40061 .30789 L
s
1 0 0 r
.46435 .27857 m
.45103 .28901 L
s
0 0 1 r
.53565 .27857 m
.54897 .28901 L
s
1 0 0 r
.34232 .64858 m
.33521 .65754 L
s
0 0 1 r
.65768 .64858 m
.66479 .65754 L
s
1 0 0 r
.56334 .28241 m
.54904 .28796 L
s
0 0 1 r
.43666 .28241 m
.45096 .28796 L
s
1 0 0 r
.4928 .2742 m
.47871 .28301 L
s
0 0 1 r
.5072 .2742 m
.52129 .28301 L
s
1 0 0 r
.33771 .64632 m
.3317 .65613 L
s
0 0 1 r
.66229 .64632 m
.6683 .65613 L
s
1 0 0 r
.38914 .68875 m
.39903 .70258 L
s
0 0 1 r
.61086 .68875 m
.60097 .70258 L
s
1 0 0 r
.6014 .29492 m
.58801 .29935 L
s
0 0 1 r
.3986 .29492 m
.41199 .29935 L
s
1 0 0 r
.36092 .66942 m
.36773 .68452 L
s
0 0 1 r
.63908 .66942 m
.63227 .68452 L
s
1 0 0 r
.52163 .27295 m
.50713 .28015 L
s
0 0 1 r
.47837 .27295 m
.49287 .28015 L
s
1 0 0 r
.33424 .64523 m
.32939 .65591 L
s
0 0 1 r
.66576 .64523 m
.67061 .65591 L
s
1 0 0 r
.35282 .66609 m
.35844 .68119 L
s
0 0 1 r
.64718 .66609 m
.64156 .68119 L
s
1 0 0 r
.33196 .64528 m
.32835 .65681 L
s
0 0 1 r
.66804 .64528 m
.67165 .65681 L
s
1 0 0 r
.58986 .28649 m
.57598 .29078 L
s
0 0 1 r
.41014 .28649 m
.42402 .29078 L
s
1 0 0 r
.55013 .27444 m
.53557 .28011 L
s
0 0 1 r
.44987 .27444 m
.46443 .28011 L
s
1 0 0 r
.44995 .27537 m
.43705 .28624 L
s
0 0 1 r
.55005 .27537 m
.56295 .28624 L
s
1 0 0 r
.37801 .6871 m
.38694 .7012 L
s
0 0 1 r
.62199 .6871 m
.61306 .7012 L
s
1 0 0 r
.33095 .6464 m
.32861 .65874 L
s
0 0 1 r
.66905 .6464 m
.67139 .65874 L
s
1 0 0 r
.3459 .66236 m
.35025 .67733 L
s
0 0 1 r
.6541 .66236 m
.64975 .67733 L
s
1 0 0 r
.65037 .32029 m
.64013 .32534 L
s
0 0 1 r
.34963 .32029 m
.35987 .32534 L
s
1 0 0 r
.64269 .31417 m
.63163 .31861 L
s
0 0 1 r
.35731 .31417 m
.36837 .31861 L
s
1 0 0 r
.47823 .26936 m
.46435 .27857 L
s
0 0 1 r
.52177 .26936 m
.53565 .27857 L
s
1 0 0 r
.6571 .32545 m
.64775 .33121 L
s
0 0 1 r
.3429 .32545 m
.35225 .33121 L
s
1 0 0 r
.33124 .64847 m
.33023 .66154 L
s
0 0 1 r
.66876 .64847 m
.66977 .66154 L
s
1 0 0 r
.63413 .30725 m
.62232 .31117 L
s
0 0 1 r
.36587 .30725 m
.37768 .31117 L
s
1 0 0 r
.34024 .65849 m
.34328 .67317 L
s
0 0 1 r
.65976 .65849 m
.65672 .67317 L
s
1 0 0 r
.66283 .32955 m
.65445 .33608 L
s
0 0 1 r
.33717 .32955 m
.34555 .33608 L
s
1 0 0 r
.33289 .6513 m
.33323 .66503 L
s
0 0 1 r
.66711 .6513 m
.66677 .66503 L
s
1 0 0 r
.33589 .65472 m
.33758 .66899 L
s
0 0 1 r
.66411 .65472 m
.66242 .66899 L
s
1 0 0 r
.5073 .26668 m
.4928 .2742 L
s
0 0 1 r
.4927 .26668 m
.5072 .2742 L
s
1 0 0 r
.39903 .70258 m
.40983 .71538 L
s
0 0 1 r
.60097 .70258 m
.59017 .71538 L
s
1 0 0 r
.66751 .33249 m
.66015 .33985 L
s
0 0 1 r
.33249 .33249 m
.33985 .33985 L
s
1 0 0 r
.33985 .66015 m
.33249 .66751 L
s
0 0 1 r
.66015 .66015 m
.66751 .66751 L
s
1 0 0 r
.62474 .29971 m
.61223 .30321 L
s
0 0 1 r
.37526 .29971 m
.38777 .30321 L
s
1 0 0 r
.57765 .27816 m
.56334 .28241 L
s
0 0 1 r
.42235 .27816 m
.43666 .28241 L
s
1 0 0 r
.36773 .68452 m
.37561 .69878 L
s
0 0 1 r
.63227 .68452 m
.62439 .69878 L
s
1 0 0 r
.33521 .65754 m
.32895 .66577 L
s
0 0 1 r
.66479 .65754 m
.67105 .66577 L
s
1 0 0 r
.53639 .26708 m
.52163 .27295 L
s
0 0 1 r
.46361 .26708 m
.47837 .27295 L
s
1 0 0 r
.61454 .29173 m
.6014 .29492 L
s
0 0 1 r
.38546 .29173 m
.3986 .29492 L
s
1 0 0 r
.3317 .65613 m
.32661 .66526 L
s
0 0 1 r
.6683 .65613 m
.67339 .66526 L
s
1 0 0 r
.35844 .68119 m
.36517 .69549 L
s
0 0 1 r
.64156 .68119 m
.63483 .69549 L
s
1 0 0 r
.46352 .26574 m
.44995 .27537 L
s
0 0 1 r
.53648 .26574 m
.55005 .27537 L
s
1 0 0 r
.38694 .7012 m
.39688 .7143 L
s
0 0 1 r
.61306 .7012 m
.60312 .7143 L
s
1 0 0 r
.56479 .27014 m
.55013 .27444 L
s
0 0 1 r
.43521 .27014 m
.44987 .27444 L
s
1 0 0 r
.32939 .65591 m
.32554 .66593 L
s
0 0 1 r
.67061 .65591 m
.67446 .66593 L
s
1 0 0 r
.60357 .28352 m
.58986 .28649 L
s
0 0 1 r
.39643 .28352 m
.41014 .28649 L
s
1 0 0 r
.49263 .26147 m
.47823 .26936 L
s
0 0 1 r
.50737 .26147 m
.52177 .26936 L
s
1 0 0 r
.35025 .67733 m
.35576 .69152 L
s
0 0 1 r
.64975 .67733 m
.64424 .69152 L
s
1 0 0 r
.32835 .65681 m
.32578 .66769 L
s
0 0 1 r
.67165 .65681 m
.67422 .66769 L
s
1 0 0 r
.52215 .26055 m
.5073 .26668 L
s
0 0 1 r
.47785 .26055 m
.4927 .26668 L
s
1 0 0 r
.40983 .71538 m
.42154 .72706 L
s
0 0 1 r
.59017 .71538 m
.57846 .72706 L
s
1 0 0 r
.34328 .67317 m
.34748 .68713 L
s
0 0 1 r
.65672 .67317 m
.65252 .68713 L
s
1 0 0 r
.32861 .65874 m
.32737 .67043 L
s
0 0 1 r
.67139 .65874 m
.67263 .67043 L
s
1 0 0 r
.65318 .31084 m
.64269 .31417 L
s
0 0 1 r
.34682 .31084 m
.35731 .31417 L
s
1 0 0 r
.65996 .31627 m
.65037 .32029 L
s
0 0 1 r
.34004 .31627 m
.34963 .32029 L
s
1 0 0 r
.33023 .66154 m
.33035 .67396 L
s
0 0 1 r
.66977 .66154 m
.66965 .67396 L
s
1 0 0 r
.33758 .66899 m
.34044 .68256 L
s
0 0 1 r
.66242 .66899 m
.65956 .68256 L
s
1 0 0 r
.37561 .69878 m
.38457 .71208 L
s
0 0 1 r
.62439 .69878 m
.61543 .71208 L
s
1 0 0 r
.33323 .66503 m
.33472 .67809 L
s
0 0 1 r
.66677 .66503 m
.66528 .67809 L
s
1 0 0 r
.64546 .30451 m
.63413 .30725 L
s
0 0 1 r
.35454 .30451 m
.36587 .30725 L
s
1 0 0 r
.66573 .32068 m
.6571 .32545 L
s
0 0 1 r
.33427 .32068 m
.3429 .32545 L
s
1 0 0 r
.59186 .27531 m
.57765 .27816 L
s
0 0 1 r
.40814 .27531 m
.42235 .27816 L
s
1 0 0 r
.67043 .32395 m
.66283 .32955 L
s
0 0 1 r
.32957 .32395 m
.33717 .32955 L
s
1 0 0 r
.55132 .26265 m
.53639 .26708 L
s
0 0 1 r
.44868 .26265 m
.46361 .26708 L
s
1 0 0 r
.63683 .29746 m
.62474 .29971 L
s
0 0 1 r
.36317 .29746 m
.37526 .29971 L
s
1 0 0 r
.674 .326 m
.66751 .33249 L
s
0 0 1 r
.326 .326 m
.33249 .33249 L
s
1 0 0 r
.33249 .66751 m
.326 .674 L
s
0 0 1 r
.66751 .66751 m
.674 .674 L
s
1 0 0 r
.47771 .25746 m
.46352 .26574 L
s
0 0 1 r
.52229 .25746 m
.53648 .26574 L
s
1 0 0 r
.36517 .69549 m
.37303 .70886 L
s
0 0 1 r
.63483 .69549 m
.62697 .70886 L
s
1 0 0 r
.62734 .28988 m
.61454 .29173 L
s
0 0 1 r
.37266 .28988 m
.38546 .29173 L
s
1 0 0 r
.39688 .7143 m
.40781 .72629 L
s
0 0 1 r
.60312 .7143 m
.59219 .72629 L
s
1 0 0 r
.32895 .66577 m
.32363 .67318 L
s
0 0 1 r
.67105 .66577 m
.67637 .67318 L
s
1 0 0 r
.50748 .25501 m
.49263 .26147 L
s
0 0 1 r
.49252 .25501 m
.50737 .26147 L
s
1 0 0 r
.57944 .2673 m
.56479 .27014 L
s
0 0 1 r
.42056 .2673 m
.43521 .27014 L
s
1 0 0 r
.32661 .66526 m
.32253 .67359 L
s
0 0 1 r
.67339 .66526 m
.67747 .67359 L
s
1 0 0 r
.35576 .69152 m
.36243 .70483 L
s
0 0 1 r
.64424 .69152 m
.63757 .70483 L
s
1 0 0 r
.61702 .28196 m
.60357 .28352 L
s
0 0 1 r
.38298 .28196 m
.39643 .28352 L
s
1 0 0 r
.42154 .72706 m
.43412 .73748 L
s
0 0 1 r
.57846 .72706 m
.56588 .73748 L
s
1 0 0 r
.53727 .25589 m
.52215 .26055 L
s
0 0 1 r
.46273 .25589 m
.47785 .26055 L
s
1 0 0 r
.32554 .66593 m
.32274 .67518 L
s
0 0 1 r
.67446 .66593 m
.67726 .67518 L
s
1 0 0 r
.34748 .68713 m
.35288 .70024 L
s
0 0 1 r
.65252 .68713 m
.64712 .70024 L
s
1 0 0 r
.38457 .71208 m
.39458 .72429 L
s
0 0 1 r
.61543 .71208 m
.60542 .72429 L
s
1 0 0 r
.32578 .66769 m
.32432 .67782 L
s
0 0 1 r
.67422 .66769 m
.67568 .67782 L
s
1 0 0 r
.34044 .68256 m
.34452 .69532 L
s
0 0 1 r
.65956 .68256 m
.65548 .69532 L
s
1 0 0 r
.32737 .67043 m
.32729 .68137 L
s
0 0 1 r
.67263 .67043 m
.67271 .68137 L
s
1 0 0 r
.6059 .27392 m
.59186 .27531 L
s
0 0 1 r
.3941 .27392 m
.40814 .27531 L
s
1 0 0 r
.56634 .25973 m
.55132 .26265 L
s
0 0 1 r
.43366 .25973 m
.44868 .26265 L
s
1 0 0 r
.33472 .67809 m
.33742 .69036 L
s
0 0 1 r
.66528 .67809 m
.66258 .69036 L
s
1 0 0 r
.33035 .67396 m
.33167 .68563 L
s
0 0 1 r
.66965 .67396 m
.66833 .68563 L
s
1 0 0 r
.66301 .3087 m
.65318 .31084 L
s
0 0 1 r
.33699 .3087 m
.34682 .31084 L
s
1 0 0 r
.49244 .25064 m
.47771 .25746 L
s
0 0 1 r
.50756 .25064 m
.52229 .25746 L
s
1 0 0 r
.66881 .31339 m
.65996 .31627 L
s
0 0 1 r
.33119 .31339 m
.34004 .31627 L
s
1 0 0 r
.65619 .30304 m
.64546 .30451 L
s
0 0 1 r
.34381 .30304 m
.35454 .30451 L
s
1 0 0 r
.67354 .31697 m
.66573 .32068 L
s
0 0 1 r
.32646 .31697 m
.33427 .32068 L
s
1 0 0 r
.40781 .72629 m
.41969 .73704 L
s
0 0 1 r
.59219 .72629 m
.58031 .73704 L
s
1 0 0 r
.37303 .70886 m
.38202 .72117 L
s
0 0 1 r
.62697 .70886 m
.61798 .72117 L
s
1 0 0 r
.64841 .29655 m
.63683 .29746 L
s
0 0 1 r
.35159 .29655 m
.36317 .29746 L
s
1 0 0 r
.67713 .31935 m
.67043 .32395 L
s
0 0 1 r
.32287 .31935 m
.32957 .32395 L
s
1 0 0 r
.5227 .25008 m
.50748 .25501 L
s
0 0 1 r
.4773 .25008 m
.49252 .25501 L
s
1 0 0 r
.63971 .28943 m
.62734 .28988 L
s
0 0 1 r
.36029 .28943 m
.37266 .28988 L
s
1 0 0 r
.59401 .266 m
.57944 .2673 L
s
0 0 1 r
.40599 .266 m
.42056 .2673 L
s
1 0 0 r
.67953 .32047 m
.674 .326 L
s
0 0 1 r
.32047 .32047 m
.326 .326 L
s
1 0 0 r
.326 .674 m
.32047 .67953 L
s
0 0 1 r
.674 .674 m
.67953 .67953 L
s
1 0 0 r
.43412 .73748 m
.44751 .74654 L
s
0 0 1 r
.56588 .73748 m
.55249 .74654 L
s
1 0 0 r
.36243 .70483 m
.37028 .71713 L
s
0 0 1 r
.63757 .70483 m
.62972 .71713 L
s
1 0 0 r
.55258 .25282 m
.53727 .25589 L
s
0 0 1 r
.44742 .25282 m
.46273 .25589 L
s
1 0 0 r
.32363 .67318 m
.31934 .67967 L
s
0 0 1 r
.67637 .67318 m
.68066 .67967 L
s
1 0 0 r
.63012 .28187 m
.61702 .28196 L
s
0 0 1 r
.36988 .28187 m
.38298 .28196 L
s
1 0 0 r
.39458 .72429 m
.40564 .73528 L
s
0 0 1 r
.60542 .72429 m
.59436 .73528 L
s
1 0 0 r
.32253 .67359 m
.31953 .68104 L
s
0 0 1 r
.67747 .67359 m
.68047 .68104 L
s
1 0 0 r
.35288 .70024 m
.35951 .71237 L
s
0 0 1 r
.64712 .70024 m
.64049 .71237 L
s
1 0 0 r
.32274 .67518 m
.3211 .68355 L
s
0 0 1 r
.67726 .67518 m
.6789 .68355 L
s
1 0 0 r
.58136 .25842 m
.56634 .25973 L
s
0 0 1 r
.41864 .25842 m
.43366 .25973 L
s
1 0 0 r
.50767 .24538 m
.49244 .25064 L
s
0 0 1 r
.49233 .24538 m
.50756 .25064 L
s
1 0 0 r
.34452 .69532 m
.34984 .70715 L
s
0 0 1 r
.65548 .69532 m
.65016 .70715 L
s
1 0 0 r
.61967 .2741 m
.6059 .27392 L
s
0 0 1 r
.38033 .2741 m
.3941 .27392 L
s
1 0 0 r
.32432 .67782 m
.32406 .68708 L
s
0 0 1 r
.67568 .67782 m
.67594 .68708 L
s
1 0 0 r
.41969 .73704 m
.43249 .74643 L
s
0 0 1 r
.58031 .73704 m
.56751 .74643 L
s
1 0 0 r
.33742 .69036 m
.34138 .70173 L
s
0 0 1 r
.66258 .69036 m
.65862 .70173 L
s
1 0 0 r
.32729 .68137 m
.32844 .69144 L
s
0 0 1 r
.67271 .68137 m
.67156 .69144 L
s
1 0 0 r
.33167 .68563 m
.33422 .69641 L
s
0 0 1 r
.66833 .68563 m
.66578 .69641 L
s
1 0 0 r
.38202 .72117 m
.39213 .7323 L
s
0 0 1 r
.61798 .72117 m
.60787 .7323 L
s
1 0 0 r
.53821 .24677 m
.5227 .25008 L
s
0 0 1 r
.46179 .24677 m
.4773 .25008 L
s
1 0 0 r
.67206 .30785 m
.66301 .3087 L
s
0 0 1 r
.32794 .30785 m
.33699 .3087 L
s
1 0 0 r
.66623 .30291 m
.65619 .30304 L
s
0 0 1 r
.33377 .30291 m
.34381 .30304 L
s
1 0 0 r
.67681 .31172 m
.66881 .31339 L
s
0 0 1 r
.32319 .31172 m
.33119 .31339 L
s
1 0 0 r
.65937 .29706 m
.64841 .29655 L
s
0 0 1 r
.34063 .29706 m
.35159 .29655 L
s
1 0 0 r
.44751 .74654 m
.46168 .75411 L
s
0 0 1 r
.55249 .74654 m
.53832 .75411 L
s
1 0 0 r
.60838 .26633 m
.59401 .266 L
s
0 0 1 r
.39162 .26633 m
.40599 .266 L
s
1 0 0 r
.68043 .31442 m
.67354 .31697 L
s
0 0 1 r
.31957 .31442 m
.32646 .31697 L
s
1 0 0 r
.65153 .29048 m
.63971 .28943 L
s
0 0 1 r
.34847 .29048 m
.36029 .28943 L
s
1 0 0 r
.56799 .25141 m
.55258 .25282 L
s
0 0 1 r
.43201 .25141 m
.44742 .25282 L
s
1 0 0 r
.37028 .71713 m
.37932 .72827 L
s
0 0 1 r
.62972 .71713 m
.62068 .72827 L
s
1 0 0 r
.68284 .31586 m
.67713 .31935 L
s
0 0 1 r
.31716 .31586 m
.32287 .31935 L
s
1 0 0 r
.40564 .73528 m
.41772 .74493 L
s
0 0 1 r
.59436 .73528 m
.58228 .74493 L
s
1 0 0 r
.684 .316 m
.67953 .32047 L
s
0 0 1 r
.316 .316 m
.32047 .32047 L
s
1 0 0 r
.32047 .67953 m
.316 .684 L
s
0 0 1 r
.67953 .67953 m
.684 .684 L
s
1 0 0 r
.64274 .28335 m
.63012 .28187 L
s
0 0 1 r
.35726 .28335 m
.36988 .28187 L
s
1 0 0 r
.35951 .71237 m
.36737 .72339 L
s
0 0 1 r
.64049 .71237 m
.63263 .72339 L
s
1 0 0 r
.52329 .2418 m
.50767 .24538 L
s
0 0 1 r
.47671 .2418 m
.49233 .24538 L
s
1 0 0 r
.31934 .67967 m
.31618 .68513 L
s
0 0 1 r
.68066 .67967 m
.68382 .68513 L
s
1 0 0 r
.59629 .25881 m
.58136 .25842 L
s
0 0 1 r
.40371 .25881 m
.41864 .25842 L
s
1 0 0 r
.43249 .74643 m
.44617 .75433 L
s
0 0 1 r
.56751 .74643 m
.55383 .75433 L
s
1 0 0 r
.31953 .68104 m
.31772 .68749 L
s
0 0 1 r
.68047 .68104 m
.68228 .68749 L
s
1 0 0 r
.63305 .27591 m
.61967 .2741 L
s
0 0 1 r
.36695 .27591 m
.38033 .2741 L
s
1 0 0 r
.34984 .70715 m
.35643 .7179 L
s
0 0 1 r
.65016 .70715 m
.64357 .7179 L
s
1 0 0 r
.55393 .24519 m
.53821 .24677 L
s
0 0 1 r
.44607 .24519 m
.46179 .24677 L
s
1 0 0 r
.39213 .7323 m
.40334 .74212 L
s
0 0 1 r
.60787 .7323 m
.59666 .74212 L
s
1 0 0 r
.3211 .68355 m
.32068 .69095 L
s
0 0 1 r
.6789 .68355 m
.67932 .69095 L
s
1 0 0 r
.34138 .70173 m
.34663 .71206 L
s
0 0 1 r
.65862 .70173 m
.65337 .71206 L
s
1 0 0 r
.32406 .68708 m
.32506 .69536 L
s
0 0 1 r
.67594 .68708 m
.67494 .69536 L
s
1 0 0 r
.46168 .75411 m
.47655 .76006 L
s
0 0 1 r
.53832 .75411 m
.52345 .76006 L
s
1 0 0 r
.33422 .69641 m
.33809 .70618 L
s
0 0 1 r
.66578 .69641 m
.66191 .70618 L
s
1 0 0 r
.32844 .69144 m
.33088 .70052 L
s
0 0 1 r
.67156 .69144 m
.66912 .70052 L
s
1 0 0 r
.62246 .26836 m
.60838 .26633 L
s
0 0 1 r
.37754 .26836 m
.39162 .26633 L
s
1 0 0 r
.58339 .25176 m
.56799 .25141 L
s
0 0 1 r
.41661 .25176 m
.43201 .25141 L
s
1 0 0 r
.67545 .30422 m
.66623 .30291 L
s
0 0 1 r
.32455 .30422 m
.33377 .30291 L
s
1 0 0 r
.68023 .30836 m
.67206 .30785 L
s
0 0 1 r
.31977 .30836 m
.32794 .30785 L
s
1 0 0 r
.66959 .29907 m
.65937 .29706 L
s
0 0 1 r
.33041 .29907 m
.34063 .29706 L
s
1 0 0 r
.37932 .72827 m
.38954 .73814 L
s
0 0 1 r
.62068 .72827 m
.61046 .73814 L
s
1 0 0 r
.68386 .31136 m
.67681 .31172 L
s
0 0 1 r
.31614 .31136 m
.32319 .31172 L
s
1 0 0 r
.41772 .74493 m
.43077 .7531 L
s
0 0 1 r
.58228 .74493 m
.56923 .7531 L
s
1 0 0 r
.66269 .2931 m
.65153 .29048 L
s
0 0 1 r
.33731 .2931 m
.34847 .29048 L
s
1 0 0 r
.68629 .31312 m
.68043 .31442 L
s
0 0 1 r
.31371 .31312 m
.31957 .31442 L
s
1 0 0 r
.53921 .23999 m
.52329 .2418 L
s
0 0 1 r
.46079 .23999 m
.47671 .2418 L
s
1 0 0 r
.65479 .28647 m
.64274 .28335 L
s
0 0 1 r
.34521 .28647 m
.35726 .28335 L
s
1 0 0 r
.68746 .31357 m
.68284 .31586 L
s
0 0 1 r
.31254 .31357 m
.31716 .31586 L
s
1 0 0 r
.61099 .26097 m
.59629 .25881 L
s
0 0 1 r
.38901 .26097 m
.40371 .25881 L
s
1 0 0 r
.36737 .72339 m
.37648 .73317 L
s
0 0 1 r
.63263 .72339 m
.62352 .73317 L
s
1 0 0 r
.44617 .75433 m
.46067 .76062 L
s
0 0 1 r
.55383 .75433 m
.53933 .76062 L
s
1 0 0 r
.6873 .3127 m
.684 .316 L
s
0 0 1 r
.3127 .3127 m
.316 .316 L
s
1 0 0 r
.316 .684 m
.3127 .6873 L
s
0 0 1 r
.684 .684 m
.6873 .6873 L
s
1 0 0 r
.56974 .24543 m
.55393 .24519 L
s
0 0 1 r
.43026 .24543 m
.44607 .24519 L
s
1 0 0 r
.64592 .27943 m
.63305 .27591 L
s
0 0 1 r
.35408 .27943 m
.36695 .27591 L
s
1 0 0 r
.40334 .74212 m
.41564 .75048 L
s
0 0 1 r
.59666 .74212 m
.58436 .75048 L
s
1 0 0 r
.31618 .68513 m
.31423 .68946 L
s
0 0 1 r
.68382 .68513 m
.68577 .68946 L
s
1 0 0 r
.35643 .7179 m
.36433 .72744 L
s
0 0 1 r
.64357 .7179 m
.63567 .72744 L
s
1 0 0 r
.47655 .76006 m
.49204 .76429 L
s
0 0 1 r
.52345 .76006 m
.50796 .76429 L
s
1 0 0 r
.31772 .68749 m
.31718 .69282 L
s
0 0 1 r
.68228 .68749 m
.68282 .69282 L
s
1 0 0 r
.34663 .71206 m
.35322 .72123 L
s
0 0 1 r
.65337 .71206 m
.64678 .72123 L
s
1 0 0 r
.59868 .25396 m
.58339 .25176 L
s
0 0 1 r
.40132 .25396 m
.41661 .25176 L
s
1 0 0 r
.32068 .69095 m
.32157 .69725 L
s
0 0 1 r
.67932 .69095 m
.67843 .69725 L
s
1 0 0 r
.63611 .27218 m
.62246 .26836 L
s
0 0 1 r
.36389 .27218 m
.37754 .26836 L
s
1 0 0 r
.33809 .70618 m
.3433 .71481 L
s
0 0 1 r
.66191 .70618 m
.6567 .71481 L
s
1 0 0 r
.32506 .69536 m
.32741 .70254 L
s
0 0 1 r
.67494 .69536 m
.67259 .70254 L
s
1 0 0 r
.33088 .70052 m
.33467 .70849 L
s
0 0 1 r
.66912 .70052 m
.66533 .70849 L
s
1 0 0 r
.43077 .7531 m
.44476 .75967 L
s
0 0 1 r
.56923 .7531 m
.55524 .75967 L
s
1 0 0 r
.38954 .73814 m
.40094 .74658 L
s
0 0 1 r
.61046 .73814 m
.59906 .74658 L
s
1 0 0 r
.68375 .30704 m
.67545 .30422 L
s
0 0 1 r
.31625 .30704 m
.32455 .30422 L
s
1 0 0 r
.67896 .30266 m
.66959 .29907 L
s
0 0 1 r
.32104 .30266 m
.33041 .29907 L
s
1 0 0 r
.55534 .24004 m
.53921 .23999 L
s
0 0 1 r
.44466 .24004 m
.46079 .23999 L
s
1 0 0 r
.6874 .31032 m
.68023 .30836 L
s
0 0 1 r
.3126 .31032 m
.31977 .30836 L
s
1 0 0 r
.67307 .29735 m
.66269 .2931 L
s
0 0 1 r
.32693 .29735 m
.33731 .2931 L
s
1 0 0 r
.68984 .31239 m
.68386 .31136 L
s
0 0 1 r
.31016 .31239 m
.31614 .31136 L
s
1 0 0 r
.62537 .26498 m
.61099 .26097 L
s
0 0 1 r
.37463 .26498 m
.38901 .26097 L
s
1 0 0 r
.46067 .76062 m
.47592 .76517 L
s
0 0 1 r
.53933 .76062 m
.52408 .76517 L
s
1 0 0 r
.66613 .2913 m
.65479 .28647 L
s
0 0 1 r
.33387 .2913 m
.34521 .28647 L
s
1 0 0 r
.37648 .73317 m
.38684 .74156 L
s
0 0 1 r
.62352 .73317 m
.61316 .74156 L
s
1 0 0 r
.69102 .31316 m
.68629 .31312 L
s
0 0 1 r
.30898 .31316 m
.31371 .31312 L
s
1 0 0 r
.58552 .24757 m
.56974 .24543 L
s
0 0 1 r
.41448 .24757 m
.43026 .24543 L
s
1 0 0 r
.41564 .75048 m
.42897 .75726 L
s
0 0 1 r
.58436 .75048 m
.57103 .75726 L
s
1 0 0 r
.69087 .31258 m
.68746 .31357 L
s
0 0 1 r
.30913 .31258 m
.31254 .31357 L
s
1 0 0 r
.49204 .76429 m
.50808 .76669 L
s
0 0 1 r
.50796 .76429 m
.49192 .76669 L
s
1 0 0 r
.65817 .28472 m
.64592 .27943 L
s
0 0 1 r
.34183 .28472 m
.35408 .27943 L
s
1 0 0 r
.36433 .72744 m
.37353 .73564 L
s
0 0 1 r
.63567 .72744 m
.62647 .73564 L
s
1 0 0 r
.68935 .31065 m
.6873 .3127 L
s
0 0 1 r
.31065 .31065 m
.3127 .3127 L
s
1 0 0 r
.3127 .6873 m
.31065 .68935 L
s
0 0 1 r
.6873 .6873 m
.68935 .68935 L
s
1 0 0 r
.61371 .25806 m
.59868 .25396 L
s
0 0 1 r
.38629 .25806 m
.40132 .25396 L
s
1 0 0 r
.31423 .68946 m
.3136 .69256 L
s
0 0 1 r
.68577 .68946 m
.6864 .69256 L
s
1 0 0 r
.64921 .27784 m
.63611 .27218 L
s
0 0 1 r
.35079 .27784 m
.36389 .27218 L
s
1 0 0 r
.44476 .75967 m
.45962 .7645 L
s
0 0 1 r
.55524 .75967 m
.54038 .7645 L
s
1 0 0 r
.35322 .72123 m
.36117 .72908 L
s
0 0 1 r
.64678 .72123 m
.63883 .72908 L
s
1 0 0 r
.31718 .69282 m
.318 .69694 L
s
0 0 1 r
.68282 .69282 m
.682 .69694 L
s
1 0 0 r
.40094 .74658 m
.41347 .75346 L
s
0 0 1 r
.59906 .74658 m
.58653 .75346 L
s
1 0 0 r
.57156 .24205 m
.55534 .24004 L
s
0 0 1 r
.42844 .24205 m
.44466 .24004 L
s
1 0 0 r
.3433 .71481 m
.34991 .72217 L
s
0 0 1 r
.6567 .71481 m
.65009 .72217 L
s
1 0 0 r
.32157 .69725 m
.32386 .70232 L
s
0 0 1 r
.67843 .69725 m
.67614 .70232 L
s
1 0 0 r
.33467 .70849 m
.33987 .7152 L
s
0 0 1 r
.66533 .70849 m
.66013 .7152 L
s
1 0 0 r
.32741 .70254 m
.33116 .70849 L
s
0 0 1 r
.67259 .70254 m
.66884 .70849 L
s
1 0 0 r
.47592 .76517 m
.49183 .76786 L
s
0 0 1 r
.52408 .76517 m
.50817 .76786 L
s
1 0 0 r
.63928 .2709 m
.62537 .26498 L
s
0 0 1 r
.36072 .2709 m
.37463 .26498 L
s
1 0 0 r
.68735 .30788 m
.67896 .30266 L
s
0 0 1 r
.31265 .30788 m
.32104 .30266 L
s
1 0 0 r
.691 .31143 m
.68375 .30704 L
s
0 0 1 r
.309 .31143 m
.31625 .30704 L
s
1 0 0 r
.68255 .30331 m
.67307 .29735 L
s
0 0 1 r
.31745 .30331 m
.32693 .29735 L
s
1 0 0 r
.60116 .25169 m
.58552 .24757 L
s
0 0 1 r
.39884 .25169 m
.41448 .24757 L
s
1 0 0 r
.69344 .31381 m
.6874 .31032 L
s
0 0 1 r
.30656 .31381 m
.3126 .31032 L
s
1 0 0 r
.38684 .74156 m
.39844 .74842 L
s
0 0 1 r
.61316 .74156 m
.60156 .74842 L
s
1 0 0 r
.67664 .29789 m
.66613 .2913 L
s
0 0 1 r
.32336 .29789 m
.33387 .2913 L
s
1 0 0 r
.50808 .76669 m
.52456 .76713 L
s
0 0 1 r
.49192 .76669 m
.47544 .76713 L
s
1 0 0 r
.42897 .75726 m
.44329 .76231 L
s
0 0 1 r
.57103 .75726 m
.55671 .76231 L
s
1 0 0 r
.69463 .3149 m
.68984 .31239 L
s
0 0 1 r
.30537 .3149 m
.31016 .31239 L
s
1 0 0 r
.66965 .29185 m
.65817 .28472 L
s
0 0 1 r
.33035 .29185 m
.34183 .28472 L
s
1 0 0 r
.69449 .31463 m
.69102 .31316 L
s
0 0 1 r
.30551 .31463 m
.30898 .31316 L
s
1 0 0 r
.62838 .26414 m
.61371 .25806 L
s
0 0 1 r
.37162 .26414 m
.38629 .25806 L
s
1 0 0 r
.37353 .73564 m
.38405 .74234 L
s
0 0 1 r
.62647 .73564 m
.61595 .74234 L
s
1 0 0 r
.69297 .31298 m
.69087 .31258 L
s
0 0 1 r
.30703 .31298 m
.30913 .31258 L
s
1 0 0 r
.45962 .7645 m
.47526 .76747 L
s
0 0 1 r
.54038 .7645 m
.52474 .76747 L
s
1 0 0 r
.66163 .28539 m
.64921 .27784 L
s
0 0 1 r
.33837 .28539 m
.35079 .27784 L
s
1 0 0 r
.58773 .2461 m
.57156 .24205 L
s
0 0 1 r
.41227 .2461 m
.42844 .24205 L
s
1 0 0 r
.69003 .30997 m
.68935 .31065 L
s
0 0 1 r
.30997 .30997 m
.31065 .31065 L
s
1 0 0 r
.31065 .68935 m
.30997 .69003 L
s
0 0 1 r
.68935 .68935 m
.69003 .69003 L
s
1 0 0 r
.41347 .75346 m
.4271 .75863 L
s
0 0 1 r
.58653 .75346 m
.5729 .75863 L
s
1 0 0 r
.36117 .72908 m
.3705 .73548 L
s
0 0 1 r
.63883 .72908 m
.6295 .73548 L
s
1 0 0 r
.49183 .76786 m
.5083 .76859 L
s
0 0 1 r
.50817 .76786 m
.4917 .76859 L
s
1 0 0 r
.3136 .69256 m
.31437 .6943 L
s
0 0 1 r
.6864 .69256 m
.68563 .6943 L
s
1 0 0 r
.34991 .72217 m
.35794 .72811 L
s
0 0 1 r
.65009 .72217 m
.64206 .72811 L
s
1 0 0 r
.65258 .27877 m
.63928 .2709 L
s
0 0 1 r
.34742 .27877 m
.36072 .2709 L
s
1 0 0 r
.61652 .25784 m
.60116 .25169 L
s
0 0 1 r
.38348 .25784 m
.39884 .25169 L
s
1 0 0 r
.318 .69694 m
.32025 .69971 L
s
0 0 1 r
.682 .69694 m
.67975 .69971 L
s
1 0 0 r
.33987 .7152 m
.34652 .72054 L
s
0 0 1 r
.66013 .7152 m
.65348 .72054 L
s
1 0 0 r
.32386 .70232 m
.3276 .70605 L
s
0 0 1 r
.67614 .70232 m
.6724 .70605 L
s
1 0 0 r
.52456 .76713 m
.54135 .76554 L
s
0 0 1 r
.47544 .76713 m
.45865 .76554 L
s
1 0 0 r
.33116 .70849 m
.33638 .71309 L
s
0 0 1 r
.66884 .70849 m
.66362 .71309 L
s
1 0 0 r
.69463 .3148 m
.68735 .30788 L
s
0 0 1 r
.30537 .3148 m
.31265 .30788 L
s
1 0 0 r
.69098 .31102 m
.68255 .30331 L
s
0 0 1 r
.30902 .31102 m
.31745 .30331 L
s
1 0 0 r
.44329 .76231 m
.45852 .7655 L
s
0 0 1 r
.55671 .76231 m
.54148 .7655 L
s
1 0 0 r
.39844 .74842 m
.41123 .75361 L
s
0 0 1 r
.60156 .74842 m
.58877 .75361 L
s
1 0 0 r
.69707 .31747 m
.691 .31143 L
s
0 0 1 r
.30293 .31747 m
.309 .31143 L
s
1 0 0 r
.68617 .3063 m
.67664 .29789 L
s
0 0 1 r
.31383 .3063 m
.32336 .29789 L
s
1 0 0 r
.69825 .31889 m
.69344 .31381 L
s
0 0 1 r
.30175 .31889 m
.30656 .31381 L
s
1 0 0 r
.64252 .27225 m
.62838 .26414 L
s
0 0 1 r
.35748 .27225 m
.37162 .26414 L
s
1 0 0 r
.68024 .30084 m
.66965 .29185 L
s
0 0 1 r
.31976 .30084 m
.33035 .29185 L
s
1 0 0 r
.69811 .31896 m
.69463 .3149 L
s
0 0 1 r
.30189 .31896 m
.30537 .3149 L
s
1 0 0 r
.47526 .76747 m
.4916 .76847 L
s
0 0 1 r
.52474 .76747 m
.5084 .76847 L
s
1 0 0 r
.60372 .25223 m
.58773 .2461 L
s
0 0 1 r
.39628 .25223 m
.41227 .2461 L
s
1 0 0 r
.38405 .74234 m
.39587 .74741 L
s
0 0 1 r
.61595 .74234 m
.60413 .74741 L
s
1 0 0 r
.67322 .29487 m
.66163 .28539 L
s
0 0 1 r
.32678 .29487 m
.33837 .28539 L
s
1 0 0 r
.69659 .31761 m
.69449 .31463 L
s
0 0 1 r
.30341 .31761 m
.30551 .31463 L
s
1 0 0 r
.4271 .75863 m
.44177 .76198 L
s
0 0 1 r
.5729 .75863 m
.55823 .76198 L
s
1 0 0 r
.5083 .76859 m
.52523 .76725 L
s
0 0 1 r
.4917 .76859 m
.47477 .76725 L
s
1 0 0 r
.69365 .31486 m
.69297 .31298 L
s
0 0 1 r
.30635 .31486 m
.30703 .31298 L
s
1 0 0 r
.63145 .26607 m
.61652 .25784 L
s
0 0 1 r
.36855 .26607 m
.38348 .25784 L
s
1 0 0 r
.3705 .73548 m
.3812 .74028 L
s
0 0 1 r
.6295 .73548 m
.6188 .74028 L
s
1 0 0 r
.66513 .28864 m
.65258 .27877 L
s
0 0 1 r
.33487 .28864 m
.34742 .27877 L
s
1 0 0 r
.54135 .76554 m
.55834 .76183 L
s
0 0 1 r
.45865 .76554 m
.44166 .76183 L
s
1 0 0 r
.68925 .31075 m
.69003 .30997 L
s
0 0 1 r
.31075 .31075 m
.30997 .30997 L
s
1 0 0 r
.30997 .69003 m
.31075 .68925 L
s
0 0 1 r
.69003 .69003 m
.68925 .68925 L
s
1 0 0 r
.35794 .72811 m
.36741 .7325 L
s
0 0 1 r
.64206 .72811 m
.63259 .7325 L
s
1 0 0 r
.45852 .7655 m
.47459 .76672 L
s
0 0 1 r
.54148 .7655 m
.52541 .76672 L
s
1 0 0 r
.31437 .6943 m
.31665 .6946 L
s
0 0 1 r
.68563 .6943 m
.68335 .6946 L
s
1 0 0 r
.41123 .75361 m
.42518 .75699 L
s
0 0 1 r
.58877 .75361 m
.57482 .75699 L
s
1 0 0 r
.32025 .69971 m
.32403 .70103 L
s
0 0 1 r
.67975 .69971 m
.67597 .70103 L
s
1 0 0 r
.34652 .72054 m
.35467 .72436 L
s
0 0 1 r
.65348 .72054 m
.64533 .72436 L
s
1 0 0 r
.69824 .32052 m
.69098 .31102 L
s
0 0 1 r
.30176 .32052 m
.30902 .31102 L
s
1 0 0 r
.65599 .28239 m
.64252 .27225 L
s
0 0 1 r
.34401 .28239 m
.35748 .27225 L
s
1 0 0 r
.69459 .31654 m
.68617 .3063 L
s
0 0 1 r
.30541 .31654 m
.31383 .3063 L
s
1 0 0 r
.70067 .32346 m
.69463 .3148 L
s
0 0 1 r
.29933 .32346 m
.30537 .3148 L
s
1 0 0 r
.3276 .70605 m
.33287 .70831 L
s
0 0 1 r
.6724 .70605 m
.66713 .70831 L
s
1 0 0 r
.33638 .71309 m
.34311 .71619 L
s
0 0 1 r
.66362 .71309 m
.65689 .71619 L
s
1 0 0 r
.70183 .32521 m
.69707 .31747 L
s
0 0 1 r
.29817 .32521 m
.30293 .31747 L
s
1 0 0 r
.68979 .31173 m
.68024 .30084 L
s
0 0 1 r
.31021 .31173 m
.31976 .30084 L
s
1 0 0 r
.61938 .2605 m
.60372 .25223 L
s
0 0 1 r
.38062 .2605 m
.39628 .25223 L
s
1 0 0 r
.4916 .76847 m
.50853 .76738 L
s
0 0 1 r
.5084 .76847 m
.49147 .76738 L
s
1 0 0 r
.70169 .32562 m
.69825 .31889 L
s
0 0 1 r
.29831 .32562 m
.30175 .31889 L
s
1 0 0 r
.68384 .3063 m
.67322 .29487 L
s
0 0 1 r
.31616 .3063 m
.32678 .29487 L
s
1 0 0 r
.52523 .76725 m
.54247 .76376 L
s
0 0 1 r
.47477 .76725 m
.45753 .76376 L
s
1 0 0 r
.39587 .74741 m
.40895 .75072 L
s
0 0 1 r
.60413 .74741 m
.59105 .75072 L
s
1 0 0 r
.70017 .32463 m
.69811 .31896 L
s
0 0 1 r
.29983 .32463 m
.30189 .31896 L
s
1 0 0 r
.44177 .76198 m
.45741 .76336 L
s
0 0 1 r
.55823 .76198 m
.54259 .76336 L
s
1 0 0 r
.64579 .2764 m
.63145 .26607 L
s
0 0 1 r
.35421 .2764 m
.36855 .26607 L
s
1 0 0 r
.55834 .76183 m
.57537 .75593 L
s
0 0 1 r
.44166 .76183 m
.42463 .75593 L
s
1 0 0 r
.67679 .3005 m
.66513 .28864 L
s
0 0 1 r
.32321 .3005 m
.33487 .28864 L
s
1 0 0 r
.69723 .32218 m
.69659 .31761 L
s
0 0 1 r
.30277 .32218 m
.30341 .31761 L
s
1 0 0 r
.3812 .74028 m
.39326 .74336 L
s
0 0 1 r
.6188 .74028 m
.60674 .74336 L
s
1 0 0 r
.47459 .76672 m
.49137 .76586 L
s
0 0 1 r
.52541 .76672 m
.50863 .76586 L
s
1 0 0 r
.69281 .31831 m
.69365 .31486 L
s
0 0 1 r
.30719 .31831 m
.30635 .31486 L
s
1 0 0 r
.66864 .29459 m
.65599 .28239 L
s
0 0 1 r
.33136 .29459 m
.34401 .28239 L
s
1 0 0 r
.42518 .75699 m
.44023 .75844 L
s
0 0 1 r
.57482 .75699 m
.55977 .75844 L
s
1 0 0 r
.36741 .7325 m
.37832 .7352 L
s
0 0 1 r
.63259 .7325 m
.62168 .7352 L
s
1 0 0 r
.68691 .31309 m
.68925 .31075 L
s
0 0 1 r
.31309 .31309 m
.31075 .31075 L
s
1 0 0 r
.31075 .68925 m
.31309 .68691 L
s
0 0 1 r
.68925 .68925 m
.68691 .68691 L
s
1 0 0 r
.63455 .27092 m
.61938 .2605 L
s
0 0 1 r
.36545 .27092 m
.38062 .2605 L
s
1 0 0 r
.50853 .76738 m
.52591 .76413 L
s
0 0 1 r
.49147 .76738 m
.47409 .76413 L
s
1 0 0 r
.70177 .32863 m
.69459 .31654 L
s
0 0 1 r
.29823 .32863 m
.30541 .31654 L
s
1 0 0 r
.70418 .33182 m
.69824 .32052 L
s
0 0 1 r
.29582 .33182 m
.30176 .32052 L
s
1 0 0 r
.31665 .6946 m
.3205 .69334 L
s
0 0 1 r
.68335 .6946 m
.6795 .69334 L
s
1 0 0 r
.69814 .3245 m
.68979 .31173 L
s
0 0 1 r
.30186 .3245 m
.31021 .31173 L
s
1 0 0 r
.35467 .72436 m
.36431 .72653 L
s
0 0 1 r
.64533 .72436 m
.63569 .72653 L
s
1 0 0 r
.70533 .33388 m
.70067 .32346 L
s
0 0 1 r
.29467 .33388 m
.29933 .32346 L
s
1 0 0 r
.32403 .70103 m
.32939 .70079 L
s
0 0 1 r
.67597 .70103 m
.67061 .70079 L
s
1 0 0 r
.54247 .76376 m
.55989 .75806 L
s
0 0 1 r
.45753 .76376 m
.44011 .75806 L
s
1 0 0 r
.34311 .71619 m
.35139 .71768 L
s
0 0 1 r
.65689 .71619 m
.64861 .71768 L
s
1 0 0 r
.33287 .70831 m
.33972 .709 L
s
0 0 1 r
.66713 .70831 m
.66028 .709 L
s
1 0 0 r
.69334 .31966 m
.68384 .3063 L
s
0 0 1 r
.30666 .31966 m
.31616 .3063 L
s
1 0 0 r
.70517 .33467 m
.70183 .32521 L
s
0 0 1 r
.29483 .33467 m
.29817 .32521 L
s
1 0 0 r
.65939 .28883 m
.64579 .2764 L
s
0 0 1 r
.34061 .28883 m
.35421 .2764 L
s
1 0 0 r
.57537 .75593 m
.59229 .74781 L
s
0 0 1 r
.42463 .75593 m
.40771 .74781 L
s
1 0 0 r
.45741 .76336 m
.4739 .76267 L
s
0 0 1 r
.54259 .76336 m
.5261 .76267 L
s
1 0 0 r
.40895 .75072 m
.42324 .75212 L
s
0 0 1 r
.59105 .75072 m
.57676 .75212 L
s
1 0 0 r
.70364 .33405 m
.70169 .32562 L
s
0 0 1 r
.29636 .33405 m
.29831 .32562 L
s
1 0 0 r
.68739 .31435 m
.67679 .3005 L
s
0 0 1 r
.31261 .31435 m
.32321 .3005 L
s
1 0 0 r
.70069 .33197 m
.70017 .32463 L
s
0 0 1 r
.29931 .33197 m
.29983 .32463 L
s
1 0 0 r
.49137 .76586 m
.50876 .76282 L
s
0 0 1 r
.50863 .76586 m
.49124 .76282 L
s
1 0 0 r
.6803 .30881 m
.66864 .29459 L
s
0 0 1 r
.3197 .30881 m
.33136 .29459 L
s
1 0 0 r
.39326 .74336 m
.40665 .74458 L
s
0 0 1 r
.60674 .74336 m
.59335 .74458 L
s
1 0 0 r
.64906 .28349 m
.63455 .27092 L
s
0 0 1 r
.35094 .28349 m
.36545 .27092 L
s
1 0 0 r
.69628 .3284 m
.69723 .32218 L
s
0 0 1 r
.30372 .3284 m
.30277 .32218 L
s
1 0 0 r
.52591 .76413 m
.5436 .75863 L
s
0 0 1 r
.47409 .76413 m
.4564 .75863 L
s
1 0 0 r
.44023 .75844 m
.45627 .75784 L
s
0 0 1 r
.55977 .75844 m
.54373 .75784 L
s
1 0 0 r
.69036 .3234 m
.69281 .31831 L
s
0 0 1 r
.30964 .3234 m
.30719 .31831 L
s
1 0 0 r
.55989 .75806 m
.57732 .75009 L
s
0 0 1 r
.44011 .75806 m
.42268 .75009 L
s
1 0 0 r
.37832 .7352 m
.39066 .73608 L
s
0 0 1 r
.62168 .7352 m
.60934 .73608 L
s
1 0 0 r
.70756 .34255 m
.70177 .32863 L
s
0 0 1 r
.29244 .34255 m
.29823 .32863 L
s
1 0 0 r
.70517 .33915 m
.69814 .3245 L
s
0 0 1 r
.29483 .33915 m
.30186 .3245 L
s
1 0 0 r
.67209 .30333 m
.65939 .28883 L
s
0 0 1 r
.32791 .30333 m
.34061 .28883 L
s
1 0 0 r
.70868 .34492 m
.70418 .33182 L
s
0 0 1 r
.29132 .34492 m
.29582 .33182 L
s
1 0 0 r
.59229 .74781 m
.60894 .73745 L
s
0 0 1 r
.40771 .74781 m
.39106 .73745 L
s
1 0 0 r
.70157 .33493 m
.69334 .31966 L
s
0 0 1 r
.29843 .33493 m
.30666 .31966 L
s
1 0 0 r
.68293 .31707 m
.68691 .31309 L
s
0 0 1 r
.31707 .31707 m
.31309 .31309 L
s
1 0 0 r
.31309 .68691 m
.31707 .68293 L
s
0 0 1 r
.68691 .68691 m
.68293 .68293 L
s
1 0 0 r
.70849 .34608 m
.70533 .33388 L
s
0 0 1 r
.29151 .34608 m
.29467 .33388 L
s
1 0 0 r
.36431 .72653 m
.37546 .72693 L
s
0 0 1 r
.63569 .72653 m
.62454 .72693 L
s
1 0 0 r
.4739 .76267 m
.49114 .75981 L
s
0 0 1 r
.5261 .76267 m
.50886 .75981 L
s
1 0 0 r
.3205 .69334 m
.326 .69044 L
s
0 0 1 r
.6795 .69334 m
.674 .69044 L
s
1 0 0 r
.69678 .33014 m
.68739 .31435 L
s
0 0 1 r
.30322 .33014 m
.31261 .31435 L
s
1 0 0 r
.35139 .71768 m
.36124 .71745 L
s
0 0 1 r
.64861 .71768 m
.63876 .71745 L
s
1 0 0 r
.42324 .75212 m
.43867 .7515 L
s
0 0 1 r
.57676 .75212 m
.56133 .7515 L
s
1 0 0 r
.70695 .34587 m
.70517 .33467 L
s
0 0 1 r
.29305 .34587 m
.29483 .33467 L
s
1 0 0 r
.32939 .70079 m
.33639 .69888 L
s
0 0 1 r
.67061 .70079 m
.66361 .69888 L
s
1 0 0 r
.33972 .709 m
.34817 .70799 L
s
0 0 1 r
.66028 .709 m
.65183 .70799 L
s
1 0 0 r
.50876 .76282 m
.5266 .75754 L
s
0 0 1 r
.49124 .76282 m
.4734 .75754 L
s
1 0 0 r
.66274 .29817 m
.64906 .28349 L
s
0 0 1 r
.33726 .29817 m
.35094 .28349 L
s
1 0 0 r
.69082 .32502 m
.6803 .30881 L
s
0 0 1 r
.30918 .32502 m
.3197 .30881 L
s
1 0 0 r
.70399 .3442 m
.70364 .33405 L
s
0 0 1 r
.29601 .3442 m
.29636 .33405 L
s
1 0 0 r
.5436 .75863 m
.56144 .75086 L
s
0 0 1 r
.4564 .75863 m
.43856 .75086 L
s
1 0 0 r
.40665 .74458 m
.4213 .74382 L
s
0 0 1 r
.59335 .74458 m
.5787 .74382 L
s
1 0 0 r
.57732 .75009 m
.59459 .73985 L
s
0 0 1 r
.42268 .75009 m
.40541 .73985 L
s
1 0 0 r
.69957 .34101 m
.70069 .33197 L
s
0 0 1 r
.30043 .34101 m
.29931 .33197 L
s
1 0 0 r
.45627 .75784 m
.47321 .75509 L
s
0 0 1 r
.54373 .75784 m
.52679 .75509 L
s
1 0 0 r
.6837 .31985 m
.67209 .30333 L
s
0 0 1 r
.3163 .31985 m
.32791 .30333 L
s
1 0 0 r
.60894 .73745 m
.62512 .72486 L
s
0 0 1 r
.39106 .73745 m
.37488 .72486 L
s
1 0 0 r
.69365 .33632 m
.69628 .3284 L
s
0 0 1 r
.30635 .33632 m
.30372 .3284 L
s
1 0 0 r
.71074 .35561 m
.70517 .33915 L
s
0 0 1 r
.28926 .35561 m
.29483 .33915 L
s
1 0 0 r
.70839 .35204 m
.70157 .33493 L
s
0 0 1 r
.29161 .35204 m
.29843 .33493 L
s
1 0 0 r
.71182 .35826 m
.70756 .34255 L
s
0 0 1 r
.28818 .35826 m
.29244 .34255 L
s
1 0 0 r
.39066 .73608 m
.40437 .73504 L
s
0 0 1 r
.60934 .73608 m
.59563 .73504 L
s
1 0 0 r
.71161 .35979 m
.70868 .34492 L
s
0 0 1 r
.28839 .35979 m
.29132 .34492 L
s
1 0 0 r
.49114 .75981 m
.50899 .7547 L
s
0 0 1 r
.50886 .75981 m
.49101 .7547 L
s
1 0 0 r
.70482 .34779 m
.69678 .33014 L
s
0 0 1 r
.29518 .34779 m
.30322 .33014 L
s
1 0 0 r
.68621 .33018 m
.69036 .3234 L
s
0 0 1 r
.31379 .33018 m
.30964 .3234 L
s
1 0 0 r
.67543 .3149 m
.66274 .29817 L
s
0 0 1 r
.32457 .3149 m
.33726 .29817 L
s
1 0 0 r
.71004 .36001 m
.70849 .34608 L
s
0 0 1 r
.28996 .36001 m
.29151 .34608 L
s
1 0 0 r
.5266 .75754 m
.54473 .74996 L
s
0 0 1 r
.4734 .75754 m
.45527 .74996 L
s
1 0 0 r
.70005 .34312 m
.69082 .32502 L
s
0 0 1 r
.29995 .34312 m
.30918 .32502 L
s
1 0 0 r
.43867 .7515 m
.45514 .74877 L
s
0 0 1 r
.56133 .7515 m
.54486 .74877 L
s
1 0 0 r
.37546 .72693 m
.38808 .72545 L
s
0 0 1 r
.62454 .72693 m
.61192 .72545 L
s
1 0 0 r
.67726 .32274 m
.68293 .31707 L
s
0 0 1 r
.32274 .32274 m
.31707 .31707 L
s
1 0 0 r
.31707 .68293 m
.32274 .67726 L
s
0 0 1 r
.68293 .68293 m
.67726 .67726 L
s
1 0 0 r
.56144 .75086 m
.57925 .74078 L
s
0 0 1 r
.43856 .75086 m
.42075 .74078 L
s
1 0 0 r
.70707 .3588 m
.70695 .34587 L
s
0 0 1 r
.29293 .3588 m
.29305 .34587 L
s
1 0 0 r
.326 .69044 m
.33319 .68581 L
s
0 0 1 r
.674 .69044 m
.66681 .68581 L
s
1 0 0 r
.36124 .71745 m
.37265 .71538 L
s
0 0 1 r
.63876 .71745 m
.62735 .71538 L
s
1 0 0 r
.59459 .73985 m
.61152 .72735 L
s
0 0 1 r
.40541 .73985 m
.38848 .72735 L
s
1 0 0 r
.33639 .69888 m
.34506 .69522 L
s
0 0 1 r
.66361 .69888 m
.65494 .69522 L
s
1 0 0 r
.34817 .70799 m
.35826 .70519 L
s
0 0 1 r
.65183 .70799 m
.64174 .70519 L
s
1 0 0 r
.62512 .72486 m
.64066 .71008 L
s
0 0 1 r
.37488 .72486 m
.35934 .71008 L
s
1 0 0 r
.69409 .33829 m
.6837 .31985 L
s
0 0 1 r
.30591 .33829 m
.3163 .31985 L
s
1 0 0 r
.70264 .35606 m
.70399 .3442 L
s
0 0 1 r
.29736 .35606 m
.29601 .3442 L
s
1 0 0 r
.47321 .75509 m
.49091 .75012 L
s
0 0 1 r
.52679 .75509 m
.50909 .75012 L
s
1 0 0 r
.4213 .74382 m
.43713 .74098 L
s
0 0 1 r
.5787 .74382 m
.56287 .74098 L
s
1 0 0 r
.71366 .3709 m
.70839 .35204 L
s
0 0 1 r
.28634 .3709 m
.29161 .35204 L
s
1 0 0 r
.7147 .3738 m
.71074 .35561 L
s
0 0 1 r
.2853 .3738 m
.28926 .35561 L
s
1 0 0 r
.71136 .36721 m
.70482 .34779 L
s
0 0 1 r
.28864 .36721 m
.29518 .34779 L
s
1 0 0 r
.69672 .35177 m
.69957 .34101 L
s
0 0 1 r
.30328 .35177 m
.30043 .34101 L
s
1 0 0 r
.68694 .33358 m
.67543 .3149 L
s
0 0 1 r
.31306 .33358 m
.32457 .3149 L
s
1 0 0 r
.71444 .37569 m
.71182 .35826 L
s
0 0 1 r
.28556 .37569 m
.28818 .35826 L
s
1 0 0 r
.50899 .7547 m
.52728 .74731 L
s
0 0 1 r
.49101 .7547 m
.47272 .74731 L
s
1 0 0 r
.70783 .363 m
.70005 .34312 L
s
0 0 1 r
.29217 .363 m
.29995 .34312 L
s
1 0 0 r
.54473 .74996 m
.56298 .74007 L
s
0 0 1 r
.45527 .74996 m
.43702 .74007 L
s
1 0 0 r
.71285 .37636 m
.71161 .35979 L
s
0 0 1 r
.28715 .37636 m
.28839 .35979 L
s
1 0 0 r
.40437 .73504 m
.41939 .73196 L
s
0 0 1 r
.59563 .73504 m
.58061 .73196 L
s
1 0 0 r
.68928 .34595 m
.69365 .33632 L
s
0 0 1 r
.31072 .34595 m
.30635 .33632 L
s
1 0 0 r
.57925 .74078 m
.59685 .72842 L
s
0 0 1 r
.42075 .74078 m
.40315 .72842 L
s
1 0 0 r
.61152 .72735 m
.62791 .71264 L
s
0 0 1 r
.38848 .72735 m
.37209 .71264 L
s
1 0 0 r
.64066 .71008 m
.65537 .69319 L
s
0 0 1 r
.35934 .71008 m
.34463 .69319 L
s
1 0 0 r
.45514 .74877 m
.47253 .74383 L
s
0 0 1 r
.54486 .74877 m
.52747 .74383 L
s
1 0 0 r
.70308 .35852 m
.69409 .33829 L
s
0 0 1 r
.29692 .35852 m
.30591 .33829 L
s
1 0 0 r
.70985 .37565 m
.71004 .36001 L
s
0 0 1 r
.29015 .37565 m
.28996 .36001 L
s
1 0 0 r
.68031 .3387 m
.68621 .33018 L
s
0 0 1 r
.31969 .3387 m
.31379 .33018 L
s
1 0 0 r
.38808 .72545 m
.40214 .72199 L
s
0 0 1 r
.61192 .72545 m
.59786 .72199 L
s
1 0 0 r
.66983 .33017 m
.67726 .32274 L
s
0 0 1 r
.33017 .33017 m
.32274 .32274 L
s
1 0 0 r
.32274 .67726 m
.33017 .66983 L
s
0 0 1 r
.67726 .67726 m
.66983 .66983 L
s
1 0 0 r
.70542 .37342 m
.70707 .3588 L
s
0 0 1 r
.29458 .37342 m
.29293 .3588 L
s
1 0 0 r
.69712 .35407 m
.68694 .33358 L
s
0 0 1 r
.30288 .35407 m
.31306 .33358 L
s
1 0 0 r
.49091 .75012 m
.50922 .74286 L
s
0 0 1 r
.50909 .75012 m
.49078 .74286 L
s
1 0 0 r
.37265 .71538 m
.38559 .71139 L
s
0 0 1 r
.62735 .71538 m
.61441 .71139 L
s
1 0 0 r
.33319 .68581 m
.34211 .6794 L
s
0 0 1 r
.66681 .68581 m
.65789 .6794 L
s
1 0 0 r
.71726 .39137 m
.71366 .3709 L
s
0 0 1 r
.28274 .39137 m
.28634 .3709 L
s
1 0 0 r
.71627 .38826 m
.71136 .36721 L
s
0 0 1 r
.28373 .38826 m
.28864 .36721 L
s
1 0 0 r
.35826 .70519 m
.36996 .70052 L
s
0 0 1 r
.64174 .70519 m
.63004 .70052 L
s
1 0 0 r
.34506 .69522 m
.35541 .68974 L
s
0 0 1 r
.65494 .69522 m
.64459 .68974 L
s
1 0 0 r
.43713 .74098 m
.45403 .73599 L
s
0 0 1 r
.56287 .74098 m
.54597 .73599 L
s
1 0 0 r
.71695 .39361 m
.7147 .3738 L
s
0 0 1 r
.28305 .39361 m
.2853 .3738 L
s
1 0 0 r
.71402 .38451 m
.70783 .363 L
s
0 0 1 r
.28598 .38451 m
.29217 .363 L
s
1 0 0 r
.52728 .74731 m
.54584 .7376 L
s
0 0 1 r
.47272 .74731 m
.45416 .7376 L
s
1 0 0 r
.6995 .36962 m
.70264 .35606 L
s
0 0 1 r
.3005 .36962 m
.29736 .35606 L
s
1 0 0 r
.56298 .74007 m
.58115 .72789 L
s
0 0 1 r
.43702 .74007 m
.41885 .72789 L
s
1 0 0 r
.62791 .71264 m
.64356 .6958 L
s
0 0 1 r
.37209 .71264 m
.35644 .6958 L
s
1 0 0 r
.59685 .72842 m
.61402 .71384 L
s
0 0 1 r
.40315 .72842 m
.38598 .71384 L
s
1 0 0 r
.65537 .69319 m
.66905 .67431 L
s
0 0 1 r
.34463 .69319 m
.33095 .67431 L
s
1 0 0 r
.71531 .39473 m
.71444 .37569 L
s
0 0 1 r
.28469 .39473 m
.28556 .37569 L
s
1 0 0 r
.71053 .3804 m
.70308 .35852 L
s
0 0 1 r
.28947 .3804 m
.29692 .35852 L
s
1 0 0 r
.69206 .36423 m
.69672 .35177 L
s
0 0 1 r
.30794 .36423 m
.30328 .35177 L
s
1 0 0 r
.7123 .39454 m
.71285 .37636 L
s
0 0 1 r
.2877 .39454 m
.28715 .37636 L
s
1 0 0 r
.41939 .73196 m
.43563 .72679 L
s
0 0 1 r
.58061 .73196 m
.56437 .72679 L
s
1 0 0 r
.47253 .74383 m
.49069 .73666 L
s
0 0 1 r
.52747 .74383 m
.50931 .73666 L
s
1 0 0 r
.70581 .37621 m
.69712 .35407 L
s
0 0 1 r
.29419 .37621 m
.30288 .35407 L
s
1 0 0 r
.68309 .3573 m
.68928 .34595 L
s
0 0 1 r
.31691 .3573 m
.31072 .34595 L
s
1 0 0 r
.70785 .39289 m
.70985 .37565 L
s
0 0 1 r
.29215 .39289 m
.29015 .37565 L
s
1 0 0 r
.71943 .41075 m
.71627 .38826 L
s
0 0 1 r
.28057 .41075 m
.28373 .38826 L
s
1 0 0 r
.7185 .40746 m
.71402 .38451 L
s
0 0 1 r
.2815 .40746 m
.28598 .38451 L
s
1 0 0 r
.50922 .74286 m
.52795 .73332 L
s
0 0 1 r
.49078 .74286 m
.47205 .73332 L
s
1 0 0 r
.71907 .4133 m
.71726 .39137 L
s
0 0 1 r
.28093 .4133 m
.28274 .39137 L
s
1 0 0 r
.66905 .67431 m
.68154 .6536 L
s
0 0 1 r
.33095 .67431 m
.31846 .6536 L
s
1 0 0 r
.64356 .6958 m
.65829 .67695 L
s
0 0 1 r
.35644 .6958 m
.34171 .67695 L
s
1 0 0 r
.40214 .72199 m
.41755 .71649 L
s
0 0 1 r
.59786 .72199 m
.58245 .71649 L
s
1 0 0 r
.61402 .71384 m
.63057 .69711 L
s
0 0 1 r
.38598 .71384 m
.36943 .69711 L
s
1 0 0 r
.71631 .40372 m
.71053 .3804 L
s
0 0 1 r
.28369 .40372 m
.28947 .3804 L
s
1 0 0 r
.54584 .7376 m
.56447 .72561 L
s
0 0 1 r
.45416 .7376 m
.43553 .72561 L
s
1 0 0 r
.67259 .34895 m
.68031 .3387 L
s
0 0 1 r
.32741 .34895 m
.31969 .3387 L
s
1 0 0 r
.58115 .72789 m
.59903 .71347 L
s
0 0 1 r
.41885 .72789 m
.40097 .71347 L
s
1 0 0 r
.71739 .41487 m
.71695 .39361 L
s
0 0 1 r
.28261 .41487 m
.28305 .39361 L
s
1 0 0 r
.70193 .38966 m
.70542 .37342 L
s
0 0 1 r
.29807 .38966 m
.29458 .37342 L
s
1 0 0 r
.45403 .73599 m
.47187 .7288 L
s
0 0 1 r
.54597 .73599 m
.52813 .7288 L
s
1 0 0 r
.38559 .71139 m
.40001 .70542 L
s
0 0 1 r
.61441 .71139 m
.59999 .70542 L
s
1 0 0 r
.66062 .33938 m
.66983 .33017 L
s
0 0 1 r
.33938 .33938 m
.33017 .33017 L
s
1 0 0 r
.33017 .66983 m
.33938 .66062 L
s
0 0 1 r
.66983 .66983 m
.66062 .66062 L
s
1 0 0 r
.71287 .39979 m
.70581 .37621 L
s
0 0 1 r
.28713 .39979 m
.29419 .37621 L
s
1 0 0 r
.71434 .41523 m
.71531 .39473 L
s
0 0 1 r
.28566 .41523 m
.28469 .39473 L
s
1 0 0 r
.36996 .70052 m
.38323 .69393 L
s
0 0 1 r
.63004 .70052 m
.61677 .69393 L
s
1 0 0 r
.34211 .6794 m
.35275 .67117 L
s
0 0 1 r
.65789 .6794 m
.64725 .67117 L
s
1 0 0 r
.35541 .68974 m
.36742 .68239 L
s
0 0 1 r
.64459 .68974 m
.63258 .68239 L
s
1 0 0 r
.6945 .38481 m
.6995 .36962 L
s
0 0 1 r
.3055 .38481 m
.3005 .36962 L
s
1 0 0 r
.68154 .6536 m
.69265 .63123 L
s
0 0 1 r
.31846 .6536 m
.30735 .63123 L
s
1 0 0 r
.65829 .67695 m
.67189 .65626 L
s
0 0 1 r
.34171 .67695 m
.32811 .65626 L
s
1 0 0 r
.72118 .43165 m
.7185 .40746 L
s
0 0 1 r
.27882 .43165 m
.2815 .40746 L
s
1 0 0 r
.70988 .4142 m
.7123 .39454 L
s
0 0 1 r
.29012 .4142 m
.2877 .39454 L
s
1 0 0 r
.72076 .43448 m
.71943 .41075 L
s
0 0 1 r
.27924 .43448 m
.28057 .41075 L
s
1 0 0 r
.49069 .73666 m
.50944 .72721 L
s
0 0 1 r
.50931 .73666 m
.49056 .72721 L
s
1 0 0 r
.72032 .42825 m
.71631 .40372 L
s
0 0 1 r
.27968 .42825 m
.28369 .40372 L
s
1 0 0 r
.63057 .69711 m
.64629 .67836 L
s
0 0 1 r
.36943 .69711 m
.35371 .67836 L
s
1 0 0 r
.43563 .72679 m
.45297 .71946 L
s
0 0 1 r
.56437 .72679 m
.54703 .71946 L
s
1 0 0 r
.71902 .43648 m
.71907 .4133 L
s
0 0 1 r
.28098 .43648 m
.28093 .4133 L
s
1 0 0 r
.59903 .71347 m
.61641 .6969 L
s
0 0 1 r
.40097 .71347 m
.38359 .6969 L
s
1 0 0 r
.71819 .42457 m
.71287 .39979 L
s
0 0 1 r
.28181 .42457 m
.28713 .39979 L
s
1 0 0 r
.68554 .37834 m
.69206 .36423 L
s
0 0 1 r
.31446 .37834 m
.30794 .36423 L
s
1 0 0 r
.52795 .73332 m
.54692 .72149 L
s
0 0 1 r
.47205 .73332 m
.45308 .72149 L
s
1 0 0 r
.56447 .72561 m
.58296 .71138 L
s
0 0 1 r
.43553 .72561 m
.41704 .71138 L
s
1 0 0 r
.70397 .41163 m
.70785 .39289 L
s
0 0 1 r
.29603 .41163 m
.29215 .39289 L
s
1 0 0 r
.71594 .4374 m
.71739 .41487 L
s
0 0 1 r
.28406 .4374 m
.28261 .41487 L
s
1 0 0 r
.69265 .63123 m
.70224 .60744 L
s
0 0 1 r
.30735 .63123 m
.29776 .60744 L
s
1 0 0 r
.67189 .65626 m
.68419 .63391 L
s
0 0 1 r
.32811 .65626 m
.31581 .63391 L
s
1 0 0 r
.67505 .37033 m
.68309 .3573 L
s
0 0 1 r
.32495 .37033 m
.31691 .3573 L
s
1 0 0 r
.72246 .45375 m
.72032 .42825 L
s
0 0 1 r
.27754 .45375 m
.27968 .42825 L
s
1 0 0 r
.41755 .71649 m
.4342 .7089 L
s
0 0 1 r
.58245 .71649 m
.5658 .7089 L
s
1 0 0 r
.72197 .45682 m
.72118 .43165 L
s
0 0 1 r
.27803 .45682 m
.27882 .43165 L
s
1 0 0 r
.72167 .45029 m
.71819 .42457 L
s
0 0 1 r
.27833 .45029 m
.28181 .42457 L
s
1 0 0 r
.64629 .67836 m
.66098 .65777 L
s
0 0 1 r
.35371 .67836 m
.33902 .65777 L
s
1 0 0 r
.47187 .7288 m
.49047 .71938 L
s
0 0 1 r
.52813 .7288 m
.50953 .71938 L
s
1 0 0 r
.71146 .43703 m
.71434 .41523 L
s
0 0 1 r
.28854 .43703 m
.28566 .41523 L
s
1 0 0 r
.72018 .45922 m
.72076 .43448 L
s
0 0 1 r
.27982 .45922 m
.27924 .43448 L
s
1 0 0 r
.69655 .40742 m
.70193 .38966 L
s
0 0 1 r
.30345 .40742 m
.29807 .38966 L
s
1 0 0 r
.66306 .36093 m
.67259 .34895 L
s
0 0 1 r
.33694 .36093 m
.32741 .34895 L
s
1 0 0 r
.70224 .60744 m
.71015 .58246 L
s
0 0 1 r
.29776 .60744 m
.28985 .58246 L
s
1 0 0 r
.61641 .6969 m
.63307 .67832 L
s
0 0 1 r
.38359 .6969 m
.36693 .67832 L
s
1 0 0 r
.40001 .70542 m
.41581 .69742 L
s
0 0 1 r
.59999 .70542 m
.58419 .69742 L
s
1 0 0 r
.71705 .46069 m
.71902 .43648 L
s
0 0 1 r
.28295 .46069 m
.28098 .43648 L
s
1 0 0 r
.68419 .63391 m
.69501 .61015 L
s
0 0 1 r
.31581 .63391 m
.30499 .61015 L
s
1 0 0 r
.50944 .72721 m
.52859 .71553 L
s
0 0 1 r
.49056 .72721 m
.47141 .71553 L
s
1 0 0 r
.72268 .47992 m
.72246 .45375 L
s
0 0 1 r
.27732 .47992 m
.27754 .45375 L
s
1 0 0 r
.72324 .47666 m
.72167 .45029 L
s
0 0 1 r
.27676 .47666 m
.27833 .45029 L
s
1 0 0 r
.64964 .35036 m
.66062 .33938 L
s
0 0 1 r
.35036 .35036 m
.33938 .33938 L
s
1 0 0 r
.33938 .66062 m
.35036 .64964 L
s
0 0 1 r
.66062 .66062 m
.64964 .64964 L
s
1 0 0 r
.58296 .71138 m
.60109 .69501 L
s
0 0 1 r
.41704 .71138 m
.39891 .69501 L
s
1 0 0 r
.70555 .43517 m
.70988 .4142 L
s
0 0 1 r
.29445 .43517 m
.29012 .4142 L
s
1 0 0 r
.54692 .72149 m
.5659 .70745 L
s
0 0 1 r
.45308 .72149 m
.4341 .70745 L
s
1 0 0 r
.38323 .69393 m
.39802 .68538 L
s
0 0 1 r
.61677 .69393 m
.60198 .68538 L
s
1 0 0 r
.72082 .48269 m
.72197 .45682 L
s
0 0 1 r
.27918 .48269 m
.27803 .45682 L
s
1 0 0 r
.68761 .40155 m
.6945 .38481 L
s
0 0 1 r
.31239 .40155 m
.3055 .38481 L
s
1 0 0 r
.35275 .67117 m
.36511 .66111 L
s
0 0 1 r
.64725 .67117 m
.63489 .66111 L
s
1 0 0 r
.71015 .58246 m
.71628 .5566 L
s
0 0 1 r
.28985 .58246 m
.28372 .5566 L
s
1 0 0 r
.36742 .68239 m
.38105 .67315 L
s
0 0 1 r
.63258 .68239 m
.61895 .67315 L
s
1 0 0 r
.66098 .65777 m
.67444 .63554 L
s
0 0 1 r
.33902 .65777 m
.32556 .63554 L
s
1 0 0 r
.71255 .46099 m
.71594 .4374 L
s
0 0 1 r
.28745 .46099 m
.28406 .4374 L
s
1 0 0 r
.72287 .50338 m
.72324 .47666 L
s
0 0 1 r
.27713 .50338 m
.27676 .47666 L
s
1 0 0 r
.45297 .71946 m
.47124 .70997 L
s
0 0 1 r
.54703 .71946 m
.52876 .70997 L
s
1 0 0 r
.69501 .61015 m
.70421 .58523 L
s
0 0 1 r
.30499 .61015 m
.29579 .58523 L
s
1 0 0 r
.71765 .48469 m
.72018 .45922 L
s
0 0 1 r
.28235 .48469 m
.27982 .45922 L
s
1 0 0 r
.72094 .50647 m
.72268 .47992 L
s
0 0 1 r
.27906 .50647 m
.27732 .47992 L
s
1 0 0 r
.71628 .5566 m
.72054 .53013 L
s
0 0 1 r
.28372 .5566 m
.27946 .53013 L
s
1 0 0 r
.72054 .53013 m
.72287 .50338 L
s
0 0 1 r
.27946 .53013 m
.27713 .50338 L
s
1 0 0 r
.63307 .67832 m
.64879 .6579 L
s
0 0 1 r
.36693 .67832 m
.35121 .6579 L
s
1 0 0 r
.69815 .43171 m
.70397 .41163 L
s
0 0 1 r
.30185 .43171 m
.29603 .41163 L
s
1 0 0 r
.67714 .39403 m
.68554 .37834 L
s
0 0 1 r
.32286 .39403 m
.31446 .37834 L
s
1 0 0 r
.71772 .50897 m
.72082 .48269 L
s
0 0 1 r
.28228 .50897 m
.27918 .48269 L
s
1 0 0 r
.70421 .58523 m
.71166 .55944 L
s
0 0 1 r
.29579 .58523 m
.28834 .55944 L
s
1 0 0 r
.71726 .53308 m
.72094 .50647 L
s
0 0 1 r
.28274 .53308 m
.27906 .50647 L
s
1 0 0 r
.67444 .63554 m
.68649 .6119 L
s
0 0 1 r
.32556 .63554 m
.31351 .6119 L
s
1 0 0 r
.70664 .4599 m
.71146 .43703 L
s
0 0 1 r
.29336 .4599 m
.28854 .43703 L
s
1 0 0 r
.71312 .48566 m
.71705 .46069 L
s
0 0 1 r
.28688 .48566 m
.28295 .46069 L
s
1 0 0 r
.71166 .55944 m
.71726 .53308 L
s
0 0 1 r
.28834 .55944 m
.28274 .53308 L
s
1 0 0 r
.60109 .69501 m
.61862 .67663 L
s
0 0 1 r
.39891 .69501 m
.38138 .67663 L
s
1 0 0 r
.49047 .71938 m
.50965 .70776 L
s
0 0 1 r
.50953 .71938 m
.49035 .70776 L
s
1 0 0 r
.4342 .7089 m
.45196 .69921 L
s
0 0 1 r
.5658 .7089 m
.54804 .69921 L
s
1 0 0 r
.71316 .5106 m
.71765 .48469 L
s
0 0 1 r
.28684 .5106 m
.28235 .48469 L
s
1 0 0 r
.71267 .53535 m
.71772 .50897 L
s
0 0 1 r
.28733 .53535 m
.28228 .50897 L
s
1 0 0 r
.66517 .38499 m
.67505 .37033 L
s
0 0 1 r
.33483 .38499 m
.32495 .37033 L
s
1 0 0 r
.5659 .70745 m
.58466 .69129 L
s
0 0 1 r
.4341 .70745 m
.41534 .69129 L
s
1 0 0 r
.68649 .6119 m
.69696 .58712 L
s
0 0 1 r
.31351 .6119 m
.30304 .58712 L
s
1 0 0 r
.52859 .71553 m
.54793 .70165 L
s
0 0 1 r
.47141 .71553 m
.45207 .70165 L
s
1 0 0 r
.68924 .42655 m
.69655 .40742 L
s
0 0 1 r
.31076 .42655 m
.30345 .40742 L
s
1 0 0 r
.64879 .6579 m
.66338 .63585 L
s
0 0 1 r
.35121 .6579 m
.33662 .63585 L
s
1 0 0 r
.70721 .48537 m
.71255 .46099 L
s
0 0 1 r
.29279 .48537 m
.28745 .46099 L
s
1 0 0 r
.70572 .5615 m
.71267 .53535 L
s
0 0 1 r
.29428 .5615 m
.28733 .53535 L
s
1 0 0 r
.69926 .45726 m
.70555 .43517 L
s
0 0 1 r
.30074 .45726 m
.29445 .43517 L
s
1 0 0 r
.69696 .58712 m
.70572 .5615 L
s
0 0 1 r
.30304 .58712 m
.29428 .5615 L
s
1 0 0 r
.41581 .69742 m
.43288 .68739 L
s
0 0 1 r
.58419 .69742 m
.56712 .68739 L
s
1 0 0 r
.65173 .37458 m
.66306 .36093 L
s
0 0 1 r
.34827 .37458 m
.33694 .36093 L
s
1 0 0 r
.70724 .51111 m
.71312 .48566 L
s
0 0 1 r
.29276 .51111 m
.28688 .48566 L
s
1 0 0 r
.70674 .53665 m
.71316 .5106 L
s
0 0 1 r
.29326 .53665 m
.28684 .5106 L
s
1 0 0 r
.61862 .67663 m
.63533 .65644 L
s
0 0 1 r
.38138 .67663 m
.36467 .65644 L
s
1 0 0 r
.66338 .63585 m
.67663 .61241 L
s
0 0 1 r
.33662 .63585 m
.32337 .61241 L
s
1 0 0 r
.47124 .70997 m
.49027 .69833 L
s
0 0 1 r
.52876 .70997 m
.50973 .69833 L
s
1 0 0 r
.67881 .4197 m
.68761 .40155 L
s
0 0 1 r
.32119 .4197 m
.31239 .40155 L
s
1 0 0 r
.63693 .36307 m
.64964 .35036 L
s
.35036 .64964 m
.36307 .63693 L
s
0 0 1 r
.36307 .36307 m
.35036 .35036 L
s
.64964 .64964 m
.63693 .63693 L
s
1 0 0 r
.39802 .68538 m
.41422 .67488 L
s
0 0 1 r
.60198 .68538 m
.58578 .67488 L
s
1 0 0 r
.69986 .48361 m
.70664 .4599 L
s
0 0 1 r
.30014 .48361 m
.29336 .4599 L
s
1 0 0 r
.36511 .66111 m
.37911 .64926 L
s
0 0 1 r
.63489 .66111 m
.62089 .64926 L
s
1 0 0 r
.38105 .67315 m
.39622 .66203 L
s
0 0 1 r
.61895 .67315 m
.60378 .66203 L
s
1 0 0 r
.69845 .56251 m
.70674 .53665 L
s
0 0 1 r
.30155 .56251 m
.29326 .53665 L
s
1 0 0 r
.6904 .45294 m
.69815 .43171 L
s
0 0 1 r
.3096 .45294 m
.30185 .43171 L
s
1 0 0 r
.67663 .61241 m
.68837 .58787 L
s
0 0 1 r
.32337 .61241 m
.31163 .58787 L
s
1 0 0 r
.58466 .69129 m
.60298 .67315 L
s
0 0 1 r
.41534 .69129 m
.39702 .67315 L
s
1 0 0 r
.68837 .58787 m
.69845 .56251 L
s
0 0 1 r
.31163 .58787 m
.30155 .56251 L
s
1 0 0 r
.50965 .70776 m
.52919 .694 L
s
0 0 1 r
.49035 .70776 m
.47081 .694 L
s
1 0 0 r
.69992 .51027 m
.70721 .48537 L
s
0 0 1 r
.30008 .51027 m
.29279 .48537 L
s
1 0 0 r
.69945 .53673 m
.70724 .51111 L
s
0 0 1 r
.30055 .53673 m
.29276 .51111 L
s
1 0 0 r
.54793 .70165 m
.56721 .68569 L
s
0 0 1 r
.45207 .70165 m
.43279 .68569 L
s
1 0 0 r
.63533 .65644 m
.651 .63463 L
s
0 0 1 r
.36467 .65644 m
.349 .63463 L
s
1 0 0 r
.66687 .41119 m
.67714 .39403 L
s
0 0 1 r
.33313 .41119 m
.32286 .39403 L
s
1 0 0 r
.45196 .69921 m
.47066 .68744 L
s
0 0 1 r
.54804 .69921 m
.52934 .68744 L
s
1 0 0 r
.69104 .48022 m
.69926 .45726 L
s
0 0 1 r
.30896 .48022 m
.30074 .45726 L
s
1 0 0 r
.68002 .44688 m
.68924 .42655 L
s
0 0 1 r
.31998 .44688 m
.31076 .42655 L
s
1 0 0 r
.6898 .56221 m
.69945 .53673 L
s
0 0 1 r
.3102 .56221 m
.30055 .53673 L
s
1 0 0 r
.651 .63463 m
.66543 .61147 L
s
0 0 1 r
.349 .63463 m
.33457 .61147 L
s
1 0 0 r
.60298 .67315 m
.6206 .65321 L
s
0 0 1 r
.39702 .67315 m
.3794 .65321 L
s
1 0 0 r
.65346 .40116 m
.66517 .38499 L
s
0 0 1 r
.34654 .40116 m
.33483 .38499 L
s
1 0 0 r
.69115 .50788 m
.69986 .48361 L
s
0 0 1 r
.30885 .50788 m
.30014 .48361 L
s
1 0 0 r
.69074 .53538 m
.69992 .51027 L
s
0 0 1 r
.30926 .53538 m
.30008 .51027 L
s
1 0 0 r
.67842 .58723 m
.6898 .56221 L
s
0 0 1 r
.32158 .58723 m
.3102 .56221 L
s
1 0 0 r
.66543 .61147 m
.67842 .58723 L
s
0 0 1 r
.33457 .61147 m
.32158 .58723 L
s
1 0 0 r
.43288 .68739 m
.45105 .67537 L
s
0 0 1 r
.56712 .68739 m
.54895 .67537 L
s
1 0 0 r
.49027 .69833 m
.50984 .68461 L
s
0 0 1 r
.50973 .69833 m
.49016 .68461 L
s
1 0 0 r
.56721 .68569 m
.58621 .66779 L
s
0 0 1 r
.43279 .68569 m
.41379 .66779 L
s
1 0 0 r
.63865 .38982 m
.65173 .37458 L
s
0 0 1 r
.36135 .38982 m
.34827 .37458 L
s
1 0 0 r
.52919 .694 m
.54885 .6782 L
s
0 0 1 r
.47081 .694 m
.45115 .6782 L
s
1 0 0 r
.68073 .47509 m
.6904 .45294 L
s
0 0 1 r
.31927 .47509 m
.3096 .45294 L
s
1 0 0 r
.66813 .43909 m
.67881 .4197 L
s
0 0 1 r
.33187 .43909 m
.32119 .4197 L
s
1 0 0 r
.6206 .65321 m
.63731 .6317 L
s
0 0 1 r
.3794 .65321 m
.36269 .6317 L
s
1 0 0 r
.41422 .67488 m
.43168 .66246 L
s
0 0 1 r
.58578 .67488 m
.56832 .66246 L
s
1 0 0 r
.67975 .5604 m
.69074 .53538 L
s
0 0 1 r
.32025 .5604 m
.30926 .53538 L
s
1 0 0 r
.36307 .63693 m
.37744 .62256 L
s
0 0 1 r
.63693 .63693 m
.62256 .62256 L
s
1 0 0 r
.62256 .37744 m
.63693 .36307 L
s
0 0 1 r
.37744 .37744 m
.36307 .36307 L
s
1 0 0 r
.39622 .66203 m
.41281 .64909 L
s
0 0 1 r
.60378 .66203 m
.58719 .64909 L
s
1 0 0 r
.37911 .64926 m
.39465 .63566 L
s
0 0 1 r
.62089 .64926 m
.60535 .63566 L
s
1 0 0 r
.68092 .50379 m
.69104 .48022 L
s
0 0 1 r
.31908 .50379 m
.30896 .48022 L
s
1 0 0 r
.68059 .53241 m
.69115 .50788 L
s
0 0 1 r
.31941 .53241 m
.30885 .50788 L
s
1 0 0 r
.63731 .6317 m
.65287 .60887 L
s
0 0 1 r
.36269 .6317 m
.34713 .60887 L
s
1 0 0 r
.47066 .68744 m
.49008 .67366 L
s
0 0 1 r
.52934 .68744 m
.50992 .67366 L
s
1 0 0 r
.66707 .585 m
.67975 .5604 L
s
0 0 1 r
.33293 .585 m
.32025 .5604 L
s
1 0 0 r
.65477 .42966 m
.66687 .41119 L
s
0 0 1 r
.34523 .42966 m
.33313 .41119 L
s
1 0 0 r
.58621 .66779 m
.60466 .64813 L
s
0 0 1 r
.41379 .66779 m
.39534 .64813 L
s
1 0 0 r
.66892 .46819 m
.68002 .44688 L
s
0 0 1 r
.33108 .46819 m
.31998 .44688 L
s
1 0 0 r
.65287 .60887 m
.66707 .585 L
s
0 0 1 r
.34713 .60887 m
.33293 .585 L
s
1 0 0 r
.50984 .68461 m
.52973 .66892 L
s
0 0 1 r
.49016 .68461 m
.47027 .66892 L
s
1 0 0 r
.54885 .6782 m
.5684 .66052 L
s
0 0 1 r
.45115 .6782 m
.4316 .66052 L
s
1 0 0 r
.66827 .5569 m
.68059 .53241 L
s
0 0 1 r
.33173 .5569 m
.31941 .53241 L
s
1 0 0 r
.63999 .41872 m
.65346 .40116 L
s
0 0 1 r
.36001 .41872 m
.34654 .40116 L
s
1 0 0 r
.66921 .49791 m
.68073 .47509 L
s
0 0 1 r
.33079 .49791 m
.31927 .47509 L
s
1 0 0 r
.45105 .67537 m
.47014 .66142 L
s
0 0 1 r
.54895 .67537 m
.52986 .66142 L
s
1 0 0 r
.60466 .64813 m
.62232 .62694 L
s
0 0 1 r
.39534 .64813 m
.37768 .62694 L
s
1 0 0 r
.66899 .52768 m
.68092 .50379 L
s
0 0 1 r
.33101 .52768 m
.31908 .50379 L
s
1 0 0 r
.65564 .45954 m
.66813 .43909 L
s
0 0 1 r
.34436 .45954 m
.33187 .43909 L
s
1 0 0 r
.65434 .58103 m
.66827 .5569 L
s
0 0 1 r
.34566 .58103 m
.33173 .5569 L
s
1 0 0 r
.6239 .40652 m
.63865 .38982 L
s
0 0 1 r
.3761 .40652 m
.36135 .38982 L
s
1 0 0 r
.62232 .62694 m
.63895 .60447 L
s
0 0 1 r
.37768 .62694 m
.36105 .60447 L
s
1 0 0 r
.43168 .66246 m
.45024 .64821 L
s
0 0 1 r
.56832 .66246 m
.54976 .64821 L
s
1 0 0 r
.5684 .66052 m
.58756 .64113 L
s
0 0 1 r
.4316 .66052 m
.41244 .64113 L
s
1 0 0 r
.63895 .60447 m
.65434 .58103 L
s
0 0 1 r
.36105 .60447 m
.34566 .58103 L
s
1 0 0 r
.49008 .67366 m
.51001 .65799 L
s
0 0 1 r
.50992 .67366 m
.48999 .65799 L
s
1 0 0 r
.37744 .62256 m
.39336 .60664 L
s
0 0 1 r
.62256 .62256 m
.60664 .60664 L
s
1 0 0 r
.60664 .39336 m
.62256 .37744 L
s
0 0 1 r
.39336 .39336 m
.37744 .37744 L
s
1 0 0 r
.41281 .64909 m
.43065 .63441 L
s
0 0 1 r
.58719 .64909 m
.56935 .63441 L
s
1 0 0 r
.65603 .49023 m
.66892 .46819 L
s
0 0 1 r
.34397 .49023 m
.33108 .46819 L
s
1 0 0 r
.39465 .63566 m
.41161 .62042 L
s
0 0 1 r
.60535 .63566 m
.58839 .62042 L
s
1 0 0 r
.52973 .66892 m
.54967 .6514 L
s
0 0 1 r
.47027 .66892 m
.45033 .6514 L
s
1 0 0 r
.65537 .55159 m
.66899 .52768 L
s
0 0 1 r
.34463 .55159 m
.33101 .52768 L
s
1 0 0 r
.64093 .44924 m
.65477 .42966 L
s
0 0 1 r
.35907 .44924 m
.34523 .42966 L
s
1 0 0 r
.65594 .52113 m
.66921 .49791 L
s
0 0 1 r
.34406 .52113 m
.33079 .49791 L
s
1 0 0 r
.58756 .64113 m
.60608 .62027 L
s
0 0 1 r
.41244 .64113 m
.39392 .62027 L
s
1 0 0 r
.47014 .66142 m
.48992 .64567 L
s
0 0 1 r
.52986 .66142 m
.51008 .64567 L
s
1 0 0 r
.64022 .5752 m
.65537 .55159 L
s
0 0 1 r
.35978 .5752 m
.34463 .55159 L
s
1 0 0 r
.62488 .43748 m
.63999 .41872 L
s
0 0 1 r
.37512 .43748 m
.36001 .41872 L
s
1 0 0 r
.64142 .48079 m
.65564 .45954 L
s
0 0 1 r
.35858 .48079 m
.34436 .45954 L
s
1 0 0 r
.60608 .62027 m
.62371 .5982 L
s
0 0 1 r
.39392 .62027 m
.37629 .5982 L
s
1 0 0 r
.54967 .6514 m
.56941 .63225 L
s
0 0 1 r
.45033 .6514 m
.43059 .63225 L
s
1 0 0 r
.62371 .5982 m
.64022 .5752 L
s
0 0 1 r
.37629 .5982 m
.35978 .5752 L
s
1 0 0 r
.51001 .65799 m
.53019 .64058 L
s
0 0 1 r
.48999 .65799 m
.46981 .64058 L
s
1 0 0 r
.64106 .54442 m
.65594 .52113 L
s
0 0 1 r
.35894 .54442 m
.34406 .52113 L
s
1 0 0 r
.45024 .64821 m
.46969 .63226 L
s
0 0 1 r
.54976 .64821 m
.53031 .63226 L
s
1 0 0 r
.64147 .51274 m
.65603 .49023 L
s
0 0 1 r
.35853 .51274 m
.34397 .49023 L
s
1 0 0 r
.60762 .42452 m
.6239 .40652 L
s
0 0 1 r
.39238 .42452 m
.3761 .40652 L
s
1 0 0 r
.43065 .63441 m
.44957 .61813 L
s
0 0 1 r
.56935 .63441 m
.55043 .61813 L
s
1 0 0 r
.39336 .60664 m
.41068 .58932 L
s
0 0 1 r
.60664 .60664 m
.58932 .58932 L
s
1 0 0 r
.58932 .41068 m
.60664 .39336 L
s
0 0 1 r
.41068 .41068 m
.39336 .39336 L
s
1 0 0 r
.62547 .46973 m
.64093 .44924 L
s
0 0 1 r
.37453 .46973 m
.35907 .44924 L
s
1 0 0 r
.41161 .62042 m
.42982 .60368 L
s
0 0 1 r
.58839 .62042 m
.57018 .60368 L
s
1 0 0 r
.56941 .63225 m
.58868 .61171 L
s
0 0 1 r
.43059 .63225 m
.41132 .61171 L
s
1 0 0 r
.62475 .56749 m
.64106 .54442 L
s
0 0 1 r
.37525 .56749 m
.35894 .54442 L
s
1 0 0 r
.48992 .64567 m
.51016 .62827 L
s
0 0 1 r
.51008 .64567 m
.48984 .62827 L
s
1 0 0 r
.53019 .64058 m
.55036 .62162 L
s
0 0 1 r
.46981 .64058 m
.44964 .62162 L
s
1 0 0 r
.62564 .5026 m
.64142 .48079 L
s
0 0 1 r
.37436 .5026 m
.35858 .48079 L
s
1 0 0 r
.58868 .61171 m
.60721 .59002 L
s
0 0 1 r
.41132 .61171 m
.39279 .59002 L
s
1 0 0 r
.6254 .53541 m
.64147 .51274 L
s
0 0 1 r
.3746 .53541 m
.35853 .51274 L
s
1 0 0 r
.60721 .59002 m
.62475 .56749 L
s
0 0 1 r
.39279 .59002 m
.37525 .56749 L
s
1 0 0 r
.60827 .45724 m
.62488 .43748 L
s
0 0 1 r
.39173 .45724 m
.37512 .43748 L
s
1 0 0 r
.46969 .63226 m
.48979 .61476 L
s
0 0 1 r
.53031 .63226 m
.51021 .61476 L
s
1 0 0 r
.55036 .62162 m
.57024 .60134 L
s
0 0 1 r
.44964 .62162 m
.42976 .60134 L
s
1 0 0 r
.58998 .44361 m
.60762 .42452 L
s
0 0 1 r
.41002 .44361 m
.39238 .42452 L
s
1 0 0 r
.60802 .55794 m
.6254 .53541 L
s
0 0 1 r
.39198 .55794 m
.3746 .53541 L
s
1 0 0 r
.60855 .49085 m
.62547 .46973 L
s
0 0 1 r
.39145 .49085 m
.37453 .46973 L
s
1 0 0 r
.51016 .62827 m
.53058 .60941 L
s
0 0 1 r
.48984 .62827 m
.46942 .60941 L
s
1 0 0 r
.44957 .61813 m
.46933 .60041 L
s
0 0 1 r
.55043 .61813 m
.53067 .60041 L
s
1 0 0 r
.41068 .58932 m
.4292 .5708 L
s
0 0 1 r
.58932 .58932 m
.5708 .5708 L
s
1 0 0 r
.5708 .4292 m
.58932 .41068 L
s
0 0 1 r
.4292 .4292 m
.41068 .41068 L
s
1 0 0 r
.60847 .52466 m
.62564 .5026 L
s
0 0 1 r
.39153 .52466 m
.37436 .5026 L
s
1 0 0 r
.42982 .60368 m
.44905 .58562 L
s
0 0 1 r
.57018 .60368 m
.55095 .58562 L
s
1 0 0 r
.57024 .60134 m
.58954 .58002 L
s
0 0 1 r
.42976 .60134 m
.41046 .58002 L
s
1 0 0 r
.58954 .58002 m
.60802 .55794 L
s
0 0 1 r
.41046 .58002 m
.39198 .55794 L
s
1 0 0 r
.59034 .47774 m
.60827 .45724 L
s
0 0 1 r
.40966 .47774 m
.39173 .45724 L
s
1 0 0 r
.48979 .61476 m
.51027 .59592 L
s
0 0 1 r
.51021 .61476 m
.48973 .59592 L
s
1 0 0 r
.53058 .60941 m
.5509 .58935 L
s
0 0 1 r
.46942 .60941 m
.4491 .58935 L
s
1 0 0 r
.59012 .54667 m
.60847 .52466 L
s
0 0 1 r
.40988 .54667 m
.39153 .52466 L
s
1 0 0 r
.59039 .51234 m
.60855 .49085 L
s
0 0 1 r
.40961 .51234 m
.39145 .49085 L
s
1 0 0 r
.57119 .46357 m
.58998 .44361 L
s
0 0 1 r
.42881 .46357 m
.41002 .44361 L
s
1 0 0 r
.46933 .60041 m
.48969 .58147 L
s
0 0 1 r
.53067 .60041 m
.51031 .58147 L
s
1 0 0 r
.5509 .58935 m
.57084 .56834 L
s
0 0 1 r
.4491 .58935 m
.42916 .56834 L
s
1 0 0 r
.57084 .56834 m
.59012 .54667 L
s
0 0 1 r
.42916 .56834 m
.40988 .54667 L
s
1 0 0 r
.4292 .5708 m
.4487 .5513 L
s
0 0 1 r
.5708 .5708 m
.5513 .5513 L
s
1 0 0 r
.5513 .4487 m
.5708 .4292 L
s
0 0 1 r
.4487 .4487 m
.4292 .4292 L
s
1 0 0 r
.44905 .58562 m
.46908 .56645 L
s
0 0 1 r
.55095 .58562 m
.53092 .56645 L
s
1 0 0 r
.51027 .59592 m
.53086 .57598 L
s
0 0 1 r
.48973 .59592 m
.46914 .57598 L
s
1 0 0 r
.57132 .49871 m
.59034 .47774 L
s
0 0 1 r
.42868 .49871 m
.40966 .47774 L
s
1 0 0 r
.5712 .53389 m
.59039 .51234 L
s
0 0 1 r
.4288 .53389 m
.40961 .51234 L
s
1 0 0 r
.48969 .58147 m
.51036 .56155 L
s
0 0 1 r
.51031 .58147 m
.48964 .56155 L
s
1 0 0 r
.53086 .57598 m
.55127 .5552 L
s
0 0 1 r
.46914 .57598 m
.44873 .5552 L
s
1 0 0 r
.55148 .48411 m
.57119 .46357 L
s
0 0 1 r
.44852 .48411 m
.42881 .46357 L
s
1 0 0 r
.55127 .5552 m
.5712 .53389 L
s
0 0 1 r
.44873 .5552 m
.4288 .53389 L
s
1 0 0 r
.46908 .56645 m
.48962 .54644 L
s
0 0 1 r
.53092 .56645 m
.51038 .54644 L
s
1 0 0 r
.53108 .46892 m
.5513 .4487 L
s
.4487 .5513 m
.46892 .53108 L
s
0 0 1 r
.46892 .46892 m
.4487 .4487 L
s
.5513 .5513 m
.53108 .53108 L
s
1 0 0 r
.55147 .51987 m
.57132 .49871 L
s
0 0 1 r
.44853 .51987 m
.42868 .49871 L
s
1 0 0 r
.51036 .56155 m
.53105 .54092 L
s
0 0 1 r
.48964 .56155 m
.46895 .54092 L
s
1 0 0 r
.53105 .54092 m
.55147 .51987 L
s
0 0 1 r
.46895 .54092 m
.44853 .51987 L
s
1 0 0 r
.53112 .50497 m
.55148 .48411 L
s
0 0 1 r
.46888 .50497 m
.44852 .48411 L
s
1 0 0 r
.48962 .54644 m
.5104 .52585 L
s
0 0 1 r
.51038 .54644 m
.4896 .52585 L
s
1 0 0 r
.46892 .53108 m
.48959 .51041 L
s
0 0 1 r
.53108 .53108 m
.51041 .51041 L
s
1 0 0 r
.51041 .48959 m
.53108 .46892 L
s
0 0 1 r
.48959 .48959 m
.46892 .46892 L
s
1 0 0 r
.5104 .52585 m
.53112 .50497 L
s
0 0 1 r
.4896 .52585 m
.46888 .50497 L
s
1 0 0 r
.48959 .51041 m
.51041 .48959 L
s
0 0 1 r
.51041 .51041 m
.48959 .48959 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
OGoo2@0O4goo2G`0OWoo001iOol401l9Ool501l9Ool5O009Ool4O01jOol007Eooa407`Eoo`@07`03
Ooml07`0009l00Eooa5l07Ioo`00Lgoo1P0O3Goo100O0goo0W`00`0O0goo17`03Goo1W`0M7oo001a
OolA01l8Ool201l00g`0Oomoo`03Ool00`0OO01l0008OolAO01bOol006ioo`@07a1oo`D07`9oo`9l
0003Ool07`0O00=oo`9l0003Ool07`0O009oo`El011oo`Al06moo`00K7oo4P0O2Goo0`0O17oo0P0O
00=l07ooOol00Woo0g`02Goo4W`0KGoo001ZOol501l?Ool501l3Ool2O002Ool201l017ooO01l07oo
0P0O00=oog`0O0000Woo0P0O0goo1G`03goo1G`0Jgoo001YOol401l2Ool;01l9Ool201l00g`0Oomo
o`03Ool00g`001l07`03Ool2O0000`0OOomoo`03Ool00`0OO01l0009Ool;O002Ool4O01ZOol006Mo
o`<07`03Ool07`0O00807`]oo`D07`Eoo`05O01oo`0O01moo`02O003Ool201l017`0Oomoogoo0P0O
00Eoog`0O01oo`0O00Eoo`El00]oo`Al0004Ooml07`0O01XOol006Ioo`D07`03Ool07`0O00D07`ao
o`<07`9l00=oo`03O0007`0O00=oo`9l0003Ool07`0O00=oo`9l000401moogooOol201l3O00<Ool7
O0000gooO01l0003O01WOol006Aoo`<07`03Ool07`0O00807`Moo`L07`Moo`04O0007`0OOol2O003
Ool201l00g`0Oomoo`03Ool00`0OO01l0003Ool201l017ooO01l000O1goo1g`01goo17`000Aoog`0
O01l06Eoo`00HWoo1P0O00=oo`0O01l0100O2goo0P0O17oo00Al07ooOomoo`807`Aoo`9l00807`=o
o`9l00807`Aoo`9l00=oo`0301moogoo009oo`9l00]oo`Il0003Ooml07`000Al06=oo`00HGoo200O
1Woo100O2Goo0P0O0W`00Woo0W`00Woo0P0O00=oog`0Ool00goo0P0O00=l07ooOol00Woo00@07goo
O01l009oo`807`9oo`807`9l00Uoo`Al00Ioo`Ql069oo`00H7oo1@0O3Woo100O1Woo00=l07oo01l0
0P0O1Woo0P0O0goo0W`000=oo`0O01l00goo0W`01Woo0g`000=oo`0OOol01Goo17`03Woo1G`0HGoo
001NOolB01l7Ool301l2Ool01W`0OomoogooO01oo`807`9oo`9l009oo`807`03O01oogoo00=oo`03
01ml07`0009oo`807`9oo`9l0003Ool07goo009oo`0301moogoo00=l00Mooa9l05moo`00GGoo1P0O
3Goo100O1Woo0W`00goo00=l07ooOol00Woo00<07g`0Ool00goo0W`00P0O0goo0W`00P0O17oo00<0
7g`0Ool00goo00@07gooOomoo`807`Ioo`Al00eoo`Il05ioo`00G7oo3P0O2Woo0`0O0Woo00=l07oo
Ool00P0O00=l07ooOol00goo00Il07oo01l07gooO004Ool00`0OOoml0004Ool01P0OOoml07`0Ool0
7`Eoo`0301ml07`0009oo`0301moogoo00=l00Yoo`il05eoo`00Fgoo0`0O00=oo`0O01l00`0O1Woo
0`0O2Woo0P0O17oo00=l07oo01l00P0O0W`017oo0P0O17oo00=l000O01l017oo0W`017oo0P0O0g`0
00=oo`0OOol00goo0W`02Woo0g`01Woo1G`000Aoog`0O01l05aoo`00FWoo1P0O17oo0`0O1Woo100O
1Woo00Il07oo01l07gooO004Ool00g`001moo`02Ool2O002Ool0100OOomoog`00goo00@07gooOoml
009oo`807`=oo`03O0007goo00=oo`0501moog`0O0007`07Ool4O006Ool3O004Ool6O01KOol005Qo
o`X07`Eoo`@07`Ioo`807`Aoo`06O01oogooOoml000O0goo00=l07ooOol00P0O00=l07ooOol00goo
0P0O1Goo0W`01Goo00<07g`0O0000Woo00H07gooOomoog`001l3Ool00`0OOomoo`02Ool2O006Ool4
O005Ool:O01IOol005Qoo`P07`9oo`<07`Ioo`<07`Eoo`807`03Ooml07oo009oo`03O01oogoo0080
7`03O01oogoo009oo`03O0007goo00=oo`9l0003Ool07goo009oo`04O01oo`0O01l4Ool00g`001mo
o`03Ool00`0OO01l0002Ool01P0OOomoogoo01moo`9l00Eoo`=l00Ioo`=l009oo`Ql05Uoo`00Egoo
1`0O0Woo0`0O0Woo0`0O1Woo0P0O1Goo0`0O00=oog`0Ool00goo00Al000O01moo`9l009oo`807`03
Ooml07oo00=oo`0301moog`000Aoo`0401moog`0O002Ool201l017ooO01l000O17oo00<07gooO000
0W`01Goo0W`01Woo0g`00Woo0g`00Woo1g`0F7oo001FOol701l00goo01moo`03Ool201l3Ool201l6
Ool201l2Ool017`0Oomoogoo0`0O0Woo00El07ooOomoo`0O00Ioo`807`Aoo`03O0007`0O00Aoo`9l
00Ioo`05O01oogooOol07`02Ool3O002Ool0100OOomoogoo0W`01Woo0W`00goo0W`017oo00=l07oo
O0001W`0Egoo001EOol501l00goo01l07`0401l4Ool201l3Ool201l6Ool201l01G`0OomoogooO000
0Woo00<07g`0Ool00Woo00=l07oo01l00goo0W`00Woo00@07gooOoml00=oo`0401moogooO002Ool2
01l3Ool00g`0Ool07`03Ool01@0OO01oogoo01l00goo00<07g`0O0001Woo0W`00goo0W`017oo37`0
EWoo001EOol501l01goo01moo`0OOol07goo00807`Aoo`0301moogoo009oo`<07`Aoo`05O0007`0O
Ooml0003Ool01G`001l07gooO0000goo0P0O00=l07ooOol00goo0P0O1Goo0W`01Goo00<07g`0O000
0Woo00<07gooOol00W`000H07gooOomoo`0OOol2O0000`0OOomoo`02Ool3O004Ool00g`0Oomoo`02
Ool2O0001gooO01oog`0Ooml07oo00El05Ioo`00E7oo1@0O00=oo`0OOol00Woo00<07goo01l00Woo
0P0O0goo0P0O1Goo0P0O00=oog`0Ool00Woo0P0O0Woo00Il07ooOomoo`0OO004Ool00g`001moo`03
Ool2O0000goo01moo`02Ool017`0Ool07`0O17oo00=l000OOol00goo00<07g`0Ool00Woo00<07goo
Ool00W`00goo00@07gooO01l00Eoo`9l00=oo`9l009oo`03O01oog`000=oo`Ml05Eoo`00E7oo1`0O
17oo00@07goo01l07`9oo`0301moogoo009oo`0301moogoo00Aoo`05O0007gooOoml0002Ool201l4
Ool00g`001l07`02Ool00g`0Oomoo`0201l00gooO01oo`03Ool00`0OOoml0004Ool01P0OOoml07`0
Ool07`=oo`9l000301moogoo009oo`9l0003Ool07goo009oo`0301ml07oo00Eoo`03O01oogoo009o
o`03O01oogoo009l0003Ooml07oo00=oo`Ml05Eoo`00E7oo1@0O0Woo00<07gooOol00Woo00@07goo
Ool07`9oo`807`=oo`807`Aoo`05O01oo`0OOoml0002Ool00g`0Ool07`02Ool017`0Oomoogoo0P0O
00=l07ooOol00Woo0P0O17oo00=l000O01l017oo0W`017oo00<07g`0O0000goo00D07gooOoml000O
00=oo`0501moog`0Ool07`04Ool2O003Ool2O002Ool017`0Oomoog`017oo00=l07ooO0001G`0EGoo
001COol601l2Ool00`0OOomoo`03Ool0100OOomoo`0O0goo00<07gooOol00Woo00@07gooOoml00=o
o`05O01oogooOoml0002Ool00`0OO01oo`04Ool00g`001moo`02Ool017`0Oomoo`0O0Woo00El07oo
Oomoo`0O009oo`04O01oogoo01l3Ool00g`001moo`03Ool00`0OOoml0002Ool01@0OOomoogoo01l0
0goo00@07gooOoml00Aoo`05O01oogooOoml0002Ool00g`0Oomoo`03Ool00g`0Oomoo`06O01DOol0
05=oo`H07`=oo`0301moogoo00=oo`0401moogoo01l3Ool00`0OOomoo`02Ool201l01G`0Oomoog`0
Ool00P0O00=l07ooOol00Woo00=l000OOol00Woo00=l07ooOol00P0O00=l07ooOol00Woo0P0O1Goo
0W`017oo00<07g`0O0000Woo00H07gooOomoog`001l4Ool01@0OO01l07oo01l00Woo00<07g`0O000
17oo00El07ooOomoog`0009oo`03O01oogoo00=oo`04O01oogooOol6O01DOol005=oo`D07`05Ool0
7gooOol07`06Ool00`0OOomoo`0201l2Ool00`0OOomoo`02Ool01G`001moogooO0000Woo00=l000O
Ool00Woo00Al07ooOol07`9l00Aoo`03O0007goo009oo`9l0003Ool07goo009oo`04O01oo`0O01l3
Ool00g`001moo`03Ool201l017`0Oomoo`0O0goo00El000OOomoo`0O009oo`03O0007goo00=oo`03
O01oogoo009l009oo`03O01oogoo00Aoo`05O01oogooO01oo`02O0000gooO01l001DOol0059oo`H0
7`03Ool07goo009oo`0301moogoo00Aoo`0501moogooOol07`02Ool201l2Ool017`0Ool07g`00Woo
00=l07ooOol00P0O00El07ooOomoog`000807`=oo`06O01oogoo01moog`017oo00<07gooO00017oo
00<07gooO0000Woo00@07gooOomoo`9l000501moogooOol07`02O0000goo01moo`02Ool0100OO01o
o`0O0Woo0W`00Woo00El07ooOomoog`000Ioo`06O01oogooOoml07oo1G`0E7oo001BOol601l2Ool0
1@0OOomoogoo01l01Woo00D07gooOomoo`0O00=oo`807`=oo`04O0007`0OO003Ool01G`001l07goo
O0000goo0P0O00=l07ooOol00Woo00<07gooOol00goo00=l000O01l01Goo00=l07ooOol00Woo00<0
7g`0O0000goo00D07gooO01l000O00=oo`0401ml07`001l3Ool2O003Ool01G`0OomoogooO0001Woo
00El07ooOomoog`0009oo`Il05=oo`00DWoo1P0O0Woo00<07gooOol00Woo00<07gooOol017oo00D0
7gooOomoo`0O00=oo`04O0007gooO002Ool01G`001moogooO0000goo00=l07ooOol00goo00=l000O
Ool00Woo00=l07oo01l00goo00El07ooOomoo`0O00=oo`03O0007goo00=oo`03O0007goo00=oo`03
01ml07oo009oo`0501moogooO0007`02Ool0100OOoml000O0goo00El07ooOomoog`000Ioo`03O01o
ogoo009oo`04O01oog`0Ool5O01COol0059oo`@07`9oo`0401moogoo01l4Ool00`0OOomoo`04Ool0
1`0OOomoogoo01moog`0009oo`0401moogooO002Ool00`0OO01oo`03Ool00g`001moo`02Ool00g`0
Oomoo`0201l01gooO01oogoo01moog`000Eoo`0301moog`0009oo`0401moog`0O002Ool01P0OOomo
ogooO0007`Aoo`0501ml07ooOol07`02Ool01W`0Oomoo`0OOoml00=oo`03O01oogoo00Aoo`03O01o
ogoo009oo`04O01oogooO002Ool4O01COol0059oo`@07`9oo`0401moogoo01l5Ool00`0OOomoo`04
Ool01@0OOomoogooO0000Woo00El07oo01moog`0009oo`03O0007goo009oo`06O01oogoo01moog`0
1Goo00=l07ooOol00Woo0P0O1Goo0W`017oo00<07gooOol00goo00<07gooO0000Woo00H07gooOomo
og`001l2Ool0100OOoml000O0Woo00<07g`0Ool00Woo00=l07ooOol017oo00=l07ooOol00Woo00Il
07ooOomoog`0Ool5O01COol0055oo`H07`03Ool07goo009oo`0301moogoo009oo`0301moogoo00Eo
o`0701moogooO0007gooO0000Woo00Al000OOoml009oo`0301moog`000Aoo`03O01oogoo00=oo`03
O01oo`0O009oo`04O01oogoo01l3Ool017`0Oomoo`0O0Woo00=l07oo01l01Goo00<07gooOol00Woo
00D07gooO01oo`0O009oo`08O0007gooOol07gooO0007`9oo`03O01oogoo00Aoo`03O01oogoo00=o
o`04O01oogooO002Ool6O01BOol0055oo`@07`05Ool07gooOol07`03Ool00`0OOomoo`02Ool00`0O
Oomoo`05Ool01@0OO01oogoo01l00goo00Al07oo01ml00=oo`03O0007goo009oo`05O01oo`0O01mo
o`02O003Ool00`0OO01oo`03Ool00`0OOoml0004Ool00`0OO01oo`02Ool201l01GooO01l07oo01l0
0goo00<07g`0Ool00Woo00@07g`0Ool07`=oo`05O01oogoo01ml0007Ool00g`0Oomoo`02Ool01G`0
OomoogooO0000Woo00=l07ooO0000g`0DWoo001AOol401l01Goo01moogoo01l017oo00<07gooOol0
0Woo00<07gooOol01Goo00@07gooOoml00807`05O01oogooO0007`03Ool01G`0Ool07gooO00017oo
00<07gooOol00goo00=l000OOol00goo00=l000O01l017oo00=l000OOol017oo00=l07ooOol00Woo
00D07gooO01oo`0O00=oo`05O0007gooOol07`02O000100OOomoog`01goo00=l07ooOol00Woo00El
07ooOomoog`000=oo`03O01oog`000=l059oo`00DGoo100O00=oo`0OOol00Woo00D07gooOomoo`0O
00Eoo`0301moogoo00=oo`04O01oo`0OO002Ool01W`001moogooO01oo`807`05O01oogooOoml0004
Ool00g`0Ool07`03Ool017`0Oomoo`0O0Woo00El07ooOomoo`0O009oo`04O01oogoo01l3Ool00g`0
Ool07`03Ool00`0OO01oo`02Ool01@0OO01l07oo01l00Woo00Ql07ooOomoo`0OO01oo`0O1Goo00=l
07ooOol00Woo00=l07ooOol00Woo00Al07ooOoml009oo`Al059oo`00DGoo100O0Woo00@07gooOol0
7`Aoo`0301moogoo00=oo`0301moogoo009oo`04O01oogoo01l2Ool017`0Ool07g`00goo00=l000O
Ool00Woo00El000O01moog`000=oo`807`03O01oogoo009oo`0301ml07oo00Aoo`0301ml07oo00=o
o`0301ml07`0009oo`0301moogoo009l000601moogooOoml000O0goo00@07g`0Ool07`9oo`04O01o
ogoo01l4Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01g`0Oomoog`0Ooml07oo00=l059oo`00DGoo
0`0O00Aoo`0OOol07`=oo`0301moogoo009oo`0301moogoo00=oo`0401moogooO002Ool017`0Ool0
7g`00goo00Ul000OOomoog`0Ool07gooO0000goo00<07g`0Ool00goo00=l000OOol00goo00=l000O
Ool017oo00=l000OOol00goo00=l000OOol00goo00<07g`0Ool00Woo00D07gooO01oo`0O009oo`09
O0007gooOol07gooO01oo`0O009oo`0401moogooO005Ool00g`0Oomoo`02Ool027`0OomoogooO01o
og`0Ool3O01BOol0055oo`<07`04Ool07goo01l3Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0O
Ooml0002Ool017`0Oomoo`0O0Woo00El07ooOol07g`000=oo`03O01oogoo009oo`03O0007goo009o
o`04O01oogoo01l2Ool017`0Oomoo`0O0goo00Al07ooOol07`9oo`04O01oogoo01l3Ool00g`001mo
o`03Ool01P0OOomoogoo01ml009oo`0401moogooO002Ool01P0OOomoo`0OOoml00Eoo`03O01oogoo
00=oo`08O01oogooOoml07ooO01oo`=l059oo`00DGoo0`0O00Eoo`0OOomoo`0O00=oo`0301moogoo
009oo`0301moogoo00Aoo`0;01ml07ooOoml07ooO01oo`0OOoml0003Ool01W`0Oomoog`0Ool07`9o
o`06O01oogoo01moog`017oo00<07g`0Ool00goo00<07gooO00017oo00<07g`0Ool00goo00<07goo
O0000Woo00D07gooOoml000O00=oo`0;01moogooOol07gooO01oo`0OOol07`02Ool00`0OO01oo`05
Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00=l07ooO0000W`0DWoo001AOol301l2Ool00`0O
Ool07`03Ool00`0OOomoo`03Ool00`0OOomoo`03Ool017`001moog`00Woo00Al07ooOol07`=oo`05
O0007gooOoml0002Ool00`0OO01oo`03Ool00`0OOomoo`03Ool00g`001moo`03Ool00g`001l07`04
Ool00g`001moo`04Ool00g`0Oomoo`02Ool02@0OO01oogoo01moog`0Ool07`03Ool017`0Oomoo`0O
0Woo00@07gooO0007`Eoo`03O01oogoo00=oo`07O01oogooOoml07ooO0000Woo0g`0DWoo001@Ool4
01l2Ool0100OOomoo`0O0goo00<07gooOol00Woo00<07gooOol00goo00Il000OOoml07ooO002Ool0
1G`0Ool07gooO0000Woo00<07g`0Ool00Woo00=l000O01l00Woo00=l07oo01l00goo00Al07ooOol0
7`9oo`05O01oogooOol07`02Ool017`0Oomoo`0O0goo00=l07oo01l00Woo0W`000H07gooOomoo`0O
O002Ool0100OOoml000O0goo00H07goo01moog`001l5Ool00g`0Oomoo`02Ool01G`0OomoogooO000
0Woo00=l07ooOol00g`0DWoo001@Ool401l3Ool00`0OOol07`03Ool00`0OOomoo`03Ool01@0OOomo
ogooO0000Woo00@07gooOoml009oo`04O01oogoo01l3Ool01G`001moogooO0000goo00<07g`0Ool0
0Woo0P0O00=l07ooOol00Woo00<07g`0Ool017oo00<07g`0Ool00goo00<07g`0O0000Woo00<07goo
O0000goo00D07gooOoml000O009oo`0501ml07ooOol07`02Ool0100OOomoog`00Woo00D07gooOomo
og`000Eoo`07O01oogooOoml07ooO0000Woo00=l07ooO0000W`0DGoo001@Ool201l00goo01l07`02
Ool0100OOomoo`0O0goo00<07gooOol00goo00@07gooOoml009oo`03O0007g`0009oo`08O01oogoo
Ooml000OOoml009oo`0301ml07oo00Aoo`03O01oogoo009oo`03O0007goo00=oo`03O0007goo00Ao
o`03O01oogoo00=oo`03O0007goo00=oo`0301moogoo00=oo`0401ml07oo01l2Ool00g`001moo`02
Ool01P0OOomoo`0OO0007`9oo`0401moogooO005Ool01G`0OomoogooO0000Woo00=l07ooOol00W`0
00=oog`0O000DGoo001@Ool201l00goo01l07`02Ool0100OOomoo`0O0goo00<07gooOol017oo00<0
7gooO0000Woo00El07oo01moog`000=oo`05O01oogoo01ml0002Ool00g`001moo`03Ool00g`0Ool0
7`02Ool017`0Oomoo`0O0goo00=l07oo01l00goo00=l07oo01l00goo00Al07ooOol07`9oo`03O01o
o`0O00Aoo`0601moogooOol07g`00Woo00T07gooOomoo`0OOoml07oo01l00Woo00<07gooO0001Woo
00El07ooOomoog`0009oo`03O01oogoo009l0003Ooml07`0055oo`00D7oo0P0O00=oo`0O01l00goo
00@07gooOol07`=oo`0301moogoo00=oo`0:01moog`0Ooml07ooO01oo`0OO002Ool01W`0Oomoogoo
O0007`9oo`03O01oo`0O009oo`06O01oogooOol07g`017oo0P0O00Ml07ooOomoo`0OOoml0003Ool0
0`0OO01l0004Ool00`0OO01oo`02Ool01P0OOomoog`0Ool07`9oo`03O0007goo009oo`0=01moogoo
01ml07oo01moo`0OOol07gooO0001Goo00El07ooOomoog`0009oo`04O01oogooOol2O0000gooO01l
001AOol0051oo`807`03Ool07`0O00=oo`0401moogoo01l4Ool00`0OOomoo`03Ool02@0OOomoog`0
Ooml07ooO0007`02Ool017`0Oomoog`00Woo00<07g`0Ool00Woo00<07g`0Ool00goo00=l000OOol0
17oo00=l000OOol00Woo00=l000O01l00goo00=l000OOol017oo00=l000OOol00goo00<07g`0Ool0
0Woo00D07g`0Oomoo`0O009oo`0901moogooO0007goo01moo`0O009oo`03O01oogoo00=oo`03O01o
ogoo009oo`04O01oogooO003Ool2O0000gooO01l001AOol0051oo`807`04Ool07goo01l2Ool01@0O
Oomoogoo01l017oo00<07gooOol00Woo00El000OO01oog`0009oo`04O01oo`0OO002Ool01W`0Oomo
ogooO0007`Aoo`05O0007gooOoml0002Ool00`0OOomoo`02O002Ool00`0OOoml0003Ool00`0OOoml
0002Ool201l2Ool017`0Oomoo`0O0Woo0W`000H07gooOomoog`001l2Ool0200OOomoogoo01ml07oo
01l2Ool01@0OOol07g`001l017oo00=l07ooOol00Woo00El07ooOomoog`0009oo`04O01oog`0Ool2
O01AOol0051oo`807`04Ool07goo01l3Ool0100OOomoo`0O17oo00<07gooOol00Woo00Ml07oo01mo
og`0Ooml0003Ool0100OOomoog`00goo00=l07oo01l00Woo00El07ooOol07g`000Aoo`0301ml07oo
00=oo`0301ml07oo00Aoo`03O01oogoo00=oo`0301ml07oo009oo`0301moog`000=oo`0501moog`0
Ool07`03Ool0100OOomoog`00goo00L07goo01moog`0Ool07`04Ool01G`0OomoogooO0000goo00Al
07ooOomoo`9l009oo`9l055oo`00D7oo0P0O0Woo00<07goo01l00Woo00D07gooOomoo`0O00Aoo`0;
01moogooOoml07ooO0007g`0Ooml0002Ool017`0Ool07g`00goo00Il07ooOomoo`0OO004Ool00g`0
Oomoo`02Ool00g`001moo`03Ool00g`001moo`04Ool00g`0Oomoo`03Ool00g`001moo`03Ool00`0O
Oomoo`03Ool01G`0Oomoogoo01l00goo00@07g`0Ool07`9oo`0701moo`0OO0007goo01l00goo00=l
07ooOol00Woo00El07ooOomoog`0009oo`04O01oog`0Ool3O01AOol0051oo`<07`04Ool07goo01l2
Ool01@0OOomoogoo01l01Goo00<07gooOol00W`000Aoo`0OOoml009oo`05O01oogooO0007`03Ool0
1W`0OomoogooO0007`=oo`03O01oo`0O009oo`04O01oogoo01l3Ool00g`0Ool07`03Ool00g`0Ool0
7`03Ool017`0Oomoo`0O0Woo00=l07oo01l00goo00=l000OOol00Woo00P07gooOomoog`001moo`0O
0goo00@07gooO01oo`807`9oo`03O01oogoo009oo`03O01oogoo009oo`07O01oogooO01oog`0Ool0
0g`0DGoo001@Ool301l017oo01moo`0O0goo00D07gooOomoo`0O00Eoo`0801ml07ooO01oog`001ml
009oo`05O01oogooO0007`02Ool01G`0OomoogooO0000Woo00<07gooO0000goo00<07g`0Ool00goo
0P0O00Ml07ooOomoo`0OOoml0003Ool00`0OO01l0004Ool00`0OO01oo`02Ool00`0OOoml0002Ool0
2@0OOomoogoo01moog`0Ool07`02Ool02`0OOomoo`0OO0007goo01moo`0OO0001Goo00El07ooOomo
og`000=oo`04O01oog`0Ool3O01AOol004moo`@07`05Ool07gooOol07`02Ool01@0OOomoogoo01l0
1Woo00T07g`0Ooml07ooO0007gooO0000Woo00El07ooOol07g`000=oo`03O01oogoo009oo`0301mo
ogoo009oo`03O0007goo00Aoo`03O0007goo009oo`03O0007`0O00=oo`03O0007goo00Aoo`03O000
7goo009oo`0301ml07oo00=oo`0601moogooOol07g`00Woo00<07goo01l00Woo00Ml000OOol07goo
01ml0005Ool00g`0Oomoo`02Ool017`0Oomoog`00Woo00=l07ooO0000W`0DGoo001?Ool401l2Ool0
0`0OOol07`02Ool00`0OOomoo`02Ool00`0OOomoo`03Ool02@0OO01oog`0Ooml07oo01ml0002Ool0
1G`0Oomoog`001l00Woo00=l07ooOol00goo00El000OOomoog`0009oo`0301moogoo009l009oo`03
01moog`000=oo`0301moog`0009oo`807`9oo`04O01oogoo01l2Ool00g`001moo`04Ool0100OOomo
og`00goo00`07gooOol07g`0Ool07goo01moo`0OO005Ool00g`0Oomoo`02Ool01W`0Oomoog`0Ooml
009oo`Al051oo`00Cgoo0`0O00Ioo`0OOol07goo01l3Ool00`0OOomoo`02Ool00`0OOomoo`02Ool0
2g`001moog`0Ooml07ooO0007gooO0000goo00Al07oo01ml00Eoo`05O01oogoo01ml0004Ool00`0O
O01oo`03Ool00`0OO01oo`04Ool00g`0Oomoo`03Ool00`0OO01oo`02Ool00`0OOoml0002Ool00`0O
Oomoo`02Ool01@0OOoml07oo01l00goo00/07gooO0007goo01moo`0OOoml000O00Aoo`03O01oogoo
009oo`0:O01oogooOoml07ooO01oog`0Ool3O01@Ool004moo`<07`04Ool07goo01l2Ool0100OOomo
o`0O17oo00<07gooOol00Woo0W`000<07gooO0000Woo00Al000OOoml009oo`05O01oogooOol07`04
Ool00g`0Oomoo`02Ool00`0OOomoo`02Ool00g`001moo`03Ool00g`001moo`04Ool00g`0Oomoo`03
Ool00g`001moo`03Ool00g`0Oomoo`02Ool00`0OOomoo`02Ool01G`0Oomoogoo01l00Woo00@07g`0
Ool07`9oo`0301moog`000807`Aoo`03O01oogoo009oo`04O01oogooO002Ool017`0Ooml07oo0g`0
D7oo001?Ool501l01Goo01moogoo01l00goo00<07gooOol00Woo00<07gooOol00W`000Ioog`001ml
07ooO002Ool0100OOomoog`00goo00=l07oo01l00Woo00=l07ooOol00Woo00=l07oo01l00Woo00Al
07ooOol07`=oo`03O01oo`0O00=oo`03O01oo`0O00=oo`03O01oo`0O00=oo`03O01oo`0O00Aoo`06
01moogooO01oo`0O0Woo00D07gooOomoog`0009oo`0701moo`0OO0007goo01l00goo00=l07ooOol0
0Woo00El07ooOomoog`0009oo`03O01oog`000Al051oo`00Cgoo100O00Ioo`0OOol07goo01l3Ool0
0`0OOomoo`02Ool00`0OOomoo`03O0001Goo01moogooO0000Woo00Al000OOoml009oo`06O01oogoo
Ool07g`017oo00Ml07ooOomoo`0OOoml0003Ool201l01g`0Oomoogoo01moog`000=oo`0301ml07`0
00=oo`0301moog`000=oo`0301moogoo009oo`0301ml07oo009oo`0701moogoo01moog`001l00Woo
00D07gooOoml07oo00<07`9oo`03O01oogoo009oo`0:O01oogooOoml07ooO01oog`0Ool4O01@Ool0
04moo`@07`04Ool07goo01l2Ool01@0OOomoogoo01l017oo00<07gooO0000W`000Aoog`001ml009o
o`04O01oogoo01l2Ool00g`0Oomoo`02Ool00g`001moo`02Ool00g`0Oomoo`03Ool00`0OOomoo`03
Ool00g`001moo`02Ool00g`001l07`03Ool00g`001moo`04Ool00g`0Oomoo`02Ool00`0OOomoo`02
Ool00g`001moo`02Ool01@0OOomoo`0OO0000Woo00L07gooOol07g`001moo`0301l00gooO01oo`03
Ool01G`0OomoogooO0000Woo00Al07ooO01oo`Al051oo`00Cgoo100O00Aoo`0OOol07`9oo`0301mo
ogoo009oo`0301moogoo009oo`0801ml07`0O01oog`0Ool07`9oo`07O01oogooO0007gooO0000goo
00Al07ooOol07`9oo`03O01oogoo009oo`03O01oo`0O009oo`9l009oo`0301moog`000=oo`0301mo
og`0009oo`807`9oo`03O01oo`0O00Aoo`0401moogooO002Ool0200OOomoogoo01moog`001l2Ool0
1`0OOomoog`0Ool07goo00<07`03O01oogoo009oo`03O01oogoo009oo`07O01oogooO01oog`0Ool0
17`0D7oo001?Ool401l2Ool00`0OOol07`02Ool01@0OOomoogoo01l017oo00D07g`0O01l07oo009l
000301moog`0009oo`04O01oogoo01l3Ool00g`0Oomoo`02Ool00`0OO01oo`03Ool01W`0Oomoogoo
01ml00Aoo`0301ml07oo00Aoo`0301moogoo00=oo`0301ml07oo009oo`0301moogoo009oo`0301ml
07oo009oo`0301moogoo009oo`06O01oogoo01moo`0O0Woo00Al000O01moo`<07`03O01oogoo009o
o`05O01oogooOoml0002Ool00g`0Ooml0002Ool4O01@Ool004moo`<07`06Ool07goo01moo`0O0Woo
00<07gooOol00Woo00<07gooOol00Woo00T07g`0Ooml07ooO01oo`0OO0000Woo00Al07ooOol07`=o
o`03O01oogoo009oo`03O0007goo009oo`03O01oogoo009oo`03O0007goo00=oo`03O0007goo00Ao
o`0301moogoo00=oo`03O0007goo00=oo`0601moogooOoml000O17oo00D07gooOoml000O009oo`0<
01moogoo01ml07oo01moo`0OOol07g`017oo00=l07ooOol00Woo00Ul07ooOoml07ooO01oog`0Ool0
0g`0D7oo001?Ool301l01Woo01moo`0OOol07`=oo`0501moogooOol07`03Ool2O000100OOoml07`0
0Woo00Al000OOoml009oo`05O01oo`0OOoml0004Ool01W`0Oomoo`0OOoml00Aoo`04O01oogoo01l3
Ool00g`0Ool07`03Ool00g`0Ool07`03Ool00g`0Ool07`05Ool01@0OOoml07oo01l01Goo00D07goo
O01oo`0O009oo`0301moog`000=oo`807`04Ooml000O01l2Ool00g`0Oomoo`02Ool02W`0Oomoogoo
O01oog`0Ooml07oo0g`0D7oo001?Ool501l01Goo01moogoo01l00Woo00<07gooOol00Woo00<07goo
Ool00W`000@07gooO01l009oo`04O01oo`0OO002Ool017`0Oomoo`0O1Goo00El07ooOomoo`0O00Eo
o`07O01oogooOol07gooO0000goo00<07gooO0000goo00<07gooO0000goo00<07gooOol00goo00El
07ooOomoo`0O00Eoo`04O01oogoo01l2Ool0100OO01oo`0O0Woo0P0O00Aoog`001l07`9oo`03O01o
ogoo009oo`04O01oogooO002Ool00g`0Ooml0004O01@Ool004moo`D07`9oo`0301moo`0O009oo`03
01moogoo009oo`0301moogoo00=l000501ml07`0Ooml0002Ool0100OOomoog`00Woo00=l07oo01l0
0goo00Ml07ooOomoog`0Ool07`03Ool00g`0Oomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`03Ool0
0g`0Oomoo`03Ool01P0OOomoogooO0007`Aoo`0601moogooOoml000O0goo00@07gooO0007`9oo`05
01moo`0O01ml000301l00gooO01oo`03Ool01g`0OomoogooO01oog`0009oo`El051oo`00Cgoo100O
00Ioo`0OOol07goo01l3Ool00`0OOomoo`02Ool00`0OOoml0003O0002P0OO01oog`0Ooml07oo01mo
og`00Woo00Il07ooOol07gooO004Ool01W`0Oomoo`0OOoml00Eoo`03O01oo`0O00=oo`03O01oo`0O
00=oo`03O01oo`0O00Eoo`0301moog`0009oo`0301moogoo009oo`0301moog`0009oo`0701moogoo
01moog`001l00Woo00@07goo01ml00@07`03Ooml07oo00=oo`0:O01oogooOoml07ooO01oog`0Ool4
O01@Ool004moo`@07`04Ool07goo01l2Ool0100OOomoo`0O17oo00T07gooO01l07ooO0007gooO000
0Woo00Al07ooOol07`9oo`03O01oogoo009oo`0301moogoo009oo`03O01oogoo009oo`0301moogoo
00=oo`07O01oogooOol07gooO0000goo00<07gooO0000goo00<07gooOol00goo00=l07ooOol00Woo
00<07gooOol00Woo00=l07ooOol00Woo00@07gooOoml009oo`0801moogoo01moog`001moo`807`03
O01oogoo009oo`05O01oogooOoml0002Ool017`0Ooml07oo17`0D7oo001?Ool401l01goo01moogoo
01moo`0O00=oo`0301moogoo009oo`0:01ml07`0O01oog`001ml07ooO002Ool017`0Ool07g`017oo
00=l07oo01l00Woo00=l07ooOol00Woo00=l07oo01l00goo00=l07ooOol00goo00<07gooOol00goo
00=l07ooOol00goo00L07gooOomoog`0Ool07`04Ool01P0OOomoog`0Ool07`=oo`0401moog`001l2
Ool01`0OOomoo`0OO0007goo00<07`03O01oogoo009oo`07O01oogooOoml07ooO0000Woo00=l07oo
O0000g`0D7oo001?Ool301l01Woo01moo`0OOol07`9oo`0401moogoo01l4Ool01G`001ml07`0Ool0
0W`000<07gooO0000Woo00Al07ooOol07`=oo`06O01oogooOol07g`017oo00Ml07ooOomoo`0OOoml
0005Ool00g`0Ool07`03Ool00g`0Ool07`05Ool00`0OOoml0003Ool01`0OOomoogoo01moog`000=o
o`0501moogooOoml0002Ool01P0OOomoo`0OOoml00807`05Ool07`0OO0007`03Ool01G`0Oomoogoo
O0000Woo00Il07ooO01oog`0Ool3O01@Ool004moo`<07`06Ool07goo01moo`0O0Woo00D07gooOomo
o`0O00=oo`05O0007g`0O01oo`02O0001Goo01moogooO0000Woo00El000OOomoog`000Eoo`0501mo
ogooOoml0005Ool00`0OOomoo`03Ool01g`0Oomoogoo01moog`000=oo`0301moogoo00=oo`03O01o
ogoo00=oo`0501moogooOoml0005Ool0100OOomoog`00goo00D07gooOoml07oo00807`05Ool07`0O
O0007`03Ool01G`0OomoogooO0000Woo00Il07ooO01oog`0Ool3O01@Ool004moo`D07`04Ool07goo
01l3Ool01@0OOomoogoo01l00Woo0W`000L07g`0O01oog`0Ool07`02Ool01g`0Oomoog`0Ool07g`0
00Eoo`05O01oo`0OOoml0005Ool00g`0Ool07`03Ool00g`0Oomoo`03Ool00`0OOomoo`03Ool01`0O
OomoogooO01oo`0O00Aoo`0601moogooO01oo`0O17oo00D07gooO01oo`0O009oo`0701moogooO01o
o`0OOol00P0O00=l000O01l00Woo00El07ooOomoog`000=oo`04O01oog`0Ool5O01@Ool004moo`D0
7`05Ool07gooOol07`02Ool01@0OOomoogoo01l00Woo0W`000T07gooO01l07ooO01oo`0OO0000Woo
00El07ooOomoo`0O00Aoo`06O01oogooOol07g`017oo00Ml07ooOomoo`0OOoml0005Ool00g`0Ool0
7`05Ool00`0OOoml0003Ool00`0OOomoo`02Ool00`0OO01oo`02Ool00`0OOomoo`02Ool01G`0Oomo
ogoo01l00Woo00D07g`0Ool07goo00807`04Ooml000O01l2Ool01G`0OomoogooO0000Woo00El07oo
Ooml07oo00El051oo`00Cgoo100O00Ioo`0OOol07goo01l3Ool01P0OOomoogoo01moo`=l000501mo
og`0Ooml0002Ool0100OOomoog`00Woo00Al07oo01moo`9l00Aoo`03O0007goo009oo`03O01oogoo
00=oo`0301moogoo00=oo`05O01oogooOol07`05Ool00g`0Oomoo`03Ool01P0OOomoogooO0007`Ao
o`807`04Ooml07oo01l2Ool0100OOomoog`00Woo00D07goo01moog`000<07`03Ooml07oo00=oo`09
O01oogooO01oog`0Ooml07oo00Al051oo`00Cgoo100O00Ioo`0OOol07goo01l3Ool01P0OOomoogoo
01moo`=l000401moog`0O002Ool017`0Ool07g`00Woo00El07ooOol07g`000Eoo`03O01oo`0O009o
o`03O01oogoo00=oo`03O01oo`0O00=oo`03O01oogoo00=oo`0701moogooOoml07oo01l01Goo00<0
7gooO0000Woo00<07gooOol00goo00@07g`0Ool07`=oo`0401ml07oo01l2Ool201l00gooO0007`02
01l00gooO01oo`02Ool02W`0OomoogooO01oog`0Ooml07oo17`0D7oo001?Ool401l017oo01moo`0O
0Woo00D07gooOomoo`0O00=oo`0301ml07`0009l000301ml07`0009oo`04O01oo`0OO002Ool01G`0
Oomoog`001l017oo00Il07ooOomoo`0OO005Ool01g`0Oomoogoo01moog`000Moo`0301moog`000=o
o`0301moogoo00=oo`0301ml07oo009oo`0301moogoo009oo`05O0007gooOol07`02Ool017`0Oomo
o`0O0Woo0P0O00=l000O01l00P0O00=l07ooOol00Woo00Al07ooOoml009oo`04O01oog`0Ool4O01@
Ool004moo`@07`07Ool07gooOol07goo01l00goo00D07gooOomoo`0O00El000401ml07ooO002Ool0
17`001moog`00Woo00Al07ooOol07`9oo`03O01oogoo009oo`03O0007goo00=oo`03O01oogoo00=o
o`0301moogoo00Moo`03O01oogoo00=oo`0301moogoo009oo`03O0007goo00=oo`0601moogooO01o
o`0O0Woo00D07gooOoml000O009oo`0401moo`0OO00501l01G`0OomoogooO0000goo00Ql07ooO01o
og`0Ooml07oo0W`0DGoo001@Ool201l01Woo01moo`0OOol07`9oo`0501moogooOol07`03Ool0100O
O01l07oo0W`000D07g`0Oomoog`0009oo`0501ml07ooOoml0003Ool00`0OO01oo`03Ool017`0Oomo
o`0O0Woo00=l07ooOol00goo00=l07oo01l01goo00=l07oo01l01Goo00H07gooOoml07oo01l5Ool0
0`0OO01oo`02Ool01`0OOomoo`0OO01oo`0O009oo`0301moog`000807`04Ool07`0OO004Ool017`0
Oomoog`00Woo00Il07ooO01oog`0Ool2O01AOol0051oo`@07`04Ool07goo01l2Ool01@0OOomoogoo
01l00goo00Ql000OO01l07ooO0007g`00Woo00Ml07ooOoml000OOoml0004Ool00g`001moo`03Ool0
1W`0Oomoogoo01ml00Eoo`05O01oogooOol07`05Ool01G`0Oomoogoo01l01Goo00<07g`0Ool00Woo
00<07gooOol00Woo00=l000OOol00goo00@07gooO0007`9oo`0701moogooO01oo`0OOol00P0O00=l
000OOol00Woo00El07ooOomoog`0009oo`04O01oog`0Ool4O01AOol0051oo`@07`04Ool07goo01l3
Ool01@0OOomoogoo01l00Woo00El000OO01l07oo009l000301moog`0009oo`04O01oogoo01l4Ool0
17`0Oomoo`0O0Woo00=l07ooOol00Woo00=l000OOol00goo00=l07ooOol00goo00D07gooOomoog`0
00Eoo`0301moogoo009oo`03O0007goo00=oo`0401moogooO002Ool00`0OOomoo`02Ool00g`0Ool0
7`02Ool0100OOomoog`00P0O00Eoo`0O01ml000O00=oo`04O01oogooO003Ool017`0Ooml07oo17`0
DGoo001@Ool401l01Goo01moogoo01l00Woo00D07gooOomoo`0O009oo`9l000301ml07oo009l0003
Ool07g`0009oo`05O01oog`0Ool07`02Ool00g`0Oomoo`02Ool00`0OO01oo`03Ool017`0Oomoo`0O
0Woo00=l07ooOol01Goo00<07gooO0001goo00@07gooOoml009oo`0301moogoo009oo`0301ml07oo
00=oo`0501moogooO0007`02Ool01P0OOomoo`0OO01oo`807`03Ool07g`000807`9oo`05O01oogoo
Ooml0002Ool01W`0Ooml07ooO01oo`=l055oo`00D7oo0`0O00Ioo`0OOol07goo01l3Ool01P0OOomo
ogoo01moo`=l000301ml07`0009oo`04O0007gooO002Ool01G`0Ool07gooO00017oo0W`000D07goo
Oomoog`000Aoo`0301ml07oo00Qoo`0301moogoo00Moo`0301ml07oo00=oo`0501moogooOoml0002
01l4Ool01@0OO01oogoo01l00Woo00@07gooO0007`9oo`807`04O0007`0O01l2Ool017`0Oomoog`0
0goo00Il07ooO01oog`0Ool3O01AOol0051oo`<07`06Ool07goo01moo`0O0goo00H07gooOomoo`0O
Ool3O0001Goo01ml07ooO0000Woo00@07gooOoml00=oo`0301moogoo009oo`07O01oogooOol07goo
O0001Goo00=l000OOol01goo00=l07oo01l027oo00=l000OOol017oo00<07gooO0000goo00H07goo
Oomoo`0OO003Ool01P0OOomoog`0Ool07`9oo`0301ml07oo00<07`03Ooml07oo009oo`0:O01oogoo
Ooml07ooO01oog`0Ool3O01AOol0051oo`<07`04Ool07goo01l2Ool01@0OOomoogoo01l00goo00<0
7g`0O0000W`000T07gooOoml07ooO0007gooO00017oo00El000OOomoog`000Eoo`0301moogoo00=o
o`04O01oogoo01l6Ool01G`0Oomoogoo01l01Woo00Al07ooOol07`Aoo`0301ml07oo00Aoo`0501mo
ogooO0007`03Ool0100OOomoog`00Woo00@07gooOoml00@07`05Ooml07ooOoml0003Ool01G`0Oomo
og`0Ool00W`000=oog`0O000DGoo001AOol02@0OOol07goo01moo`0OOol07`03Ool01@0OOomoogoo
01l01G`000P07g`0Oomoog`0Ool07g`00goo00El07ooOol07g`000Ioo`0301moogoo009oo`03O01o
ogoo009oo`0301moogoo009oo`03O01oogoo00=oo`0301moogoo009oo`03O01oogoo009oo`0601mo
ogooOoml000O1Goo00<07gooO0000Woo00P07gooOomoo`0OO01oo`0O0Woo00<07g`001l0100O00El
07ooOomoog`000=oo`06O01oog`0Ooml07oo0g`0DWoo001AOol301l017oo01moo`0O0Woo00D07goo
Oomoo`0O00=oo`0901ml07`0Ooml07oo01moog`0009oo`05O0007gooOoml0004Ool00`0OOomoo`03
Ool00g`0Ool07`02Ool00g`0Oomoo`04Ool0100OOomoog`01goo00@07gooOoml00Ioo`0601moogoo
O01oo`0O1Goo00=l07ooOol00Woo00@07gooOoml00=oo`0401moog`0Ool501l017`0Oomoog`00goo
00Ml07ooOoml07ooO01oo`03O01BOol0055oo`<07`07Ool07gooOol07goo01l00goo00D07gooOomo
o`0O00=l0004Ooml000OO003Ool017`0Ool07g`017oo00=l07oo01l00goo00Il07ooOomoo`0OO008
Ool00`0OO01oo`08Ool00`0OO01oo`07Ool00`0OO01oo`02Ool01`0OOomoogooO01oo`0O00=oo`05
01moog`0Ool07`02Ool00`0OOoml000201l017oo01l07g`00goo00Ml07ooOomoog`0Ooml0002Ool0
0g`0Ooml0002O01BOol0055oo`<07`05Ool07gooOol07`02Ool01@0OOomoogoo01l00Woo00Ql000O
Ooml07ooO01oo`0O0Woo00El07ooOol07g`000=oo`05O01oogooOol07`02O004Ool00g`001moo`07
Ool00g`001moo`08Ool00g`001moo`07Ool00g`001moo`03Ool201l01G`0Oomoogoo01l00goo00D0
7g`0Oomoo`0O009oo`04O01oo`0OOol201l01G`001moogooO0000goo00Al07ooOoml009oo`9l0003
Ooml07`0059oo`00DGoo0P0O00Aoo`0OOol07`9oo`0301moo`0O00Aoo`0501moog`001moo`02O000
1GooO01oo`0OO0000goo00El000OOomoog`000Aoo`0301moogoo00=oo`04O01oogoo01l6Ool017`0
Oomoo`0O1goo00Al07ooOol07`Ioo`04O01oogoo01l5Ool01G`0Oomoogoo01l00goo00Ql000OOomo
o`0OOoml000O0Woo0P0O00Eoog`001moog`000Aoo`03O01oog`0009oo`04O01oog`0Ool2O01BOol0
055oo`807`04Ool07goo01l2Ool0100OOomoo`0O0goo00D07gooO01l000O009l0005Ooml07oo01ml
0002Ool01W`0Oomoo`0OOoml00=oo`03O01oo`0O00=oo`03O01oogoo009oo`0301moogoo009oo`03
O01oogoo009oo`0301moogoo00=oo`03O01oogoo009oo`0301moogoo009oo`03O01oogoo009oo`07
01moogooOoml07oo01l00goo00D07gooO01oo`0O00=oo`0501ml07oo01moo`0201l01G`001l07goo
O0000goo00Al07ooOoml009oo`05O01oog`0Ooml001COol0059oo`<07`05Ool07gooOol07`02Ool0
0`0OOomoo`02Ool01`0OO01l07`001moog`0009oo`05O0007gooOoml0003Ool01@0OOomoogooO000
0goo00<07gooO0001Woo00@07gooOoml00Ioo`0501moogooOoml0006Ool0100OOomoog`01Woo00<0
7gooO0000Woo00<07gooOol00Woo00El07ooOomoo`0O009oo`07O0007goo01moo`0OO0000`0O00=l
07ooOol00Woo00Al07ooOoml009oo`03O01oog`0009l05=oo`00DWoo0P0O00Aoo`0OOol07`9oo`04
01moogoo01l3Ool00`0OO01l0002O000100OO01oog`00Woo00<07g`0Ool00Woo00=l000OOol00Woo
00=l07ooOol00Woo00=l07ooOol01Woo00<07g`0Ool01goo00<07gooO00027oo00<07g`0Ool01goo
00<07gooOol00Woo00H07gooOoml07oo01l2Ool01@0OOoml07oo01l00Woo00<07g`001l00`0O00El
07ooOomoog`0009oo`07O01oogooO01oog`0Ool00W`0Dgoo001BOol201l017oo01moo`0O0Woo00@0
7gooOol07`=oo`06O0007g`0O01oo`0O0Woo00El07ooOol07g`0009oo`06O01oogoo01moog`017oo
00=l07oo01l01goo00=l000OOol01goo00=l000O01l027oo00=l000OOol01Woo00=l07oo01l017oo
00<07gooO0000Woo00D07gooOol07g`0009oo`0901moo`0OO0007goo01ml000O00=oo`04O01oogoo
O002Ool017`0Ooml07oo0W`0Dgoo001BOol201l01Goo01moogoo01l00Woo00@07gooOol07`9oo`08
O0007g`0O01oog`001ml00=oo`04O0007gooO004Ool00`0OOomoo`02Ool01G`0Oomoogoo01l01Goo
00Al07ooOol07`Ioo`05O01oogooOol07`06Ool017`0Oomoo`0O1Goo00El07ooOomoo`0O00Aoo`03
O01oogoo009oo`0401moog`001l2Ool01@0OOoml000OOol00P0O00El000OOomoog`0009oo`04O01o
ogooO002Ool00g`0Ooml001DOol005=oo`<07`9oo`0401moogoo01l2Ool00`0OOomoo`02O0001P0O
O01oog`0Ool07`9oo`04O01oogoo01l4Ool00g`0Ool07`02Ool00g`0Oomoo`02Ool00`0OOomoo`02
Ool00g`0Oomoo`02Ool00`0OOomoo`02Ool00g`0Oomoo`03Ool00`0OOomoo`02Ool00g`0Oomoo`02
Ool01@0OOomoogooO0001Goo00H07gooOoml07oo01l4Ool017`0Oomoo`0O0Woo00Il07oo01moo`0O
O00201l2Ool017`0Oomoog`00Woo00=l07ooOol00g`0E7oo001COol201l01Goo01moogoo01l00Woo
00D07gooOol07goo00=l000701ml07ooO0007gooO0000Woo00=l07oo01l00Woo00Il07ooOomoo`0O
O006Ool0100OOomoog`01Woo00@07gooOoml00Moo`0401moogooO006Ool0100OOomoog`01Woo00<0
7g`0Ool00Woo00D07gooOoml000O00=oo`0301moog`0009oo`0301ml000O00807`05Ooml07ooOoml
0002Ool01G`0Oomoog`0Ool00W`0E7oo001COol201l01Goo01moogoo01l00Woo00D07gooOomoo`0O
00=l000601ml07ooO01oo`0O0goo00El07oo01moog`000Aoo`03O0007goo00Ioo`0301ml07oo00Mo
o`0301ml07oo00Qoo`0301ml07oo00Moo`0301ml07oo00Ioo`03O0007goo00=oo`0501moog`0Ool0
7`03Ool01W`0Ool07goo01ml00<07`05O01oogooOoml0002Ool01G`0Oomoog`0Ool00W`0E7oo001D
Ool301l2Ool01@0OOomoogoo01l00Woo00<07g`0O0000W`000P07g`0Ooml07oo01moog`00goo00<0
7gooOol00Woo00Al07ooOol07`Ioo`03O0007goo00Moo`03O0007goo00Qoo`03O0007goo00Moo`03
O0007goo00Eoo`04O01oogoo01l4Ool037`0Oomoogoo01moog`001moo`0OOoml00@07`04O01oogoo
O003Ool00g`0Oomoo`03O01EOol005Aoo`807`05Ool07gooOol07`02Ool01@0OOomoogoo01l00g`0
00L07g`0Ooml07oo01ml0003Ool00g`0Ool07`02Ool00g`0Oomoo`02Ool00`0OOomoo`02Ool017`0
Oomoo`0O1Woo00Al07ooOol07`Moo`04O01oogoo01l6Ool017`0Oomoo`0O17oo00=l07ooOol00Woo
00H07gooOoml07oo01l3Ool01`0OO01oo`0OOol07g`000<07`05O01oogooOoml0002Ool01G`0Oomo
og`0Ool00W`0EGoo001DOol201l01Goo01moogoo01l00goo00@07gooOol07`Al000301ml07oo009o
o`0401moogooO003Ool00`0OO01oo`05Ool0100OOomoog`017oo00<07gooOol00Woo00=l07ooOol0
0Woo00<07gooOol00goo00=l07ooOol00Woo00<07gooOol00Woo00=l07ooOol00Woo00@07gooOoml
00Ioo`0301ml07oo009oo`0401moogooO003Ool01`0OO0007`0OOol07g`0009oo`05O01oogooOoml
0002Ool2O0000gooO01oo`1DOol005Aoo`0501moo`0OOol07`02Ool01@0OOomoo`0OOol00W`000D0
7g`0O01l000O00=oo`04O01oo`0OO004Ool00g`001moo`06Ool00`0OO01oo`05Ool201l00gooO01o
o`05Ool01@0OOomoogooO0001Woo00@07gooO01l00Ioo`0301ml07oo00Ioo`03O0007goo009oo`05
01moog`0Ool07`02Ool00`0OO0007`0201l01G`001moogooO0000Woo00Ql07ooOoml07ooO01oog`0
EGoo001EOol201l01Goo01moogoo01l00goo00D07g`0O0007goo00=l000301moog`000=oo`0501mo
ogooOoml0002Ool00`0OOomoo`04Ool00g`001moo`07Ool00`0OOomoo`06Ool00`0OOoml0008Ool0
0g`0Oomoo`06Ool00g`001moo`05Ool017`0Oomoo`0O0goo00Ml07ooOomoo`0OOoml000401l017`0
01l07g`00goo00El07ooOoml07oo009l05Ioo`00EGoo00D07goo01moo`0O009oo`0401moogoo01l3
O0000`0OO01l0002Ool02@0OOomoogooO01oo`0OOoml0004Ool00`0OOomoo`02Ool017`0Oomoo`0O
1Woo00=l07oo01l01goo00=l000O01l01goo00=l07oo01l01Woo00Al07ooOol07`Aoo`03O01oogoo
009oo`0501moog`0Ool07`02Ool00`0OO01oo`0301l01G`001l07`0OO0000Woo00Ql07ooOoml07oo
O01oog`0EWoo001EOol01@0OOol07goo01l00Woo00D07gooOomoo`0O00=l000801ml07ooOoml000O
Ooml009oo`0301ml07oo00Eoo`0401moogooO004Ool00`0OOomoo`02Ool01G`0Oomoogoo01l01Goo
00El07ooOomoo`0O00Eoo`05O01oogooOol07`04Ool00g`0Oomoo`02Ool0100OOomoog`01Woo00P0
7g`0Oomoo`0OOoml000O0Woo00<07g`001l00P0O00El07ooOomoog`0009oo`05O01oog`0Ooml001F
Ool005Ioo`807`9oo`0401moogoo01l2Ool01G`001ml07`001l00g`000=oo`0OO0000goo00=l000O
Ool01Woo00<07g`0Ool01Goo00@07gooOoml00Eoo`0501moogooOoml0005Ool01@0OOomoogooO000
1Goo00@07gooOoml00Ioo`0301ml07oo00Ioo`03O0007goo009oo`03O01oogoo00<07`05O0007`0O
O0007`02Ool027`0Oomoog`0Ooml07ooO01GOol005Ioo`0501moo`0OOol07`02Ool01@0OOomoog`0
01l00g`000H07g`0Oomoog`001l2Ool017`0Oomoo`0O1Woo00=l000OOol01Woo00<07g`0Ool01Woo
00<07gooO0001goo00<07gooO0001goo00<07g`0Ool01Woo00=l000OOol01Goo00Al07ooOol07`9o
o`06O0007gooOol07g`00`0O00El000OOomoog`0009oo`05O01oog`0Ooml001GOol005Moo`807`9o
o`0501moogoo01moo`02O0001@0OO01oog`001l00W`00Woo00<07g`0Ool00goo00<07gooOol00Woo
00=l07oo01l01goo00=l000OOol01goo00<07gooOol01goo00=l07ooOol01Woo00=l000OOol01Goo
00Al07ooOol07`Aoo`03O01oogoo009oo`0401ml07ooOol201l01G`001moo`0OO0000P0O00Uoog`0
Oomoog`0Ooml07ooO000F7oo001GOol01@0OOol07goo01l00Woo00X07gooO01l000OO01oog`0Ool0
7`=oo`03O0007goo00Aoo`0401moogooO003Ool00`0OOomoo`03Ool017`0Oomoo`0O1Goo0W`000=o
o`0OOol01Woo00Al07oo01l07`Eoo`04O01oogoo01l5Ool01G`0Oomoogoo01l00Woo00=l07ooOol0
0goo00=l000OOol00Woo00Il07oo01moo`0OO00201l02GooO01oogooO01oog`0Ooml001HOol005Qo
o`807`9oo`0401moogoo01l3O0001@0OO01l07`001l00Woo00Al07ooOol07`Eoo`0301ml07oo00Ao
o`0301moogoo009l00Aoo`0501moogooOoml0004Ool00`0OOomoo`03Ool00g`0Oomoo`02Ool01@0O
OomoogooO00017oo0P0O0Woo00=l07ooOol00goo00<07g`0Ool017oo00Al07ooOol07`9oo`05O000
7`0O01ml000301l027`0Oomoog`0Ooml07ooO01IOol005Qoo`0501moo`0OOol07`02Ool01@0OO01l
07`001l017`000<07g`0Ool00Woo00<07gooOol00Woo00=l000OOol01Woo00<07g`0Ool01Woo00<0
7gooO0001Woo00D07gooOomoog`000Ioo`0301moog`000Moo`0301ml07oo00Eoo`03O01oo`0O00Ao
o`06O01oogooOol07g`0100O00El000O01l07g`0009oo`05O01oog`0Ooml001IOol005Qoo`0901mo
ogoo01moo`0OOoml000O009l0007Ool07g`0O01oog`001l017oo00@07gooOoml009oo`0301moogoo
00Aoo`03O0007goo00Moo`0301moogoo00Ioo`0301moog`000Qoo`03O01oogoo00Ioo`03O0007goo
00Eoo`04O01oogoo01l2Ool00g`0Oomoo`02Ool00g`001moo`0201l037`0Ool07`0OO0007gooO01o
og`0Ooml05Yoo`00FGoo00<07goo01l00Woo00P07g`0O0007g`0Ooml000O0g`000<07gooOol00goo
00<07g`0Ool00goo00<07gooOol00Woo00Al07ooOol07`Ioo`03O01oo`0O00Moo`03O0007`0O00Mo
o`03O01oo`0O00Ioo`04O01oogoo01l4Ool00g`0Oomoo`02Ool00`0OO01oo`04Ool02G`001l07`0O
O0007goo01ml000201l01W`0Oomoog`0Ooml05Yoo`00FGoo00H07gooOol07goo01l2O0002P0OO01l
07`001ml07ooO01oo`0O0goo0W`000<07gooOol00goo00@07gooO01l00Aoo`807`=oo`05O01oogoo
Ool07`05Ool01G`0Oomoogoo01l01Goo00El07ooOomoo`0O00=oo`9l00Aoo`807`03Ooml07oo00Ao
o`03O0007`0O00=oo`06O01oo`0OOol07g`00`0O00Ql000O01ml07ooO01oog`0Fgoo001JOol01P0O
Ool07gooO0007`9l000501ml07ooO0007`02O002Ool00`0OOoml0002Ool00`0OOomoo`04Ool00g`0
Oomoo`06Ool00`0OOoml0005Ool01@0OOomoogooO0001Goo00D07gooOomoog`000Eoo`0301moog`0
00Qoo`0301moogoo00Aoo`0?O01oogoo01moog`0Ool07goo01ml000OOol07g`000807`06O0007goo
O01oog`0Fgoo001JOol0100OOomoo`0O0W`000@07g`0O0007`9l0007Ool07gooO01oo`0OO00017oo
00<07gooOol00Woo00=l07oo01l027oo00=l07ooOol01Goo0P0O00=l07ooOol01Goo00<07g`0O000
1goo00<07gooOol01Woo00=l07oo01l017oo00=l07ooOol00Woo00L07g`0Ool07gooO01oo`0201l0
17`001l07g`00P0O00=l07ooO000G7oo001KOol00`0OOol07`02O000200OO01l000OOoml07oo01l2
O0000gooO0007`05Ool0100OOomoog`00goo00<07gooOol00goo0W`000=oo`0OOol01Goo00=l07oo
01l01goo00=l07oo01l01Woo00Al07oo01l07`Eoo`05O01oogooOol07`02Ool00g`0Oomoo`03Ool0
2W`001l07goo01ml07oo01moog`00P0O00Il000O01ml07ooO01LOol005]oo`0401moogoo01l2O000
1@0OO01l000OO0000Woo00<07g`0O0000Woo00<07gooOol00goo00<07g`0Ool017oo00D07gooOomo
og`000Aoo`0401moogooOol2O003Ool00`0OOomoo`03Ool017`0Oomoogoo0P0O0goo00=l07ooOol0
0Woo00D07gooOomoog`000Eoo`0301ml07oo00Aoo`03O01oogoo00807`05O01oogoo01ml000201l0
1W`001l07g`0Ooml05eoo`00G7oo00@07gooO0007`9l000:01ml07`001ml07ooO0007gooO002Ool0
1`0OOomoogooO01oo`0O00Ioo`0301ml07`000Ioo`0301moog`000Ioo`0501moogooOoml0006Ool0
0`0OOoml0006Ool201l00g`0Oomoo`04Ool00g`0Ool07`03Ool02W`0Oomoo`0OOoml000OOol07g`0
0P0O00Ml000O01ml000OOoml001MOol005aoo`0401ml07`001l2O0002P0OO01oog`001ml07ooO000
7g`00Woo00@07gooOoml00=oo`0301moogoo00=oo`03O0007goo00Moo`0301moogoo00Ioo`0301mo
og`000Qoo`03O01oogoo00Ioo`03O0007goo00Aoo`07O01oogooOol07gooO0000goo00X07g`001mo
o`0OO0007goo01ml00807`03O0007g`005ioo`00GGoo01007g`0O0007gooO0007gooO0007g`0Ooml
000OOoml009oo`0301ml07oo00Aoo`0301moogoo009l009oo`0301moogoo00=oo`9l0003Ool07goo
00Ioo`03O0007`0O00Moo`04O01oo`0O01l5Ool00g`0Oomoo`0201l2Ool00g`0Oomoo`03Ool01`0O
O01oogoo01ml000O009oo`08O0007`0OOoml000OOoml00807`03O01oogoo05aoo`00G7oo00=l000O
O0000W`000L07g`0O0007g`0Ool07`02Ool017`001ml07oo0W`000<07gooOol017oo0W`01Goo0P0O
0Woo00=l07ooOol00Woo00<07gooOol00goo00El07ooOomoo`0O00Eoo`03O01oogoo009oo`0301mo
ogoo009l00Eoo`807`Ioo`07O0007`0OOol07g`001l00Woo00Ul07oo01ml07oo01ml000OOol00`0O
GGoo001LOol2O000100OOoml000O0W`000X07g`0Ooml000OOoml07oo01ml00=oo`0301moogoo009o
o`03O01oo`0O00Moo`0301ml07oo00Eoo`0501moogooOoml0005Ool01@0OOomoogooO0001Woo00<0
7g`0Ool01Woo00=l07oo01l017oo00il07ooOomoo`0OO01oo`0OOoml07oo01moog`00P0O00Al000O
Ooml00807eeoo`00Fgoo17`000`07g`0O0007gooO0007g`0Ooml000OOol2O0000`0OOomoo`02Ool0
100OOomoog`00goo0P0O1Goo00=l000OOol01Woo0P0O00=l07ooOol01Goo00<07g`0O0001goo00=l
000OOol017oo0W`00goo00@07gooOoml00=oo`0=01ml000O01moog`001moo`0OO0007gooO0000P0O
00Al000O01l07eeoo`00Fgoo0g`000=oog`001l00W`000D07g`0Ool07goo00Al009oo`0301moogoo
009oo`0301ml07oo00Eoo`0301moogoo009l009oo`0301moogoo00Aoo`9l000301moogoo00Eoo`03
O0007`0O00Ioo`03O01oogoo00807`9oo`03O01oogoo00Aoo`0301ml07oo00=oo`03O01oogoo00<0
7`9oo`09O0007gooO01oo`0OO0007goo00@07e]oo`00FWoo17`000Moog`001ml07ooO0007`02O000
2@0OO01l07oo01ml07ooO0007`02Ool017`0Ool07`0O1Woo00<07g`0Ool017oo00<07gooOol00Woo
00El07ooOomoo`0O00Eoo`05O01oogooOol07`04Ool00g`0Oomoo`03Ool00`0OO01oo`05Ool2O000
1Goo01moogooO0000Woo00<07g`0Ool00P0O00Yl07oo01ml000OOol07g`001moo`@07e]oo`00FGoo
27`000@07gooO0007`9l000601moog`0Ool07g`00Woo00=l000OO00017oo00<07gooOol00goo00=l
000OOol01Goo0P0O00=oog`0Ool017oo0P0O00=oog`0O0001Goo00@07gooO01l00Ioo`03O0007goo
00Aoo`03O01oogoo009oo`0301ml000O009oo`05O01oo`0OOoml000201l01GooO0007`0OO000200O
FWoo001HOol00g`0Ooml0006O0001Goo01moog`001l00W`000D07gooO01oo`0O00Al000301moogoo
00=oo`0301moogoo009l009oo`0301moogoo00Aoo`03O0007goo00Moo`0301moogoo00Ioo`03O000
7goo00Eoo`03O01oogoo00807`9oo`03O01oogoo00=oo`03O0007`0O00807`0<O01oo`0OOoml07oo
01ml000OOoml07oo1`0O00=oo`0OOol0F7oo001JOol7O0002WooO01l07`0Ool07gooO0007g`00Woo
00Il07ooOoml07oo01l5Ool2O005Ool0100OOomoogoo0W`00Woo00<07gooOol00goo0W`000=oo`0O
01l01Goo00=l07ooOol00P0O0goo00=l07ooOol00goo0P0O1Goo00Al000OOomoo`807`04Ool07goo
O00201l00g`0Ool07`0201l00goo01l07`0501mKOol005]oo`Al000<Ooml07`0Ooml000OO01oo`0O
Ooml000O0W`000Moo`0OOomoog`0Ool07`02Ool2O0000goo01moo`05Ool00`0OO01l0005Ool01@0O
OomoogooO0001Goo00D07gooOomoog`000Eoo`807`03O01oogoo00Aoo`04O01oo`0O01l2Ool00g`0
Ool07`02Ool03G`0Ool07`0OO0007gooO01oo`0OO0007goo00807`03Ool07`0O00807eaoo`00G7oo
1W`000Moog`0Ool07gooO0007`02O0001@0OO01oogoo01l00Woo00Al07oo01ml00Aoo`0301moogoo
009oo`9l000301moogoo00Eoo`807`03O01oogoo00Eoo`0301ml07`000Moo`03O0007`0O00Aoo`03
O01oogoo009oo`0401ml07oo01l2Ool01G`0Oomoo`0OO0000P0O00Ml07oo01ml07oo01moo`0601mM
Ool005eoo`=l0004Ooml07`0Ool4O0001@0OOoml07oo01l00Woo00=l000O01l00W`000=oo`0OOol0
17oo00@07gooO01l00=oo`807`Aoo`9l0003Ool07goo00Ioo`04O01oo`0O01l4Ool2O003Ool201l0
0gooO01oo`04Ool017`0Ool07`0O0W`00Woo00H07g`0Ool07gooO00401l017oo01l07goo0`0OGWoo
001OOol6O0002GooO0007goo01moog`0Ool07`02Ool2O0001@0OO01oogoo01l017oo00=l000OOol0
1Woo00@07gooOoml00Aoo`0301moogoo00=oo`03O01oogoo009oo`0401moogooO007Ool00g`001mo
o`03Ool01G`0Ool07gooO0000P0O0Woo00Ql07oo01moog`0Ooml07oo1`0OH7oo001POol037`0Ooml
07`0Ooml07ooO0007g`001moo`El009oo`0601ml07ooOol07goo0W`00Woo0P0O1Woo0P0O1Woo0P0O
00=oog`0O0001Woo0W`01Woo0W`00Woo0P0O00Uoog`0Oomoo`0OO01oo`0OOol0100O00Qoog`001ml
000OOol07goo100OHGoo001QOol8O000100OO01l07`00Woo00<07gooO0000Woo00<07g`0Ool00W`0
1Woo00@07gooOomoo`9l009oo`0301moogoo00Aoo`03O0007`0O00Ioo`03O01oogoo00807`=oo`03
O01oogoo00Aoo`807`03Ool07g`0009oo`0301moog`0009oo`<07`03O0007`0O00H07f9oo`00HWoo
0W`000Qoog`0O01oog`001ml07oo0P0O0Woo00<07gooO0000Woo0P0O0Woo0P0O1Goo0P0O00=l07oo
Ool00goo0P0O0Woo0W`00goo0P0O0Woo0W`01Goo00<07g`0O0001Goo0W`00Woo0W`00Woo00<07goo
O0000Woo0W`000D07gooO0007goo00807`03Ool07`0O06=oo`00I7oo17`000Aoog`001ml009oo`04
01moogoo01l3O002Ool01@0OOomoogoo01l00goo0W`000=oo`0OOol01Woo0P0O1goo0W`01goo00Al
07oo01l07`=oo`05O01oogooOoml0002Ool301l017`0Oomoog`00Woo00@07g`001moo`@07fEoo`00
IGoo1W`000<07g`0O00017`000@07gooOoml009oo`0501moogooOol07`02O004Ool201l3Ool2O002
Ool00`0OOomoo`03Ool00g`0Oomoo`0201l3Ool2O004Ool201l01G`0OomoogooO0000Woo00@07goo
Ooml00H07`03O0007`0O00@07fIoo`00Igoo0g`000Yoog`001l07gooO0007gooO0007`9oo`04O01o
ogoo01l2O0000goo01l07`06Ool201l00g`0Oomoo`03Ool201l00gooO01l0005Ool00`0OO01l0006
Ool2O00017oo01l07g`00Woo00@07gooOoml009oo`03O0007goo009l000301moo`0O00807fQoo`00
J7oo1W`00P0O00Al000O01ml00807`Al00807`=oo`807`=oo`9l0003Ool07goo00Eoo`03O0007`0O
00Ioo`04O01oo`0O01l3Ool2O003Ool2O00401l2O000100OO01l000O0W`01P0OJGoo001ZOol2O000
0gooO01l0004O0000`0OO01oo`0201l01G`0Oomoogoo01l00goo00Al000OO01l00Aoo`807`04Ooml
07`0O003Ool301l00gooO01l0004Ool201l00g`001moo`02Ool01G`0Oomoogoo01l00W`000=oo`0O
O0001P0O00=oo`0O01l0Jgoo001/Ool5O00201l027`001ml07`0Ool07g`0Ool2O0000`0OO01l0003
Ool201l4Ool00g`001l07`07Ool2O0000`0OOomoo`02Ool2O003Ool201l01g`001l07goo01ml07oo
00807`04O0007g`0O00501m]Ool006ioo`El000401ml000O01l5O002Ool201l5Ool201l2O003Ool2
01l3Ool2O003Ool201l2O005Ool2O002Ool501l2O0000`0OO0007`0401m_Ool0071oo`Al0003Ool0
7g`000807`9oo`807`=oo`807`=l009oo`807`Eoo`<07`Eoo`9l009oo`<07`9l00=oo`9l009oo`9l
000301ml07oo00@07g5oo`00Lgoo1W`000D07g`0O01l000O009l0004Ooml000O01l5Ool201l3O003
Ool301l2O005Ool2O0001@0OOol07`0OO0000`0O00=l000O01l0100OM7oo001eOol3O00501l2Ool2
01l2Ool00g`001l07`04O00017oo01l07`0O0goo0g`000=oo`0O01l00P0O0W`000<07gooOol00W`0
0Woo1G`00`0OMWoo001hOol5O00201l2O0000`0OO01l0002O00401l4Ool301l4Ool4O00401l00g`0
01l07`02O00501miOol007aoo`04O0007`0OO00201l00gooO0007`0201l3O00201l2O0000`0OOoml
000201l2O00301l3O0001@0OOoml07`001l00W`000<07gooOol0Ngoo0021Ool00g`001ml0003O004
01l4O00501l4O00401l00g`001moo`21Ool008Ioo`807`=l00H07`=l00<07`9l08Moo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {618.563, 389.188}} -> {-0.399192, \
1.69674, 0.00348777, 0.00348777}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["The rotation matrix about the z-axis by ",
    FontFamily->"New York"],
  Cell[BoxData[
      \(TraditionalForm\`\(-\(\[Pi]\/4\)\)\)]],
  StyleBox[", is given by \"zrotneg.\" Thus,",
    FontFamily->"New York"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[\[Theta]]\), "\[IndentingNewLine]", 
    \(\(Equ10 = zrot[\[Pi]\/4] . Equ6;\)\), "\[IndentingNewLine]", 
    \(MatrixForm[%]\)}], "Input",
  TextJustification->1],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/2 + Cos[\[Theta]]\/2\), \(\(-\(1\/2\)\) + 
                Cos[\[Theta]]\/2\), \(Sin[\[Theta]]\/\@2\)},
            {\(\(-\(1\/2\)\) + Cos[\[Theta]]\/2\), \(1\/2 + 
                Cos[\[Theta]]\/2\), \(Sin[\[Theta]]\/\@2\)},
            {\(-\(Sin[\[Theta]]\/\@2\)\), \(-\(Sin[\[Theta]]\/\@2\)\), \(Cos[\
\[Theta]]\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ComponentFunct[Equ10, {R\ \ Cos[\[Phi]], 0, R\ \ Sin[\[Phi]]}, 
        Blue];\)\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.38348 .3637 m
.3999 .34991 L
s
.36783 .37838 m
.38348 .3637 L
s
.35303 .39386 m
.36783 .37838 L
s
.3999 .34991 m
.41699 .33708 L
s
.33916 .41008 m
.35303 .39386 L
s
.41699 .33708 m
.43469 .32527 L
s
.32629 .42694 m
.33916 .41008 L
s
.43469 .32527 m
.45289 .31455 L
s
.3145 .44437 m
.32629 .42694 L
s
.45289 .31455 m
.47151 .305 L
s
.30386 .46228 m
.3145 .44437 L
s
.47151 .305 m
.49044 .29667 L
s
.29444 .48057 m
.30386 .46228 L
s
.49044 .29667 m
.5096 .28962 L
s
.2863 .49915 m
.29444 .48057 L
s
.5096 .28962 m
.52887 .28391 L
s
.27951 .51792 m
.2863 .49915 L
s
.52887 .28391 m
.54816 .27958 L
s
.27413 .53679 m
.27951 .51792 L
s
.54816 .27958 m
.56735 .2767 L
s
.27021 .55563 m
.27413 .53679 L
s
.56735 .2767 m
.58632 .2753 L
s
.26781 .57434 m
.27021 .55563 L
s
.58632 .2753 m
.60497 .27541 L
s
.26696 .5928 m
.26781 .57434 L
s
.60497 .27541 m
.62316 .27708 L
s
.26772 .6109 m
.26696 .5928 L
s
.62316 .27708 m
.64078 .28032 L
s
.27011 .62851 m
.26772 .6109 L
s
.64078 .28032 m
.65769 .28515 L
s
.27416 .64551 m
.27011 .62851 L
s
.65769 .28515 m
.67377 .29158 L
s
.27987 .66175 m
.27416 .64551 L
s
.67377 .29158 m
.68889 .29961 L
s
.28727 .67713 m
.27987 .66175 L
s
.68889 .29961 m
.70292 .30922 L
s
.29632 .69149 m
.28727 .67713 L
s
.70292 .30922 m
.71572 .32039 L
s
.30702 .70472 m
.29632 .69149 L
s
.71572 .32039 m
.72717 .33307 L
s
.31934 .71668 m
.30702 .70472 L
s
.72717 .33307 m
.73715 .34721 L
s
.33321 .72725 m
.31934 .71668 L
s
.73715 .34721 m
.74554 .36274 L
s
.34857 .73631 m
.33321 .72725 L
s
.74554 .36274 m
.75224 .37957 L
s
.36534 .74374 m
.34857 .73631 L
s
.75224 .37957 m
.75713 .3976 L
s
.38342 .74944 m
.36534 .74374 L
s
.75713 .3976 m
.76014 .41671 L
s
.40268 .75332 m
.38342 .74944 L
s
.76014 .41671 m
.7612 .43677 L
s
.423 .75531 m
.40268 .75332 L
s
.7612 .43677 m
.76025 .45762 L
s
.44421 .75534 m
.423 .75531 L
s
.76025 .45762 m
.75725 .47909 L
s
.46614 .75338 m
.44421 .75534 L
s
.75725 .47909 m
.7522 .501 L
s
.48862 .74939 m
.46614 .75338 L
s
.7522 .501 m
.74509 .52317 L
s
.51144 .74339 m
.48862 .74939 L
s
.74509 .52317 m
.73596 .54538 L
s
.53439 .73539 m
.51144 .74339 L
s
.73596 .54538 m
.72487 .56743 L
s
.55727 .72544 m
.53439 .73539 L
s
.72487 .56743 m
.7119 .58912 L
s
.57985 .71362 m
.55727 .72544 L
s
.7119 .58912 m
.69714 .61022 L
s
.60191 .70002 m
.57985 .71362 L
s
.69714 .61022 m
.68074 .63053 L
s
.62323 .68476 m
.60191 .70002 L
s
.68074 .63053 m
.66284 .64985 L
s
.64361 .66798 m
.62323 .68476 L
s
.66284 .64985 m
.64361 .66798 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00:1ooaD07f]oo`00Vgoo1@0O5Goo1@0OIWoo002FOol5
01lOOol401mROol009Aoo`807bQoo`807f1oo`00TGoo0`0O;7oo0P0OGWoo002>Ool301laOol201mL
Ool008]oo`<07cIoo`807eYoo`00RGoo0P0O>goo00<07gooOol0Egoo0027Ool201lnOol201mGOol0
08Eoo`807d9oo`0301moogoo05Aoo`00Pgoo0P0OAGoo00<07gooOol0Dgoo0021Ool201m8Ool201mC
Ool007moo`807daoo`0301moogoo051oo`00OGoo0P0OCgoo00<07gooOol0Cgoo001lOol00`0OOomo
o`1?Ool00`0OOomoo`1?Ool007Yoo`807e=oo`0301moogoo04ioo`00N7oo0P0OEWoo00<07gooOol0
CGoo001gOol00`0OOomoo`1GOol00`0OOomoo`1<Ool007Ioo`0301moogoo05Qoo`0301moogoo04ao
o`00M7oo0P0OG7oo00<07gooOol0Bgoo001cOol00`0OOomoo`1MOol00`0OOomoo`1:Ool0079oo`03
01moogoo05ioo`0301moogoo04Yoo`00LGoo00<07gooOol0H7oo00<07gooOol0BGoo001`Ool00`0O
Oomoo`1QOol00`0OOomoo`19Ool006moo`0301moogoo06=oo`0301moogoo04Qoo`00KWoo00<07goo
Ool0I7oo00<07gooOol0B7oo001]Ool00`0OOomoo`1UOol00`0OOomoo`18Ool006]oo`807fUoo`03
01moogoo04Moo`00JWoo00<07gooOol0JGoo00<07gooOol0Agoo001YOol00`0OOomoo`1[Ool00`0O
Oomoo`16Ool006Qoo`0301moogoo06aoo`0301moogoo04Ioo`00Igoo00<07gooOol0KWoo00<07goo
Ool0AGoo001WOol00`0OOomoo`1^Ool00`0OOomoo`15Ool006Ioo`0301moogoo06moo`0301moogoo
04Eoo`00IGoo00<07gooOol0LGoo00<07gooOol0A7oo001TOol00`0OOomoo`1bOol00`0OOomoo`14
Ool006=oo`0301moogoo07=oo`0301moogoo04Aoo`00HWoo00<07gooOol0M7oo00<07gooOol0A7oo
001QOol00`0OOomoo`1fOol00`0OOomoo`13Ool0061oo`0301moogoo07Moo`0301moogoo04=oo`00
Ggoo00<07gooOol0N7oo00<07gooOol0@goo001OOol00`0OOomoo`1hOol00`0OOomoo`13Ool005io
o`0301moogoo07Uoo`0301moogoo04=oo`00GGoo00<07gooOol0NWoo00<07gooOol0@goo001LOol0
0`0OOomoo`1kOol00`0OOomoo`13Ool005aoo`0301moogoo07]oo`0301moogoo04=oo`00Fgoo00<0
7gooOol0O7oo00<07gooOol0@goo001KOol00`0OOomoo`1lOol00`0OOomoo`13Ool005Yoo`0301mo
ogoo07eoo`0301moogoo04=oo`00FGoo00<07gooOol0OWoo00<07gooOol0@goo001IOol00`0OOomo
o`1nOol00`0OOomoo`13Ool005Qoo`0301moogoo07moo`0301moogoo04=oo`00F7oo00<07gooOol0
Ogoo00<07gooOol0@goo001GOol00`0OOomoo`20Ool00`0OOomoo`13Ool005Ioo`0301moogoo085o
o`0301moogoo04=oo`00EWoo00<07gooOol0P7oo00<07gooOol0A7oo001EOol00`0OOomoo`21Ool0
0`0OOomoo`14Ool005Eoo`0301moogoo085oo`0301moogoo04Aoo`00E7oo00<07gooOol0PWoo00<0
7gooOol0A7oo001DOol00`0OOomoo`22Ool00`0OOomoo`14Ool005=oo`0301moogoo089oo`0301mo
ogoo04Eoo`00Dgoo00<07gooOol0PWoo00<07gooOol0AGoo001COol00`0OOomoo`22Ool00`0OOomo
o`15Ool0059oo`0301moogoo089oo`0301moogoo04Ioo`00DWoo00<07gooOol0PWoo00<07gooOol0
AWoo001BOol00`0OOomoo`22Ool00`0OOomoo`16Ool0055oo`0301moogoo089oo`0301moogoo04Mo
o`00DGoo00<07gooOol0PWoo00<07gooOol0Agoo001@Ool00`0OOomoo`23Ool00`0OOomoo`17Ool0
051oo`0301moogoo08=oo`0301moogoo04Moo`00D7oo00<07gooOol0PWoo00<07gooOol0B7oo001?
Ool00`0OOomoo`23Ool00`0OOomoo`18Ool004moo`0301moogoo08=oo`0301moogoo04Qoo`00Cgoo
00<07gooOol0PWoo00<07gooOol0BGoo001>Ool00`0OOomoo`23Ool00`0OOomoo`19Ool004ioo`03
01moogoo08=oo`0301moogoo04Uoo`00CWoo00<07gooOol0PWoo00<07gooOol0BWoo001>Ool00`0O
Oomoo`22Ool00`0OOomoo`1:Ool004eoo`0301moogoo089oo`0301moogoo04]oo`00CGoo00<07goo
Ool0PWoo00<07gooOol0Bgoo001=Ool00`0OOomoo`21Ool00`0OOomoo`1<Ool004eoo`0301moogoo
085oo`0301moogoo04aoo`00CGoo00<07gooOol0P7oo00<07gooOol0CGoo001<Ool00`0OOomoo`21
Ool00`0OOomoo`1=Ool004aoo`0301moogoo081oo`0301moogoo04ioo`00C7oo00<07gooOol0P7oo
00<07gooOol0CWoo001<Ool00`0OOomoo`1oOol00`0OOomoo`1?Ool004aoo`0301moogoo07moo`03
01moogoo04moo`00C7oo00<07gooOol0OWoo00<07gooOol0D7oo001<Ool00`0OOomoo`1nOol00`0O
Oomoo`1@Ool004aoo`0301moogoo07eoo`0301moogoo055oo`00C7oo00<07gooOol0O7oo00<07goo
Ool0DWoo001<Ool00`0OOomoo`1lOol00`0OOomoo`1BOol004aoo`0301moogoo07]oo`0301moogoo
05=oo`00C7oo00<07gooOol0NWoo00<07gooOol0E7oo001<Ool00`0OOomoo`1jOol00`0OOomoo`1D
Ool004aoo`0301moogoo07Uoo`0301moogoo05Eoo`00C7oo00<07gooOol0N7oo00<07gooOol0EWoo
001<Ool00`0OOomoo`1gOol00`0OOomoo`1GOol004eoo`0301moogoo07Eoo`0301moogoo05Qoo`00
CGoo00<07gooOol0M7oo00<07gooOol0FGoo001=Ool00`0OOomoo`1cOol00`0OOomoo`1JOol004eo
o`0301moogoo079oo`0301moogoo05]oo`00CGoo00<07gooOol0LGoo00<07gooOol0G7oo001>Ool0
0`0OOomoo`1_Ool00`0OOomoo`1MOol004ioo`0301moogoo06moo`0301moogoo05eoo`00CWoo00<0
7gooOol0KWoo00<07gooOol0GWoo001>Ool00`0OOomoo`1]Ool00`0OOomoo`1OOol004moo`0301mo
ogoo06]oo`0301moogoo061oo`00Cgoo00<07gooOol0JWoo00<07gooOol0HGoo001@Ool00`0OOomo
o`1WOol201mTOol0051oo`0301moogoo06Ioo`0301moogoo06Aoo`00DGoo00<07gooOol0I7oo00<0
7gooOol0IGoo001AOol00`0OOomoo`1SOol00`0OOomoo`1VOol0059oo`0301moogoo065oo`0301mo
ogoo06Moo`00DWoo00<07gooOol0Ggoo0P0OJWoo001COol00`0OOomoo`1MOol00`0OOomoo`1ZOol0
05=oo`0301moogoo05aoo`0301moogoo06]oo`00E7oo00<07gooOol0FGoo0P0OKWoo001EOol00`0O
Oomoo`1GOol00`0OOomoo`1^Ool005Ioo`0301moogoo05Aoo`807g5oo`00EWoo00<07gooOol0Dgoo
00<07gooOol0LGoo001GOol00`0OOomoo`1@Ool201mdOol005Qoo`0301moogoo04ioo`0301moogoo
07Aoo`00FGoo00<07gooOol0Bgoo0P0OMgoo001JOol00`0OOomoo`19Ool00`0OOomoo`1gOol005]o
o`0301moogoo04Ioo`807gYoo`00G7oo00<07gooOol0@goo0P0OO7oo001MOol201m1Ool201mnOol0
05moo`0301moogoo03eoo`0301moogoo07ioo`00H7oo0P0O>goo0P0OPGoo001ROol201lgOol201n3
Ool006Aoo`0301moogoo035oo`<07hEoo`00IGoo0P0O;Goo100OR7oo001WOol301lWOol301n<Ool0
06Yoo`<07b5oo`<07hmoo`00KGoo100O67oo1@0OTWoo001aOolH01nGOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.33591 .34359 m
.35418 .32568 L
s
.31872 .36253 m
.33591 .34359 L
s
.35418 .32568 m
.37343 .30891 L
s
.3027 .38241 m
.31872 .36253 L
s
.37343 .30891 m
.39357 .29335 L
s
.28795 .40311 m
.3027 .38241 L
s
.39357 .29335 m
.41448 .27912 L
s
.27455 .42453 m
.28795 .40311 L
s
.41448 .27912 m
.43606 .26628 L
s
.26258 .44656 m
.27455 .42453 L
s
.43606 .26628 m
.45819 .25492 L
s
.25212 .46908 m
.26258 .44656 L
s
.45819 .25492 m
.48075 .24512 L
s
.24324 .49197 m
.25212 .46908 L
s
.48075 .24512 m
.50363 .23695 L
s
.23602 .5151 m
.24324 .49197 L
s
.50363 .23695 m
.5267 .23049 L
s
.23051 .53835 m
.23602 .5151 L
s
.5267 .23049 m
.54982 .22579 L
s
.22678 .56158 m
.23051 .53835 L
s
.54982 .22579 m
.57285 .2229 L
s
.22487 .58465 m
.22678 .56158 L
s
.57285 .2229 m
.59566 .22189 L
s
.22482 .60741 m
.22487 .58465 L
s
.59566 .22189 m
.6181 .22278 L
s
.22669 .62973 m
.22482 .60741 L
s
.6181 .22278 m
.64002 .22562 L
s
.23048 .65145 m
.22669 .62973 L
s
.64002 .22562 m
.66128 .23042 L
s
.23621 .67242 m
.23048 .65145 L
s
.66128 .23042 m
.6817 .23719 L
s
.2439 .69247 m
.23621 .67242 L
s
.6817 .23719 m
.70114 .24594 L
s
.25353 .71146 m
.2439 .69247 L
s
.70114 .24594 m
.71944 .25664 L
s
.26508 .72923 m
.25353 .71146 L
s
.71944 .25664 m
.73645 .26928 L
s
.27852 .74562 m
.26508 .72923 L
s
.73645 .26928 m
.752 .28379 L
s
.29378 .76047 m
.27852 .74562 L
s
.752 .28379 m
.76595 .30013 L
s
.3108 .77365 m
.29378 .76047 L
s
.76595 .30013 m
.77815 .3182 L
s
.32949 .78501 m
.3108 .77365 L
s
.77815 .3182 m
.78846 .33791 L
s
.34975 .79442 m
.32949 .78501 L
s
.78846 .33791 m
.79677 .35913 L
s
.37145 .80175 m
.34975 .79442 L
s
.79677 .35913 m
.80295 .38174 L
s
.39443 .80691 m
.37145 .80175 L
s
.80295 .38174 m
.80692 .40557 L
s
.41855 .80979 m
.39443 .80691 L
s
.80692 .40557 m
.80858 .43045 L
s
.44362 .81034 m
.41855 .80979 L
s
.80858 .43045 m
.80788 .45619 L
s
.46944 .80849 m
.44362 .81034 L
s
.80788 .45619 m
.80478 .48256 L
s
.4958 .80423 m
.46944 .80849 L
s
.80478 .48256 m
.79927 .50936 L
s
.52247 .79755 m
.4958 .80423 L
s
.79927 .50936 m
.79137 .53634 L
s
.54921 .78847 m
.52247 .79755 L
s
.79137 .53634 m
.7811 .56327 L
s
.57579 .77704 m
.54921 .78847 L
s
.7811 .56327 m
.76854 .58989 L
s
.60196 .76334 m
.57579 .77704 L
s
.76854 .58989 m
.75378 .61596 L
s
.62747 .74749 m
.60196 .76334 L
s
.75378 .61596 m
.73694 .64122 L
s
.65207 .7296 m
.62747 .74749 L
s
.73694 .64122 m
.71818 .66544 L
s
.67554 .70984 m
.65207 .7296 L
s
.71818 .66544 m
.69764 .68839 L
s
.69764 .68839 m
.67554 .70984 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo002QOolC01m/Ool009aoo`D07a=oo`D07fMoo`00VGoo0`0O7Goo0`0O
I7oo002FOol301lSOol301mQOol0099oo`@07bUoo`<07eioo`00Sgoo0`0O<7oo0`0OFgoo002;Ool4
01lfOol301mHOol008Uoo`807ceoo`807eIoo`00Qgoo0P0O@Goo0P0OE7oo0025Ool201m5Ool201mB
Ool008=oo`807dUoo`0301moogoo04moo`00PGoo0P0OC7oo00<07gooOol0CWoo001oOol201m?Ool2
01m>Ool007eoo`807e=oo`0301moogoo04]oo`00Ngoo0P0OEWoo00<07gooOol0BWoo001iOol201mI
Ool00`0OOomoo`19Ool007Moo`807eaoo`0301moogoo04Qoo`00MWoo00<07gooOol0GGoo00<07goo
Ool0Agoo001dOol201mQOol00`0OOomoo`16Ool007=oo`0301moogoo069oo`0301moogoo04Eoo`00
LGoo0P0OIWoo00<07gooOol0A7oo001`Ool00`0OOomoo`1VOol00`0OOomoo`14Ool006moo`0301mo
ogoo06Qoo`0301moogoo04=oo`00KGoo0P0OK7oo00<07gooOol0@Woo001/Ool00`0OOomoo`1]Ool0
0`0OOomoo`11Ool006]oo`0301moogoo06moo`0301moogoo041oo`00JWoo00<07gooOol0L7oo00<0
7gooOol0@7oo001YOol00`0OOomoo`1bOol00`0OOomoo`0oOol006Moo`807gIoo`0301moogoo03io
o`00IWoo00<07gooOol0Mgoo00<07gooOol0?Goo001UOol00`0OOomoo`1hOol00`0OOomoo`0mOol0
06Aoo`0301moogoo07Yoo`0301moogoo03aoo`00Hgoo00<07gooOol0Ngoo00<07gooOol0?7oo001R
Ool00`0OOomoo`1mOol00`0OOomoo`0kOol0065oo`0301moogoo07ioo`0301moogoo03]oo`00H7oo
00<07gooOol0P7oo00<07gooOol0>Woo001OOol00`0OOomoo`21Ool00`0OOomoo`0jOol005ioo`03
01moogoo089oo`0301moogoo03Yoo`00GGoo00<07gooOol0Pgoo00<07gooOol0>Woo001MOol00`0O
Oomoo`24Ool00`0OOomoo`0iOol005aoo`0301moogoo08Eoo`0301moogoo03Uoo`00Fgoo00<07goo
Ool0QWoo00<07gooOol0>Goo001JOol00`0OOomoo`28Ool00`0OOomoo`0hOol005Uoo`0301moogoo
08Uoo`0301moogoo03Qoo`00F7oo00<07gooOol0RWoo00<07gooOol0>7oo001GOol00`0OOomoo`2<
Ool00`0OOomoo`0gOol005Ioo`0301moogoo08eoo`0301moogoo03Moo`00EGoo00<07gooOol0SWoo
00<07gooOol0=goo001EOol00`0OOomoo`2>Ool00`0OOomoo`0gOol005Aoo`0301moogoo08moo`03
01moogoo03Moo`00Dgoo00<07gooOol0TGoo00<07gooOol0=Woo001COol00`0OOomoo`2AOol00`0O
Oomoo`0fOol0059oo`0301moogoo099oo`0301moogoo03Ioo`00DGoo00<07gooOol0Tgoo00<07goo
Ool0=Woo001AOol00`0OOomoo`2COol00`0OOomoo`0fOol0051oo`0301moogoo09Aoo`0301moogoo
03Ioo`00Cgoo00<07gooOol0UGoo00<07gooOol0=Woo001?Ool00`0OOomoo`2FOol00`0OOomoo`0e
Ool004ioo`0301moogoo09Moo`0301moogoo03Eoo`00CWoo00<07gooOol0Ugoo00<07gooOol0=Goo
001=Ool00`0OOomoo`2HOol00`0OOomoo`0eOol004eoo`0301moogoo09Qoo`0301moogoo03Eoo`00
C7oo00<07gooOol0VGoo00<07gooOol0=Goo001<Ool00`0OOomoo`2IOol00`0OOomoo`0eOol004]o
o`0301moogoo09Uoo`0301moogoo03Ioo`00Bgoo00<07gooOol0VGoo00<07gooOol0=Woo001:Ool0
0`0OOomoo`2JOol00`0OOomoo`0fOol004Yoo`0301moogoo09Yoo`0301moogoo03Ioo`00BGoo00<0
7gooOol0Vgoo00<07gooOol0=Woo0019Ool00`0OOomoo`2KOol00`0OOomoo`0fOol004Qoo`0301mo
ogoo09aoo`0301moogoo03Ioo`00B7oo00<07gooOol0Vgoo00<07gooOol0=goo0018Ool00`0OOomo
o`2KOol00`0OOomoo`0gOol004Moo`0301moogoo09aoo`0301moogoo03Moo`00Agoo00<07gooOol0
W7oo00<07gooOol0=goo0016Ool00`0OOomoo`2MOol00`0OOomoo`0gOol004Ioo`0301moogoo09eo
o`0301moogoo03Moo`00AGoo00<07gooOol0WWoo00<07gooOol0=goo0015Ool00`0OOomoo`2NOol0
0`0OOomoo`0gOol004Eoo`0301moogoo09eoo`0301moogoo03Qoo`00A7oo00<07gooOol0WWoo00<0
7gooOol0>7oo0014Ool00`0OOomoo`2NOol00`0OOomoo`0hOol004Aoo`0301moogoo09ioo`0301mo
ogoo03Qoo`00@goo00<07gooOol0Wgoo00<07gooOol0>7oo0013Ool00`0OOomoo`2OOol00`0OOomo
o`0hOol004=oo`0301moogoo09ioo`0301moogoo03Uoo`00@goo00<07gooOol0WWoo00<07gooOol0
>Goo0013Ool00`0OOomoo`2NOol00`0OOomoo`0iOol0049oo`0301moogoo09moo`0301moogoo03Uo
o`00@Woo00<07gooOol0WWoo00<07gooOol0>Woo0012Ool00`0OOomoo`2NOol00`0OOomoo`0jOol0
049oo`0301moogoo09ioo`0301moogoo03Yoo`00@Woo00<07gooOol0WGoo00<07gooOol0>goo0012
Ool00`0OOomoo`2MOol00`0OOomoo`0kOol0049oo`0301moogoo09aoo`0301moogoo03aoo`00@Goo
00<07gooOol0WGoo00<07gooOol0?7oo0011Ool00`0OOomoo`2MOol00`0OOomoo`0lOol0045oo`03
01moogoo09aoo`0301moogoo03eoo`00@Goo00<07gooOol0W7oo00<07gooOol0?Goo0011Ool00`0O
Oomoo`2KOol00`0OOomoo`0nOol0045oo`0301moogoo09]oo`0301moogoo03ioo`00@7oo00<07goo
Ool0Vgoo00<07gooOol0?goo0010Ool00`0OOomoo`2KOol00`0OOomoo`0oOol0041oo`0301moogoo
09Yoo`0301moogoo041oo`00@7oo00<07gooOol0VWoo00<07gooOol0@7oo0010Ool00`0OOomoo`2I
Ool00`0OOomoo`11Ool0041oo`0301moogoo09Uoo`0301moogoo045oo`00@7oo00<07gooOol0V7oo
00<07gooOol0@Woo0010Ool00`0OOomoo`2HOol00`0OOomoo`12Ool0041oo`0301moogoo09Moo`03
01moogoo04=oo`00@7oo00<07gooOol0Ugoo00<07gooOol0@goo0010Ool00`0OOomoo`2FOol00`0O
Oomoo`14Ool0041oo`0301moogoo09Ioo`0301moogoo04Aoo`00@7oo00<07gooOol0UGoo00<07goo
Ool0AGoo0010Ool00`0OOomoo`2DOol00`0OOomoo`16Ool0045oo`0301moogoo09=oo`0301moogoo
04Ioo`00@Goo00<07gooOol0TWoo00<07gooOol0Agoo0011Ool00`0OOomoo`2AOol00`0OOomoo`18
Ool0045oo`0301moogoo095oo`0301moogoo04Qoo`00@Goo00<07gooOol0T7oo00<07gooOol0BGoo
0011Ool00`0OOomoo`2@Ool00`0OOomoo`19Ool0049oo`0301moogoo08ioo`0301moogoo04Yoo`00
@Woo00<07gooOol0SGoo00<07gooOol0Bgoo0012Ool00`0OOomoo`2<Ool00`0OOomoo`1<Ool0049o
o`0301moogoo08]oo`0301moogoo04eoo`00@Woo00<07gooOol0Rgoo00<07gooOol0CGoo0012Ool0
0`0OOomoo`2:Ool00`0OOomoo`1>Ool004=oo`0301moogoo08Qoo`0301moogoo04moo`00@goo00<0
7gooOol0Qgoo00<07gooOol0D7oo0013Ool00`0OOomoo`26Ool00`0OOomoo`1AOol004=oo`0301mo
ogoo08Eoo`0301moogoo059oo`00A7oo00<07gooOol0Q7oo00<07gooOol0DWoo0014Ool00`0OOomo
o`23Ool00`0OOomoo`1COol004Eoo`0301moogoo085oo`0301moogoo05Aoo`00AGoo00<07gooOol0
P7oo00<07gooOol0EGoo0016Ool00`0OOomoo`1nOol00`0OOomoo`1FOol004Ioo`0301moogoo07eo
o`0301moogoo05Moo`00Agoo00<07gooOol0NWoo0P0OFWoo0017Ool00`0OOomoo`1iOol00`0OOomo
o`1JOol004Moo`0301moogoo07Qoo`0301moogoo05]oo`00B7oo00<07gooOol0MWoo00<07gooOol0
G7oo0018Ool00`0OOomoo`1eOol00`0OOomoo`1MOol004Uoo`0301moogoo07=oo`0301moogoo05io
o`00BWoo00<07gooOol0LGoo00<07gooOol0Ggoo001:Ool00`0OOomoo`1`Ool00`0OOomoo`1POol0
04]oo`0301moogoo06ioo`0301moogoo065oo`00C7oo00<07gooOol0K7oo00<07gooOol0HWoo001=
Ool00`0OOomoo`1YOol201mUOol004eoo`0301moogoo06Qoo`0301moogoo06Eoo`00CWoo00<07goo
Ool0IWoo00<07gooOol0IWoo001?Ool00`0OOomoo`1SOol201mYOol0051oo`0301moogoo065oo`03
01moogoo06Uoo`00DGoo00<07gooOol0GWoo0P0OK7oo001BOol00`0OOomoo`1LOol00`0OOomoo`1/
Ool005=oo`0301moogoo05Uoo`807fmoo`00E7oo00<07gooOol0EWoo0P0OLGoo001EOol00`0OOomo
o`1DOol00`0OOomoo`1aOol005Ioo`807e9oo`807gAoo`00F7oo00<07gooOol0CGoo0P0OMWoo001I
Ool00`0OOomoo`1:Ool201mhOol005Yoo`807dQoo`807gYoo`00G7oo0P0OA7oo0P0OO7oo001NOol2
01loOol301mnOol0061oo`<07cUoo`<07h5oo`00Hgoo0P0O<goo100OQ7oo001UOol201l]Ool401n8
Ool006Moo`807bMoo`@07haoo`00JGoo1@0O7goo0`0OT7oo001^Ool701lDOol401nCOol007Eooa@0
7iMoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.31103 .3512 m
.32795 .33179 L
s
.29535 .3716 m
.31103 .3512 L
s
.32795 .33179 m
.34603 .31349 L
s
.28101 .39289 m
.29535 .3716 L
s
.34603 .31349 m
.36516 .29639 L
s
.26809 .41496 m
.28101 .39289 L
s
.36516 .29639 m
.38525 .2806 L
s
.25667 .43767 m
.26809 .41496 L
s
.38525 .2806 m
.40618 .26621 L
s
.24681 .46092 m
.25667 .43767 L
s
.40618 .26621 m
.42785 .25331 L
s
.2386 .48456 m
.24681 .46092 L
s
.42785 .25331 m
.45013 .24199 L
s
.23209 .50848 m
.2386 .48456 L
s
.45013 .24199 m
.47292 .23233 L
s
.22734 .53253 m
.23209 .50848 L
s
.47292 .23233 m
.49607 .2244 L
s
.2244 .55658 m
.22734 .53253 L
s
.49607 .2244 m
.51946 .21827 L
s
.22331 .58048 m
.2244 .55658 L
s
.51946 .21827 m
.54296 .21401 L
s
.22412 .60409 m
.22331 .58048 L
s
.54296 .21401 m
.56641 .21167 L
s
.22684 .62725 m
.22412 .60409 L
s
.56641 .21167 m
.58968 .21129 L
s
.23149 .6498 m
.22684 .62725 L
s
.58968 .21129 m
.61261 .21293 L
s
.23809 .6716 m
.23149 .6498 L
s
.61261 .21293 m
.63505 .21659 L
s
.24662 .69248 m
.23809 .6716 L
s
.63505 .21659 m
.65684 .2223 L
s
.25706 .71228 m
.24662 .69248 L
s
.65684 .2223 m
.67781 .23007 L
s
.26939 .73084 m
.25706 .71228 L
s
.67781 .23007 m
.69781 .23988 L
s
.28356 .74801 m
.26939 .73084 L
s
.69781 .23988 m
.71668 .25171 L
s
.29951 .76364 m
.28356 .74801 L
s
.71668 .25171 m
.73425 .26551 L
s
.31716 .77757 m
.29951 .76364 L
s
.73425 .26551 m
.75037 .28123 L
s
.33641 .78966 m
.31716 .77757 L
s
.75037 .28123 m
.76487 .2988 L
s
.35715 .79978 m
.33641 .78966 L
s
.76487 .2988 m
.77763 .31811 L
s
.37926 .8078 m
.35715 .79978 L
s
.77763 .31811 m
.78848 .33905 L
s
.40258 .81362 m
.37926 .8078 L
s
.78848 .33905 m
.79732 .3615 L
s
.42695 .81715 m
.40258 .81362 L
s
.79732 .3615 m
.80402 .38529 L
s
.45219 .81831 m
.42695 .81715 L
s
.80402 .38529 m
.8085 .41026 L
s
.47809 .81705 m
.45219 .81831 L
s
.8085 .41026 m
.81066 .43622 L
s
.50447 .81333 m
.47809 .81705 L
s
.81066 .43622 m
.81045 .46296 L
s
.53108 .80714 m
.50447 .81333 L
s
.81045 .46296 m
.80784 .49026 L
s
.5577 .79852 m
.53108 .80714 L
s
.80784 .49026 m
.8028 .51788 L
s
.58409 .78749 m
.5577 .79852 L
s
.8028 .51788 m
.79537 .5456 L
s
.61001 .77413 m
.58409 .78749 L
s
.79537 .5456 m
.78557 .57315 L
s
.63523 .75854 m
.61001 .77413 L
s
.78557 .57315 m
.77347 .60029 L
s
.6595 .74085 m
.63523 .75854 L
s
.77347 .60029 m
.75916 .62676 L
s
.6826 .72119 m
.6595 .74085 L
s
.75916 .62676 m
.74277 .65232 L
s
.70431 .69976 m
.6826 .72119 L
s
.74277 .65232 m
.72443 .67673 L
s
.72443 .67673 m
.70431 .69976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.30287 .34033 m
.31962 .32055 L
s
.28744 .36116 m
.30287 .34033 L
s
.27342 .38294 m
.28744 .36116 L
s
.31962 .32055 m
.3376 .30195 L
s
.2609 .40555 m
.27342 .38294 L
s
.3376 .30195 m
.35671 .28464 L
s
.24994 .42884 m
.2609 .40555 L
s
.35671 .28464 m
.37685 .2687 L
s
.24061 .45271 m
.24994 .42884 L
s
.37685 .2687 m
.39791 .25426 L
s
.233 .47701 m
.24061 .45271 L
s
.39791 .25426 m
.41977 .24139 L
s
.22714 .50161 m
.233 .47701 L
s
.41977 .24139 m
.44231 .2302 L
s
.22309 .52636 m
.22714 .50161 L
s
.44231 .2302 m
.46541 .22075 L
s
.2209 .55112 m
.22309 .52636 L
s
.46541 .22075 m
.48893 .21314 L
s
.22059 .57575 m
.2209 .55112 L
s
.48893 .21314 m
.51274 .20742 L
s
.22221 .60008 m
.22059 .57575 L
s
.51274 .20742 m
.5367 .20367 L
s
.22576 .62397 m
.22221 .60008 L
s
.5367 .20367 m
.56065 .20193 L
s
.23125 .64725 m
.22576 .62397 L
s
.56065 .20193 m
.58445 .20225 L
s
.23869 .66977 m
.23125 .64725 L
s
.58445 .20225 m
.60793 .20466 L
s
.24805 .69136 m
.23869 .66977 L
s
.60793 .20466 m
.63094 .20919 L
s
.25931 .71187 m
.24805 .69136 L
s
.63094 .20919 m
.6533 .21584 L
s
.27243 .73113 m
.25931 .71187 L
s
.6533 .21584 m
.67487 .2246 L
s
.28735 .74898 m
.27243 .73113 L
s
.67487 .2246 m
.69545 .23546 L
s
.304 .76528 m
.28735 .74898 L
s
.69545 .23546 m
.7149 .24838 L
s
.3223 .77987 m
.304 .76528 L
s
.7149 .24838 m
.73305 .26332 L
s
.34214 .79261 m
.3223 .77987 L
s
.73305 .26332 m
.74972 .28018 L
s
.36342 .80336 m
.34214 .79261 L
s
.74972 .28018 m
.76478 .2989 L
s
.38598 .81201 m
.36342 .80336 L
s
.76478 .2989 m
.77805 .31936 L
s
.40968 .81844 m
.38598 .81201 L
s
.77805 .31936 m
.78942 .34142 L
s
.43436 .82257 m
.40968 .81844 L
s
.78942 .34142 m
.79875 .36495 L
s
.45984 .82431 m
.43436 .82257 L
s
.79875 .36495 m
.80593 .38978 L
s
.4859 .82361 m
.45984 .82431 L
s
.80593 .38978 m
.81085 .41573 L
s
.51236 .82044 m
.4859 .82361 L
s
.81085 .41573 m
.81346 .44258 L
s
.53899 .81478 m
.51236 .82044 L
s
.81346 .44258 m
.81367 .47014 L
s
.56557 .80664 m
.53899 .81478 L
s
.81367 .47014 m
.81147 .49816 L
s
.59185 .79607 m
.56557 .80664 L
s
.81147 .49816 m
.80684 .52642 L
s
.61762 .78312 m
.59185 .79607 L
s
.80684 .52642 m
.7998 .55466 L
s
.64263 .76789 m
.61762 .78312 L
s
.7998 .55466 m
.79038 .58263 L
s
.66666 .7505 m
.64263 .76789 L
s
.79038 .58263 m
.77866 .61008 L
s
.68949 .73108 m
.66666 .7505 L
s
.77866 .61008 m
.76472 .63676 L
s
.71089 .7098 m
.68949 .73108 L
s
.76472 .63676 m
.74868 .66243 L
s
.73069 .68685 m
.71089 .7098 L
s
.74868 .66243 m
.73069 .68685 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002NOol601mlOol009Moo`L07`Ioo``07g1oo`00
TWoo1@0O6Goo100OK7oo002>Ool401lROol401mXOol008]oo`<07bYoo`@07fAoo`00Qgoo100O<Goo
0P0OHWoo0024Ool301lgOol201mPOol0089oo`807caoo`807eioo`00P7oo0P0O@7oo0P0OG7oo001n
Ool201m4Ool201mJOol007aoo`807dQoo`807eQoo`00NWoo0P0OC7oo0P0OEWoo001hOol201m@Ool0
0`0OOomoo`1COol007Ioo`807e=oo`807e=oo`00M7oo0P0OEgoo00<07gooOol0D7oo001bOol201mJ
Ool00`0OOomoo`1?Ool0075oo`0301moogoo05]oo`807dmoo`00L7oo00<07gooOol0GWoo00<07goo
Ool0C7oo001^Ool201mROol00`0OOomoo`1;Ool006eoo`0301moogoo06=oo`0301moogoo04Yoo`00
K7oo00<07gooOol0IGoo00<07gooOol0BGoo001ZOol201mYOol00`0OOomoo`18Ool006Uoo`0301mo
ogoo06Yoo`0301moogoo04Moo`00Igoo0P0OKWoo00<07gooOol0AWoo001VOol00`0OOomoo`1_Ool0
0`0OOomoo`15Ool006Eoo`0301moogoo075oo`0301moogoo04Aoo`00I7oo00<07gooOol0LWoo00<0
7gooOol0A7oo001ROol201mfOol00`0OOomoo`13Ool0065oo`0301moogoo07Moo`0301moogoo049o
o`00H7oo00<07gooOol0NGoo00<07gooOol0@Goo001OOol00`0OOomoo`1jOol00`0OOomoo`11Ool0
05ioo`0301moogoo07aoo`0301moogoo041oo`00GGoo00<07gooOol0OWoo00<07gooOol0?goo001L
Ool00`0OOomoo`1oOol00`0OOomoo`0oOol005]oo`0301moogoo085oo`0301moogoo03ioo`00FWoo
00<07gooOol0PWoo00<07gooOol0?Woo001IOol00`0OOomoo`24Ool00`0OOomoo`0mOol005Qoo`03
01moogoo08Eoo`0301moogoo03eoo`00F7oo00<07gooOol0QWoo00<07gooOol0?7oo001GOol00`0O
Oomoo`27Ool00`0OOomoo`0lOol005Ioo`0301moogoo08Uoo`0301moogoo03]oo`00EGoo00<07goo
Ool0RWoo00<07gooOol0>goo001EOol00`0OOomoo`2;Ool00`0OOomoo`0jOol005Aoo`0301moogoo
08aoo`0301moogoo03Yoo`00Dgoo00<07gooOol0SWoo00<07gooOol0>Goo001COol00`0OOomoo`2>
Ool00`0OOomoo`0iOol0059oo`0301moogoo091oo`0301moogoo03Qoo`00DGoo00<07gooOol0TGoo
00<07gooOol0>7oo001AOol00`0OOomoo`2AOol00`0OOomoo`0hOol0051oo`0301moogoo09=oo`03
01moogoo03Moo`00Cgoo00<07gooOol0U7oo00<07gooOol0=goo001?Ool00`0OOomoo`2DOol00`0O
Oomoo`0gOol004ioo`0301moogoo09Eoo`0301moogoo03Moo`00CGoo00<07gooOol0Ugoo00<07goo
Ool0=Woo001=Ool00`0OOomoo`2GOol00`0OOomoo`0fOol004aoo`0301moogoo09Qoo`0301moogoo
03Ioo`00C7oo00<07gooOol0V7oo00<07gooOol0=Woo001;Ool00`0OOomoo`2IOol00`0OOomoo`0f
Ool004]oo`0301moogoo09Uoo`0301moogoo03Ioo`00BWoo00<07gooOol0Vgoo00<07gooOol0=Goo
001:Ool00`0OOomoo`2KOol00`0OOomoo`0eOol004Uoo`0301moogoo09aoo`0301moogoo03Eoo`00
BGoo00<07gooOol0W7oo00<07gooOol0=Goo0018Ool00`0OOomoo`2MOol00`0OOomoo`0eOol004Qo
o`0301moogoo09eoo`0301moogoo03Eoo`00Agoo00<07gooOol0WWoo00<07gooOol0=Goo0017Ool0
0`0OOomoo`2NOol00`0OOomoo`0eOol004Moo`0301moogoo09moo`0301moogoo03Aoo`00AWoo00<0
7gooOol0X7oo00<07gooOol0=7oo0016Ool00`0OOomoo`2POol00`0OOomoo`0dOol004Ioo`0301mo
ogoo0:1oo`0301moogoo03Aoo`00AGoo00<07gooOol0XGoo00<07gooOol0=7oo0015Ool00`0OOomo
o`2QOol00`0OOomoo`0dOol004Eoo`0301moogoo0:5oo`0301moogoo03Aoo`00A7oo00<07gooOol0
XWoo00<07gooOol0=7oo0014Ool00`0OOomoo`2ROol00`0OOomoo`0dOol004=oo`0301moogoo0:=o
o`0301moogoo03Aoo`00@goo00<07gooOol0Xgoo00<07gooOol0=7oo0012Ool00`0OOomoo`2TOol0
0`0OOomoo`0dOol0049oo`0301moogoo0:Aoo`0301moogoo03Aoo`00@Woo00<07gooOol0Y7oo00<0
7gooOol0=7oo0012Ool00`0OOomoo`2SOol00`0OOomoo`0eOol0049oo`0301moogoo0:=oo`0301mo
ogoo03Eoo`00@Goo00<07gooOol0Y7oo00<07gooOol0=Goo0011Ool00`0OOomoo`2TOol00`0OOomo
o`0eOol0045oo`0301moogoo0:Aoo`0301moogoo03Eoo`00@Goo00<07gooOol0Y7oo00<07gooOol0
=Goo0011Ool00`0OOomoo`2TOol00`0OOomoo`0eOol0045oo`0301moogoo0:Aoo`0301moogoo03Eo
o`00@Goo00<07gooOol0Y7oo00<07gooOol0=Goo0010Ool00`0OOomoo`2TOol00`0OOomoo`0fOol0
041oo`0301moogoo0:Aoo`0301moogoo03Ioo`00@7oo00<07gooOol0Y7oo00<07gooOol0=Woo0010
Ool00`0OOomoo`2TOol00`0OOomoo`0fOol0041oo`0301moogoo0:Aoo`0301moogoo03Ioo`00@7oo
00<07gooOol0Y7oo00<07gooOol0=Woo0010Ool00`0OOomoo`2SOol00`0OOomoo`0gOol0041oo`03
01moogoo0:=oo`0301moogoo03Moo`00?goo00<07gooOol0Y7oo00<07gooOol0=goo000oOol00`0O
Oomoo`2TOol00`0OOomoo`0gOol003moo`0301moogoo0:=oo`0301moogoo03Qoo`00?goo00<07goo
Ool0Xgoo00<07gooOol0>7oo000oOol00`0OOomoo`2SOol00`0OOomoo`0hOol003moo`0301moogoo
0:=oo`0301moogoo03Qoo`00?goo00<07gooOol0XWoo00<07gooOol0>Goo000oOol00`0OOomoo`2R
Ool00`0OOomoo`0iOol003moo`0301moogoo0:5oo`0301moogoo03Yoo`00?goo00<07gooOol0XGoo
00<07gooOol0>Woo000oOol00`0OOomoo`2QOol00`0OOomoo`0jOol003moo`0301moogoo0:1oo`03
01moogoo03]oo`00?goo00<07gooOol0X7oo00<07gooOol0>goo000oOol00`0OOomoo`2POol00`0O
Oomoo`0kOol003moo`0301moogoo09moo`0301moogoo03aoo`00?goo00<07gooOol0Wgoo00<07goo
Ool0?7oo000oOol00`0OOomoo`2NOol00`0OOomoo`0mOol003moo`0301moogoo09ioo`0301moogoo
03eoo`00?goo00<07gooOol0WWoo00<07gooOol0?Goo000oOol00`0OOomoo`2MOol00`0OOomoo`0n
Ool003moo`0301moogoo09eoo`0301moogoo03ioo`00@7oo00<07gooOol0Vgoo00<07gooOol0?goo
0010Ool00`0OOomoo`2KOol00`0OOomoo`0oOol0041oo`0301moogoo09Yoo`0301moogoo041oo`00
@7oo00<07gooOol0VWoo00<07gooOol0@7oo0010Ool00`0OOomoo`2IOol00`0OOomoo`11Ool0045o
o`0301moogoo09Qoo`0301moogoo045oo`00@Goo00<07gooOol0Ugoo00<07gooOol0@Woo0011Ool0
0`0OOomoo`2FOol00`0OOomoo`13Ool0049oo`0301moogoo09Eoo`0301moogoo04=oo`00@Woo00<0
7gooOol0U7oo00<07gooOol0A7oo0012Ool00`0OOomoo`2COol00`0OOomoo`15Ool004=oo`0301mo
ogoo099oo`0301moogoo04Eoo`00@goo00<07gooOol0TGoo00<07gooOol0AWoo0013Ool00`0OOomo
o`2AOol00`0OOomoo`16Ool004=oo`0301moogoo091oo`0301moogoo04Moo`00A7oo00<07gooOol0
SWoo00<07gooOol0B7oo0014Ool00`0OOomoo`2>Ool00`0OOomoo`18Ool004Aoo`0301moogoo08eo
o`0301moogoo04Uoo`00AGoo00<07gooOol0Rgoo00<07gooOol0BWoo0015Ool00`0OOomoo`2:Ool0
0`0OOomoo`1;Ool004Ioo`0301moogoo08Uoo`0301moogoo04]oo`00AWoo00<07gooOol0R7oo00<0
7gooOol0C7oo0017Ool00`0OOomoo`26Ool00`0OOomoo`1=Ool004Moo`0301moogoo08Eoo`0301mo
ogoo04ioo`00B7oo00<07gooOol0Pgoo00<07gooOol0Cgoo0018Ool00`0OOomoo`23Ool00`0OOomo
o`1?Ool004Uoo`0301moogoo085oo`0301moogoo051oo`00BGoo00<07gooOol0P7oo00<07gooOol0
DGoo001:Ool00`0OOomoo`1nOol00`0OOomoo`1BOol004]oo`0301moogoo07aoo`0301moogoo05=o
o`00C7oo00<07gooOol0NGoo0P0OEWoo001<Ool00`0OOomoo`1hOol00`0OOomoo`1FOol004eoo`03
01moogoo07Ioo`0301moogoo05Moo`00CWoo00<07gooOol0M7oo00<07gooOol0F7oo001?Ool00`0O
Oomoo`1bOol00`0OOomoo`1IOol0051oo`0301moogoo071oo`0301moogoo05Yoo`00D7oo00<07goo
Ool0Kgoo00<07gooOol0Fgoo001AOol00`0OOomoo`1]Ool00`0OOomoo`1LOol0059oo`0301moogoo
06]oo`0301moogoo05eoo`00Dgoo00<07gooOol0JGoo00<07gooOol0GWoo001DOol00`0OOomoo`1V
Ool201mQOol005Eoo`0301moogoo06Aoo`0301moogoo065oo`00EWoo00<07gooOol0HWoo00<07goo
Ool0HWoo001GOol00`0OOomoo`1OOol201mUOol005Qoo`0301moogoo05eoo`0301moogoo06Eoo`00
FGoo0P0OFgoo0P0OJ7oo001KOol00`0OOomoo`1FOol201mZOol005aoo`0301moogoo05=oo`807fao
o`00GGoo0P0ODWoo00<07gooOol0K7oo001OOol00`0OOomoo`1=Ool201m_Ool0061oo`807d]oo`80
7g5oo`00HWoo00<07gooOol0AWoo0P0OLgoo001SOol201m3Ool301meOol006Eoo`807cmoo`807gQo
o`00Igoo0P0O>goo0P0ONWoo001YOol201lfOol301mlOol006]oo`807c1oo`@07gmoo`00KGoo1@0O
9goo100OPgoo001bOol501lNOol401n7Ool007Moo`@07aEoo`D07h]oo`00Ngoo5@0OT7oo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.27923 .3513 m
.29451 .33013 L
s
.26544 .37347 m
.27923 .3513 L
s
.25321 .39652 m
.26544 .37347 L
s
.29451 .33013 m
.31119 .31008 L
s
.24263 .4203 m
.25321 .39652 L
s
.31119 .31008 m
.32918 .29127 L
s
.23376 .44469 m
.24263 .4203 L
s
.32918 .29127 m
.34837 .27382 L
s
.22665 .46954 m
.23376 .44469 L
s
.34837 .27382 m
.36866 .25783 L
s
.22137 .49472 m
.22665 .46954 L
s
.36866 .25783 m
.38994 .24341 L
s
.21795 .52006 m
.22137 .49472 L
s
.38994 .24341 m
.41209 .23066 L
s
.21644 .54543 m
.21795 .52006 L
s
.41209 .23066 m
.43498 .21966 L
s
.21686 .57067 m
.21644 .54543 L
s
.43498 .21966 m
.45848 .21051 L
s
.21923 .59562 m
.21686 .57067 L
s
.45848 .21051 m
.48245 .20328 L
s
.22357 .62013 m
.21923 .59562 L
s
.48245 .20328 m
.50675 .19804 L
s
.22986 .64403 m
.22357 .62013 L
s
.50675 .19804 m
.53123 .19484 L
s
.2381 .66715 m
.22986 .64403 L
s
.53123 .19484 m
.55574 .19375 L
s
.24827 .68935 m
.2381 .66715 L
s
.55574 .19375 m
.58012 .1948 L
s
.26032 .71045 m
.24827 .68935 L
s
.58012 .1948 m
.60419 .19801 L
s
.27421 .73029 m
.26032 .71045 L
s
.60419 .19801 m
.62779 .20341 L
s
.28987 .74872 m
.27421 .73029 L
s
.62779 .20341 m
.65076 .21098 L
s
.30722 .76559 m
.28987 .74872 L
s
.65076 .21098 m
.67292 .22072 L
s
.32618 .78073 m
.30722 .76559 L
s
.67292 .22072 m
.69409 .2326 L
s
.34663 .79402 m
.32618 .78073 L
s
.69409 .2326 m
.71411 .24657 L
s
.36844 .80532 m
.34663 .79402 L
s
.71411 .24657 m
.7328 .26256 L
s
.39149 .81451 m
.36844 .80532 L
s
.7328 .26256 m
.75 .28049 L
s
.41561 .82149 m
.39149 .81451 L
s
.75 .28049 m
.76556 .30025 L
s
.44064 .82615 m
.41561 .82149 L
s
.76556 .30025 m
.77931 .32173 L
s
.46638 .82842 m
.44064 .82615 L
s
.77931 .32173 m
.79113 .34478 L
s
.49266 .82825 m
.46638 .82842 L
s
.79113 .34478 m
.80088 .36925 L
s
.51926 .8256 m
.49266 .82825 L
s
.80088 .36925 m
.80846 .39495 L
s
.54596 .82045 m
.51926 .8256 L
s
.80846 .39495 m
.81376 .42168 L
s
.57256 .81281 m
.54596 .82045 L
s
.81376 .42168 m
.81672 .44925 L
s
.59881 .80271 m
.57256 .81281 L
s
.81672 .44925 m
.81728 .47743 L
s
.62449 .79022 m
.59881 .80271 L
s
.81728 .47743 m
.8154 .50598 L
s
.64937 .77542 m
.62449 .79022 L
s
.8154 .50598 m
.81108 .53466 L
s
.67324 .75841 m
.64937 .77542 L
s
.81108 .53466 m
.80434 .56322 L
s
.69587 .73933 m
.67324 .75841 L
s
.80434 .56322 m
.79522 .59142 L
s
.71705 .71833 m
.69587 .73933 L
s
.79522 .59142 m
.78378 .619 L
s
.73661 .6956 m
.71705 .71833 L
s
.78378 .619 m
.77012 .64571 L
s
.75435 .67132 m
.73661 .6956 L
s
.77012 .64571 m
.75435 .67132 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol009EooaD07gIoo`00T7oo1@0O5Goo1@0OLGoo002<Ool401lOOol401m]Ool0
08Uoo`<07bMoo`<07fYoo`00QGoo100O;Goo0`0OIgoo0022Ool301ldOol301mTOol0081oo`807cYo
o`807f9oo`00OWoo0P0O?Woo0P0OH7oo001lOol201m2Ool201mNOol007Yoo`807dIoo`807eaoo`00
N7oo0P0OBWoo0P0OFWoo001eOol301m>Ool201mHOol007=oo`807e=oo`0301moogoo05Eoo`00LGoo
0P0OEWoo0P0OEGoo001_Ool201mJOol00`0OOomoo`1BOol006eoo`807eeoo`0301moogoo055oo`00
K7oo00<07gooOol0GWoo00<07gooOol0D7oo001ZOol201mROol00`0OOomoo`1?Ool006Uoo`0301mo
ogoo06=oo`807dmoo`00J7oo00<07gooOol0IWoo00<07gooOol0C7oo001WOol00`0OOomoo`1XOol0
0`0OOomoo`1;Ool006Eoo`807faoo`0301moogoo04Yoo`00I7oo00<07gooOol0KGoo00<07gooOol0
BGoo001SOol00`0OOomoo`1_Ool00`0OOomoo`18Ool0069oo`0301moogoo075oo`0301moogoo04Mo
o`00HGoo00<07gooOol0Lgoo00<07gooOol0AWoo001POol00`0OOomoo`1eOol00`0OOomoo`15Ool0
05moo`0301moogoo07Ioo`0301moogoo04Eoo`00GWoo00<07gooOol0N7oo00<07gooOol0A7oo001M
Ool00`0OOomoo`1jOol00`0OOomoo`13Ool005aoo`0301moogoo07]oo`0301moogoo04=oo`00Fgoo
00<07gooOol0OGoo00<07gooOol0@Woo001JOol00`0OOomoo`1oOol00`0OOomoo`11Ool005Uoo`03
01moogoo081oo`0301moogoo045oo`00F7oo00<07gooOol0PWoo00<07gooOol0@7oo001GOol00`0O
Oomoo`24Ool00`0OOomoo`0oOol005Ioo`0301moogoo08Eoo`0301moogoo03moo`00EWoo00<07goo
Ool0QWoo00<07gooOol0?Woo001EOol00`0OOomoo`28Ool00`0OOomoo`0mOol005Aoo`0301moogoo
08Uoo`0301moogoo03eoo`00Dgoo00<07gooOol0Rgoo00<07gooOol0?7oo001COol00`0OOomoo`2<
Ool00`0OOomoo`0kOol0059oo`0301moogoo08eoo`0301moogoo03]oo`00DGoo00<07gooOol0Sgoo
00<07gooOol0>Woo001AOol00`0OOomoo`2?Ool00`0OOomoo`0jOol0051oo`0301moogoo095oo`03
01moogoo03Uoo`00Cgoo00<07gooOol0TWoo00<07gooOol0>Goo001?Ool00`0OOomoo`2BOol00`0O
Oomoo`0iOol004ioo`0301moogoo09=oo`0301moogoo03Uoo`00CWoo00<07gooOol0U7oo00<07goo
Ool0>7oo001=Ool00`0OOomoo`2EOol00`0OOomoo`0hOol004eoo`0301moogoo09Eoo`0301moogoo
03Qoo`00C7oo00<07gooOol0Ugoo00<07gooOol0=goo001;Ool00`0OOomoo`2HOol00`0OOomoo`0g
Ool004]oo`0301moogoo09Qoo`0301moogoo03Moo`00BWoo00<07gooOol0VWoo00<07gooOol0=Woo
0019Ool00`0OOomoo`2KOol00`0OOomoo`0fOol004Uoo`0301moogoo09aoo`0301moogoo03Eoo`00
B7oo00<07gooOol0WGoo00<07gooOol0=Goo0018Ool00`0OOomoo`2MOol00`0OOomoo`0eOol004Mo
o`0301moogoo09ioo`0301moogoo03Eoo`00Agoo00<07gooOol0WWoo00<07gooOol0=Goo0016Ool0
0`0OOomoo`2OOol00`0OOomoo`0eOol004Ioo`0301moogoo0:1oo`0301moogoo03Aoo`00AGoo00<0
7gooOol0XGoo00<07gooOol0=7oo0015Ool00`0OOomoo`2QOol00`0OOomoo`0dOol004Eoo`0301mo
ogoo0:5oo`0301moogoo03Aoo`00A7oo00<07gooOol0XWoo00<07gooOol0=7oo0014Ool00`0OOomo
o`2ROol00`0OOomoo`0dOol004Aoo`0301moogoo0:9oo`0301moogoo03Aoo`00A7oo00<07gooOol0
Xgoo00<07gooOol0<goo0013Ool00`0OOomoo`2TOol00`0OOomoo`0cOol004=oo`0301moogoo0:Ao
o`0301moogoo03=oo`00@goo00<07gooOol0Y7oo00<07gooOol0<goo0012Ool00`0OOomoo`2UOol0
0`0OOomoo`0cOol0049oo`0301moogoo0:Eoo`0301moogoo03=oo`00@Woo00<07gooOol0YGoo00<0
7gooOol0<goo0012Ool00`0OOomoo`2UOol00`0OOomoo`0cOol0045oo`0301moogoo0:Ioo`0301mo
ogoo03=oo`00@Goo00<07gooOol0YWoo00<07gooOol0<goo0011Ool00`0OOomoo`2VOol00`0OOomo
o`0cOol0041oo`0301moogoo0:Moo`0301moogoo03=oo`00@7oo00<07gooOol0Ygoo00<07gooOol0
<goo0010Ool00`0OOomoo`2WOol00`0OOomoo`0cOol0041oo`0301moogoo0:Moo`0301moogoo03=o
o`00?goo00<07gooOol0Z7oo00<07gooOol0<goo000oOol00`0OOomoo`2XOol00`0OOomoo`0cOol0
03moo`0301moogoo0:Qoo`0301moogoo03=oo`00?goo00<07gooOol0Z7oo00<07gooOol0<goo000o
Ool00`0OOomoo`2XOol00`0OOomoo`0cOol003ioo`0301moogoo0:Uoo`0301moogoo03=oo`00?Woo
00<07gooOol0ZGoo00<07gooOol0<goo000nOol00`0OOomoo`2XOol00`0OOomoo`0dOol003ioo`03
01moogoo0:Qoo`0301moogoo03Aoo`00?Woo00<07gooOol0Z7oo00<07gooOol0=7oo000nOol00`0O
Oomoo`2XOol00`0OOomoo`0dOol003ioo`0301moogoo0:Moo`0301moogoo03Eoo`00?Woo00<07goo
Ool0Ygoo00<07gooOol0=Goo000nOol00`0OOomoo`2WOol00`0OOomoo`0eOol003ioo`0301moogoo
0:Moo`0301moogoo03Eoo`00?Woo00<07gooOol0YWoo00<07gooOol0=Woo000nOol00`0OOomoo`2V
Ool00`0OOomoo`0fOol003ioo`0301moogoo0:Ioo`0301moogoo03Ioo`00?Woo00<07gooOol0YWoo
00<07gooOol0=Woo000nOol00`0OOomoo`2UOol00`0OOomoo`0gOol003ioo`0301moogoo0:Eoo`03
01moogoo03Moo`00?Woo00<07gooOol0YGoo00<07gooOol0=goo000nOol00`0OOomoo`2UOol00`0O
Oomoo`0gOol003ioo`0301moogoo0:Aoo`0301moogoo03Qoo`00?Woo00<07gooOol0Y7oo00<07goo
Ool0>7oo000nOol00`0OOomoo`2TOol00`0OOomoo`0hOol003ioo`0301moogoo0:Aoo`0301moogoo
03Qoo`00?Woo00<07gooOol0Xgoo00<07gooOol0>Goo000nOol00`0OOomoo`2SOol00`0OOomoo`0i
Ool003ioo`0301moogoo0:=oo`0301moogoo03Uoo`00?Woo00<07gooOol0XWoo00<07gooOol0>Woo
000nOol00`0OOomoo`2ROol00`0OOomoo`0jOol003moo`0301moogoo0:1oo`0301moogoo03]oo`00
?goo00<07gooOol0X7oo00<07gooOol0>goo000oOol00`0OOomoo`2OOol00`0OOomoo`0lOol003mo
o`0301moogoo09moo`0301moogoo03aoo`00@7oo00<07gooOol0WGoo00<07gooOol0?Goo0010Ool0
0`0OOomoo`2MOol00`0OOomoo`0mOol0041oo`0301moogoo09eoo`0301moogoo03eoo`00@7oo00<0
7gooOol0W7oo00<07gooOol0?Woo0010Ool00`0OOomoo`2LOol00`0OOomoo`0nOol0045oo`0301mo
ogoo09Yoo`0301moogoo03moo`00@Goo00<07gooOol0VWoo00<07gooOol0?goo0011Ool00`0OOomo
o`2JOol00`0OOomoo`0oOol0045oo`0301moogoo09Uoo`0301moogoo041oo`00@Goo00<07gooOol0
VGoo00<07gooOol0@7oo0012Ool00`0OOomoo`2GOol00`0OOomoo`11Ool0049oo`0301moogoo09Mo
o`0301moogoo045oo`00@goo00<07gooOol0UGoo00<07gooOol0@Woo0013Ool00`0OOomoo`2DOol0
0`0OOomoo`13Ool004Aoo`0301moogoo099oo`0301moogoo04Aoo`00A7oo00<07gooOol0TWoo00<0
7gooOol0A7oo0014Ool00`0OOomoo`2AOol00`0OOomoo`15Ool004Eoo`0301moogoo08moo`0301mo
ogoo04Ioo`00AGoo00<07gooOol0Sgoo00<07gooOol0AWoo0016Ool00`0OOomoo`2=Ool00`0OOomo
o`17Ool004Ioo`0301moogoo08aoo`0301moogoo04Qoo`00Agoo00<07gooOol0RWoo00<07gooOol0
BGoo0017Ool00`0OOomoo`2:Ool00`0OOomoo`19Ool004Qoo`0301moogoo08Qoo`0301moogoo04Yo
o`00B7oo00<07gooOol0Qgoo00<07gooOol0Bgoo0019Ool00`0OOomoo`25Ool00`0OOomoo`1<Ool0
04Uoo`0301moogoo08Aoo`0301moogoo04eoo`00BWoo00<07gooOol0Pgoo00<07gooOol0CGoo001;
Ool00`0OOomoo`21Ool00`0OOomoo`1>Ool004]oo`0301moogoo081oo`0301moogoo04moo`00C7oo
00<07gooOol0OWoo00<07gooOol0D7oo001=Ool00`0OOomoo`1lOol00`0OOomoo`1AOol004eoo`03
01moogoo07]oo`0301moogoo059oo`00CWoo00<07gooOol0NGoo00<07gooOol0Dgoo001?Ool00`0O
Oomoo`1gOol00`0OOomoo`1DOol0051oo`0301moogoo07Eoo`0301moogoo05Eoo`00DGoo00<07goo
Ool0Lgoo00<07gooOol0EWoo001BOol00`0OOomoo`1aOol00`0OOomoo`1GOol005=oo`0301moogoo
06moo`0301moogoo05Qoo`00E7oo00<07gooOol0K7oo0P0OFgoo001EOol00`0OOomoo`1ZOol00`0O
Oomoo`1KOol005Ioo`0301moogoo06Qoo`0301moogoo05aoo`00Egoo00<07gooOol0IGoo0P0OGgoo
001HOol00`0OOomoo`1SOol00`0OOomoo`1OOol005Uoo`0301moogoo065oo`0301moogoo061oo`00
FWoo00<07gooOol0GWoo0P0OHgoo001KOol00`0OOomoo`1LOol00`0OOomoo`1SOol005aoo`0301mo
ogoo05Uoo`807fIoo`00GGoo00<07gooOol0EWoo0P0OJ7oo001NOol201mDOol201mZOol0061oo`80
7e5oo`0301moogoo06Yoo`00HWoo0P0OCGoo0P0OKGoo001TOol201m9Ool201m_Ool006Ioo`0301mo
ogoo04Aoo`807g5oo`00Igoo0P0O@Goo0`0OLgoo001YOol201lmOol201mfOol006]oo`@07cMoo`80
7gQoo`00Kgoo0`0O<Goo0`0ONWoo001bOol401lYOol401mmOol007Ioo`<07b1oo`H07h5oo`00NGoo
100O5Goo1`0OQgoo001mOolE01n>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.25735 .36467 m
.27102 .34219 L
s
.24533 .38807 m
.25735 .36467 L
s
.27102 .34219 m
.28625 .32077 L
s
.23503 .41225 m
.24533 .38807 L
s
.28625 .32077 m
.30296 .30053 L
s
.2265 .43706 m
.23503 .41225 L
s
.30296 .30053 m
.32105 .28159 L
s
.21982 .46237 m
.2265 .43706 L
s
.32105 .28159 m
.34042 .26408 L
s
.21503 .48802 m
.21982 .46237 L
s
.34042 .26408 m
.36095 .24812 L
s
.21216 .51387 m
.21503 .48802 L
s
.36095 .24812 m
.38255 .2338 L
s
.21125 .53974 m
.21216 .51387 L
s
.38255 .2338 m
.40506 .22122 L
s
.21232 .56549 m
.21125 .53974 L
s
.40506 .22122 m
.42838 .21049 L
s
.21538 .59095 m
.21232 .56549 L
s
.42838 .21049 m
.45235 .20169 L
s
.22043 .61597 m
.21538 .59095 L
s
.45235 .20169 m
.47684 .19489 L
s
.22746 .64037 m
.22043 .61597 L
s
.47684 .19489 m
.50169 .19017 L
s
.23645 .664 m
.22746 .64037 L
s
.50169 .19017 m
.52674 .18757 L
s
.24737 .68668 m
.23645 .664 L
s
.52674 .18757 m
.55184 .18715 L
s
.26017 .70826 m
.24737 .68668 L
s
.55184 .18715 m
.57682 .18893 L
s
.2748 .72857 m
.26017 .70826 L
s
.57682 .18893 m
.60149 .19295 L
s
.29117 .74746 m
.2748 .72857 L
s
.60149 .19295 m
.6257 .1992 L
s
.3092 .76478 m
.29117 .74746 L
s
.6257 .1992 m
.64925 .20768 L
s
.3288 .78038 m
.3092 .76478 L
s
.64925 .20768 m
.67198 .21835 L
s
.34984 .79411 m
.3288 .78038 L
s
.67198 .21835 m
.6937 .23119 L
s
.37219 .80586 m
.34984 .79411 L
s
.6937 .23119 m
.71424 .24613 L
s
.39572 .81549 m
.37219 .80586 L
s
.71424 .24613 m
.73343 .26308 L
s
.42026 .82291 m
.39572 .81549 L
s
.73343 .26308 m
.75109 .28196 L
s
.44564 .82803 m
.42026 .82291 L
s
.75109 .28196 m
.76707 .30265 L
s
.47169 .83076 m
.44564 .82803 L
s
.76707 .30265 m
.78122 .32501 L
s
.4982 .83106 m
.47169 .83076 L
s
.78122 .32501 m
.7934 .34889 L
s
.52497 .82888 m
.4982 .83106 L
s
.7934 .34889 m
.80348 .37411 L
s
.55178 .82421 m
.52497 .82888 L
s
.80348 .37411 m
.81136 .4005 L
s
.57844 .81705 m
.55178 .82421 L
s
.81136 .4005 m
.81694 .42785 L
s
.6047 .80744 m
.57844 .81705 L
s
.81694 .42785 m
.82016 .45594 L
s
.63034 .79542 m
.6047 .80744 L
s
.82016 .45594 m
.82095 .48454 L
s
.65516 .78107 m
.63034 .79542 L
s
.82095 .48454 m
.8193 .51342 L
s
.67892 .7645 m
.65516 .78107 L
s
.8193 .51342 m
.81519 .54233 L
s
.70142 .74583 m
.67892 .7645 L
s
.81519 .54233 m
.80866 .57103 L
s
.72246 .72521 m
.70142 .74583 L
s
.80866 .57103 m
.79973 .59926 L
s
.74185 .7028 m
.72246 .72521 L
s
.79973 .59926 m
.78849 .62679 L
s
.75942 .67878 m
.74185 .7028 L
s
.78849 .62679 m
.77501 .65338 L
s
.77501 .65338 m
.75942 .67878 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
U7oo3P0OOWoo002<Ool801l>Ool701mgOol008Moo`D07aeoo`D07g9oo`00Pgoo100O9goo100OKWoo
0020Ool301l_Ool301m[Ool007ioo`807cEoo`@07fMoo`00O7oo0P0O>goo0P0OIGoo001jOol201lo
Ool201mSOol007Qoo`807d=oo`807f5oo`00MWoo0P0OAgoo0P0OGgoo001dOol201m;Ool201mMOol0
079oo`807dmoo`807e]oo`00L7oo0P0ODgoo0P0OFGoo001^Ool201mGOol00`0OOomoo`1FOol006eo
o`0301moogoo05Qoo`0301moogoo05Eoo`00Jgoo0P0OG7oo0P0OEGoo001ZOol00`0OOomoo`1NOol0
0`0OOomoo`1BOol006Qoo`807f9oo`0301moogoo055oo`00Igoo00<07gooOol0Hgoo00<07gooOol0
D7oo001UOol201mWOol00`0OOomoo`1?Ool006Aoo`0301moogoo06Qoo`807dmoo`00HWoo0P0OKGoo
00<07gooOol0C7oo001QOol00`0OOomoo`1^Ool00`0OOomoo`1;Ool0061oo`0301moogoo071oo`03
01moogoo04Yoo`00Ggoo00<07gooOol0LWoo00<07gooOol0BGoo001NOol00`0OOomoo`1dOol00`0O
Oomoo`18Ool005eoo`0301moogoo07Ioo`0301moogoo04Moo`00G7oo00<07gooOol0N7oo00<07goo
Ool0AWoo001KOol00`0OOomoo`1jOol00`0OOomoo`15Ool005Yoo`0301moogoo07aoo`0301moogoo
04Aoo`00FGoo00<07gooOol0OGoo00<07gooOol0A7oo001HOol00`0OOomoo`1oOol00`0OOomoo`13
Ool005Moo`0301moogoo085oo`0301moogoo049oo`00EWoo00<07gooOol0Pgoo00<07gooOol0@Goo
001EOol00`0OOomoo`25Ool00`0OOomoo`10Ool005Eoo`0301moogoo08Eoo`0301moogoo041oo`00
E7oo00<07gooOol0Qgoo00<07gooOol0?goo001COol00`0OOomoo`28Ool00`0OOomoo`0oOol005=o
o`0301moogoo08Uoo`0301moogoo03ioo`00DWoo00<07gooOol0RWoo00<07gooOol0?Woo001AOol0
0`0OOomoo`2<Ool00`0OOomoo`0mOol0051oo`0301moogoo08eoo`0301moogoo03eoo`00Cgoo00<0
7gooOol0Sgoo00<07gooOol0?7oo001?Ool00`0OOomoo`2?Ool00`0OOomoo`0lOol004ioo`0301mo
ogoo095oo`0301moogoo03]oo`00CGoo00<07gooOol0TWoo00<07gooOol0>goo001<Ool00`0OOomo
o`2DOol00`0OOomoo`0jOol004aoo`0301moogoo09Aoo`0301moogoo03Yoo`00Bgoo00<07gooOol0
UGoo00<07gooOol0>Woo001:Ool00`0OOomoo`2GOol00`0OOomoo`0iOol004Yoo`0301moogoo09Mo
o`0301moogoo03Uoo`00BGoo00<07gooOol0VGoo00<07gooOol0>7oo0019Ool00`0OOomoo`2IOol0
0`0OOomoo`0hOol004Qoo`0301moogoo09]oo`0301moogoo03Moo`00B7oo00<07gooOol0Vgoo00<0
7gooOol0=goo0017Ool00`0OOomoo`2LOol00`0OOomoo`0gOol004Moo`0301moogoo09eoo`0301mo
ogoo03Ioo`00AWoo00<07gooOol0WWoo00<07gooOol0=Woo0016Ool00`0OOomoo`2NOol00`0OOomo
o`0fOol004Ioo`0301moogoo09ioo`0301moogoo03Ioo`00AGoo00<07gooOol0X7oo00<07gooOol0
=Goo0015Ool00`0OOomoo`2POol00`0OOomoo`0eOol004Aoo`0301moogoo0:5oo`0301moogoo03Eo
o`00A7oo00<07gooOol0XGoo00<07gooOol0=Goo0013Ool00`0OOomoo`2SOol00`0OOomoo`0dOol0
04=oo`0301moogoo0:=oo`0301moogoo03Aoo`00@goo00<07gooOol0Xgoo00<07gooOol0=7oo0012
Ool00`0OOomoo`2TOol00`0OOomoo`0dOol0049oo`0301moogoo0:Eoo`0301moogoo03=oo`00@Woo
00<07gooOol0YGoo00<07gooOol0<goo0012Ool00`0OOomoo`2UOol00`0OOomoo`0cOol0045oo`03
01moogoo0:Ioo`0301moogoo03=oo`00@Goo00<07gooOol0YWoo00<07gooOol0<goo0011Ool00`0O
Oomoo`2VOol00`0OOomoo`0cOol0041oo`0301moogoo0:Qoo`0301moogoo039oo`00@7oo00<07goo
Ool0Z7oo00<07gooOol0<Woo0010Ool00`0OOomoo`2XOol00`0OOomoo`0bOol0041oo`0301moogoo
0:Qoo`0301moogoo039oo`00?goo00<07gooOol0ZGoo00<07gooOol0<Woo000oOol00`0OOomoo`2Y
Ool00`0OOomoo`0bOol003moo`0301moogoo0:Uoo`0301moogoo039oo`00?Woo00<07gooOol0ZWoo
00<07gooOol0<Woo000nOol00`0OOomoo`2ZOol00`0OOomoo`0bOol003ioo`0301moogoo0:Yoo`03
01moogoo039oo`00?Woo00<07gooOol0ZWoo00<07gooOol0<Woo000mOol00`0OOomoo`2[Ool00`0O
Oomoo`0bOol003eoo`0301moogoo0:]oo`0301moogoo039oo`00?Goo00<07gooOol0Zgoo00<07goo
Ool0<Woo000mOol00`0OOomoo`2[Ool00`0OOomoo`0bOol003eoo`0301moogoo0:]oo`0301moogoo
039oo`00?Goo00<07gooOol0Zgoo00<07gooOol0<Woo000lOol00`0OOomoo`2/Ool00`0OOomoo`0b
Ool003aoo`0301moogoo0:aoo`0301moogoo039oo`00?7oo00<07gooOol0[7oo00<07gooOol0<Woo
000lOol00`0OOomoo`2/Ool00`0OOomoo`0bOol003aoo`0301moogoo0:aoo`0301moogoo039oo`00
?7oo00<07gooOol0Zgoo00<07gooOol0<goo000lOol00`0OOomoo`2[Ool00`0OOomoo`0cOol003ao
o`0301moogoo0:]oo`0301moogoo03=oo`00?7oo00<07gooOol0Zgoo00<07gooOol0<goo000lOol0
0`0OOomoo`2ZOol00`0OOomoo`0dOol003aoo`0301moogoo0:Yoo`0301moogoo03Aoo`00?7oo00<0
7gooOol0ZWoo00<07gooOol0=7oo000lOol00`0OOomoo`2ZOol00`0OOomoo`0dOol003aoo`0301mo
ogoo0:Yoo`0301moogoo03Aoo`00?7oo00<07gooOol0ZWoo00<07gooOol0=7oo000lOol00`0OOomo
o`2YOol00`0OOomoo`0eOol003aoo`0301moogoo0:Uoo`0301moogoo03Eoo`00?7oo00<07gooOol0
ZGoo00<07gooOol0=Goo000lOol00`0OOomoo`2YOol00`0OOomoo`0eOol003aoo`0301moogoo0:Uo
o`0301moogoo03Eoo`00?7oo00<07gooOol0ZGoo00<07gooOol0=Goo000lOol00`0OOomoo`2XOol0
0`0OOomoo`0fOol003eoo`0301moogoo0:Moo`0301moogoo03Ioo`00?Goo00<07gooOol0YWoo00<0
7gooOol0=goo000mOol00`0OOomoo`2VOol00`0OOomoo`0gOol003eoo`0301moogoo0:Ioo`0301mo
ogoo03Moo`00?Goo00<07gooOol0YGoo00<07gooOol0>7oo000nOol00`0OOomoo`2TOol00`0OOomo
o`0hOol003ioo`0301moogoo0:Aoo`0301moogoo03Qoo`00?Woo00<07gooOol0Xgoo00<07gooOol0
>Goo000nOol00`0OOomoo`2SOol00`0OOomoo`0iOol003moo`0301moogoo0:5oo`0301moogoo03Yo
o`00?goo00<07gooOol0XGoo00<07gooOol0>Woo000oOol00`0OOomoo`2QOol00`0OOomoo`0jOol0
041oo`0301moogoo09moo`0301moogoo03]oo`00@7oo00<07gooOol0Wgoo00<07gooOol0>goo0010
Ool00`0OOomoo`2NOol00`0OOomoo`0lOol0041oo`0301moogoo09ioo`0301moogoo03aoo`00@Goo
00<07gooOol0W7oo00<07gooOol0?Goo0011Ool00`0OOomoo`2LOol00`0OOomoo`0mOol0045oo`03
01moogoo09]oo`0301moogoo03ioo`00@Woo00<07gooOol0VWoo00<07gooOol0?Woo0012Ool00`0O
Oomoo`2IOol00`0OOomoo`0oOol0049oo`0301moogoo09Uoo`0301moogoo03moo`00@Woo00<07goo
Ool0V7oo00<07gooOol0@7oo0013Ool00`0OOomoo`2GOol00`0OOomoo`10Ool004=oo`0301moogoo
09Ioo`0301moogoo045oo`00@goo00<07gooOol0UGoo00<07gooOol0@Woo0014Ool00`0OOomoo`2C
Ool00`0OOomoo`13Ool004Aoo`0301moogoo09=oo`0301moogoo04=oo`00AGoo00<07gooOol0TGoo
00<07gooOol0A7oo0015Ool00`0OOomoo`2@Ool00`0OOomoo`15Ool004Ioo`0301moogoo08moo`03
01moogoo04Eoo`00AWoo00<07gooOol0SWoo00<07gooOol0AWoo0017Ool00`0OOomoo`2<Ool00`0O
Oomoo`17Ool004Moo`0301moogoo08]oo`0301moogoo04Qoo`00B7oo00<07gooOol0RWoo00<07goo
Ool0B7oo0019Ool00`0OOomoo`28Ool00`0OOomoo`19Ool004Uoo`0301moogoo08Moo`0301moogoo
04Yoo`00BWoo00<07gooOol0QWoo00<07gooOol0BWoo001;Ool00`0OOomoo`24Ool00`0OOomoo`1;
Ool004]oo`0301moogoo08=oo`0301moogoo04aoo`00C7oo00<07gooOol0PGoo00<07gooOol0CGoo
001=Ool00`0OOomoo`20Ool00`0OOomoo`1=Ool004eoo`0301moogoo07moo`0301moogoo04ioo`00
CWoo00<07gooOol0OGoo00<07gooOol0Cgoo001?Ool00`0OOomoo`1kOol00`0OOomoo`1@Ool0051o
o`0301moogoo07Uoo`0301moogoo055oo`00DGoo00<07gooOol0Mgoo00<07gooOol0DWoo001BOol0
0`0OOomoo`1eOol00`0OOomoo`1COol005=oo`0301moogoo07=oo`0301moogoo05Aoo`00E7oo00<0
7gooOol0L7oo0P0OEgoo001EOol00`0OOomoo`1^Ool00`0OOomoo`1GOol005Ioo`0301moogoo06ao
o`0301moogoo05Qoo`00Egoo00<07gooOol0JGoo0P0OFgoo001HOol00`0OOomoo`1WOol00`0OOomo
o`1KOol005Uoo`807fIoo`0301moogoo05aoo`00Fgoo00<07gooOol0HWoo00<07gooOol0GGoo001L
Ool201mPOol201mPOol005ioo`0301moogoo05aoo`0301moogoo061oo`00Ggoo0P0OFgoo00<07goo
Ool0HGoo001QOol00`0OOomoo`1FOol201mTOol0069oo`807eAoo`807fIoo`00I7oo00<07gooOol0
Cgoo0P0OJ7oo001UOol201m<Ool301mZOol006Moo`0301moogoo04Moo`807feoo`00J7oo0P0OAGoo
0P0OKgoo001ZOol201m0Ool301maOol006aoo`807caoo`807gAoo`00KWoo0P0O>7oo0P0OMWoo001`
Ool301lbOol301mhOol007=oo`@07bYoo`@07g]oo`00Mgoo1@0O7goo1P0OOgoo001lOol701l@Ool8
01n5Ool008=ooa007heoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.23744 .38032 m
.24936 .35664 L
s
.22731 .40482 m
.23744 .38032 L
s
.24936 .35664 m
.26301 .33393 L
s
.21903 .42998 m
.22731 .40482 L
s
.26301 .33393 m
.2783 .31232 L
s
.21267 .45567 m
.21903 .42998 L
s
.2783 .31232 m
.29514 .29195 L
s
.20826 .48172 m
.21267 .45567 L
s
.29514 .29195 m
.31343 .27295 L
s
.20585 .50797 m
.20826 .48172 L
s
.31343 .27295 m
.33307 .25545 L
s
.20545 .53427 m
.20585 .50797 L
s
.33307 .25545 m
.35395 .23956 L
s
.20708 .56044 m
.20545 .53427 L
s
.35395 .23956 m
.37594 .22539 L
s
.21074 .58632 m
.20708 .56044 L
s
.37594 .22539 m
.39891 .21305 L
s
.21643 .61175 m
.21074 .58632 L
s
.39891 .21305 m
.42272 .20263 L
s
.22413 .63656 m
.21643 .61175 L
s
.42272 .20263 m
.44723 .19421 L
s
.23381 .66059 m
.22413 .63656 L
s
.44723 .19421 m
.47228 .18788 L
s
.24542 .68366 m
.23381 .66059 L
s
.47228 .18788 m
.49772 .18369 L
s
.25891 .70561 m
.24542 .68366 L
s
.49772 .18369 m
.52338 .1817 L
s
.27422 .72629 m
.25891 .70561 L
s
.52338 .1817 m
.54908 .18195 L
s
.29125 .74554 m
.27422 .72629 L
s
.54908 .18195 m
.57466 .18447 L
s
.30992 .76321 m
.29125 .74554 L
s
.57466 .18447 m
.59993 .18927 L
s
.33012 .77915 m
.30992 .76321 L
s
.59993 .18927 m
.62472 .19635 L
s
.35173 .79323 m
.33012 .77915 L
s
.62472 .19635 m
.64883 .20568 L
s
.3746 .80531 m
.35173 .79323 L
s
.64883 .20568 m
.67208 .21723 L
s
.3986 .8153 m
.3746 .80531 L
s
.67208 .21723 m
.6943 .23095 L
s
.42355 .82307 m
.3986 .8153 L
s
.6943 .23095 m
.71529 .24676 L
s
.4493 .82856 m
.42355 .82307 L
s
.71529 .24676 m
.73489 .26458 L
s
.47564 .83167 m
.4493 .82856 L
s
.73489 .26458 m
.75293 .28429 L
s
.5024 .83236 m
.47564 .83167 L
s
.75293 .28429 m
.76925 .30576 L
s
.52936 .83059 m
.5024 .83236 L
s
.76925 .30576 m
.78369 .32886 L
s
.55632 .82634 m
.52936 .83059 L
s
.78369 .32886 m
.79613 .35341 L
s
.58306 .81963 m
.55632 .82634 L
s
.79613 .35341 m
.80644 .37923 L
s
.60937 .81046 m
.58306 .81963 L
s
.80644 .37923 m
.81451 .40614 L
s
.63504 .7989 m
.60937 .81046 L
s
.81451 .40614 m
.82026 .43392 L
s
.65983 .78502 m
.63504 .7989 L
s
.82026 .43392 m
.82362 .46235 L
s
.68355 .76891 m
.65983 .78502 L
s
.82362 .46235 m
.82454 .4912 L
s
.70599 .75068 m
.68355 .76891 L
s
.82454 .4912 m
.82301 .52024 L
s
.72695 .73048 m
.70599 .75068 L
s
.82301 .52024 m
.81901 .54922 L
s
.74626 .70846 m
.72695 .73048 L
s
.81901 .54922 m
.81257 .57789 L
s
.76373 .68481 m
.74626 .70846 L
s
.81257 .57789 m
.80375 .60602 L
s
.77922 .65971 m
.76373 .68481 L
s
.80375 .60602 m
.7926 .63337 L
s
.7926 .63337 m
.77922 .65971 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol008]ooa/07gYo
o`00QWoo1@0O6goo100OMWoo0022Ool401lTOol401mbOol007moo`<07baoo`@07fioo`00OGoo0P0O
<goo0`0OJgoo001kOol201lhOol201mYOol007Qoo`<07caoo`807fMoo`00MWoo0P0O@Goo0P0OIGoo
001dOol201m5Ool201mSOol0075oo`<07dUoo`807f5oo`00Kgoo0P0OCWoo0P0OGgoo001]Ool201mB
Ool201mMOol006]oo`807eIoo`807e]oo`00JGoo0P0OFWoo0P0OFGoo001XOol00`0OOomoo`1LOol0
0`0OOomoo`1FOol006Ioo`807f1oo`807eIoo`00IGoo00<07gooOol0HWoo00<07gooOol0Dgoo001T
Ool00`0OOomoo`1TOol201mCOol006=oo`0301moogoo06Moo`0301moogoo051oo`00HGoo0P0OJgoo
00<07gooOol0Cgoo001POol00`0OOomoo`1/Ool00`0OOomoo`1>Ool005moo`0301moogoo06ioo`03
01moogoo04eoo`00GWoo00<07gooOol0L7oo00<07gooOol0C7oo001MOol00`0OOomoo`1bOol00`0O
Oomoo`1;Ool005]oo`807gIoo`0301moogoo04Yoo`00FWoo00<07gooOol0Mgoo00<07gooOol0BGoo
001IOol00`0OOomoo`1iOol00`0OOomoo`18Ool005Qoo`0301moogoo07]oo`0301moogoo04Moo`00
Egoo00<07gooOol0OGoo00<07gooOol0AWoo001FOol00`0OOomoo`1oOol00`0OOomoo`15Ool005Eo
o`0301moogoo085oo`0301moogoo04Aoo`00E7oo00<07gooOol0PWoo00<07gooOol0A7oo001COol0
0`0OOomoo`24Ool00`0OOomoo`13Ool0059oo`0301moogoo08Ioo`0301moogoo049oo`00DGoo00<0
7gooOol0Qgoo00<07gooOol0@Woo001AOol00`0OOomoo`28Ool00`0OOomoo`11Ool0051oo`0301mo
ogoo08Yoo`0301moogoo041oo`00Cgoo00<07gooOol0Rgoo00<07gooOol0@7oo001>Ool00`0OOomo
o`2=Ool00`0OOomoo`0oOol004ioo`0301moogoo08eoo`0301moogoo03moo`00CGoo00<07gooOol0
Sgoo00<07gooOol0?Woo001<Ool00`0OOomoo`2@Ool00`0OOomoo`0nOol004aoo`0301moogoo095o
o`0301moogoo03eoo`00Bgoo00<07gooOol0Tgoo00<07gooOol0?7oo001:Ool00`0OOomoo`2DOol0
0`0OOomoo`0lOol004Yoo`0301moogoo09Eoo`0301moogoo03]oo`00BGoo00<07gooOol0UWoo00<0
7gooOol0>goo0019Ool00`0OOomoo`2GOol00`0OOomoo`0jOol004Qoo`0301moogoo09Qoo`0301mo
ogoo03Yoo`00B7oo00<07gooOol0VGoo00<07gooOol0>Goo0017Ool00`0OOomoo`2JOol00`0OOomo
o`0iOol004Moo`0301moogoo09]oo`0301moogoo03Qoo`00AWoo00<07gooOol0W7oo00<07gooOol0
>7oo0016Ool00`0OOomoo`2MOol00`0OOomoo`0gOol004Eoo`0301moogoo09ioo`0301moogoo03Mo
o`00AGoo00<07gooOol0Wgoo00<07gooOol0=Woo0014Ool00`0OOomoo`2POol00`0OOomoo`0fOol0
04Aoo`0301moogoo0:1oo`0301moogoo03Ioo`00A7oo00<07gooOol0X7oo00<07gooOol0=Woo0013
Ool00`0OOomoo`2ROol00`0OOomoo`0eOol004=oo`0301moogoo0:9oo`0301moogoo03Eoo`00@Woo
00<07gooOol0Xgoo00<07gooOol0=Goo0012Ool00`0OOomoo`2SOol00`0OOomoo`0eOol0045oo`03
01moogoo0:Eoo`0301moogoo03Aoo`00@Goo00<07gooOol0YGoo00<07gooOol0=7oo0011Ool00`0O
Oomoo`2UOol00`0OOomoo`0dOol0041oo`0301moogoo0:Ioo`0301moogoo03Aoo`00@7oo00<07goo
Ool0Ygoo00<07gooOol0<goo000oOol00`0OOomoo`2XOol00`0OOomoo`0cOol003moo`0301moogoo
0:Qoo`0301moogoo03=oo`00?Woo00<07gooOol0ZGoo00<07gooOol0<goo000nOol00`0OOomoo`2Z
Ool00`0OOomoo`0bOol003ioo`0301moogoo0:Yoo`0301moogoo039oo`00?Woo00<07gooOol0ZWoo
00<07gooOol0<Woo000nOol00`0OOomoo`2ZOol00`0OOomoo`0bOol003eoo`0301moogoo0:]oo`03
01moogoo039oo`00?Goo00<07gooOol0Zgoo00<07gooOol0<Woo000mOol00`0OOomoo`2/Ool00`0O
Oomoo`0aOol003eoo`0301moogoo0:aoo`0301moogoo035oo`00?Goo00<07gooOol0[7oo00<07goo
Ool0<Goo000lOol00`0OOomoo`2]Ool00`0OOomoo`0aOol003aoo`0301moogoo0:eoo`0301moogoo
035oo`00?7oo00<07gooOol0[Goo00<07gooOol0<Goo000lOol00`0OOomoo`2]Ool00`0OOomoo`0a
Ool003]oo`0301moogoo0:ioo`0301moogoo035oo`00>goo00<07gooOol0[Woo00<07gooOol0<Goo
000kOol00`0OOomoo`2^Ool00`0OOomoo`0aOol003]oo`0301moogoo0:ioo`0301moogoo035oo`00
>goo00<07gooOol0[Woo00<07gooOol0<Goo000kOol00`0OOomoo`2^Ool00`0OOomoo`0aOol003]o
o`0301moogoo0:ioo`0301moogoo035oo`00>goo00<07gooOol0[Woo00<07gooOol0<Goo000kOol0
0`0OOomoo`2^Ool00`0OOomoo`0aOol003]oo`0301moogoo0:ioo`0301moogoo035oo`00>goo00<0
7gooOol0[Woo00<07gooOol0<Goo000kOol00`0OOomoo`2^Ool00`0OOomoo`0aOol003]oo`0301mo
ogoo0:ioo`0301moogoo035oo`00>Woo00<07gooOol0[goo00<07gooOol0<Goo000jOol00`0OOomo
o`2_Ool00`0OOomoo`0aOol003Yoo`0301moogoo0:moo`0301moogoo035oo`00>Woo00<07gooOol0
[goo00<07gooOol0<Goo000jOol00`0OOomoo`2^Ool00`0OOomoo`0bOol003Yoo`0301moogoo0:io
o`0301moogoo039oo`00>Woo00<07gooOol0[Woo00<07gooOol0<Woo000jOol00`0OOomoo`2^Ool0
0`0OOomoo`0bOol003]oo`0301moogoo0:eoo`0301moogoo039oo`00>goo00<07gooOol0[Goo00<0
7gooOol0<Woo000kOol00`0OOomoo`2/Ool00`0OOomoo`0cOol003]oo`0301moogoo0:aoo`0301mo
ogoo03=oo`00>goo00<07gooOol0[7oo00<07gooOol0<goo000kOol00`0OOomoo`2/Ool00`0OOomo
o`0cOol003]oo`0301moogoo0:]oo`0301moogoo03Aoo`00>goo00<07gooOol0Zgoo00<07gooOol0
=7oo000lOol00`0OOomoo`2ZOol00`0OOomoo`0dOol003aoo`0301moogoo0:Yoo`0301moogoo03Ao
o`00?7oo00<07gooOol0ZGoo00<07gooOol0=Goo000lOol00`0OOomoo`2YOol00`0OOomoo`0eOol0
03aoo`0301moogoo0:Qoo`0301moogoo03Ioo`00?Goo00<07gooOol0Ygoo00<07gooOol0=Woo000m
Ool00`0OOomoo`2WOol00`0OOomoo`0fOol003eoo`0301moogoo0:Ioo`0301moogoo03Moo`00?Goo
00<07gooOol0YWoo00<07gooOol0=goo000nOol00`0OOomoo`2UOol00`0OOomoo`0gOol003ioo`03
01moogoo0:Aoo`0301moogoo03Qoo`00?Woo00<07gooOol0Y7oo00<07gooOol0>7oo000oOol00`0O
Oomoo`2ROol00`0OOomoo`0iOol003moo`0301moogoo0:9oo`0301moogoo03Uoo`00?goo00<07goo
Ool0XWoo00<07gooOol0>Goo000oOol00`0OOomoo`2QOol00`0OOomoo`0jOol0041oo`0301moogoo
0:1oo`0301moogoo03Yoo`00@7oo00<07gooOol0Wgoo00<07gooOol0>goo0010Ool00`0OOomoo`2O
Ool00`0OOomoo`0kOol0045oo`0301moogoo09eoo`0301moogoo03aoo`00@Goo00<07gooOol0WGoo
00<07gooOol0?7oo0012Ool00`0OOomoo`2KOol00`0OOomoo`0mOol0049oo`0301moogoo09]oo`03
01moogoo03eoo`00@goo00<07gooOol0VGoo00<07gooOol0?Woo0013Ool00`0OOomoo`2IOol00`0O
Oomoo`0nOol004=oo`0301moogoo09Qoo`0301moogoo03moo`00A7oo00<07gooOol0Ugoo00<07goo
Ool0?goo0014Ool00`0OOomoo`2FOol00`0OOomoo`10Ool004Eoo`0301moogoo09Eoo`0301moogoo
041oo`00AGoo00<07gooOol0U7oo00<07gooOol0@Goo0016Ool00`0OOomoo`2COol00`0OOomoo`11
Ool004Ioo`0301moogoo099oo`0301moogoo049oo`00Agoo00<07gooOol0T7oo00<07gooOol0@goo
0017Ool00`0OOomoo`2@Ool00`0OOomoo`13Ool004Qoo`0301moogoo08ioo`0301moogoo04Aoo`00
BGoo00<07gooOol0S7oo00<07gooOol0AGoo0019Ool00`0OOomoo`2;Ool00`0OOomoo`16Ool004Yo
o`0301moogoo08Yoo`0301moogoo04Ioo`00Bgoo00<07gooOol0R7oo00<07gooOol0Agoo001;Ool0
0`0OOomoo`27Ool00`0OOomoo`18Ool004aoo`0301moogoo08Eoo`0301moogoo04Uoo`00CGoo00<0
7gooOol0Pgoo00<07gooOol0BWoo001=Ool00`0OOomoo`22Ool00`0OOomoo`1;Ool004ioo`0301mo
ogoo081oo`0301moogoo04aoo`00Cgoo00<07gooOol0OWoo00<07gooOol0CGoo001@Ool00`0OOomo
o`1lOol00`0OOomoo`1>Ool0055oo`0301moogoo07Yoo`0301moogoo04moo`00DWoo00<07gooOol0
N7oo00<07gooOol0D7oo001COol00`0OOomoo`1fOol00`0OOomoo`1AOol005Aoo`0301moogoo07Ao
o`0301moogoo059oo`00EGoo00<07gooOol0LWoo00<07gooOol0Dgoo001EOol00`0OOomoo`1aOol0
0`0OOomoo`1DOol005Ioo`0301moogoo06moo`0301moogoo05Eoo`00Egoo00<07gooOol0K7oo0P0O
F7oo001HOol00`0OOomoo`1ZOol00`0OOomoo`1HOol005Uoo`807fUoo`0301moogoo05Uoo`00Fgoo
00<07gooOol0I7oo0P0OG7oo001LOol201mSOol00`0OOomoo`1LOol005ioo`0301moogoo05moo`03
01moogoo05eoo`00Ggoo0P0OGGoo0P0OH7oo001QOol00`0OOomoo`1IOol00`0OOomoo`1POol0069o
o`807eMoo`807f=oo`00I7oo00<07gooOol0DWoo0P0OIGoo001UOol201m@Ool201mWOol006Moo`80
7daoo`807fUoo`00JGoo0P0OB7oo0P0OJgoo001[Ool201m3Ool301m]Ool006eoo`@07caoo`<07g1o
o`00LGoo0`0O=goo0P0OLgoo001dOol201lcOol201meOol007Ioo`807bioo`<07gMoo`00N7oo1@0O
9Goo100ONWoo001mOol701lHOol601mnOol008AooaP07hAoo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.2197 .39812 m
.22977 .37336 L
s
.21157 .42358 m
.2197 .39812 L
s
.20542 .44958 m
.21157 .42358 L
s
.22977 .37336 m
.2417 .34946 L
s
.2013 .47596 m
.20542 .44958 L
s
.2417 .34946 m
.25543 .32656 L
s
.19923 .50256 m
.2013 .47596 L
s
.25543 .32656 m
.27088 .30482 L
s
.19924 .5292 m
.19923 .50256 L
s
.27088 .30482 m
.28796 .28438 L
s
.20133 .55572 m
.19924 .5292 L
s
.28796 .28438 m
.30655 .26536 L
s
.2055 .58195 m
.20133 .55572 L
s
.30655 .26536 m
.32656 .24791 L
s
.21174 .60771 m
.2055 .58195 L
s
.32656 .24791 m
.34786 .23214 L
s
.22002 .63285 m
.21174 .60771 L
s
.34786 .23214 m
.37032 .21816 L
s
.2303 .65718 m
.22002 .63285 L
s
.37032 .21816 m
.39381 .20608 L
s
.24253 .68055 m
.2303 .65718 L
s
.39381 .20608 m
.41817 .19599 L
s
.25664 .70279 m
.24253 .68055 L
s
.41817 .19599 m
.44326 .18799 L
s
.27257 .72374 m
.25664 .70279 L
s
.44326 .18799 m
.46891 .18213 L
s
.29021 .74325 m
.27257 .72374 L
s
.46891 .18213 m
.49496 .17849 L
s
.30946 .76117 m
.29021 .74325 L
s
.49496 .17849 m
.52123 .1771 L
s
.33022 .77735 m
.30946 .76117 L
s
.52123 .1771 m
.54754 .17802 L
s
.35235 .79167 m
.33022 .77735 L
s
.54754 .17802 m
.5737 .18124 L
s
.3757 .804 m
.35235 .79167 L
s
.5737 .18124 m
.59954 .18679 L
s
.40014 .81424 m
.3757 .804 L
s
.59954 .18679 m
.62485 .19464 L
s
.42549 .82227 m
.40014 .81424 L
s
.62485 .19464 m
.64946 .20476 L
s
.45157 .82802 m
.42549 .82227 L
s
.64946 .20476 m
.67317 .21711 L
s
.47821 .83143 m
.45157 .82802 L
s
.67317 .21711 m
.6958 .23162 L
s
.50521 .83243 m
.47821 .83143 L
s
.6958 .23162 m
.71716 .24821 L
s
.53237 .83099 m
.50521 .83243 L
s
.71716 .24821 m
.73708 .26677 L
s
.55948 .8271 m
.53237 .83099 L
s
.73708 .26677 m
.75539 .28718 L
s
.58634 .82077 m
.55948 .8271 L
s
.75539 .28718 m
.77193 .30931 L
s
.61273 .812 m
.58634 .82077 L
s
.77193 .30931 m
.78655 .333 L
s
.63843 .80087 m
.61273 .812 L
s
.78655 .333 m
.79913 .35807 L
s
.66325 .78742 m
.63843 .80087 L
s
.79913 .35807 m
.80954 .38434 L
s
.68697 .77176 m
.66325 .78742 L
s
.80954 .38434 m
.81768 .4116 L
s
.70939 .75398 m
.68697 .77176 L
s
.81768 .4116 m
.82348 .43965 L
s
.73033 .73422 m
.70939 .75398 L
s
.82348 .43965 m
.82687 .46827 L
s
.74961 .71264 m
.73033 .73422 L
s
.82687 .46827 m
.82781 .49721 L
s
.76706 .68939 m
.74961 .71264 L
s
.82781 .49721 m
.82628 .52626 L
s
.78253 .66467 m
.76706 .68939 L
s
.82628 .52626 m
.82228 .55516 L
s
.79589 .63867 m
.78253 .66467 L
s
.82228 .55516 m
.81585 .58369 L
s
.80703 .6116 m
.79589 .63867 L
s
.81585 .58369 m
.80703 .6116 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00TWoo1`0OQgoo002;Ool701l7Ool801mo
Ool008=oo`P07aIoo`L07gQoo`00OWoo1@0O9Goo1P0OLWoo001lOol201l`Ool401m^Ool007Yoo`80
7cIoo`<07f]oo`00Mgoo0`0O>goo0P0OJGoo001eOol201m0Ool201mWOol007=oo`807dAoo`807fEo
o`00L7oo0`0OB7oo0P0OHgoo001^Ool201m=Ool201mQOol006aoo`807e5oo`807emoo`00JWoo0P0O
EGoo00<07gooOol0G7oo001XOol201mHOol201mLOol006Ioo`807eaoo`0301moogoo05Uoo`00I7oo
0P0OGgoo0P0OFGoo001SOol00`0OOomoo`1QOol00`0OOomoo`1FOol0069oo`0301moogoo06=oo`03
01moogoo05Eoo`00HGoo00<07gooOol0IGoo00<07gooOol0E7oo001OOol201mYOol201mDOol005io
o`0301moogoo06]oo`0301moogoo055oo`00GGoo00<07gooOol0KGoo00<07gooOol0D7oo001LOol0
0`0OOomoo`1_Ool00`0OOomoo`1?Ool005]oo`0301moogoo075oo`0301moogoo04ioo`00FGoo0P0O
MGoo0P0OCWoo001HOol00`0OOomoo`1gOol00`0OOomoo`1;Ool005Moo`0301moogoo07Uoo`0301mo
ogoo04Yoo`00EWoo00<07gooOol0Ngoo00<07gooOol0BGoo001EOol00`0OOomoo`1mOol00`0OOomo
o`18Ool005Aoo`0301moogoo07ioo`0301moogoo04Qoo`00Dgoo00<07gooOol0P7oo00<07gooOol0
Agoo001BOol00`0OOomoo`22Ool00`0OOomoo`16Ool0055oo`0301moogoo08Aoo`0301moogoo04Eo
o`00D7oo00<07gooOol0QWoo00<07gooOol0A7oo001?Ool00`0OOomoo`28Ool00`0OOomoo`13Ool0
04moo`0301moogoo08Qoo`0301moogoo04=oo`00CWoo00<07gooOol0RWoo00<07gooOol0@Woo001=
Ool00`0OOomoo`2<Ool00`0OOomoo`11Ool004aoo`0301moogoo08ioo`0301moogoo041oo`00C7oo
00<07gooOol0Sgoo00<07gooOol0?goo001;Ool00`0OOomoo`2@Ool00`0OOomoo`0oOol004Yoo`03
01moogoo099oo`0301moogoo03ioo`00BWoo00<07gooOol0TWoo00<07gooOol0?Woo0019Ool00`0O
Oomoo`2DOol00`0OOomoo`0mOol004Qoo`0301moogoo09Eoo`0301moogoo03eoo`00B7oo00<07goo
Ool0UWoo00<07gooOol0?7oo0017Ool00`0OOomoo`2HOol00`0OOomoo`0kOol004Moo`0301moogoo
09Qoo`0301moogoo03]oo`00AWoo00<07gooOol0VWoo00<07gooOol0>Woo0016Ool00`0OOomoo`2J
Ool00`0OOomoo`0jOol004Eoo`0301moogoo09aoo`0301moogoo03Uoo`00A7oo00<07gooOol0WGoo
00<07gooOol0>Goo0014Ool00`0OOomoo`2NOol00`0OOomoo`0hOol004=oo`0301moogoo09moo`03
01moogoo03Qoo`00@goo00<07gooOol0X7oo00<07gooOol0=goo0012Ool00`0OOomoo`2QOol00`0O
Oomoo`0gOol0049oo`0301moogoo0:5oo`0301moogoo03Moo`00@Goo00<07gooOol0Xgoo00<07goo
Ool0=Woo0011Ool00`0OOomoo`2SOol00`0OOomoo`0fOol0041oo`0301moogoo0:Eoo`0301moogoo
03Eoo`00@7oo00<07gooOol0YGoo00<07gooOol0=Goo0010Ool00`0OOomoo`2UOol00`0OOomoo`0e
Ool0041oo`0301moogoo0:Eoo`0301moogoo03Eoo`00?goo00<07gooOol0Ygoo00<07gooOol0=7oo
000oOol00`0OOomoo`2WOol00`0OOomoo`0dOol003moo`0301moogoo0:Moo`0301moogoo03Aoo`00
?Woo00<07gooOol0Z7oo00<07gooOol0=7oo000nOol00`0OOomoo`2YOol00`0OOomoo`0cOol003eo
o`0301moogoo0:Yoo`0301moogoo03=oo`00?Goo00<07gooOol0ZWoo00<07gooOol0<goo000lOol0
0`0OOomoo`2[Ool00`0OOomoo`0cOol003aoo`0301moogoo0:aoo`0301moogoo039oo`00?7oo00<0
7gooOol0[7oo00<07gooOol0<Woo000kOol00`0OOomoo`2]Ool00`0OOomoo`0bOol003]oo`0301mo
ogoo0:eoo`0301moogoo039oo`00>goo00<07gooOol0[Woo00<07gooOol0<Goo000kOol00`0OOomo
o`2^Ool00`0OOomoo`0aOol003Yoo`0301moogoo0:moo`0301moogoo035oo`00>Woo00<07gooOol0
[goo00<07gooOol0<Goo000jOol00`0OOomoo`2_Ool00`0OOomoo`0aOol003Yoo`0301moogoo0:mo
o`0301moogoo035oo`00>Woo00<07gooOol0/7oo00<07gooOol0<7oo000jOol00`0OOomoo`2`Ool0
0`0OOomoo`0`Ool003Uoo`0301moogoo0;5oo`0301moogoo031oo`00>Goo00<07gooOol0/Goo00<0
7gooOol0<7oo000iOol00`0OOomoo`2aOol00`0OOomoo`0`Ool003Uoo`0301moogoo0;5oo`0301mo
ogoo031oo`00>Goo00<07gooOol0/Goo00<07gooOol0<7oo000iOol00`0OOomoo`2aOol00`0OOomo
o`0`Ool003Uoo`0301moogoo0;5oo`0301moogoo031oo`00>Goo00<07gooOol0/Goo00<07gooOol0
<7oo000iOol00`0OOomoo`2aOol00`0OOomoo`0`Ool003Uoo`0301moogoo0;5oo`0301moogoo031o
o`00>Goo00<07gooOol0/Goo00<07gooOol0<7oo000iOol00`0OOomoo`2aOol00`0OOomoo`0`Ool0
03Uoo`0301moogoo0;5oo`0301moogoo031oo`00>Goo00<07gooOol0/Goo00<07gooOol0<7oo000i
Ool00`0OOomoo`2aOol00`0OOomoo`0`Ool003Uoo`0301moogoo0;5oo`0301moogoo031oo`00>Goo
00<07gooOol0/Goo00<07gooOol0<7oo000iOol00`0OOomoo`2aOol00`0OOomoo`0`Ool003Uoo`03
01moogoo0;5oo`0301moogoo031oo`00>Goo00<07gooOol0/Goo00<07gooOol0<7oo000iOol00`0O
Oomoo`2`Ool00`0OOomoo`0aOol003Uoo`0301moogoo0;1oo`0301moogoo035oo`00>Goo00<07goo
Ool0/7oo00<07gooOol0<Goo000iOol00`0OOomoo`2`Ool00`0OOomoo`0aOol003Uoo`0301moogoo
0:moo`0301moogoo039oo`00>Goo00<07gooOol0[goo00<07gooOol0<Woo000iOol00`0OOomoo`2_
Ool00`0OOomoo`0bOol003Uoo`0301moogoo0:moo`0301moogoo039oo`00>Goo00<07gooOol0[goo
00<07gooOol0<Woo000iOol00`0OOomoo`2_Ool00`0OOomoo`0bOol003Uoo`0301moogoo0:ioo`03
01moogoo03=oo`00>Woo00<07gooOol0[Goo00<07gooOol0<goo000jOol00`0OOomoo`2]Ool00`0O
Oomoo`0cOol003Yoo`0301moogoo0:eoo`0301moogoo03=oo`00>Woo00<07gooOol0[Goo00<07goo
Ool0<goo000jOol00`0OOomoo`2]Ool00`0OOomoo`0cOol003]oo`0301moogoo0:]oo`0301moogoo
03Aoo`00>goo00<07gooOol0Zgoo00<07gooOol0=7oo000kOol00`0OOomoo`2ZOol00`0OOomoo`0e
Ool003]oo`0301moogoo0:Yoo`0301moogoo03Eoo`00?7oo00<07gooOol0ZGoo00<07gooOol0=Goo
000lOol00`0OOomoo`2XOol00`0OOomoo`0fOol003aoo`0301moogoo0:Qoo`0301moogoo03Ioo`00
?Goo00<07gooOol0Ygoo00<07gooOol0=Woo000mOol00`0OOomoo`2VOol00`0OOomoo`0gOol003io
o`0301moogoo0:Eoo`0301moogoo03Moo`00?Woo00<07gooOol0Y7oo00<07gooOol0>7oo000oOol0
0`0OOomoo`2SOol00`0OOomoo`0hOol003moo`0301moogoo0:=oo`0301moogoo03Qoo`00?goo00<0
7gooOol0XWoo00<07gooOol0>Goo0010Ool00`0OOomoo`2QOol00`0OOomoo`0iOol0041oo`0301mo
ogoo0:1oo`0301moogoo03Yoo`00@Goo00<07gooOol0Wgoo00<07gooOol0>Woo0011Ool00`0OOomo
o`2NOol00`0OOomoo`0kOol0049oo`0301moogoo09eoo`0301moogoo03]oo`00@Woo00<07gooOol0
W7oo00<07gooOol0?7oo0012Ool00`0OOomoo`2LOol00`0OOomoo`0lOol004=oo`0301moogoo09Yo
o`0301moogoo03eoo`00@goo00<07gooOol0VGoo00<07gooOol0?Woo0014Ool00`0OOomoo`2HOol0
0`0OOomoo`0nOol004Aoo`0301moogoo09Moo`0301moogoo03moo`00AGoo00<07gooOol0UWoo00<0
7gooOol0?goo0015Ool00`0OOomoo`2EOol00`0OOomoo`10Ool004Ioo`0301moogoo09Aoo`0301mo
ogoo041oo`00AWoo00<07gooOol0Tgoo00<07gooOol0@Goo0017Ool00`0OOomoo`2AOol00`0OOomo
o`12Ool004Qoo`0301moogoo091oo`0301moogoo049oo`00B7oo00<07gooOol0Sgoo00<07gooOol0
@goo0019Ool00`0OOomoo`2=Ool00`0OOomoo`14Ool004Yoo`0301moogoo08]oo`0301moogoo04Eo
o`00Bgoo00<07gooOol0RWoo00<07gooOol0AGoo001;Ool00`0OOomoo`29Ool00`0OOomoo`16Ool0
04aoo`0301moogoo08Moo`0301moogoo04Moo`00CGoo00<07gooOol0QGoo00<07gooOol0B7oo001>
Ool00`0OOomoo`23Ool00`0OOomoo`19Ool004moo`0301moogoo085oo`0301moogoo04Yoo`00D7oo
00<07gooOol0Ogoo00<07gooOol0Bgoo001@Ool00`0OOomoo`1nOol00`0OOomoo`1<Ool0055oo`03
01moogoo07aoo`0301moogoo04eoo`00DWoo00<07gooOol0NWoo00<07gooOol0CWoo001COol00`0O
Oomoo`1hOol00`0OOomoo`1?Ool005Aoo`0301moogoo07Ioo`0301moogoo051oo`00EGoo00<07goo
Ool0M7oo00<07gooOol0DGoo001FOol00`0OOomoo`1bOol00`0OOomoo`1BOol005Moo`0301moogoo
071oo`0301moogoo05=oo`00F7oo00<07gooOol0KWoo00<07gooOol0E7oo001IOol00`0OOomoo`1[
Ool201mGOol005Yoo`0301moogoo06Uoo`0301moogoo05Moo`00Fgoo0P0OJ7oo00<07gooOol0F7oo
001MOol00`0OOomoo`1SOol201mKOol005ioo`0301moogoo061oo`807eeoo`00Ggoo0P0OGWoo0P0O
Ggoo001QOol201mKOol00`0OOomoo`1OOol006=oo`807eMoo`807f9oo`00IGoo00<07gooOol0DWoo
0P0OI7oo001VOol201m@Ool201mVOol006Qoo`807deoo`0301moogoo06Ioo`00JWoo0`0OB7oo0P0O
JGoo001]Ool201m4Ool201m[Ool006moo`807d1oo`807feoo`00LGoo0`0O>Woo0`0OKgoo001dOol4
01lbOol401mbOol007Qoo`@07b]oo`<07gIoo`00O7oo100O8goo100ONGoo0020Ool501lHOol601mm
Ool008EooaP07h=oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.19837 .44422 m
.20441 .41795 L
s
.19442 .47087 m
.19837 .44422 L
s
.20441 .41795 m
.21251 .39225 L
s
.19259 .49775 m
.19442 .47087 L
s
.21251 .39225 m
.22262 .36728 L
s
.1929 .52468 m
.19259 .49775 L
s
.22262 .36728 m
.23467 .34319 L
s
.19535 .55149 m
.1929 .52468 L
s
.23467 .34319 m
.24859 .32016 L
s
.19993 .57799 m
.19535 .55149 L
s
.24859 .32016 m
.26429 .29833 L
s
.20662 .60402 m
.19993 .57799 L
s
.26429 .29833 m
.28169 .27785 L
s
.21539 .62941 m
.20662 .60402 L
s
.28169 .27785 m
.30067 .25885 L
s
.22618 .65397 m
.21539 .62941 L
s
.30067 .25885 m
.32111 .24148 L
s
.23893 .67756 m
.22618 .65397 L
s
.32111 .24148 m
.3429 .22585 L
s
.25358 .7 m
.23893 .67756 L
s
.3429 .22585 m
.36589 .21209 L
s
.27004 .72113 m
.25358 .7 L
s
.36589 .21209 m
.38994 .20029 L
s
.28821 .74081 m
.27004 .72113 L
s
.38994 .20029 m
.41489 .19055 L
s
.30798 .75888 m
.28821 .74081 L
s
.41489 .19055 m
.44058 .18296 L
s
.32923 .77521 m
.30798 .75888 L
s
.44058 .18296 m
.46683 .17758 L
s
.35182 .78968 m
.32923 .77521 L
s
.46683 .17758 m
.49348 .17448 L
s
.3756 .80215 m
.35182 .78968 L
s
.49348 .17448 m
.52033 .17368 L
s
.40043 .81253 m
.3756 .80215 L
s
.52033 .17368 m
.54721 .17523 L
s
.42613 .82073 m
.40043 .81253 L
s
.54721 .17523 m
.57391 .17912 L
s
.45252 .82666 m
.42613 .82073 L
s
.57391 .17912 m
.60024 .18536 L
s
.47942 .83026 m
.45252 .82666 L
s
.60024 .18536 m
.62601 .19392 L
s
.50664 .83148 m
.47942 .83026 L
s
.62601 .19392 m
.65103 .20476 L
s
.53398 .83029 m
.50664 .83148 L
s
.65103 .20476 m
.6751 .21782 L
s
.56123 .82668 m
.53398 .83029 L
s
.6751 .21782 m
.69803 .23302 L
s
.58819 .82065 m
.56123 .82668 L
s
.69803 .23302 m
.71963 .25027 L
s
.61466 .81223 m
.58819 .82065 L
s
.71963 .25027 m
.73975 .26945 L
s
.64042 .80146 m
.61466 .81223 L
s
.73975 .26945 m
.7582 .29044 L
s
.66527 .7884 m
.64042 .80146 L
s
.7582 .29044 m
.77483 .31308 L
s
.68901 .77315 m
.66527 .7884 L
s
.77483 .31308 m
.7895 .33721 L
s
.71145 .75581 m
.68901 .77315 L
s
.7895 .33721 m
.80209 .36265 L
s
.73241 .7365 m
.71145 .75581 L
s
.80209 .36265 m
.81247 .38921 L
s
.7517 .71536 m
.73241 .7365 L
s
.81247 .38921 m
.82056 .41668 L
s
.76918 .69255 m
.7517 .71536 L
s
.82056 .41668 m
.82629 .44486 L
s
.78469 .66824 m
.76918 .69255 L
s
.82629 .44486 m
.82959 .47351 L
s
.7981 .64264 m
.78469 .66824 L
s
.82959 .47351 m
.83043 .50241 L
s
.8093 .61592 m
.7981 .64264 L
s
.83043 .50241 m
.8288 .53134 L
s
.81819 .58832 m
.8093 .61592 L
s
.8288 .53134 m
.82471 .56005 L
s
.82471 .56005 m
.81819 .58832 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol0099oo`L07hMoo`00Q7oo3P0O1goo200OOgoo0020Ool4
01lMOol501mjOol007eoo`<07bIoo`@07gIoo`00NGoo100O;Goo100OLWoo001fOol301leOol401m^
Ool007Aoo`807caoo`<07f]oo`00LGoo0`0O@Goo0P0OJGoo001_Ool201m6Ool201mWOol006eoo`80
7dYoo`807fEoo`00Jgoo0P0OCWoo0P0OHgoo001YOol201mBOol201mQOol006Moo`807eIoo`807emo
o`00IGoo0P0OFWoo00<07gooOol0G7oo001SOol201mMOol201mLOol0069oo`0301moogoo05moo`80
7eYoo`00HGoo00<07gooOol0HWoo0P0OF7oo001POol00`0OOomoo`1UOol00`0OOomoo`1EOol005io
o`807fUoo`0301moogoo05Aoo`00GGoo00<07gooOol0JWoo00<07gooOol0Dgoo001LOol00`0OOomo
o`1/Ool201mCOol005]oo`0301moogoo06moo`0301moogoo051oo`00FWoo00<07gooOol0LGoo00<0
7gooOol0Cgoo001HOol201meOol00`0OOomoo`1>Ool005Moo`0301moogoo07Ioo`0301moogoo04eo
o`00EWoo00<07gooOol0N7oo00<07gooOol0C7oo001EOol00`0OOomoo`1jOol00`0OOomoo`1;Ool0
05Aoo`0301moogoo07aoo`0301moogoo04Yoo`00DWoo0P0OP7oo00<07gooOol0BGoo001AOol00`0O
Oomoo`21Ool00`0OOomoo`18Ool0051oo`0301moogoo08=oo`0301moogoo04Moo`00Cgoo00<07goo
Ool0Q7oo00<07gooOol0Agoo001>Ool00`0OOomoo`26Ool00`0OOomoo`16Ool004eoo`0301moogoo
08Qoo`0301moogoo04Eoo`00CGoo00<07gooOol0RGoo00<07gooOol0A7oo001<Ool00`0OOomoo`2;
Ool00`0OOomoo`13Ool004]oo`0301moogoo08eoo`0301moogoo049oo`00BWoo00<07gooOol0SWoo
00<07gooOol0@Woo001:Ool00`0OOomoo`2?Ool00`0OOomoo`11Ool004Uoo`0301moogoo095oo`03
01moogoo041oo`00B7oo00<07gooOol0Tgoo00<07gooOol0?goo0018Ool00`0OOomoo`2DOol00`0O
Oomoo`0nOol004Moo`0301moogoo09Eoo`0301moogoo03ioo`00AWoo00<07gooOol0Ugoo00<07goo
Ool0?Goo0016Ool00`0OOomoo`2GOol00`0OOomoo`0mOol004Eoo`0301moogoo09Uoo`0301moogoo
03aoo`00AGoo00<07gooOol0VGoo00<07gooOol0?7oo0014Ool00`0OOomoo`2KOol00`0OOomoo`0k
Ool004Aoo`0301moogoo09]oo`0301moogoo03]oo`00@goo00<07gooOol0WGoo00<07gooOol0>Woo
0012Ool00`0OOomoo`2NOol00`0OOomoo`0jOol0049oo`0301moogoo09moo`0301moogoo03Uoo`00
@Goo00<07gooOol0X7oo00<07gooOol0>Goo0011Ool00`0OOomoo`2QOol00`0OOomoo`0hOol0041o
o`0301moogoo0:9oo`0301moogoo03Qoo`00@7oo00<07gooOol0Xgoo00<07gooOol0=goo000oOol0
0`0OOomoo`2TOol00`0OOomoo`0gOol003moo`0301moogoo0:Eoo`0301moogoo03Ioo`00?Woo00<0
7gooOol0YWoo00<07gooOol0=Woo000nOol00`0OOomoo`2WOol00`0OOomoo`0eOol003eoo`0301mo
ogoo0:Qoo`0301moogoo03Eoo`00?Goo00<07gooOol0ZGoo00<07gooOol0=7oo000lOol00`0OOomo
o`2ZOol00`0OOomoo`0dOol003aoo`0301moogoo0:Yoo`0301moogoo03Aoo`00?7oo00<07gooOol0
ZWoo00<07gooOol0=7oo000kOol00`0OOomoo`2/Ool00`0OOomoo`0cOol003]oo`0301moogoo0:ao
o`0301moogoo03=oo`00>goo00<07gooOol0[7oo00<07gooOol0<goo000kOol00`0OOomoo`2/Ool0
0`0OOomoo`0cOol003Yoo`0301moogoo0:ioo`0301moogoo039oo`00>Woo00<07gooOol0[Woo00<0
7gooOol0<Woo000jOol00`0OOomoo`2^Ool00`0OOomoo`0bOol003Uoo`0301moogoo0:moo`0301mo
ogoo039oo`00>Goo00<07gooOol0/7oo00<07gooOol0<Goo000iOol00`0OOomoo`2`Ool00`0OOomo
o`0aOol003Uoo`0301moogoo0;1oo`0301moogoo035oo`00>7oo00<07gooOol0/Goo00<07gooOol0
<Goo000hOol00`0OOomoo`2bOol00`0OOomoo`0`Ool003Qoo`0301moogoo0;9oo`0301moogoo031o
o`00>7oo00<07gooOol0/Woo00<07gooOol0<7oo000hOol00`0OOomoo`2bOol00`0OOomoo`0`Ool0
03Qoo`0301moogoo0;9oo`0301moogoo031oo`00=goo00<07gooOol0/goo00<07gooOol0<7oo000g
Ool00`0OOomoo`2dOol00`0OOomoo`0_Ool003Moo`0301moogoo0;Aoo`0301moogoo02moo`00=goo
00<07gooOol0]7oo00<07gooOol0;goo000gOol00`0OOomoo`2dOol00`0OOomoo`0_Ool003Moo`03
01moogoo0;Aoo`0301moogoo02moo`00=goo00<07gooOol0]7oo00<07gooOol0;goo000gOol00`0O
Oomoo`2dOol00`0OOomoo`0_Ool003Moo`0301moogoo0;Aoo`0301moogoo02moo`00=goo00<07goo
Ool0]7oo00<07gooOol0;goo000gOol00`0OOomoo`2dOol00`0OOomoo`0_Ool003Moo`0301moogoo
0;Aoo`0301moogoo02moo`00=goo00<07gooOol0]7oo00<07gooOol0;goo000gOol00`0OOomoo`2d
Ool00`0OOomoo`0_Ool003Moo`0301moogoo0;Aoo`0301moogoo02moo`00=goo00<07gooOol0]7oo
00<07gooOol0;goo000gOol00`0OOomoo`2dOol00`0OOomoo`0_Ool003Moo`0301moogoo0;=oo`03
01moogoo031oo`00=goo00<07gooOol0/goo00<07gooOol0<7oo000gOol00`0OOomoo`2cOol00`0O
Oomoo`0`Ool003Moo`0301moogoo0;=oo`0301moogoo031oo`00=goo00<07gooOol0/goo00<07goo
Ool0<7oo000gOol00`0OOomoo`2cOol00`0OOomoo`0`Ool003Moo`0301moogoo0;=oo`0301moogoo
031oo`00>7oo00<07gooOol0/Woo00<07gooOol0<7oo000hOol00`0OOomoo`2aOol00`0OOomoo`0a
Ool003Qoo`0301moogoo0;5oo`0301moogoo035oo`00>7oo00<07gooOol0/Goo00<07gooOol0<Goo
000hOol00`0OOomoo`2aOol00`0OOomoo`0aOol003Qoo`0301moogoo0;5oo`0301moogoo035oo`00
>7oo00<07gooOol0/Goo00<07gooOol0<Goo000iOol00`0OOomoo`2_Ool00`0OOomoo`0bOol003Uo
o`0301moogoo0:moo`0301moogoo039oo`00>Goo00<07gooOol0[goo00<07gooOol0<Woo000iOol0
0`0OOomoo`2_Ool00`0OOomoo`0bOol003Uoo`0301moogoo0:ioo`0301moogoo03=oo`00>Goo00<0
7gooOol0[Woo00<07gooOol0<goo000jOol00`0OOomoo`2]Ool00`0OOomoo`0cOol003Yoo`0301mo
ogoo0:eoo`0301moogoo03=oo`00>Woo00<07gooOol0[7oo00<07gooOol0=7oo000jOol00`0OOomo
o`2/Ool00`0OOomoo`0dOol003]oo`0301moogoo0:]oo`0301moogoo03Aoo`00>goo00<07gooOol0
Zgoo00<07gooOol0=7oo000kOol00`0OOomoo`2ZOol00`0OOomoo`0eOol003aoo`0301moogoo0:Uo
o`0301moogoo03Eoo`00?7oo00<07gooOol0ZGoo00<07gooOol0=Goo000lOol00`0OOomoo`2YOol0
0`0OOomoo`0eOol003aoo`0301moogoo0:Qoo`0301moogoo03Ioo`00?Goo00<07gooOol0Ygoo00<0
7gooOol0=Woo000mOol00`0OOomoo`2VOol00`0OOomoo`0gOol003eoo`0301moogoo0:Ioo`0301mo
ogoo03Moo`00?Woo00<07gooOol0YGoo00<07gooOol0=goo000nOol00`0OOomoo`2TOol00`0OOomo
o`0hOol003moo`0301moogoo0:=oo`0301moogoo03Qoo`00?goo00<07gooOol0XWoo00<07gooOol0
>Goo0010Ool00`0OOomoo`2QOol00`0OOomoo`0iOol0041oo`0301moogoo0:1oo`0301moogoo03Yo
o`00@Goo00<07gooOol0Wgoo00<07gooOol0>Woo0011Ool00`0OOomoo`2NOol00`0OOomoo`0kOol0
049oo`0301moogoo09eoo`0301moogoo03]oo`00@Woo00<07gooOol0W7oo00<07gooOol0?7oo0013
Ool00`0OOomoo`2JOol00`0OOomoo`0mOol004=oo`0301moogoo09Yoo`0301moogoo03eoo`00A7oo
00<07gooOol0V7oo00<07gooOol0?Woo0015Ool00`0OOomoo`2FOol00`0OOomoo`0oOol004Eoo`03
01moogoo09Eoo`0301moogoo041oo`00AWoo00<07gooOol0U7oo00<07gooOol0@7oo0017Ool00`0O
Oomoo`2BOol00`0OOomoo`11Ool004Moo`0301moogoo095oo`0301moogoo049oo`00B7oo00<07goo
Ool0T7oo00<07gooOol0@Woo0019Ool00`0OOomoo`2>Ool00`0OOomoo`13Ool004Yoo`0301moogoo
08aoo`0301moogoo04Aoo`00BWoo00<07gooOol0Rgoo00<07gooOol0AGoo001;Ool00`0OOomoo`2:
Ool00`0OOomoo`15Ool004aoo`0301moogoo08Qoo`0301moogoo04Ioo`00CGoo00<07gooOol0QWoo
00<07gooOol0Agoo001>Ool00`0OOomoo`24Ool00`0OOomoo`18Ool004moo`0301moogoo089oo`03
01moogoo04Uoo`00Cgoo00<07gooOol0PWoo00<07gooOol0BGoo001@Ool00`0OOomoo`20Ool00`0O
Oomoo`1:Ool0055oo`0301moogoo07ioo`0301moogoo04]oo`00DWoo00<07gooOol0O7oo00<07goo
Ool0C7oo001COol00`0OOomoo`1jOol00`0OOomoo`1=Ool005Aoo`0301moogoo07Moo`807e1oo`00
EGoo0P0OMWoo00<07gooOol0D7oo001GOol00`0OOomoo`1bOol00`0OOomoo`1AOol005Qoo`0301mo
ogoo06moo`807eAoo`00FGoo00<07gooOol0KGoo00<07gooOol0E7oo001JOol00`0OOomoo`1[Ool0
0`0OOomoo`1EOol005]oo`807fUoo`807eQoo`00GGoo00<07gooOol0IGoo00<07gooOol0F7oo001N
Ool00`0OOomoo`1ROol201mKOol005moo`807f5oo`0301moogoo05]oo`00HGoo00<07gooOol0GGoo
00<07gooOol0G7oo001ROol201mKOol201mOOol006Aoo`0301moogoo05Moo`0301moogoo05moo`00
IGoo0P0OEGoo0P0OHWoo001WOol201mAOol201mTOol006Uoo`807deoo`807fIoo`00Jgoo0P0OBGoo
0P0OJ7oo001]Ool201m5Ool201mZOol006moo`807d5oo`807faoo`00LGoo0`0O>goo0`0OKWoo001d
Ool401lcOol401maOol007Qoo`@07b]oo`@07gEoo`00O7oo100O8goo100ONGoo0020Ool501lIOol5
01mmOol008EooaT07h9oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.18628 .49367 m
.18798 .46656 L
s
.18679 .52083 m
.18628 .49367 L
s
.18798 .46656 m
.19186 .43967 L
s
.18949 .54786 m
.18679 .52083 L
s
.19186 .43967 m
.1979 .41319 L
s
.19437 .57458 m
.18949 .54786 L
s
.1979 .41319 m
.20607 .38728 L
s
.2014 .60081 m
.19437 .57458 L
s
.20607 .38728 m
.21631 .36214 L
s
.21054 .62638 m
.2014 .60081 L
s
.21631 .36214 m
.22857 .33791 L
s
.22174 .65111 m
.21054 .62638 L
s
.22857 .33791 m
.24277 .31477 L
s
.23492 .67483 m
.22174 .65111 L
s
.24277 .31477 m
.25881 .29288 L
s
.25001 .69739 m
.23492 .67483 L
s
.25881 .29288 m
.2766 .27239 L
s
.26691 .71862 m
.25001 .69739 L
s
.2766 .27239 m
.29603 .25344 L
s
.28552 .73838 m
.26691 .71862 L
s
.29603 .25344 m
.31697 .23618 L
s
.30572 .75651 m
.28552 .73838 L
s
.31697 .23618 m
.33928 .22072 L
s
.32737 .7729 m
.30572 .75651 L
s
.33928 .22072 m
.36283 .20718 L
s
.35034 .78741 m
.32737 .7729 L
s
.36283 .20718 m
.38745 .19567 L
s
.37448 .79993 m
.35034 .78741 L
s
.38745 .19567 m
.41299 .18629 L
s
.39962 .81036 m
.37448 .79993 L
s
.41299 .18629 m
.43926 .17911 L
s
.4256 .81862 m
.39962 .81036 L
s
.43926 .17911 m
.46609 .1742 L
s
.45224 .82463 m
.4256 .81862 L
s
.46609 .1742 m
.49329 .1716 L
s
.47935 .82832 m
.45224 .82463 L
s
.49329 .1716 m
.52067 .17137 L
s
.50674 .82967 m
.47935 .82832 L
s
.52067 .17137 m
.54803 .1735 L
s
.53421 .82864 m
.50674 .82967 L
s
.54803 .1735 m
.57518 .17801 L
s
.56156 .82521 m
.53421 .82864 L
s
.57518 .17801 m
.60191 .18488 L
s
.5886 .81941 m
.56156 .82521 L
s
.60191 .18488 m
.62803 .19408 L
s
.61511 .81125 m
.5886 .81941 L
s
.62803 .19408 m
.65333 .20555 L
s
.6409 .80078 m
.61511 .81125 L
s
.65333 .20555 m
.67762 .21922 L
s
.66578 .78807 m
.6409 .80078 L
s
.67762 .21922 m
.70071 .235 L
s
.68953 .77319 m
.66578 .78807 L
s
.70071 .235 m
.72242 .2528 L
s
.71199 .75625 m
.68953 .77319 L
s
.72242 .2528 m
.74258 .27247 L
s
.73297 .73736 m
.71199 .75625 L
s
.74258 .27247 m
.76102 .2939 L
s
.7523 .71666 m
.73297 .73736 L
s
.76102 .2939 m
.7776 .31691 L
s
.76983 .6943 m
.7523 .71666 L
s
.7776 .31691 m
.79217 .34134 L
s
.78541 .67044 m
.76983 .6943 L
s
.79217 .34134 m
.80462 .367 L
s
.79891 .64526 m
.78541 .67044 L
s
.80462 .367 m
.81485 .3937 L
s
.81023 .61897 m
.79891 .64526 L
s
.81485 .3937 m
.82275 .42124 L
s
.81926 .59175 m
.81023 .61897 L
s
.82275 .42124 m
.82828 .4494 L
s
.82594 .56382 m
.81926 .59175 L
s
.82828 .4494 m
.83138 .47796 L
s
.83021 .53539 m
.82594 .56382 L
s
.83138 .47796 m
.83202 .5067 L
s
.83202 .5067 m
.83021 .53539 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol008Aooa/07h5oo`00P7oo100O6goo100OOGoo001mOol3
01lSOol401miOol007Uoo`@07bYoo`@07gEoo`00MGoo100O<Woo0`0OLWoo001cOol201liOol401m^
Ool0075oo`807cmoo`@07fYoo`00KWoo0`0OAGoo0P0OJ7oo001/Ool201m:Ool201mVOol006Yoo`80
7dioo`807fAoo`00J7oo0P0ODWoo0P0OHWoo001VOol201mFOol201mPOol006Aoo`807eYoo`807eio
o`00HWoo0P0OGWoo00<07gooOol0Fgoo001QOol00`0OOomoo`1OOol201mKOol005moo`807fAoo`03
01moogoo05Qoo`00GGoo0P0OIgoo00<07gooOol0Egoo001KOol201mZOol201mGOol005Yoo`0301mo
ogoo06aoo`0301moogoo05Aoo`00FGoo00<07gooOol0KWoo00<07gooOol0Dgoo001HOol00`0OOomo
o`1`Ool00`0OOomoo`1BOol005Ioo`807gAoo`807e9oo`00EGoo00<07gooOol0MWoo00<07gooOol0
Cgoo001DOol00`0OOomoo`1hOol00`0OOomoo`1>Ool005=oo`0301moogoo07Yoo`0301moogoo04eo
o`00DWoo00<07gooOol0O7oo00<07gooOol0C7oo001AOol00`0OOomoo`1nOol00`0OOomoo`1;Ool0
055oo`0301moogoo07moo`0301moogoo04Yoo`00D7oo00<07gooOol0PGoo00<07gooOol0BGoo001?
Ool00`0OOomoo`23Ool00`0OOomoo`18Ool004ioo`0301moogoo08Eoo`0301moogoo04Moo`00CGoo
00<07gooOol0Qgoo00<07gooOol0AWoo001<Ool00`0OOomoo`28Ool00`0OOomoo`16Ool004aoo`03
01moogoo08Uoo`0301moogoo04Eoo`00Bgoo00<07gooOol0Rgoo00<07gooOol0A7oo001:Ool00`0O
Oomoo`2=Ool00`0OOomoo`13Ool004Uoo`0301moogoo08moo`0301moogoo049oo`00B7oo00<07goo
Ool0TGoo00<07gooOol0@Goo0017Ool00`0OOomoo`2BOol00`0OOomoo`11Ool004Moo`0301moogoo
09=oo`0301moogoo041oo`00AWoo00<07gooOol0UGoo00<07gooOol0?goo0015Ool00`0OOomoo`2G
Ool00`0OOomoo`0nOol004Aoo`0301moogoo09Uoo`0301moogoo03eoo`00A7oo00<07gooOol0VGoo
00<07gooOol0?Goo0013Ool00`0OOomoo`2KOol00`0OOomoo`0lOol0049oo`0301moogoo09aoo`03
01moogoo03aoo`00@Woo00<07gooOol0WGoo00<07gooOol0>goo0011Ool00`0OOomoo`2NOol00`0O
Oomoo`0kOol0045oo`0301moogoo09moo`0301moogoo03Yoo`00@7oo00<07gooOol0X7oo00<07goo
Ool0>Woo0010Ool00`0OOomoo`2QOol00`0OOomoo`0iOol003moo`0301moogoo0:9oo`0301moogoo
03Uoo`00?goo00<07gooOol0XWoo00<07gooOol0>Goo000nOol00`0OOomoo`2TOol00`0OOomoo`0h
Ool003ioo`0301moogoo0:Aoo`0301moogoo03Qoo`00?Woo00<07gooOol0YGoo00<07gooOol0=goo
000mOol00`0OOomoo`2VOol00`0OOomoo`0gOol003eoo`0301moogoo0:Ioo`0301moogoo03Moo`00
?7oo00<07gooOol0Z7oo00<07gooOol0=Woo000lOol00`0OOomoo`2XOol00`0OOomoo`0fOol003ao
o`0301moogoo0:Uoo`0301moogoo03Eoo`00>goo00<07gooOol0ZWoo00<07gooOol0=Goo000kOol0
0`0OOomoo`2[Ool00`0OOomoo`0dOol003]oo`0301moogoo0:]oo`0301moogoo03Aoo`00>Woo00<0
7gooOol0[7oo00<07gooOol0=7oo000jOol00`0OOomoo`2]Ool00`0OOomoo`0cOol003Uoo`0301mo
ogoo0:ioo`0301moogoo03=oo`00>Goo00<07gooOol0[Woo00<07gooOol0<goo000hOol00`0OOomo
o`2`Ool00`0OOomoo`0bOol003Qoo`0301moogoo0;1oo`0301moogoo039oo`00>7oo00<07gooOol0
/Goo00<07gooOol0<Goo000hOol00`0OOomoo`2aOol00`0OOomoo`0aOol003Qoo`0301moogoo0;5o
o`0301moogoo035oo`00=goo00<07gooOol0/Woo00<07gooOol0<Goo000gOol00`0OOomoo`2bOol0
0`0OOomoo`0aOol003Moo`0301moogoo0;9oo`0301moogoo035oo`00=goo00<07gooOol0/goo00<0
7gooOol0<7oo000gOol00`0OOomoo`2cOol00`0OOomoo`0`Ool003Moo`0301moogoo0;=oo`0301mo
ogoo031oo`00=Woo00<07gooOol0]7oo00<07gooOol0<7oo000fOol00`0OOomoo`2dOol00`0OOomo
o`0`Ool003Ioo`0301moogoo0;Aoo`0301moogoo031oo`00=Woo00<07gooOol0]7oo00<07gooOol0
<7oo000eOol00`0OOomoo`2eOol00`0OOomoo`0`Ool003Eoo`0301moogoo0;Ioo`0301moogoo02mo
o`00=Goo00<07gooOol0]Woo00<07gooOol0;goo000eOol00`0OOomoo`2fOol00`0OOomoo`0_Ool0
03Eoo`0301moogoo0;Ioo`0301moogoo02moo`00=Goo00<07gooOol0]Woo00<07gooOol0;goo000e
Ool00`0OOomoo`2fOol00`0OOomoo`0_Ool003Eoo`0301moogoo0;Ioo`0301moogoo02moo`00=Goo
00<07gooOol0]Woo00<07gooOol0;goo000eOol00`0OOomoo`2fOol00`0OOomoo`0_Ool003Eoo`03
01moogoo0;Ioo`0301moogoo02moo`00=Goo00<07gooOol0]Woo00<07gooOol0;goo000eOol00`0O
Oomoo`2fOol00`0OOomoo`0_Ool003Eoo`0301moogoo0;Ioo`0301moogoo02moo`00=Goo00<07goo
Ool0]Woo00<07gooOol0;goo000eOol00`0OOomoo`2fOol00`0OOomoo`0_Ool003Eoo`0301moogoo
0;Ioo`0301moogoo02moo`00=Goo00<07gooOol0]Woo00<07gooOol0;goo000eOol00`0OOomoo`2f
Ool00`0OOomoo`0_Ool003Eoo`0301moogoo0;Ioo`0301moogoo02moo`00=Goo00<07gooOol0]Woo
00<07gooOol0;goo000eOol00`0OOomoo`2fOol00`0OOomoo`0_Ool003Ioo`0301moogoo0;Eoo`03
01moogoo02moo`00=Woo00<07gooOol0]Goo00<07gooOol0;goo000fOol00`0OOomoo`2eOol00`0O
Oomoo`0_Ool003Ioo`0301moogoo0;Aoo`0301moogoo031oo`00=Woo00<07gooOol0]7oo00<07goo
Ool0<7oo000fOol00`0OOomoo`2dOol00`0OOomoo`0`Ool003Ioo`0301moogoo0;Aoo`0301moogoo
031oo`00=goo00<07gooOol0/goo00<07gooOol0<7oo000gOol00`0OOomoo`2cOol00`0OOomoo`0`
Ool003Moo`0301moogoo0;9oo`0301moogoo035oo`00=goo00<07gooOol0/Woo00<07gooOol0<Goo
000gOol00`0OOomoo`2bOol00`0OOomoo`0aOol003Moo`0301moogoo0;9oo`0301moogoo035oo`00
>7oo00<07gooOol0/7oo00<07gooOol0<Woo000hOol00`0OOomoo`2`Ool00`0OOomoo`0bOol003Qo
o`0301moogoo0;1oo`0301moogoo039oo`00>7oo00<07gooOol0/7oo00<07gooOol0<Woo000iOol0
0`0OOomoo`2^Ool00`0OOomoo`0cOol003Uoo`0301moogoo0:ioo`0301moogoo03=oo`00>Goo00<0
7gooOol0[Goo00<07gooOol0=7oo000jOol00`0OOomoo`2/Ool00`0OOomoo`0dOol003Yoo`0301mo
ogoo0:aoo`0301moogoo03Aoo`00>goo00<07gooOol0ZWoo00<07gooOol0=Goo000kOol00`0OOomo
o`2ZOol00`0OOomoo`0eOol003aoo`0301moogoo0:Uoo`0301moogoo03Eoo`00?7oo00<07gooOol0
Z7oo00<07gooOol0=Woo000lOol00`0OOomoo`2XOol00`0OOomoo`0fOol003eoo`0301moogoo0:Io
o`0301moogoo03Moo`00?Goo00<07gooOol0YWoo00<07gooOol0=goo000nOol00`0OOomoo`2UOol0
0`0OOomoo`0gOol003ioo`0301moogoo0:Aoo`0301moogoo03Qoo`00?goo00<07gooOol0Xgoo00<0
7gooOol0>7oo000oOol00`0OOomoo`2ROol00`0OOomoo`0iOol0041oo`0301moogoo0:5oo`0301mo
ogoo03Uoo`00@7oo00<07gooOol0X7oo00<07gooOol0>Woo0011Ool00`0OOomoo`2OOol00`0OOomo
o`0jOol0045oo`0301moogoo09ioo`0301moogoo03]oo`00@Woo00<07gooOol0WGoo00<07gooOol0
>goo0012Ool00`0OOomoo`2LOol00`0OOomoo`0lOol004=oo`0301moogoo09Yoo`0301moogoo03eo
o`00A7oo00<07gooOol0VGoo00<07gooOol0?Goo0014Ool00`0OOomoo`2HOol00`0OOomoo`0nOol0
04Eoo`0301moogoo09Ioo`0301moogoo03moo`00AGoo00<07gooOol0UGoo00<07gooOol0@7oo0016
Ool00`0OOomoo`2DOol00`0OOomoo`10Ool004Ioo`0301moogoo09=oo`0301moogoo045oo`00Agoo
00<07gooOol0TGoo00<07gooOol0@Woo0018Ool00`0OOomoo`2?Ool00`0OOomoo`13Ool004Uoo`03
01moogoo08eoo`0301moogoo04Aoo`00BGoo00<07gooOol0SGoo00<07gooOol0A7oo001:Ool00`0O
Oomoo`2;Ool00`0OOomoo`15Ool004]oo`0301moogoo08Uoo`0301moogoo04Ioo`00C7oo00<07goo
Ool0Qgoo00<07gooOol0Agoo001=Ool00`0OOomoo`25Ool00`0OOomoo`18Ool004ioo`0301moogoo
08=oo`0301moogoo04Uoo`00Cgoo00<07gooOol0PWoo00<07gooOol0BGoo001@Ool00`0OOomoo`20
Ool00`0OOomoo`1:Ool0055oo`0301moogoo07ioo`0301moogoo04]oo`00DWoo00<07gooOol0O7oo
00<07gooOol0C7oo001COol00`0OOomoo`1jOol00`0OOomoo`1=Ool005Aoo`0301moogoo07Qoo`03
01moogoo04ioo`00EGoo00<07gooOol0MWoo00<07gooOol0Cgoo001FOol00`0OOomoo`1dOol00`0O
Oomoo`1@Ool005Moo`0301moogoo079oo`0301moogoo055oo`00F7oo0P0OL7oo0P0OE7oo001JOol0
0`0OOomoo`1[Ool201mFOol005]oo`807fUoo`807eQoo`00GGoo00<07gooOol0IGoo00<07gooOol0
F7oo001NOol201mTOol00`0OOomoo`1IOol0061oo`807f5oo`0301moogoo05Yoo`00HWoo0P0OGGoo
0P0OGGoo001TOol00`0OOomoo`1IOol00`0OOomoo`1MOol006Eoo`807eMoo`807f1oo`00Igoo0P0O
Dgoo0P0OHWoo001YOol201m>Ool301mTOol006]oo`807dUoo`<07fMoo`00KGoo0P0OAGoo0P0OJWoo
001_Ool201m1Ool201m/Ool0075oo`<07c]oo`<07fioo`00M7oo100O=Goo0P0OLGoo001hOol401l^
Ool301mcOol007aoo`@07bEoo`D07gIoo`00P7oo1@0O6Goo1`0ONgoo0025Ool801l9Ool801n2Ool0
08eoo`T07hYoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.18926 .57179 m
.18419 .54492 L
s
.19653 .59816 m
.18926 .57179 L
s
.20593 .62383 m
.19653 .59816 L
s
.18419 .54492 m
.18135 .51772 L
s
.21742 .64865 m
.20593 .62383 L
s
.18135 .51772 m
.18076 .49038 L
s
.23092 .67244 m
.21742 .64865 L
s
.18076 .49038 m
.18243 .46308 L
s
.24633 .69503 m
.23092 .67244 L
s
.18243 .46308 m
.18634 .43601 L
s
.26356 .71627 m
.24633 .69503 L
s
.18634 .43601 m
.19248 .40936 L
s
.28249 .73602 m
.26356 .71627 L
s
.19248 .40936 m
.20081 .3833 L
s
.30301 .75413 m
.28249 .73602 L
s
.20081 .3833 m
.21128 .35802 L
s
.32496 .77047 m
.30301 .75413 L
s
.21128 .35802 m
.22382 .33369 L
s
.34821 .78493 m
.32496 .77047 L
s
.22382 .33369 m
.23835 .31048 L
s
.37259 .7974 m
.34821 .78493 L
s
.23835 .31048 m
.25479 .28856 L
s
.39796 .80779 m
.37259 .7974 L
s
.25479 .28856 m
.27302 .26809 L
s
.42412 .81601 m
.39796 .80779 L
s
.27302 .26809 m
.29292 .24922 L
s
.45091 .82199 m
.42412 .81601 L
s
.29292 .24922 m
.31437 .23207 L
s
.47813 .82569 m
.45091 .82199 L
s
.31437 .23207 m
.33722 .2168 L
s
.5056 .82706 m
.47813 .82569 L
s
.33722 .2168 m
.36131 .2035 L
s
.53313 .82609 m
.5056 .82706 L
s
.36131 .2035 m
.38648 .19229 L
s
.56051 .82277 m
.53313 .82609 L
s
.38648 .19229 m
.41255 .18326 L
s
.58755 .81711 m
.56051 .82277 L
s
.41255 .18326 m
.43935 .17648 L
s
.61405 .80914 m
.58755 .81711 L
s
.43935 .17648 m
.46668 .17201 L
s
.63982 .79891 m
.61405 .80914 L
s
.46668 .17201 m
.49435 .1699 L
s
.66466 .78648 m
.63982 .79891 L
s
.49435 .1699 m
.52215 .17018 L
s
.6884 .77192 m
.66466 .78648 L
s
.52215 .17018 m
.54988 .17286 L
s
.71084 .75534 m
.6884 .77192 L
s
.54988 .17286 m
.57734 .17792 L
s
.73182 .73685 m
.71084 .75534 L
s
.57734 .17792 m
.60432 .18535 L
s
.75117 .71657 m
.73182 .73685 L
s
.60432 .18535 m
.63062 .19509 L
s
.76874 .69466 m
.75117 .71657 L
s
.63062 .19509 m
.65604 .20709 L
s
.78439 .67126 m
.76874 .69466 L
s
.65604 .20709 m
.68039 .22126 L
s
.798 .64655 m
.78439 .67126 L
s
.68039 .22126 m
.70347 .23751 L
s
.80946 .62071 m
.798 .64655 L
s
.70347 .23751 m
.72512 .25572 L
s
.81867 .59393 m
.80946 .62071 L
s
.72512 .25572 m
.74515 .27576 L
s
.82556 .56641 m
.81867 .59393 L
s
.74515 .27576 m
.76342 .29747 L
s
.83007 .53837 m
.82556 .56641 L
s
.76342 .29747 m
.77978 .32071 L
s
.83215 .51001 m
.83007 .53837 L
s
.77978 .32071 m
.79409 .34529 L
s
.8318 .48155 m
.83215 .51001 L
s
.79409 .34529 m
.80626 .37103 L
s
.829 .4532 m
.8318 .48155 L
s
.80626 .37103 m
.81618 .39773 L
s
.82378 .42519 m
.829 .4532 L
s
.81618 .39773 m
.82378 .42519 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo002:Ool?01n7Ool0089oo`P07`moo`H07h5oo`00OGoo1@0O7Goo100O
OGoo001iOol401lVOol401miOol007Eoo`@07bioo`@07gEoo`00Lgoo0P0O=Woo100OLGoo001`Ool3
01llOol401m]Ool006eoo`<07d=oo`807f]oo`00Jgoo0P0OB7oo0P0OJGoo001YOol201m<Ool201mW
Ool006Moo`807e1oo`807fEoo`00IGoo0P0OE7oo0P0OHgoo001SOol201mHOol201mQOol0065oo`80
7eaoo`807emoo`00H7oo00<07gooOol0GWoo0P0OGGoo001NOol201mSOol00`0OOomoo`1JOol005eo
o`0301moogoo06Aoo`0301moogoo05Uoo`00Fgoo0P0OJ7oo00<07gooOol0F7oo001JOol00`0OOomo
o`1YOol201mHOol005Uoo`0301moogoo06aoo`0301moogoo05Eoo`00F7oo00<07gooOol0KWoo00<0
7gooOol0E7oo001FOol201mbOol201mDOol005Eoo`0301moogoo07Aoo`0301moogoo055oo`00E7oo
00<07gooOol0MWoo00<07gooOol0D7oo001COol00`0OOomoo`1hOol201m@Ool0059oo`0301moogoo
07]oo`0301moogoo04eoo`00D7oo0P0OOgoo00<07gooOol0C7oo001?Ool00`0OOomoo`20Ool00`0O
Oomoo`1;Ool004ioo`0301moogoo085oo`0301moogoo04]oo`00CGoo00<07gooOol0Pgoo00<07goo
Ool0BWoo001<Ool00`0OOomoo`25Ool00`0OOomoo`19Ool004]oo`0301moogoo08Moo`0301moogoo
04Qoo`00Bgoo00<07gooOol0R7oo00<07gooOol0Agoo001:Ool00`0OOomoo`2:Ool00`0OOomoo`16
Ool004Uoo`0301moogoo08aoo`0301moogoo04Eoo`00B7oo00<07gooOol0SWoo00<07gooOol0A7oo
0018Ool00`0OOomoo`2?Ool00`0OOomoo`13Ool004Moo`0301moogoo095oo`0301moogoo049oo`00
AWoo00<07gooOol0Tgoo00<07gooOol0@Goo0015Ool00`0OOomoo`2DOol00`0OOomoo`11Ool004Eo
o`0301moogoo09Eoo`0301moogoo041oo`00A7oo00<07gooOol0UWoo00<07gooOol0@7oo0013Ool0
0`0OOomoo`2HOol00`0OOomoo`0oOol004=oo`0301moogoo09Qoo`0301moogoo03moo`00@Woo00<0
7gooOol0VWoo00<07gooOol0?Woo0011Ool00`0OOomoo`2LOol00`0OOomoo`0mOol0045oo`0301mo
ogoo09aoo`0301moogoo03eoo`00@7oo00<07gooOol0WWoo00<07gooOol0?7oo000oOol00`0OOomo
o`2OOol00`0OOomoo`0lOol003moo`0301moogoo0:1oo`0301moogoo03]oo`00?Woo00<07gooOol0
XGoo00<07gooOol0>goo000nOol00`0OOomoo`2ROol00`0OOomoo`0jOol003eoo`0301moogoo0:Ao
o`0301moogoo03Uoo`00?Goo00<07gooOol0Y7oo00<07gooOol0>Goo000lOol00`0OOomoo`2VOol0
0`0OOomoo`0hOol003aoo`0301moogoo0:Ioo`0301moogoo03Qoo`00>goo00<07gooOol0Z7oo00<0
7gooOol0=goo000kOol00`0OOomoo`2XOol00`0OOomoo`0gOol003Yoo`0301moogoo0:Yoo`0301mo
ogoo03Ioo`00>Woo00<07gooOol0ZWoo00<07gooOol0=Woo000jOol00`0OOomoo`2[Ool00`0OOomo
o`0eOol003Uoo`0301moogoo0:aoo`0301moogoo03Eoo`00>Goo00<07gooOol0[7oo00<07gooOol0
=Goo000iOol00`0OOomoo`2]Ool00`0OOomoo`0dOol003Qoo`0301moogoo0:ioo`0301moogoo03Ao
o`00>7oo00<07gooOol0[goo00<07gooOol0<goo000hOol00`0OOomoo`2_Ool00`0OOomoo`0cOol0
03Qoo`0301moogoo0:moo`0301moogoo03=oo`00=goo00<07gooOol0/7oo00<07gooOol0<goo000g
Ool00`0OOomoo`2aOol00`0OOomoo`0bOol003Moo`0301moogoo0;5oo`0301moogoo039oo`00=Woo
00<07gooOol0/Woo00<07gooOol0<Woo000fOol00`0OOomoo`2bOol00`0OOomoo`0bOol003Ioo`03
01moogoo0;=oo`0301moogoo035oo`00=Woo00<07gooOol0/goo00<07gooOol0<Goo000eOol00`0O
Oomoo`2dOol00`0OOomoo`0aOol003Eoo`0301moogoo0;Aoo`0301moogoo035oo`00=Goo00<07goo
Ool0]7oo00<07gooOol0<Goo000eOol00`0OOomoo`2dOol00`0OOomoo`0aOol003Eoo`0301moogoo
0;Eoo`0301moogoo031oo`00=Goo00<07gooOol0]Goo00<07gooOol0<7oo000dOol00`0OOomoo`2f
Ool00`0OOomoo`0`Ool003Aoo`0301moogoo0;Ioo`0301moogoo031oo`00=7oo00<07gooOol0]Woo
00<07gooOol0<7oo000dOol00`0OOomoo`2fOol00`0OOomoo`0`Ool003Aoo`0301moogoo0;Ioo`03
01moogoo031oo`00=7oo00<07gooOol0]Woo00<07gooOol0<7oo000dOol00`0OOomoo`2gOol00`0O
Oomoo`0_Ool003=oo`0301moogoo0;Qoo`0301moogoo02moo`00<goo00<07gooOol0^7oo00<07goo
Ool0;goo000cOol00`0OOomoo`2hOol00`0OOomoo`0_Ool003=oo`0301moogoo0;Qoo`0301moogoo
02moo`00<goo00<07gooOol0^7oo00<07gooOol0;goo000cOol00`0OOomoo`2hOol00`0OOomoo`0_
Ool003=oo`0301moogoo0;Qoo`0301moogoo02moo`00<goo00<07gooOol0^7oo00<07gooOol0;goo
000cOol00`0OOomoo`2hOol00`0OOomoo`0_Ool003Aoo`0301moogoo0;Moo`0301moogoo02moo`00
=7oo00<07gooOol0]goo00<07gooOol0;goo000dOol00`0OOomoo`2gOol00`0OOomoo`0_Ool003Ao
o`0301moogoo0;Moo`0301moogoo02moo`00=7oo00<07gooOol0]goo00<07gooOol0;goo000dOol0
0`0OOomoo`2gOol00`0OOomoo`0_Ool003Aoo`0301moogoo0;Moo`0301moogoo02moo`00=7oo00<0
7gooOol0]goo00<07gooOol0;goo000dOol00`0OOomoo`2gOol00`0OOomoo`0_Ool003Aoo`0301mo
ogoo0;Moo`0301moogoo02moo`00=7oo00<07gooOol0]goo00<07gooOol0;goo000dOol00`0OOomo
o`2fOol00`0OOomoo`0`Ool003Aoo`0301moogoo0;Ioo`0301moogoo031oo`00=7oo00<07gooOol0
]Woo00<07gooOol0<7oo000eOol00`0OOomoo`2eOol00`0OOomoo`0`Ool003Eoo`0301moogoo0;Ao
o`0301moogoo035oo`00=Goo00<07gooOol0]7oo00<07gooOol0<Goo000eOol00`0OOomoo`2dOol0
0`0OOomoo`0aOol003Ioo`0301moogoo0;=oo`0301moogoo035oo`00=Woo00<07gooOol0/Woo00<0
7gooOol0<Woo000fOol00`0OOomoo`2bOol00`0OOomoo`0bOol003Moo`0301moogoo0;5oo`0301mo
ogoo039oo`00=goo00<07gooOol0/Goo00<07gooOol0<Woo000gOol00`0OOomoo`2`Ool00`0OOomo
o`0cOol003Moo`0301moogoo0;1oo`0301moogoo03=oo`00>7oo00<07gooOol0[goo00<07gooOol0
<goo000hOol00`0OOomoo`2_Ool00`0OOomoo`0cOol003Qoo`0301moogoo0:ioo`0301moogoo03Ao
o`00>Goo00<07gooOol0[Goo00<07gooOol0=7oo000iOol00`0OOomoo`2]Ool00`0OOomoo`0dOol0
03Uoo`0301moogoo0:eoo`0301moogoo03Aoo`00>Woo00<07gooOol0Zgoo00<07gooOol0=Goo000j
Ool00`0OOomoo`2[Ool00`0OOomoo`0eOol003]oo`0301moogoo0:Yoo`0301moogoo03Eoo`00>goo
00<07gooOol0ZWoo00<07gooOol0=Goo000kOol00`0OOomoo`2YOol00`0OOomoo`0fOol003aoo`03
01moogoo0:Qoo`0301moogoo03Ioo`00?7oo00<07gooOol0Ygoo00<07gooOol0=goo000mOol00`0O
Oomoo`2VOol00`0OOomoo`0gOol003eoo`0301moogoo0:Eoo`0301moogoo03Qoo`00?Woo00<07goo
Ool0Y7oo00<07gooOol0>7oo000nOol00`0OOomoo`2SOol00`0OOomoo`0iOol003moo`0301moogoo
0:9oo`0301moogoo03Uoo`00?goo00<07gooOol0XGoo00<07gooOol0>Woo0010Ool00`0OOomoo`2P
Ool00`0OOomoo`0jOol0045oo`0301moogoo09ioo`0301moogoo03]oo`00@Goo00<07gooOol0WWoo
00<07gooOol0>goo0012Ool00`0OOomoo`2LOol00`0OOomoo`0lOol004=oo`0301moogoo09Yoo`03
01moogoo03eoo`00@goo00<07gooOol0VWoo00<07gooOol0?Goo0014Ool00`0OOomoo`2HOol00`0O
Oomoo`0nOol004Aoo`0301moogoo09Moo`0301moogoo03moo`00AGoo00<07gooOol0UGoo00<07goo
Ool0@7oo0015Ool00`0OOomoo`2EOol00`0OOomoo`10Ool004Ioo`0301moogoo09=oo`0301moogoo
045oo`00Agoo00<07gooOol0TGoo00<07gooOol0@Woo0018Ool00`0OOomoo`2?Ool00`0OOomoo`13
Ool004Qoo`0301moogoo08ioo`0301moogoo04Aoo`00BGoo00<07gooOol0SGoo00<07gooOol0A7oo
001:Ool00`0OOomoo`2;Ool00`0OOomoo`15Ool004]oo`0301moogoo08Uoo`0301moogoo04Ioo`00
C7oo00<07gooOol0Qgoo00<07gooOol0Agoo001=Ool00`0OOomoo`25Ool00`0OOomoo`18Ool004io
o`0301moogoo08=oo`0301moogoo04Uoo`00Cgoo00<07gooOol0PWoo00<07gooOol0BGoo001@Ool0
0`0OOomoo`20Ool00`0OOomoo`1:Ool0055oo`0301moogoo07ioo`0301moogoo04]oo`00DWoo00<0
7gooOol0O7oo00<07gooOol0C7oo001COol00`0OOomoo`1jOol00`0OOomoo`1=Ool005Aoo`0301mo
ogoo07Moo`807e1oo`00EGoo00<07gooOol0MGoo00<07gooOol0D7oo001FOol00`0OOomoo`1cOol0
0`0OOomoo`1AOol005Moo`807g5oo`807eAoo`00FGoo00<07gooOol0KGoo00<07gooOol0E7oo001J
Ool00`0OOomoo`1[Ool00`0OOomoo`1EOol005]oo`807fUoo`807eQoo`00GGoo00<07gooOol0IGoo
00<07gooOol0F7oo001NOol201mSOol201mKOol0061oo`0301moogoo05ioo`807eeoo`00HGoo0P0O
G7oo0P0OGgoo001SOol201mIOol00`0OOomoo`1OOol006Eoo`807eEoo`807f9oo`00Igoo0P0ODGoo
0P0OI7oo001YOol301m<Ool201mVOol006aoo`807dQoo`807fQoo`00KWoo0`0O@goo0P0OJWoo001a
Ool301lnOol201m/Ool007Aoo`807cUoo`<07fioo`00MWoo0P0O<goo100OLGoo001hOol501lZOol4
01meOol007eoo`P07aioo`@07gUoo`00QGoo200O47oo1P0OOGoo002=Ool@01n3Ool00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.25988 .71459 m
.24241 .69337 L
s
.27905 .73428 m
.25988 .71459 L
s
.29979 .75232 m
.27905 .73428 L
s
.24241 .69337 m
.22676 .67078 L
s
.32196 .76856 m
.29979 .75232 L
s
.22676 .67078 m
.21305 .64695 L
s
.3454 .78291 m
.32196 .76856 L
s
.21305 .64695 m
.20137 .62207 L
s
.36996 .79526 m
.3454 .78291 L
s
.20137 .62207 m
.19179 .5963 L
s
.39547 .80552 m
.36996 .79526 L
s
.19179 .5963 m
.1844 .56981 L
s
.42175 .81362 m
.39547 .80552 L
s
.1844 .56981 m
.17925 .54278 L
s
.44863 .8195 m
.42175 .81362 L
s
.17925 .54278 m
.17637 .51542 L
s
.47591 .82311 m
.44863 .8195 L
s
.17637 .51542 m
.1758 .48789 L
s
.50341 .82443 m
.47591 .82311 L
s
.1758 .48789 m
.17753 .46041 L
s
.53093 .82343 m
.50341 .82443 L
s
.17753 .46041 m
.18158 .43315 L
s
.55829 .82012 m
.53093 .82343 L
s
.18158 .43315 m
.18791 .40631 L
s
.58529 .81451 m
.55829 .82012 L
s
.18791 .40631 m
.19649 .38008 L
s
.61174 .80664 m
.58529 .81451 L
s
.19649 .38008 m
.20726 .35465 L
s
.63745 .79655 m
.61174 .80664 L
s
.20726 .35465 m
.22016 .3302 L
s
.66224 .78431 m
.63745 .79655 L
s
.22016 .3302 m
.23511 .30691 L
s
.68592 .76999 m
.66224 .78431 L
s
.23511 .30691 m
.252 .28495 L
s
.70833 .75369 m
.68592 .76999 L
s
.252 .28495 m
.27072 .26448 L
s
.72929 .73553 m
.70833 .75369 L
s
.27072 .26448 m
.29114 .24566 L
s
.74865 .71562 m
.72929 .73553 L
s
.29114 .24566 m
.31313 .22863 L
s
.76627 .6941 m
.74865 .71562 L
s
.31313 .22863 m
.33652 .21351 L
s
.782 .67112 m
.76627 .6941 L
s
.33652 .21351 m
.36115 .20044 L
s
.79574 .64684 m
.782 .67112 L
s
.36115 .20044 m
.38685 .1895 L
s
.80736 .62144 m
.79574 .64684 L
s
.38685 .1895 m
.41344 .18079 L
s
.81678 .5951 m
.80736 .62144 L
s
.41344 .18079 m
.44071 .17438 L
s
.82391 .56801 m
.81678 .5951 L
s
.44071 .17438 m
.46847 .17033 L
s
.82871 .54036 m
.82391 .56801 L
s
.46847 .17033 m
.49652 .16867 L
s
.83112 .51237 m
.82871 .54036 L
s
.49652 .16867 m
.52465 .16942 L
s
.83113 .48423 m
.83112 .51237 L
s
.52465 .16942 m
.55265 .17258 L
s
.82872 .45615 m
.83113 .48423 L
s
.55265 .17258 m
.5803 .17814 L
s
.8239 .42836 m
.82872 .45615 L
s
.5803 .17814 m
.60741 .18606 L
s
.81671 .40105 m
.8239 .42836 L
s
.60741 .18606 m
.63377 .19628 L
s
.8072 .37443 m
.81671 .40105 L
s
.63377 .19628 m
.65917 .20873 L
s
.79544 .3487 m
.8072 .37443 L
s
.65917 .20873 m
.68343 .22332 L
s
.7815 .32406 m
.79544 .3487 L
s
.68343 .22332 m
.70636 .23994 L
s
.7655 .30069 m
.7815 .32406 L
s
.70636 .23994 m
.72778 .25847 L
s
.74755 .27877 m
.7655 .30069 L
s
.72778 .25847 m
.74755 .27877 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0025OolE01n6Ool0085oo`@07aEoo`H07h1oo`00Ngoo1P0O7goo100O
O7oo001eOol601lYOol401mhOol007=oo`807c=oo`@07gAoo`00LGoo0P0O>Goo100OL7oo001^Ool3
01loOol201m^Ool006aoo`807dAoo`807faoo`00JGoo0`0OB7oo0`0OJGoo001WOol201m>Ool201mW
Ool006Eoo`807e9oo`<07fAoo`00Hgoo0P0OEgoo0P0OHWoo001QOol201mKOol201mPOol0061oo`03
01moogoo05eoo`0301moogoo05eoo`00GWoo0P0OHGoo00<07gooOol0G7oo001LOol201mTOol201mL
Ool005Yoo`807fQoo`0301moogoo05Uoo`00FGoo00<07gooOol0JGoo0P0OFGoo001HOol00`0OOomo
o`1/Ool00`0OOomoo`1FOol005Moo`0301moogoo06ioo`807eIoo`00EGoo0P0OLgoo00<07gooOol0
Dgoo001DOol00`0OOomoo`1dOol00`0OOomoo`1BOol005=oo`0301moogoo07Ioo`0301moogoo055o
o`00DWoo00<07gooOol0N7oo00<07gooOol0D7oo001AOol00`0OOomoo`1jOol00`0OOomoo`1?Ool0
04moo`807gioo`0301moogoo04ioo`00CWoo00<07gooOol0Ogoo00<07gooOol0CGoo001=Ool00`0O
Oomoo`21Ool00`0OOomoo`1<Ool004aoo`0301moogoo08=oo`0301moogoo04]oo`00Bgoo00<07goo
Ool0QGoo00<07gooOol0BWoo001:Ool00`0OOomoo`27Ool00`0OOomoo`19Ool004Yoo`0301moogoo
08Qoo`0301moogoo04Qoo`00BGoo00<07gooOol0RWoo00<07gooOol0Agoo0018Ool00`0OOomoo`2<
Ool00`0OOomoo`16Ool004Moo`0301moogoo08ioo`0301moogoo04Eoo`00Agoo00<07gooOol0SWoo
00<07gooOol0AGoo0016Ool00`0OOomoo`2@Ool00`0OOomoo`14Ool004Eoo`0301moogoo099oo`03
01moogoo04=oo`00A7oo00<07gooOol0U7oo00<07gooOol0@Woo0014Ool00`0OOomoo`2EOol00`0O
Oomoo`11Ool004=oo`0301moogoo09Ioo`0301moogoo045oo`00@Woo00<07gooOol0V7oo00<07goo
Ool0@7oo0012Ool00`0OOomoo`2IOol00`0OOomoo`0oOol0045oo`0301moogoo09]oo`0301moogoo
03ioo`00@7oo00<07gooOol0W7oo00<07gooOol0?Woo0010Ool00`0OOomoo`2MOol00`0OOomoo`0m
Ool003moo`0301moogoo09moo`0301moogoo03aoo`00?Woo00<07gooOol0X7oo00<07gooOol0?7oo
000nOol00`0OOomoo`2QOol00`0OOomoo`0kOol003eoo`0301moogoo0:9oo`0301moogoo03]oo`00
?Goo00<07gooOol0Xgoo00<07gooOol0>Woo000lOol00`0OOomoo`2TOol00`0OOomoo`0jOol003ao
o`0301moogoo0:Eoo`0301moogoo03Uoo`00>goo00<07gooOol0YWoo00<07gooOol0>Goo000kOol0
0`0OOomoo`2WOol00`0OOomoo`0hOol003Yoo`0301moogoo0:Qoo`0301moogoo03Qoo`00>Woo00<0
7gooOol0ZGoo00<07gooOol0=goo000iOol00`0OOomoo`2ZOol00`0OOomoo`0gOol003Uoo`0301mo
ogoo0:]oo`0301moogoo03Ioo`00>Goo00<07gooOol0Zgoo00<07gooOol0=Woo000hOol00`0OOomo
o`2/Ool00`0OOomoo`0fOol003Qoo`0301moogoo0:eoo`0301moogoo03Eoo`00>7oo00<07gooOol0
[Goo00<07gooOol0=Goo000gOol00`0OOomoo`2^Ool00`0OOomoo`0eOol003Moo`0301moogoo0:mo
o`0301moogoo03Aoo`00=Woo00<07gooOol0/7oo00<07gooOol0=7oo000fOol00`0OOomoo`2aOol0
0`0OOomoo`0cOol003Eoo`0301moogoo0;9oo`0301moogoo03=oo`00=Goo00<07gooOol0/Woo00<0
7gooOol0<goo000eOol00`0OOomoo`2cOol00`0OOomoo`0bOol003Eoo`0301moogoo0;=oo`0301mo
ogoo039oo`00=Goo00<07gooOol0/goo00<07gooOol0<Woo000dOol00`0OOomoo`2dOol00`0OOomo
o`0bOol003Aoo`0301moogoo0;Eoo`0301moogoo035oo`00=7oo00<07gooOol0]Goo00<07gooOol0
<Goo000dOol00`0OOomoo`2eOol00`0OOomoo`0aOol003Aoo`0301moogoo0;Eoo`0301moogoo035o
o`00=7oo00<07gooOol0]Goo00<07gooOol0<Goo000cOol00`0OOomoo`2fOol00`0OOomoo`0aOol0
03=oo`0301moogoo0;Moo`0301moogoo031oo`00<goo00<07gooOol0]goo00<07gooOol0<7oo000c
Ool00`0OOomoo`2gOol00`0OOomoo`0`Ool0039oo`0301moogoo0;Qoo`0301moogoo031oo`00<Woo
00<07gooOol0^7oo00<07gooOol0<7oo000bOol00`0OOomoo`2hOol00`0OOomoo`0`Ool0039oo`03
01moogoo0;Qoo`0301moogoo031oo`00<Woo00<07gooOol0^7oo00<07gooOol0<7oo000bOol00`0O
Oomoo`2iOol00`0OOomoo`0_Ool0039oo`0301moogoo0;Uoo`0301moogoo02moo`00<Woo00<07goo
Ool0^Goo00<07gooOol0;goo000bOol00`0OOomoo`2iOol00`0OOomoo`0_Ool0039oo`0301moogoo
0;Uoo`0301moogoo02moo`00<Woo00<07gooOol0^Goo00<07gooOol0;goo000bOol00`0OOomoo`2i
Ool00`0OOomoo`0_Ool0039oo`0301moogoo0;Uoo`0301moogoo02moo`00<Woo00<07gooOol0^Goo
00<07gooOol0;goo000bOol00`0OOomoo`2iOol00`0OOomoo`0_Ool0039oo`0301moogoo0;Uoo`03
01moogoo02moo`00<Woo00<07gooOol0^Goo00<07gooOol0;goo000bOol00`0OOomoo`2iOol00`0O
Oomoo`0_Ool0039oo`0301moogoo0;Uoo`0301moogoo02moo`00<Woo00<07gooOol0^Goo00<07goo
Ool0;goo000bOol00`0OOomoo`2iOol00`0OOomoo`0_Ool0039oo`0301moogoo0;Qoo`0301moogoo
031oo`00<goo00<07gooOol0]goo00<07gooOol0<7oo000cOol00`0OOomoo`2gOol00`0OOomoo`0`
Ool003=oo`0301moogoo0;Moo`0301moogoo031oo`00<goo00<07gooOol0]goo00<07gooOol0<7oo
000cOol00`0OOomoo`2gOol00`0OOomoo`0`Ool003=oo`0301moogoo0;Moo`0301moogoo031oo`00
<goo00<07gooOol0]goo00<07gooOol0<7oo000cOol00`0OOomoo`2fOol00`0OOomoo`0aOol003Ao
o`0301moogoo0;Eoo`0301moogoo035oo`00=7oo00<07gooOol0]Goo00<07gooOol0<Goo000dOol0
0`0OOomoo`2eOol00`0OOomoo`0aOol003Aoo`0301moogoo0;Eoo`0301moogoo035oo`00=7oo00<0
7gooOol0]Goo00<07gooOol0<Goo000eOol00`0OOomoo`2cOol00`0OOomoo`0bOol003Eoo`0301mo
ogoo0;=oo`0301moogoo039oo`00=Goo00<07gooOol0/goo00<07gooOol0<Woo000fOol00`0OOomo
o`2bOol00`0OOomoo`0bOol003Ioo`0301moogoo0;5oo`0301moogoo03=oo`00=goo00<07gooOol0
/7oo00<07gooOol0<goo000gOol00`0OOomoo`2`Ool00`0OOomoo`0cOol003Moo`0301moogoo0:mo
o`0301moogoo03Aoo`00>7oo00<07gooOol0[Woo00<07gooOol0=7oo000hOol00`0OOomoo`2]Ool0
0`0OOomoo`0eOol003Qoo`0301moogoo0:eoo`0301moogoo03Eoo`00>7oo00<07gooOol0[Goo00<0
7gooOol0=Goo000iOol00`0OOomoo`2[Ool00`0OOomoo`0fOol003Uoo`0301moogoo0:]oo`0301mo
ogoo03Ioo`00>Woo00<07gooOol0ZWoo00<07gooOol0=Woo000jOol00`0OOomoo`2YOol00`0OOomo
o`0gOol003]oo`0301moogoo0:Qoo`0301moogoo03Moo`00>goo00<07gooOol0Ygoo00<07gooOol0
>7oo000lOol00`0OOomoo`2VOol00`0OOomoo`0hOol003aoo`0301moogoo0:Eoo`0301moogoo03Uo
o`00?Goo00<07gooOol0Y7oo00<07gooOol0>Goo000nOol00`0OOomoo`2ROol00`0OOomoo`0jOol0
03ioo`0301moogoo0:9oo`0301moogoo03Yoo`00?goo00<07gooOol0X7oo00<07gooOol0>goo000o
Ool00`0OOomoo`2POol00`0OOomoo`0kOol0041oo`0301moogoo09ioo`0301moogoo03aoo`00@7oo
00<07gooOol0WWoo00<07gooOol0?7oo0011Ool00`0OOomoo`2LOol00`0OOomoo`0mOol0049oo`03
01moogoo09Yoo`0301moogoo03ioo`00@Woo00<07gooOol0VWoo00<07gooOol0?Woo0013Ool00`0O
Oomoo`2HOol00`0OOomoo`0oOol004Aoo`0301moogoo09Ioo`0301moogoo041oo`00A7oo00<07goo
Ool0UGoo00<07gooOol0@Goo0015Ool00`0OOomoo`2DOol00`0OOomoo`11Ool004Ioo`0301moogoo
099oo`0301moogoo049oo`00AWoo00<07gooOol0TGoo00<07gooOol0@goo0017Ool00`0OOomoo`2?
Ool00`0OOomoo`14Ool004Qoo`0301moogoo08eoo`0301moogoo04Eoo`00BGoo00<07gooOol0S7oo
00<07gooOol0AGoo0019Ool00`0OOomoo`2;Ool00`0OOomoo`16Ool004Yoo`0301moogoo08Uoo`03
01moogoo04Moo`00Bgoo00<07gooOol0Qgoo00<07gooOol0B7oo001<Ool00`0OOomoo`25Ool00`0O
Oomoo`19Ool004eoo`807hAoo`0301moogoo04Yoo`00Cgoo00<07gooOol0PGoo00<07gooOol0BWoo
001@Ool00`0OOomoo`1oOol00`0OOomoo`1;Ool0055oo`0301moogoo07eoo`0301moogoo04aoo`00
DWoo00<07gooOol0Ngoo00<07gooOol0CGoo001COol201mjOol00`0OOomoo`1>Ool005Eoo`0301mo
ogoo07Eoo`807e5oo`00EWoo00<07gooOol0Lgoo00<07gooOol0DGoo001GOol00`0OOomoo`1aOol0
0`0OOomoo`1BOol005Qoo`0301moogoo06ioo`807eEoo`00FGoo0P0OK7oo0P0OEgoo001KOol00`0O
Oomoo`1WOol201mIOol005aoo`0301moogoo06Eoo`0301moogoo05Uoo`00GGoo0P0OI7oo00<07goo
Ool0FWoo001OOol201mQOol00`0OOomoo`1KOol0065oo`807eeoo`807eioo`00Hgoo00<07gooOol0
FGoo00<07gooOol0GWoo001TOol201mGOol201mQOol006Ioo`807e=oo`807f=oo`00J7oo0P0OCWoo
0`0OIGoo001ZOol201m9Ool301mXOol006aoo`807dEoo`807f]oo`00KWoo0P0O@Goo0P0OKGoo001`
Ool301lkOol301m_Ool007=oo`@07c=oo`@07g9oo`00Mgoo100O:goo100OMWoo001kOol401lSOol4
01mjOol007moo`D07aUoo`D07gioo`00Q7oo6@0OPgoo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.47292 .8203 m
.4457 .81686 L
s
.50033 .82147 m
.47292 .8203 L
s
.52775 .82035 m
.50033 .82147 L
s
.4457 .81686 m
.41885 .81117 L
s
.55498 .81697 m
.52775 .82035 L
s
.41885 .81117 m
.39257 .80327 L
s
.58184 .81133 m
.55498 .81697 L
s
.39257 .80327 m
.36704 .79321 L
s
.60814 .80347 m
.58184 .81133 L
s
.36704 .79321 m
.34243 .78107 L
s
.6337 .79345 m
.60814 .80347 L
s
.34243 .78107 m
.3189 .7669 L
s
.65834 .78133 m
.6337 .79345 L
s
.3189 .7669 m
.29664 .75083 L
s
.68189 .76719 m
.65834 .78133 L
s
.29664 .75083 m
.27579 .73294 L
s
.70418 .75113 m
.68189 .76719 L
s
.27579 .73294 m
.2565 .71336 L
s
.72506 .73324 m
.70418 .75113 L
s
.2565 .71336 m
.23892 .69223 L
s
.74437 .71365 m
.72506 .73324 L
s
.23892 .69223 m
.22316 .66968 L
s
.76198 .6925 m
.74437 .71365 L
s
.22316 .66968 m
.20934 .64587 L
s
.77776 .66992 m
.76198 .6925 L
s
.20934 .64587 m
.19758 .62096 L
s
.79158 .64607 m
.77776 .66992 L
s
.19758 .62096 m
.18795 .59513 L
s
.80334 .62112 m
.79158 .64607 L
s
.18795 .59513 m
.18054 .56855 L
s
.81296 .59523 m
.80334 .62112 L
s
.18054 .56855 m
.1754 .5414 L
s
.82035 .56859 m
.81296 .59523 L
s
.1754 .5414 m
.17258 .51389 L
s
.82546 .54138 m
.82035 .56859 L
s
.17258 .51389 m
.17212 .48621 L
s
.82823 .5138 m
.82546 .54138 L
s
.17212 .48621 m
.17401 .45855 L
s
.82864 .48605 m
.82823 .5138 L
s
.17401 .45855 m
.17827 .43112 L
s
.82668 .45833 m
.82864 .48605 L
s
.17827 .43112 m
.18486 .40411 L
s
.82235 .43084 m
.82668 .45833 L
s
.18486 .40411 m
.19375 .37772 L
s
.81567 .40377 m
.82235 .43084 L
s
.19375 .37772 m
.20489 .35216 L
s
.80668 .37734 m
.81567 .40377 L
s
.20489 .35216 m
.21819 .3276 L
s
.79544 .35173 m
.80668 .37734 L
s
.21819 .3276 m
.23358 .30424 L
s
.78203 .32714 m
.79544 .35173 L
s
.23358 .30424 m
.25093 .28224 L
s
.76654 .30375 m
.78203 .32714 L
s
.25093 .28224 m
.27014 .26179 L
s
.74907 .28175 m
.76654 .30375 L
s
.27014 .26179 m
.29106 .24303 L
s
.72975 .2613 m
.74907 .28175 L
s
.29106 .24303 m
.31355 .22611 L
s
.70872 .24256 m
.72975 .2613 L
s
.31355 .22611 m
.33743 .21116 L
s
.68614 .22566 m
.70872 .24256 L
s
.33743 .21116 m
.36254 .1983 L
s
.66216 .21075 m
.68614 .22566 L
s
.36254 .1983 m
.38869 .18762 L
s
.63697 .19794 m
.66216 .21075 L
s
.38869 .18762 m
.41568 .17922 L
s
.61076 .18733 m
.63697 .19794 L
s
.41568 .17922 m
.44331 .17316 L
s
.58371 .17899 m
.61076 .18733 L
s
.44331 .17316 m
.47137 .16949 L
s
.55604 .17301 m
.58371 .17899 L
s
.47137 .16949 m
.49966 .16824 L
s
.52795 .16941 m
.55604 .17301 L
s
.49966 .16824 m
.52795 .16941 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0024OolG01n5Ool007ioo`H07aMoo`H07gmoo`00NWoo100O8goo100O
Ngoo001fOol401l[Ool401mgOol0079oo`@07c=oo`@07g=oo`00KWoo100O>goo100OKgoo001/Ool2
01m3Ool201m]Ool006Yoo`807dMoo`807f]oo`00J7oo0P0OBgoo0P0OJGoo001VOol201m?Ool201mW
Ool006Aoo`807e=oo`807fEoo`00HWoo0P0OEgoo0P0OHgoo001POol201mKOol201mQOol005ioo`80
7emoo`807emoo`00G7oo0P0OHgoo00<07gooOol0G7oo001JOol201mVOol201mLOol005Uoo`0301mo
ogoo06Qoo`0301moogoo05Uoo`00F7oo00<07gooOol0JWoo0P0OFGoo001GOol00`0OOomoo`1]Ool0
0`0OOomoo`1FOol005Eoo`807g5oo`0301moogoo05Eoo`00E7oo00<07gooOol0LWoo0P0OEGoo001C
Ool00`0OOomoo`1eOol00`0OOomoo`1BOol0059oo`0301moogoo07Moo`0301moogoo055oo`00DGoo
00<07gooOol0NGoo00<07gooOol0D7oo001@Ool00`0OOomoo`1kOol201m@Ool004moo`0301moogoo
07ioo`0301moogoo04eoo`00CWoo00<07gooOol0P7oo00<07gooOol0C7oo001=Ool00`0OOomoo`22
Ool00`0OOomoo`1;Ool004aoo`0301moogoo08Aoo`0301moogoo04Yoo`00Bgoo00<07gooOol0QGoo
00<07gooOol0BWoo001:Ool00`0OOomoo`27Ool00`0OOomoo`19Ool004Yoo`0301moogoo08Qoo`03
01moogoo04Qoo`00BGoo00<07gooOol0RWoo00<07gooOol0Agoo0018Ool00`0OOomoo`2<Ool00`0O
Oomoo`16Ool004Moo`0301moogoo08eoo`0301moogoo04Ioo`00AWoo00<07gooOol0Sgoo00<07goo
Ool0AGoo0015Ool00`0OOomoo`2AOol00`0OOomoo`14Ool004Eoo`0301moogoo099oo`0301moogoo
04=oo`00A7oo00<07gooOol0Tgoo00<07gooOol0@goo0013Ool00`0OOomoo`2EOol00`0OOomoo`12
Ool0049oo`0301moogoo09Moo`0301moogoo045oo`00@Woo00<07gooOol0V7oo00<07gooOol0@7oo
0011Ool00`0OOomoo`2IOol00`0OOomoo`10Ool0041oo`0301moogoo09]oo`0301moogoo03moo`00
?goo00<07gooOol0WGoo00<07gooOol0?Woo000oOol00`0OOomoo`2NOol00`0OOomoo`0mOol003io
o`0301moogoo0:1oo`0301moogoo03aoo`00?Goo00<07gooOol0XGoo00<07gooOol0?7oo000mOol0
0`0OOomoo`2ROol00`0OOomoo`0kOol003aoo`0301moogoo0:=oo`0301moogoo03]oo`00?7oo00<0
7gooOol0Y7oo00<07gooOol0>Woo000kOol00`0OOomoo`2UOol00`0OOomoo`0jOol003]oo`0301mo
ogoo0:Ioo`0301moogoo03Uoo`00>Woo00<07gooOol0Ygoo00<07gooOol0>Goo000jOol00`0OOomo
o`2XOol00`0OOomoo`0hOol003Uoo`0301moogoo0:Uoo`0301moogoo03Qoo`00>Goo00<07gooOol0
ZGoo00<07gooOol0>7oo000hOol00`0OOomoo`2[Ool00`0OOomoo`0gOol003Qoo`0301moogoo0:]o
o`0301moogoo03Moo`00=goo00<07gooOol0[Goo00<07gooOol0=Woo000gOol00`0OOomoo`2]Ool0
0`0OOomoo`0fOol003Moo`0301moogoo0:eoo`0301moogoo03Ioo`00=Woo00<07gooOol0[goo00<0
7gooOol0=Goo000fOol00`0OOomoo`2_Ool00`0OOomoo`0eOol003Ioo`0301moogoo0;1oo`0301mo
ogoo03Aoo`00=Woo00<07gooOol0/7oo00<07gooOol0=7oo000eOol00`0OOomoo`2bOol00`0OOomo
o`0cOol003Eoo`0301moogoo0;9oo`0301moogoo03=oo`00=Goo00<07gooOol0/Woo00<07gooOol0
<goo000dOol00`0OOomoo`2cOol00`0OOomoo`0cOol003Aoo`0301moogoo0;Aoo`0301moogoo039o
o`00=7oo00<07gooOol0]7oo00<07gooOol0<Woo000dOol00`0OOomoo`2dOol00`0OOomoo`0bOol0
03=oo`0301moogoo0;Eoo`0301moogoo039oo`00<goo00<07gooOol0]Woo00<07gooOol0<Goo000c
Ool00`0OOomoo`2fOol00`0OOomoo`0aOol003=oo`0301moogoo0;Ioo`0301moogoo035oo`00<Woo
00<07gooOol0]goo00<07gooOol0<Goo000bOol00`0OOomoo`2gOol00`0OOomoo`0aOol0039oo`03
01moogoo0;Moo`0301moogoo035oo`00<Woo00<07gooOol0^7oo00<07gooOol0<7oo000aOol00`0O
Oomoo`2iOol00`0OOomoo`0`Ool0035oo`0301moogoo0;Uoo`0301moogoo031oo`00<Goo00<07goo
Ool0^Goo00<07gooOol0<7oo000aOol00`0OOomoo`2iOol00`0OOomoo`0`Ool0035oo`0301moogoo
0;Uoo`0301moogoo031oo`00<Goo00<07gooOol0^Goo00<07gooOol0<7oo000aOol00`0OOomoo`2i
Ool00`0OOomoo`0`Ool0035oo`0301moogoo0;Uoo`0301moogoo031oo`00<Goo00<07gooOol0^Goo
00<07gooOol0<7oo000aOol00`0OOomoo`2iOol00`0OOomoo`0`Ool0035oo`0301moogoo0;Uoo`03
01moogoo031oo`00<Goo00<07gooOol0^Goo00<07gooOol0<7oo000aOol00`0OOomoo`2iOol00`0O
Oomoo`0`Ool0035oo`0301moogoo0;Uoo`0301moogoo031oo`00<Goo00<07gooOol0^Goo00<07goo
Ool0<7oo000aOol00`0OOomoo`2iOol00`0OOomoo`0`Ool0035oo`0301moogoo0;Uoo`0301moogoo
031oo`00<Goo00<07gooOol0^Goo00<07gooOol0<7oo000aOol00`0OOomoo`2iOol00`0OOomoo`0`
Ool0035oo`0301moogoo0;Uoo`0301moogoo031oo`00<Goo00<07gooOol0^Goo00<07gooOol0<7oo
000aOol00`0OOomoo`2iOol00`0OOomoo`0`Ool0035oo`0301moogoo0;Qoo`0301moogoo035oo`00
<Woo00<07gooOol0]goo00<07gooOol0<Goo000bOol00`0OOomoo`2gOol00`0OOomoo`0aOol0039o
o`0301moogoo0;Moo`0301moogoo035oo`00<Woo00<07gooOol0]goo00<07gooOol0<Goo000bOol0
0`0OOomoo`2gOol00`0OOomoo`0aOol0039oo`0301moogoo0;Moo`0301moogoo035oo`00<Woo00<0
7gooOol0]goo00<07gooOol0<Goo000bOol00`0OOomoo`2fOol00`0OOomoo`0bOol003=oo`0301mo
ogoo0;Eoo`0301moogoo039oo`00<goo00<07gooOol0]Goo00<07gooOol0<Woo000cOol00`0OOomo
o`2eOol00`0OOomoo`0bOol003=oo`0301moogoo0;Eoo`0301moogoo039oo`00<goo00<07gooOol0
]Goo00<07gooOol0<Woo000dOol00`0OOomoo`2cOol00`0OOomoo`0cOol003Aoo`0301moogoo0;=o
o`0301moogoo03=oo`00=7oo00<07gooOol0/goo00<07gooOol0<goo000dOol00`0OOomoo`2cOol0
0`0OOomoo`0cOol003Eoo`0301moogoo0;5oo`0301moogoo03Aoo`00=Goo00<07gooOol0/Goo00<0
7gooOol0=7oo000eOol00`0OOomoo`2aOol00`0OOomoo`0dOol003Ioo`0301moogoo0:moo`0301mo
ogoo03Eoo`00=Woo00<07gooOol0[goo00<07gooOol0=Goo000fOol00`0OOomoo`2^Ool00`0OOomo
o`0fOol003Moo`0301moogoo0:eoo`0301moogoo03Ioo`00=goo00<07gooOol0[Goo00<07gooOol0
=Woo000hOol00`0OOomoo`2[Ool00`0OOomoo`0gOol003Qoo`0301moogoo0:]oo`0301moogoo03Mo
o`00>Goo00<07gooOol0ZWoo00<07gooOol0=goo000iOol00`0OOomoo`2YOol00`0OOomoo`0hOol0
03Yoo`0301moogoo0:Qoo`0301moogoo03Qoo`00>Woo00<07gooOol0Ygoo00<07gooOol0>Goo000k
Ool00`0OOomoo`2VOol00`0OOomoo`0iOol003]oo`0301moogoo0:Eoo`0301moogoo03Yoo`00?7oo
00<07gooOol0Y7oo00<07gooOol0>Woo000mOol00`0OOomoo`2ROol00`0OOomoo`0kOol003eoo`03
01moogoo0:9oo`0301moogoo03]oo`00?Woo00<07gooOol0X7oo00<07gooOol0?7oo000nOol00`0O
Oomoo`2POol00`0OOomoo`0lOol003moo`0301moogoo09ioo`0301moogoo03eoo`00?goo00<07goo
Ool0WWoo00<07gooOol0?Goo0010Ool00`0OOomoo`2LOol00`0OOomoo`0nOol0045oo`0301moogoo
09Yoo`0301moogoo03moo`00@Goo00<07gooOol0VGoo00<07gooOol0@7oo0012Ool00`0OOomoo`2G
Ool00`0OOomoo`11Ool004=oo`0301moogoo09Ioo`0301moogoo045oo`00@goo00<07gooOol0UGoo
00<07gooOol0@Woo0014Ool00`0OOomoo`2COol00`0OOomoo`13Ool004Eoo`0301moogoo095oo`03
01moogoo04Aoo`00AWoo00<07gooOol0Sgoo00<07gooOol0AGoo0016Ool00`0OOomoo`2>Ool00`0O
Oomoo`16Ool004Moo`0301moogoo08eoo`0301moogoo04Ioo`00B7oo00<07gooOol0Rgoo00<07goo
Ool0Agoo0019Ool00`0OOomoo`29Ool00`0OOomoo`18Ool004Yoo`0301moogoo08Moo`0301moogoo
04Uoo`00Bgoo00<07gooOol0QGoo00<07gooOol0BWoo001<Ool00`0OOomoo`23Ool00`0OOomoo`1;
Ool004eoo`0301moogoo089oo`0301moogoo04]oo`00CWoo00<07gooOol0P7oo00<07gooOol0C7oo
001?Ool00`0OOomoo`1nOol00`0OOomoo`1=Ool0051oo`0301moogoo07aoo`0301moogoo04ioo`00
DGoo00<07gooOol0NWoo00<07gooOol0Cgoo001BOol201mhOol201mBOol005Aoo`0301moogoo07Ao
o`0301moogoo059oo`00EGoo00<07gooOol0LWoo00<07gooOol0Dgoo001FOol00`0OOomoo`1_Ool2
01mFOol005Moo`0301moogoo06eoo`0301moogoo05Ioo`00F7oo0P0OK7oo00<07gooOol0Egoo001J
Ool00`0OOomoo`1WOol201mJOol005]oo`0301moogoo06Eoo`0301moogoo05Yoo`00G7oo0P0OHgoo
0P0OGGoo001NOol201mOOol201mOOol0061oo`807e]oo`807f5oo`00HWoo0P0OEgoo0P0OHgoo001T
Ool201mCOol201mUOol006Ioo`807dmoo`807fMoo`00J7oo0`0OBGoo0`0OJGoo001[Ool201m5Ool2
01m/Ool006eoo`807d5oo`807fioo`00Kgoo0`0O>goo0`0OL7oo001bOol401lcOol401mcOol007Io
o`@07b]oo`@07gMoo`00NWoo100O8goo100ONgoo001nOol501lIOol501moOol008=ooaT07hAoo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.62883 .79009 m
.60351 .80013 L
s
.65324 .77801 m
.62883 .79009 L
s
.67657 .76397 m
.65324 .77801 L
s
.60351 .80013 m
.57745 .80805 L
s
.69868 .74806 m
.67657 .76397 L
s
.57745 .80805 m
.55083 .8138 L
s
.7194 .73039 m
.69868 .74806 L
s
.55083 .8138 m
.52383 .81735 L
s
.7386 .71106 m
.7194 .73039 L
s
.52383 .81735 m
.49662 .81865 L
s
.75614 .69022 m
.7386 .71106 L
s
.49662 .81865 m
.46939 .81771 L
s
.7719 .66799 m
.75614 .69022 L
s
.46939 .81771 m
.44233 .81452 L
s
.78577 .64453 m
.7719 .66799 L
s
.44233 .81452 m
.41562 .80909 L
s
.79764 .61999 m
.78577 .64453 L
s
.41562 .80909 m
.38945 .80146 L
s
.80743 .59454 m
.79764 .61999 L
s
.38945 .80146 m
.36399 .79167 L
s
.81506 .56834 m
.80743 .59454 L
s
.36399 .79167 m
.33943 .77978 L
s
.82047 .54158 m
.81506 .56834 L
s
.33943 .77978 m
.31594 .76585 L
s
.82362 .51444 m
.82047 .54158 L
s
.31594 .76585 m
.29368 .74999 L
s
.82446 .4871 m
.82362 .51444 L
s
.29368 .74999 m
.27282 .73229 L
s
.82298 .45976 m
.82446 .4871 L
s
.27282 .73229 m
.25352 .71286 L
s
.81918 .43261 m
.82298 .45976 L
s
.25352 .71286 m
.23592 .69183 L
s
.81308 .40584 m
.81918 .43261 L
s
.23592 .69183 m
.22014 .66935 L
s
.8047 .37965 m
.81308 .40584 L
s
.22014 .66935 m
.20633 .64556 L
s
.79409 .35423 m
.8047 .37965 L
s
.20633 .64556 m
.19458 .62063 L
s
.78131 .32977 m
.79409 .35423 L
s
.19458 .62063 m
.18499 .59474 L
s
.76646 .30645 m
.78131 .32977 L
s
.18499 .59474 m
.17765 .56806 L
s
.74961 .28444 m
.76646 .30645 L
s
.17765 .56806 m
.17262 .54079 L
s
.73089 .26392 m
.74961 .28444 L
s
.17262 .54079 m
.16995 .51312 L
s
.71042 .24504 m
.73089 .26392 L
s
.16995 .51312 m
.16967 .48527 L
s
.68835 .22796 m
.71042 .24504 L
s
.16967 .48527 m
.1718 .45742 L
s
.66483 .2128 m
.68835 .22796 L
s
.1718 .45742 m
.17633 .42979 L
s
.64003 .1997 m
.66483 .2128 L
s
.17633 .42979 m
.18325 .40259 L
s
.61414 .18876 m
.64003 .1997 L
s
.18325 .40259 m
.1925 .37603 L
s
.58734 .18007 m
.61414 .18876 L
s
.1925 .37603 m
.20404 .35031 L
s
.55983 .17371 m
.58734 .18007 L
s
.20404 .35031 m
.21777 .32562 L
s
.53182 .16973 m
.55983 .17371 L
s
.21777 .32562 m
.23361 .30217 L
s
.50352 .16817 m
.53182 .16973 L
s
.23361 .30217 m
.25144 .28012 L
s
.47515 .16906 m
.50352 .16817 L
s
.25144 .28012 m
.27112 .25966 L
s
.44693 .17238 m
.47515 .16906 L
s
.27112 .25966 m
.29252 .24095 L
s
.41907 .17811 m
.44693 .17238 L
s
.29252 .24095 m
.31546 .22412 L
s
.39178 .18623 m
.41907 .17811 L
s
.31546 .22412 m
.33978 .20932 L
s
.36529 .19665 m
.39178 .18623 L
s
.33978 .20932 m
.36529 .19665 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0025OolG01n4Ool007moo`H07aMoo`H07gioo`00Ngoo100O8goo100O
NWoo001gOol401l[Ool401mfOol007=oo`@07c=oo`807gAoo`00Kgoo100O>Goo0`0OLGoo001]Ool2
01m0Ool301m^Ool006Yoo`<07dEoo`807faoo`00J7oo0P0OBWoo0P0OJWoo001VOol201m>Ool201mX
Ool006Aoo`807e9oo`807fIoo`00HWoo0P0OEWoo0P0OI7oo001QOol00`0OOomoo`1HOol201mROol0
05moo`807eeoo`0301moogoo05moo`00GGoo0P0OH7oo0P0OGgoo001KOol201mTOol201mMOol005Yo
o`0301moogoo06Ioo`807e]oo`00F7oo0P0OJgoo00<07gooOol0F7oo001GOol00`0OOomoo`1/Ool0
0`0OOomoo`1GOol005Ioo`0301moogoo06ioo`0301moogoo05Ioo`00E7oo0P0OLWoo0P0OEWoo001C
Ool00`0OOomoo`1dOol00`0OOomoo`1COol0059oo`0301moogoo07Ioo`0301moogoo059oo`00DGoo
00<07gooOol0N7oo00<07gooOol0DGoo001?Ool201mlOol00`0OOomoo`1@Ool004ioo`0301moogoo
07eoo`807e1oo`00CGoo00<07gooOol0P7oo00<07gooOol0CGoo001<Ool00`0OOomoo`22Ool00`0O
Oomoo`1<Ool004]oo`0301moogoo08Aoo`0301moogoo04]oo`00BWoo00<07gooOol0QWoo00<07goo
Ool0BWoo001:Ool00`0OOomoo`27Ool00`0OOomoo`19Ool004Uoo`0301moogoo08Uoo`0301moogoo
04Qoo`00B7oo00<07gooOol0Rgoo00<07gooOol0Agoo0017Ool00`0OOomoo`2=Ool00`0OOomoo`16
Ool004Ioo`0301moogoo08moo`0301moogoo04Eoo`00AGoo00<07gooOol0T7oo00<07gooOol0AGoo
0015Ool00`0OOomoo`2AOol00`0OOomoo`14Ool004Aoo`0301moogoo09=oo`0301moogoo04=oo`00
@goo00<07gooOol0U7oo00<07gooOol0@goo0012Ool00`0OOomoo`2FOol00`0OOomoo`12Ool0049o
o`0301moogoo09Moo`0301moogoo045oo`00@Goo00<07gooOol0V7oo00<07gooOol0@Goo0010Ool0
0`0OOomoo`2JOol00`0OOomoo`10Ool003moo`0301moogoo09aoo`0301moogoo03moo`00?goo00<0
7gooOol0WGoo00<07gooOol0?Woo000nOol00`0OOomoo`2NOol00`0OOomoo`0nOol003eoo`0301mo
ogoo0:1oo`0301moogoo03eoo`00?Goo00<07gooOol0X7oo00<07gooOol0?Goo000lOol00`0OOomo
o`2ROol00`0OOomoo`0lOol003aoo`0301moogoo0:9oo`0301moogoo03aoo`00>goo00<07gooOol0
Y7oo00<07gooOol0>goo000kOol00`0OOomoo`2TOol00`0OOomoo`0kOol003Yoo`0301moogoo0:Io
o`0301moogoo03Yoo`00>Woo00<07gooOol0YWoo00<07gooOol0>Woo000iOol00`0OOomoo`2WOol0
0`0OOomoo`0jOol003Uoo`0301moogoo0:Qoo`0301moogoo03Uoo`00>7oo00<07gooOol0ZGoo00<0
7gooOol0>Goo000hOol00`0OOomoo`2ZOol00`0OOomoo`0hOol003Moo`0301moogoo0:]oo`0301mo
ogoo03Qoo`00=goo00<07gooOol0[7oo00<07gooOol0=goo000gOol00`0OOomoo`2/Ool00`0OOomo
o`0gOol003Ioo`0301moogoo0:eoo`0301moogoo03Moo`00=Woo00<07gooOol0[Woo00<07gooOol0
=Woo000eOol00`0OOomoo`2_Ool00`0OOomoo`0fOol003Eoo`0301moogoo0:moo`0301moogoo03Io
o`00=Goo00<07gooOol0/7oo00<07gooOol0=Goo000dOol00`0OOomoo`2aOol00`0OOomoo`0eOol0
03Aoo`0301moogoo0;9oo`0301moogoo03Aoo`00=7oo00<07gooOol0/Woo00<07gooOol0=7oo000c
Ool00`0OOomoo`2cOol00`0OOomoo`0dOol003=oo`0301moogoo0;=oo`0301moogoo03Aoo`00<goo
00<07gooOol0]7oo00<07gooOol0<goo000cOol00`0OOomoo`2dOol00`0OOomoo`0cOol0039oo`03
01moogoo0;Eoo`0301moogoo03=oo`00<Woo00<07gooOol0]Goo00<07gooOol0<goo000bOol00`0O
Oomoo`2fOol00`0OOomoo`0bOol0039oo`0301moogoo0;Ioo`0301moogoo039oo`00<Woo00<07goo
Ool0]Woo00<07gooOol0<Woo000bOol00`0OOomoo`2fOol00`0OOomoo`0bOol0035oo`0301moogoo
0;Moo`0301moogoo039oo`00<Goo00<07gooOol0^7oo00<07gooOol0<Goo000aOol00`0OOomoo`2h
Ool00`0OOomoo`0aOol0035oo`0301moogoo0;Qoo`0301moogoo035oo`00<Goo00<07gooOol0^7oo
00<07gooOol0<Goo000aOol00`0OOomoo`2hOol00`0OOomoo`0aOol0035oo`0301moogoo0;Qoo`03
01moogoo035oo`00<Goo00<07gooOol0^7oo00<07gooOol0<Goo000`Ool00`0OOomoo`2iOol00`0O
Oomoo`0aOol0031oo`0301moogoo0;Uoo`0301moogoo035oo`00<7oo00<07gooOol0^Goo00<07goo
Ool0<Goo000`Ool00`0OOomoo`2iOol00`0OOomoo`0aOol0031oo`0301moogoo0;Uoo`0301moogoo
035oo`00<7oo00<07gooOol0^Goo00<07gooOol0<Goo000`Ool00`0OOomoo`2iOol00`0OOomoo`0a
Ool0031oo`0301moogoo0;Uoo`0301moogoo035oo`00<7oo00<07gooOol0^Goo00<07gooOol0<Goo
000`Ool00`0OOomoo`2iOol00`0OOomoo`0aOol0031oo`0301moogoo0;Uoo`0301moogoo035oo`00
<7oo00<07gooOol0^Goo00<07gooOol0<Goo000`Ool00`0OOomoo`2iOol00`0OOomoo`0aOol0031o
o`0301moogoo0;Uoo`0301moogoo035oo`00<7oo00<07gooOol0^Goo00<07gooOol0<Goo000`Ool0
0`0OOomoo`2iOol00`0OOomoo`0aOol0031oo`0301moogoo0;Qoo`0301moogoo039oo`00<Goo00<0
7gooOol0]goo00<07gooOol0<Woo000aOol00`0OOomoo`2gOol00`0OOomoo`0bOol0035oo`0301mo
ogoo0;Moo`0301moogoo039oo`00<Goo00<07gooOol0]goo00<07gooOol0<Woo000aOol00`0OOomo
o`2gOol00`0OOomoo`0bOol0035oo`0301moogoo0;Ioo`0301moogoo03=oo`00<Goo00<07gooOol0
]Woo00<07gooOol0<goo000aOol00`0OOomoo`2fOol00`0OOomoo`0cOol0039oo`0301moogoo0;Eo
o`0301moogoo03=oo`00<Woo00<07gooOol0]7oo00<07gooOol0=7oo000bOol00`0OOomoo`2dOol0
0`0OOomoo`0dOol0039oo`0301moogoo0;Aoo`0301moogoo03Aoo`00<Woo00<07gooOol0]7oo00<0
7gooOol0=7oo000cOol00`0OOomoo`2bOol00`0OOomoo`0eOol003=oo`0301moogoo0;9oo`0301mo
ogoo03Eoo`00=7oo00<07gooOol0/Goo00<07gooOol0=Goo000dOol00`0OOomoo`2aOol00`0OOomo
o`0eOol003Eoo`0301moogoo0:moo`0301moogoo03Ioo`00=Goo00<07gooOol0[goo00<07gooOol0
=Woo000eOol00`0OOomoo`2_Ool00`0OOomoo`0fOol003Eoo`0301moogoo0:ioo`0301moogoo03Mo
o`00=Woo00<07gooOol0[Goo00<07gooOol0=goo000fOol00`0OOomoo`2/Ool00`0OOomoo`0hOol0
03Ioo`0301moogoo0:aoo`0301moogoo03Qoo`00=Woo00<07gooOol0Zgoo00<07gooOol0>Goo000g
Ool00`0OOomoo`2ZOol00`0OOomoo`0iOol003Moo`0301moogoo0:Yoo`0301moogoo03Uoo`00>7oo
00<07gooOol0Z7oo00<07gooOol0>Woo000hOol00`0OOomoo`2XOol00`0OOomoo`0jOol003Uoo`03
01moogoo0:Ioo`0301moogoo03]oo`00>Goo00<07gooOol0YWoo00<07gooOol0>goo000jOol00`0O
Oomoo`2TOol00`0OOomoo`0lOol003Yoo`0301moogoo0:Aoo`0301moogoo03aoo`00>goo00<07goo
Ool0XWoo00<07gooOol0?Goo000lOol00`0OOomoo`2QOol00`0OOomoo`0mOol003aoo`0301moogoo
0:1oo`0301moogoo03ioo`00?Goo00<07gooOol0Wgoo00<07gooOol0?Woo000mOol00`0OOomoo`2N
Ool00`0OOomoo`0oOol003ioo`0301moogoo09eoo`0301moogoo03moo`00?Woo00<07gooOol0W7oo
00<07gooOol0@7oo000oOol00`0OOomoo`2JOol00`0OOomoo`11Ool0041oo`0301moogoo09Uoo`03
01moogoo045oo`00@7oo00<07gooOol0V7oo00<07gooOol0@Woo0011Ool00`0OOomoo`2GOol00`0O
Oomoo`12Ool0049oo`0301moogoo09Eoo`0301moogoo04=oo`00@Woo00<07gooOol0UGoo00<07goo
Ool0@goo0013Ool00`0OOomoo`2COol00`0OOomoo`14Ool004Aoo`0301moogoo095oo`0301moogoo
04Eoo`00AGoo00<07gooOol0Sgoo00<07gooOol0AWoo0015Ool00`0OOomoo`2>Ool00`0OOomoo`17
Ool004Ioo`0301moogoo08aoo`0301moogoo04Qoo`00Agoo00<07gooOol0RWoo00<07gooOol0BGoo
0018Ool00`0OOomoo`28Ool00`0OOomoo`1:Ool004Uoo`0301moogoo08Ioo`0301moogoo04]oo`00
BWoo00<07gooOol0Q7oo00<07gooOol0C7oo001;Ool00`0OOomoo`22Ool00`0OOomoo`1=Ool004ao
o`0301moogoo081oo`0301moogoo04ioo`00CGoo00<07gooOol0OWoo00<07gooOol0Cgoo001>Ool0
0`0OOomoo`1lOol00`0OOomoo`1@Ool004moo`0301moogoo07Yoo`0301moogoo055oo`00D7oo00<0
7gooOol0Mgoo0P0OE7oo001AOol201mfOol00`0OOomoo`1DOol005=oo`0301moogoo079oo`0301mo
ogoo05Eoo`00E7oo00<07gooOol0L7oo00<07gooOol0EWoo001EOol201m_Ool00`0OOomoo`1GOol0
05Moo`0301moogoo06Yoo`807eYoo`00F7oo0P0OJGoo00<07gooOol0FWoo001JOol00`0OOomoo`1U
Ool00`0OOomoo`1KOol005]oo`807f=oo`807eioo`00GGoo0P0OGgoo0P0OH7oo001OOol201mKOol2
01mROol0065oo`0301moogoo05Ioo`807fAoo`00HWoo0P0OE7oo0P0OIWoo001TOol201m@Ool201mX
Ool006Ioo`807d]oo`<07fYoo`00J7oo0P0OAgoo0P0OKGoo001ZOol201m3Ool201m_Ool006aoo`80
7cioo`<07g5oo`00KWoo0`0O=goo100OM7oo001aOol401l_Ool401mhOol007Eoo`H07bEoo`@07gao
o`00Ngoo1`0O6Goo1@0OP7oo0022OolI01n5Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.69186 .74457 m
.67005 .76039 L
s
.71232 .72705 m
.69186 .74457 L
s
.7313 .70794 m
.71232 .72705 L
s
.67005 .76039 m
.64704 .7744 L
s
.74869 .68736 m
.7313 .70794 L
s
.64704 .7744 m
.62298 .7865 L
s
.76435 .66544 m
.74869 .68736 L
s
.62298 .7865 m
.59802 .79662 L
s
.77819 .64234 m
.76435 .66544 L
s
.59802 .79662 m
.57232 .80468 L
s
.7901 .61819 m
.77819 .64234 L
s
.57232 .80468 m
.54606 .81063 L
s
.80001 .59316 m
.7901 .61819 L
s
.54606 .81063 m
.51941 .8144 L
s
.80784 .5674 m
.80001 .59316 L
s
.51941 .8144 m
.49253 .81598 L
s
.81353 .54108 m
.80784 .5674 L
s
.49253 .81598 m
.46561 .81533 L
s
.81702 .51439 m
.81353 .54108 L
s
.46561 .81533 m
.43884 .81245 L
s
.81829 .48748 m
.81702 .51439 L
s
.43884 .81245 m
.41238 .80736 L
s
.81732 .46056 m
.81829 .48748 L
s
.41238 .80736 m
.38644 .80005 L
s
.81408 .4338 m
.81732 .46056 L
s
.38644 .80005 m
.36118 .79058 L
s
.8086 .40738 m
.81408 .4338 L
s
.36118 .79058 m
.33678 .779 L
s
.80089 .38149 m
.8086 .40738 L
s
.33678 .779 m
.31343 .76536 L
s
.79099 .35632 m
.80089 .38149 L
s
.31343 .76536 m
.2913 .74975 L
s
.77895 .33205 m
.79099 .35632 L
s
.2913 .74975 m
.27055 .73226 L
s
.76484 .30886 m
.77895 .33205 L
s
.27055 .73226 m
.25134 .713 L
s
.74875 .28692 m
.76484 .30886 L
s
.25134 .713 m
.23382 .69211 L
s
.73078 .2664 m
.74875 .28692 L
s
.23382 .69211 m
.21813 .6697 L
s
.71103 .24747 m
.73078 .2664 L
s
.21813 .6697 m
.20441 .64595 L
s
.68965 .23026 m
.71103 .24747 L
s
.20441 .64595 m
.19277 .62101 L
s
.66677 .21493 m
.68965 .23026 L
s
.19277 .62101 m
.18331 .59505 L
s
.64256 .2016 m
.66677 .21493 L
s
.18331 .59505 m
.17612 .56827 L
s
.61718 .19039 m
.64256 .2016 L
s
.17612 .56827 m
.17127 .54086 L
s
.59082 .1814 m
.61718 .19039 L
s
.17127 .54086 m
.16881 .51302 L
s
.56368 .17471 m
.59082 .1814 L
s
.16881 .51302 m
.16878 .48497 L
s
.53594 .17039 m
.56368 .17471 L
s
.16878 .48497 m
.1712 .45692 L
s
.50784 .16848 m
.53594 .17039 L
s
.1712 .45692 m
.17606 .42908 L
s
.47957 .16902 m
.50784 .16848 L
s
.17606 .42908 m
.18333 .40167 L
s
.45136 .17201 m
.47957 .16902 L
s
.18333 .40167 m
.19298 .37492 L
s
.42343 .17745 m
.45136 .17201 L
s
.19298 .37492 m
.20492 .34902 L
s
.396 .18529 m
.42343 .17745 L
s
.20492 .34902 m
.21909 .32419 L
s
.36929 .19548 m
.396 .18529 L
s
.21909 .32419 m
.23536 .30063 L
s
.34351 .20796 m
.36929 .19548 L
s
.23536 .30063 m
.25363 .27852 L
s
.31886 .22262 m
.34351 .20796 L
s
.25363 .27852 m
.27374 .25804 L
s
.29554 .23936 m
.31886 .22262 L
s
.27374 .25804 m
.29554 .23936 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo0026OolE01n5Ool007ioo`P07aEoo`@07h5oo`00N7oo1P0O8Goo100O
OGoo001fOol201l[Ool401miOol007=oo`<07c5oo`@07gEoo`00L7oo0`0O>7oo100OLGoo001^Ool2
01loOol401m]Ool006]oo`<07dEoo`807f]oo`00J7oo0`0OBWoo0P0OJGoo001VOol201m?Ool201mW
Ool006Aoo`807e=oo`807fEoo`00HWoo0P0OEgoo0P0OHgoo001POol201mKOol201mQOol005ioo`80
7emoo`0301moogoo05ioo`00G7oo0P0OHWoo00<07gooOol0GGoo001KOol00`0OOomoo`1SOol00`0O
Oomoo`1LOol005Uoo`807fMoo`807eaoo`00F7oo00<07gooOol0JGoo00<07gooOol0FGoo001GOol0
0`0OOomoo`1[Ool00`0OOomoo`1HOol005Eoo`807fmoo`807eQoo`00E7oo00<07gooOol0LGoo00<0
7gooOol0EGoo001COol00`0OOomoo`1cOol00`0OOomoo`1DOol0059oo`0301moogoo07Eoo`807eAo
o`00DGoo00<07gooOol0N7oo00<07gooOol0DGoo001@Ool00`0OOomoo`1jOol00`0OOomoo`1@Ool0
04moo`0301moogoo07aoo`0301moogoo04moo`00CWoo00<07gooOol0OWoo00<07gooOol0CWoo001=
Ool00`0OOomoo`20Ool00`0OOomoo`1=Ool004aoo`0301moogoo089oo`0301moogoo04aoo`00BWoo
0P0OQWoo00<07gooOol0Bgoo0019Ool00`0OOomoo`27Ool00`0OOomoo`1:Ool004Qoo`0301moogoo
08Qoo`0301moogoo04Yoo`00Agoo00<07gooOol0RWoo00<07gooOol0BGoo0017Ool00`0OOomoo`2;
Ool00`0OOomoo`18Ool004Ioo`0301moogoo08eoo`0301moogoo04Moo`00AGoo00<07gooOol0Sgoo
00<07gooOol0AWoo0014Ool00`0OOomoo`2AOol00`0OOomoo`15Ool004Aoo`0301moogoo095oo`03
01moogoo04Eoo`00@goo00<07gooOol0Tgoo00<07gooOol0A7oo0012Ool00`0OOomoo`2EOol00`0O
Oomoo`13Ool0049oo`0301moogoo09Ioo`0301moogoo049oo`00@Goo00<07gooOol0V7oo00<07goo
Ool0@Goo0010Ool00`0OOomoo`2IOol00`0OOomoo`11Ool003moo`0301moogoo09]oo`0301moogoo
041oo`00?goo00<07gooOol0Vgoo00<07gooOol0@7oo000nOol00`0OOomoo`2MOol00`0OOomoo`0o
Ool003eoo`0301moogoo09ioo`0301moogoo03moo`00?Goo00<07gooOol0Wgoo00<07gooOol0?Woo
000lOol00`0OOomoo`2QOol00`0OOomoo`0mOol003aoo`0301moogoo0:5oo`0301moogoo03eoo`00
>goo00<07gooOol0Xgoo00<07gooOol0?7oo000kOol00`0OOomoo`2SOol00`0OOomoo`0lOol003Yo
o`0301moogoo0:Eoo`0301moogoo03]oo`00>Woo00<07gooOol0YGoo00<07gooOol0>goo000iOol0
0`0OOomoo`2WOol00`0OOomoo`0jOol003Uoo`0301moogoo0:Moo`0301moogoo03Yoo`00>7oo00<0
7gooOol0ZGoo00<07gooOol0>Goo000hOol00`0OOomoo`2YOol00`0OOomoo`0iOol003Moo`0301mo
ogoo0:Yoo`0301moogoo03Uoo`00=goo00<07gooOol0ZWoo00<07gooOol0>Goo000gOol00`0OOomo
o`2[Ool00`0OOomoo`0hOol003Ioo`0301moogoo0:aoo`0301moogoo03Qoo`00=Woo00<07gooOol0
[7oo00<07gooOol0>7oo000eOol00`0OOomoo`2^Ool00`0OOomoo`0gOol003Eoo`0301moogoo0:io
o`0301moogoo03Moo`00=Goo00<07gooOol0[goo00<07gooOol0=Woo000dOol00`0OOomoo`2`Ool0
0`0OOomoo`0fOol003Aoo`0301moogoo0;5oo`0301moogoo03Eoo`00=7oo00<07gooOol0/Goo00<0
7gooOol0=Goo000cOol00`0OOomoo`2bOol00`0OOomoo`0eOol003=oo`0301moogoo0;9oo`0301mo
ogoo03Eoo`00<goo00<07gooOol0/Woo00<07gooOol0=Goo000cOol00`0OOomoo`2bOol00`0OOomo
o`0eOol0039oo`0301moogoo0;Aoo`0301moogoo03Aoo`00<Woo00<07gooOol0]7oo00<07gooOol0
=7oo000bOol00`0OOomoo`2dOol00`0OOomoo`0dOol0039oo`0301moogoo0;Aoo`0301moogoo03Ao
o`00<Woo00<07gooOol0]7oo00<07gooOol0=7oo000bOol00`0OOomoo`2dOol00`0OOomoo`0dOol0
035oo`0301moogoo0;Eoo`0301moogoo03Aoo`00<Goo00<07gooOol0]Goo00<07gooOol0=7oo000a
Ool00`0OOomoo`2fOol00`0OOomoo`0cOol0035oo`0301moogoo0;Ioo`0301moogoo03=oo`00<Goo
00<07gooOol0]Woo00<07gooOol0<goo000aOol00`0OOomoo`2fOol00`0OOomoo`0cOol0035oo`03
01moogoo0;Ioo`0301moogoo03=oo`00<Goo00<07gooOol0]Woo00<07gooOol0<goo000`Ool00`0O
Oomoo`2gOol00`0OOomoo`0cOol0031oo`0301moogoo0;Moo`0301moogoo03=oo`00<7oo00<07goo
Ool0]goo00<07gooOol0<goo000`Ool00`0OOomoo`2gOol00`0OOomoo`0cOol0031oo`0301moogoo
0;Moo`0301moogoo03=oo`00<7oo00<07gooOol0]goo00<07gooOol0<goo000`Ool00`0OOomoo`2g
Ool00`0OOomoo`0cOol0031oo`0301moogoo0;Moo`0301moogoo03=oo`00<7oo00<07gooOol0]goo
00<07gooOol0<goo000`Ool00`0OOomoo`2gOol00`0OOomoo`0cOol0031oo`0301moogoo0;Moo`03
01moogoo03=oo`00<7oo00<07gooOol0]goo00<07gooOol0<goo000`Ool00`0OOomoo`2gOol00`0O
Oomoo`0cOol0031oo`0301moogoo0;Moo`0301moogoo03=oo`00<7oo00<07gooOol0]goo00<07goo
Ool0<goo000`Ool00`0OOomoo`2gOol00`0OOomoo`0cOol0031oo`0301moogoo0;Ioo`0301moogoo
03Aoo`00<Goo00<07gooOol0]Goo00<07gooOol0=7oo000aOol00`0OOomoo`2eOol00`0OOomoo`0d
Ool0035oo`0301moogoo0;Eoo`0301moogoo03Aoo`00<Goo00<07gooOol0]Goo00<07gooOol0=7oo
000aOol00`0OOomoo`2eOol00`0OOomoo`0dOol0035oo`0301moogoo0;Aoo`0301moogoo03Eoo`00
<Goo00<07gooOol0]7oo00<07gooOol0=Goo000aOol00`0OOomoo`2dOol00`0OOomoo`0eOol0039o
o`0301moogoo0;=oo`0301moogoo03Eoo`00<Woo00<07gooOol0/Woo00<07gooOol0=Woo000bOol0
0`0OOomoo`2bOol00`0OOomoo`0fOol0039oo`0301moogoo0;9oo`0301moogoo03Ioo`00<Woo00<0
7gooOol0/Goo00<07gooOol0=goo000cOol00`0OOomoo`2`Ool00`0OOomoo`0gOol003=oo`0301mo
ogoo0;1oo`0301moogoo03Moo`00<goo00<07gooOol0/7oo00<07gooOol0=goo000cOol00`0OOomo
o`2_Ool00`0OOomoo`0hOol003Aoo`0301moogoo0:ioo`0301moogoo03Qoo`00=7oo00<07gooOol0
[Woo00<07gooOol0>7oo000dOol00`0OOomoo`2^Ool00`0OOomoo`0hOol003Eoo`0301moogoo0:ao
o`0301moogoo03Uoo`00=Goo00<07gooOol0[7oo00<07gooOol0>Goo000eOol00`0OOomoo`2[Ool0
0`0OOomoo`0jOol003Ioo`0301moogoo0:Yoo`0301moogoo03Yoo`00=Woo00<07gooOol0ZGoo00<0
7gooOol0>goo000gOol00`0OOomoo`2XOol00`0OOomoo`0kOol003Moo`0301moogoo0:Qoo`0301mo
ogoo03]oo`00=goo00<07gooOol0Ygoo00<07gooOol0?7oo000hOol00`0OOomoo`2VOol00`0OOomo
o`0lOol003Qoo`0301moogoo0:Eoo`0301moogoo03eoo`00>Goo00<07gooOol0Y7oo00<07gooOol0
?Goo000iOol00`0OOomoo`2SOol00`0OOomoo`0nOol003Yoo`0301moogoo0:9oo`0301moogoo03io
o`00>Woo00<07gooOol0XGoo00<07gooOol0?goo000kOol00`0OOomoo`2POol00`0OOomoo`0oOol0
03]oo`0301moogoo09moo`0301moogoo041oo`00?7oo00<07gooOol0WGoo00<07gooOol0@Goo000l
Ool00`0OOomoo`2MOol00`0OOomoo`11Ool003eoo`0301moogoo09]oo`0301moogoo049oo`00?Goo
00<07gooOol0VWoo00<07gooOol0@goo000nOol00`0OOomoo`2IOol00`0OOomoo`13Ool003moo`03
01moogoo09Moo`0301moogoo04Aoo`00@7oo00<07gooOol0UGoo00<07gooOol0AGoo0010Ool00`0O
Oomoo`2DOol00`0OOomoo`16Ool0045oo`0301moogoo09=oo`0301moogoo04Ioo`00@Woo00<07goo
Ool0TGoo00<07gooOol0Agoo0013Ool00`0OOomoo`2?Ool00`0OOomoo`18Ool004Aoo`0301moogoo
08eoo`0301moogoo04Uoo`00AGoo00<07gooOol0Rgoo00<07gooOol0BWoo0015Ool00`0OOomoo`2;
Ool00`0OOomoo`1:Ool004Ioo`0301moogoo08Uoo`0301moogoo04]oo`00Agoo00<07gooOol0Qgoo
00<07gooOol0C7oo0018Ool00`0OOomoo`25Ool00`0OOomoo`1=Ool004Uoo`0301moogoo08=oo`03
01moogoo04ioo`00BWoo00<07gooOol0PGoo00<07gooOol0Cgoo001:Ool00`0OOomoo`20Ool00`0O
Oomoo`1@Ool004]oo`0301moogoo07ioo`0301moogoo055oo`00C7oo00<07gooOol0O7oo00<07goo
Ool0DWoo001=Ool00`0OOomoo`1jOol00`0OOomoo`1COol004ioo`0301moogoo07Moo`807eIoo`00
Cgoo00<07gooOol0MGoo00<07gooOol0EWoo001@Ool201mdOol00`0OOomoo`1GOol0059oo`0301mo
ogoo071oo`0301moogoo05Qoo`00Dgoo00<07gooOol0KWoo00<07gooOol0FGoo001DOol201m/Ool2
01mLOol005Ioo`0301moogoo06Qoo`0301moogoo05aoo`00Egoo0P0OIgoo00<07gooOol0GGoo001I
Ool00`0OOomoo`1ROol201mPOol005Yoo`807f1oo`807f9oo`00G7oo0P0OG7oo0P0OI7oo001NOol2
01mHOol201mVOol0061oo`807eAoo`807fQoo`00HWoo0P0OD7oo0P0OJWoo001TOol201m;Ool301m/
Ool006Ioo`<07dIoo`807fmoo`00JGoo0P0O@Woo0P0OLGoo001[Ool201lmOol301mcOol006eoo`<0
7cIoo`@07gIoo`00L7oo100O;goo0`0ONWoo001dOol401lWOol401mmOol007Qoo`@07aeoo`H07h5o
o`00O7oo3@0O2Goo1`0OQgoo0029Ool901n>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}]
}, Closed]]
}, Closed]],

Cell[TextData[{
  StyleBox["The LHCP photon-e&mvf that is generated by the rotation of the \
great-circle basis elements in the xz- and yz-planes about the ",
    FontFamily->"New York"],
  "(",
  Cell[BoxData[
      \(TraditionalForm\`i\_x\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(-i\_y\)\)]],
  ",0",
  Cell[BoxData[
      \(TraditionalForm\`i\_z\)]],
  ")",
  StyleBox["-axis by ",
    FontFamily->"New York"],
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]],
  StyleBox[" corresponding to the output of the matrix given by Eq. (10) is \
shown in Figure 4.",
    FontFamily->"New York"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(EFieldLHCP\  = \ 
        Show[Array[p, {Steps}], ViewPoint \[Rule] {0, 0, 2}];\)\)], "Input",
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.49116 .5 m
.50884 .5 L
s
.47352 .5 m
.49116 .5 L
s
.50884 .5 m
.52648 .5 L
s
.49343 .48459 m
.51112 .48465 L
s
.47577 .48462 m
.49343 .48459 L
s
.51112 .48465 m
.52877 .4848 L
s
.45595 .5 m
.47352 .5 L
s
.52648 .5 m
.54405 .5 L
s
.45818 .48474 m
.47577 .48462 L
s
.49579 .46929 m
.51349 .46953 L
s
.47809 .46923 m
.49579 .46929 L
s
.52877 .4848 m
.54633 .48504 L
s
.51349 .46953 m
.53116 .46994 L
s
.46046 .46934 m
.47809 .46923 L
s
.53116 .46994 m
.54874 .47053 L
s
.4385 .5 m
.45595 .5 L
s
.54405 .5 m
.5615 .5 L
s
.44071 .48495 m
.45818 .48474 L
s
.49831 .45424 m
.51606 .45478 L
s
.48056 .45397 m
.49831 .45424 L
s
.51606 .45478 m
.53375 .45557 L
s
.54633 .48504 m
.56376 .48537 L
s
.46287 .45397 m
.48056 .45397 L
s
.44294 .46964 m
.46046 .46934 L
s
.53375 .45557 m
.55135 .45664 L
s
.54874 .47053 m
.56617 .4713 L
s
.44529 .45423 m
.46287 .45397 L
s
.50108 .43961 m
.51888 .44056 L
s
.48328 .43901 m
.50108 .43961 L
s
.42342 .48525 m
.44071 .48495 L
s
.42125 .5 m
.4385 .5 L
s
.5615 .5 m
.57875 .5 L
s
.51888 .44056 m
.53661 .44185 L
s
.46552 .43877 m
.48328 .43901 L
s
.42559 .47012 m
.44294 .46964 L
s
.56376 .48537 m
.581 .48578 L
s
.55135 .45664 m
.56878 .45796 L
s
.53661 .44185 m
.55422 .4435 L
s
.44785 .43888 m
.46552 .43877 L
s
.42787 .45477 m
.44529 .45423 L
s
.56617 .4713 m
.58339 .47225 L
s
.50418 .42555 m
.52202 .42702 L
s
.48631 .42451 m
.50418 .42555 L
s
.52202 .42702 m
.53978 .42892 L
s
.46847 .42392 m
.48631 .42451 L
s
.40636 .48563 m
.42342 .48525 L
s
.55422 .4435 m
.57165 .44548 L
s
.40423 .5 m
.42125 .5 L
s
.57875 .5 m
.59577 .5 L
s
.40847 .47077 m
.42559 .47012 L
s
.43035 .43936 m
.44785 .43888 L
s
.56878 .45796 m
.586 .45955 L
s
.53978 .42892 m
.55739 .43125 L
s
.581 .48578 m
.59798 .48629 L
s
.45072 .42376 m
.46847 .42392 L
s
.41067 .45557 m
.42787 .45477 L
s
.58339 .47225 m
.60036 .47337 L
s
.50765 .41221 m
.52552 .41431 L
s
.48973 .41062 m
.50765 .41221 L
s
.52552 .41431 m
.54329 .41692 L
s
.55739 .43125 m
.57481 .434 L
s
.47182 .40956 m
.48973 .41062 L
s
.57165 .44548 m
.58885 .44782 L
s
.43311 .42406 m
.45072 .42376 L
s
.41305 .4402 m
.43035 .43936 L
s
.54329 .41692 m
.56089 .42003 L
s
.45397 .40902 m
.47182 .40956 L
s
.38959 .48611 m
.40636 .48563 L
s
.586 .45955 m
.60294 .4614 L
s
.38752 .5 m
.40423 .5 L
s
.59577 .5 m
.61248 .5 L
s
.39164 .47162 m
.40847 .47077 L
s
.59798 .48629 m
.61466 .48688 L
s
.57481 .434 m
.59197 .43718 L
s
.39376 .45666 m
.41067 .45557 L
s
.56089 .42003 m
.57826 .42364 L
s
.51153 .39972 m
.52941 .40255 L
s
.49358 .39749 m
.51153 .39972 L
s
.4157 .42481 m
.43311 .42406 L
s
.52941 .40255 m
.54715 .40596 L
s
.43625 .40902 m
.45397 .40902 L
s
.4756 .39585 m
.49358 .39749 L
s
.58885 .44782 m
.60575 .45049 L
s
.60036 .47337 m
.617 .47467 L
s
.54715 .40596 m
.5647 .40995 L
s
.39603 .44141 m
.41305 .4402 L
s
.45767 .39482 m
.4756 .39585 L
s
.57826 .42364 m
.59535 .42775 L
s
.60294 .4614 m
.61954 .4635 L
s
.5647 .40995 m
.58199 .4145 L
s
.41872 .40957 m
.43625 .40902 L
s
.37319 .48669 m
.38959 .48611 L
s
.59197 .43718 m
.60881 .44077 L
s
.37517 .47264 m
.39164 .47162 L
s
.37117 .5 m
.38752 .5 L
s
.61248 .5 m
.62883 .5 L
s
.51583 .38823 m
.53368 .39188 L
s
.49787 .38525 m
.51583 .38823 L
s
.39856 .42602 m
.4157 .42481 L
s
.53368 .39188 m
.55135 .39617 L
s
.43985 .39441 m
.45767 .39482 L
s
.37719 .45802 m
.39376 .45666 L
s
.47987 .38294 m
.49787 .38525 L
s
.61466 .48688 m
.63096 .48756 L
s
.55135 .39617 m
.5688 .40111 L
s
.60575 .45049 m
.6223 .45351 L
s
.58199 .4145 m
.59896 .41961 L
s
.46188 .38131 m
.47987 .38294 L
s
.37935 .44299 m
.39603 .44141 L
s
.59535 .42775 m
.61209 .43234 L
s
.617 .47467 m
.63325 .47615 L
s
.5688 .40111 m
.58595 .40667 L
s
.42219 .39464 m
.43985 .39441 L
s
.40144 .41066 m
.41872 .40957 L
s
.53829 .38238 m
.55584 .38764 L
s
.52053 .37784 m
.53829 .38238 L
s
.50263 .37403 m
.52053 .37784 L
s
.60881 .44077 m
.62527 .44478 L
s
.44397 .38039 m
.46188 .38131 L
s
.61954 .4635 m
.63573 .46587 L
s
.55584 .38764 m
.57312 .39358 L
s
.38175 .4277 m
.39856 .42602 L
s
.48463 .37095 m
.50263 .37403 L
s
.58595 .40667 m
.60274 .41284 L
s
.59896 .41961 m
.61555 .42527 L
s
.35721 .48735 m
.37319 .48669 L
s
.35911 .47386 m
.37517 .47264 L
s
.35525 .5 m
.37117 .5 L
s
.62883 .5 m
.64475 .5 L
s
.57312 .39358 m
.59005 .4002 L
s
.36104 .45967 m
.37719 .45802 L
s
.46662 .36863 m
.48463 .37095 L
s
.6223 .45351 m
.63841 .45686 L
s
.61209 .43234 m
.62841 .43741 L
s
.40477 .3955 m
.42219 .39464 L
s
.63096 .48756 m
.64682 .48834 L
s
.4262 .38018 m
.44397 .38039 L
s
.38448 .41232 m
.40144 .41066 L
s
.5432 .37416 m
.56054 .38041 L
s
.52559 .36866 m
.5432 .37416 L
s
.36308 .44494 m
.37935 .44299 L
s
.5078 .36394 m
.52559 .36866 L
s
.56054 .38041 m
.57757 .38741 L
s
.59005 .4002 m
.60658 .40747 L
s
.60274 .41284 m
.6191 .41961 L
s
.63325 .47615 m
.64905 .4778 L
s
.44864 .36709 m
.46662 .36863 L
s
.48987 .36002 m
.5078 .36394 L
s
.57757 .38741 m
.59421 .39512 L
s
.62527 .44478 m
.64126 .4492 L
s
.61555 .42527 m
.63168 .43147 L
s
.36534 .42985 m
.38175 .4277 L
s
.63573 .46587 m
.65145 .4685 L
s
.47188 .35692 m
.48987 .36002 L
s
.40864 .38069 m
.4262 .38018 L
s
.59421 .39512 m
.61039 .40352 L
s
.60658 .40747 m
.62265 .41539 L
s
.5483 .36725 m
.56535 .37455 L
s
.53094 .36074 m
.5483 .36725 L
s
.38766 .39701 m
.40477 .3955 L
s
.56535 .37455 m
.58203 .38262 L
s
.43078 .36634 m
.44864 .36709 L
s
.51333 .35506 m
.53094 .36074 L
s
.62841 .43741 m
.64425 .44296 L
s
.58203 .38262 m
.59828 .39143 L
s
.34355 .47526 m
.35911 .47386 L
s
.34173 .48811 m
.35721 .48735 L
s
.6191 .41961 m
.63497 .42697 L
s
.34537 .4616 m
.36104 .45967 L
s
.33985 .5 m
.35525 .5 L
s
.64475 .5 m
.66015 .5 L
s
.63841 .45686 m
.65402 .46055 L
s
.36792 .41454 m
.38448 .41232 L
s
.49555 .35024 m
.51333 .35506 L
s
.4539 .35467 m
.47188 .35692 L
s
.59828 .39143 m
.61402 .40097 L
s
.61039 .40352 m
.62606 .4126 L
s
.64682 .48834 m
.66216 .4892 L
s
.34729 .44728 m
.36308 .44494 L
s
.57014 .37005 m
.58637 .3792 L
s
.55348 .36169 m
.57014 .37005 L
s
.53646 .35415 m
.55348 .36169 L
s
.63168 .43147 m
.64728 .43819 L
s
.58637 .3792 m
.60212 .38911 L
s
.62265 .41539 m
.63817 .42394 L
s
.47766 .34629 m
.49555 .35024 L
s
.64126 .4492 m
.65673 .45403 L
s
.39137 .38195 m
.40864 .38069 L
s
.51914 .34748 m
.53646 .35415 L
s
.41311 .3664 m
.43078 .36634 L
s
.64905 .4778 m
.66431 .47963 L
s
.60212 .38911 m
.61731 .39974 L
s
.61402 .40097 m
.6292 .41118 L
s
.34941 .43248 m
.36534 .42985 L
s
.37092 .39919 m
.38766 .39701 L
s
.43599 .35328 m
.4539 .35467 L
s
.59042 .3771 m
.60556 .38807 L
s
.57474 .36688 m
.59042 .3771 L
s
.55859 .35747 m
.57474 .36688 L
s
.62606 .4126 m
.64114 .42232 L
s
.63497 .42697 m
.65026 .43491 L
s
.50159 .34169 m
.51914 .34748 L
s
.60556 .38807 m
.6201 .39977 L
s
.54202 .3489 m
.55859 .35747 L
s
.61731 .39974 m
.6319 .41106 L
s
.65145 .4685 m
.66661 .47139 L
s
.64425 .44296 m
.65951 .44898 L
s
.45973 .34324 m
.47766 .34629 L
s
.59401 .37624 m
.60843 .38822 L
s
.579 .365 m
.59401 .37624 L
s
.60843 .38822 m
.62222 .40092 L
s
.56346 .35456 m
.579 .365 L
s
.6201 .39977 m
.63399 .41214 L
s
.6292 .41118 m
.64374 .42205 L
s
.5251 .34121 m
.54202 .3489 L
s
.35182 .41734 m
.36792 .41454 L
s
.62222 .40092 m
.6353 .41426 L
s
.63817 .42394 m
.65307 .43308 L
s
.48388 .33683 m
.50159 .34169 L
s
.32856 .47685 m
.34355 .47526 L
s
.54746 .34497 m
.56346 .35456 L
s
.32683 .48896 m
.34173 .48811 L
s
.65402 .46055 m
.66905 .46458 L
s
.6319 .41106 m
.6458 .42304 L
s
.33028 .46381 m
.34537 .4616 L
s
.39569 .36729 m
.41311 .3664 L
s
.64728 .43819 m
.66228 .44544 L
s
.41823 .35279 m
.43599 .35328 L
s
.32503 .5 m
.33985 .5 L
s
.66015 .5 m
.67497 .5 L
s
.6353 .41426 m
.64763 .42822 L
s
.63399 .41214 m
.64715 .42515 L
s
.37445 .38396 m
.39137 .38195 L
s
.50789 .33444 m
.5251 .34121 L
s
.64114 .42232 m
.65556 .43266 L
s
.33207 .45001 m
.34729 .44728 L
s
.44182 .34114 m
.45973 .34324 L
s
.53105 .33627 m
.54746 .34497 L
s
.66216 .4892 m
.67689 .49016 L
s
.65673 .45403 m
.67159 .45925 L
s
.64374 .42205 m
.65757 .43355 L
s
.65026 .43491 m
.66491 .44339 L
s
.35464 .40204 m
.37092 .39919 L
s
.46608 .33293 m
.48388 .33683 L
s
.64763 .42822 m
.65915 .44273 L
s
.6458 .42304 m
.65895 .43563 L
s
.33403 .43559 m
.34941 .43248 L
s
.64715 .42515 m
.65952 .43875 L
s
.66431 .47963 m
.67894 .48164 L
s
.49046 .32863 m
.50789 .33444 L
s
.5143 .3285 m
.53105 .33627 L
s
.65307 .43308 m
.66729 .4428 L
s
.65951 .44898 m
.67413 .45545 L
s
.40069 .3532 m
.41823 .35279 L
s
.37861 .36903 m
.39569 .36729 L
s
.66661 .47139 m
.68113 .47454 L
s
.65915 .44273 m
.66979 .45775 L
s
.42402 .33999 m
.44182 .34114 L
s
.65556 .43266 m
.66925 .44358 L
s
.33628 .42072 m
.35182 .41734 L
s
.44825 .33002 m
.46608 .33293 L
s
.65952 .43875 m
.67105 .45289 L
s
.35798 .38674 m
.37445 .38396 L
s
.65757 .43355 m
.67063 .44563 L
s
.66228 .44544 m
.67659 .45318 L
s
.65895 .43563 m
.67129 .44878 L
s
.47288 .32381 m
.49046 .32863 L
s
.49727 .32171 m
.5143 .3285 L
s
.66905 .46458 m
.68342 .46893 L
s
.31423 .47863 m
.32856 .47685 L
s
.3126 .4899 m
.32683 .48896 L
s
.31584 .46632 m
.33028 .46381 L
s
.66491 .44339 m
.67884 .45242 L
s
.66979 .45775 m
.6795 .47321 L
s
.31089 .5 m
.32503 .5 L
s
.67497 .5 m
.68911 .5 L
s
.3175 .45312 m
.33207 .45001 L
s
.33891 .40557 m
.35464 .40204 L
s
.67159 .45925 m
.68574 .46487 L
s
.66729 .4428 m
.68073 .45308 L
s
.4064 .33983 m
.42402 .33999 L
s
.67689 .49016 m
.69093 .49121 L
s
.38345 .35455 m
.40069 .3532 L
s
.67105 .45289 m
.68166 .46752 L
s
.43048 .32814 m
.44825 .33002 L
s
.31931 .43919 m
.33403 .43559 L
s
.45523 .32005 m
.47288 .32381 L
s
.48003 .31596 m
.49727 .32171 L
s
.66925 .44358 m
.68212 .45507 L
s
.36194 .37162 m
.37861 .36903 L
s
.67129 .44878 m
.68273 .46247 L
s
.67063 .44563 m
.68284 .45826 L
s
.67413 .45545 m
.68802 .46237 L
s
.67894 .48164 m
.69287 .48382 L
s
.6795 .47321 m
.68821 .48907 L
s
.34204 .39031 m
.35798 .38674 L
s
.32137 .42469 m
.33628 .42072 L
s
.67659 .45318 m
.69013 .46142 L
s
.68113 .47454 m
.69492 .47794 L
s
.68166 .46752 m
.69129 .4826 L
s
.67884 .45242 m
.69194 .46195 L
s
.46265 .31129 m
.48003 .31596 L
s
.41284 .32731 m
.43048 .32814 L
s
.43757 .31736 m
.45523 .32005 L
s
.38905 .34068 m
.4064 .33983 L
s
.68342 .46893 m
.69702 .47361 L
s
.36661 .35685 m
.38345 .35455 L
s
.68273 .46247 m
.69322 .47663 L
s
.68073 .45308 m
.69332 .46388 L
s
.3238 .40979 m
.33891 .40557 L
s
.30065 .4806 m
.31423 .47863 L
s
.30214 .46912 m
.31584 .46632 L
s
.68284 .45826 m
.69411 .4714 L
s
.68212 .45507 m
.69409 .46708 L
s
.29913 .49094 m
.3126 .4899 L
s
.30367 .45663 m
.3175 .45312 L
s
.34579 .3751 m
.36194 .37162 L
s
.68821 .48907 m
.69586 .50525 L
s
.68574 .46487 m
.69911 .47088 L
s
.29752 .5 m
.31089 .5 L
s
.68911 .5 m
.70248 .5 L
s
.30533 .44329 m
.31931 .43919 L
s
.69093 .49121 m
.70419 .49234 L
s
.68802 .46237 m
.70107 .46972 L
s
.69129 .4826 m
.69987 .49805 L
s
.32672 .39466 m
.34204 .39031 L
s
.44521 .30774 m
.46265 .31129 L
s
.41999 .31579 m
.43757 .31736 L
s
.39542 .32758 m
.41284 .32731 L
s
.69287 .48382 m
.706 .48618 L
s
.30721 .42926 m
.32137 .42469 L
s
.69013 .46142 m
.7028 .47012 L
s
.37205 .34258 m
.38905 .34068 L
s
.69322 .47663 m
.70267 .49122 L
s
.35025 .36012 m
.36661 .35685 L
s
.69194 .46195 m
.70415 .47197 L
s
.69586 .50525 m
.7024 .5217 L
s
.69492 .47794 m
.70788 .48159 L
s
.69411 .4714 m
.70437 .485 L
s
.69332 .46388 m
.70496 .47518 L
s
.69409 .46708 m
.70509 .47958 L
s
.30943 .41472 m
.3238 .40979 L
s
.33024 .37947 m
.34579 .3751 L
s
.69702 .47361 m
.70977 .47861 L
s
.69987 .49805 m
.70732 .51382 L
s
.42779 .30537 m
.44521 .30774 L
s
.2893 .47221 m
.30214 .46912 L
s
.28793 .48277 m
.30065 .4806 L
s
.40258 .31539 m
.41999 .31579 L
s
.29069 .46053 m
.30367 .45663 L
s
.28652 .49208 m
.29913 .49094 L
s
.69911 .47088 m
.71158 .47725 L
s
.37832 .32897 m
.39542 .32758 L
s
.28503 .5 m
.29752 .5 L
s
.70248 .5 m
.71497 .5 L
s
.29218 .44788 m
.30533 .44329 L
s
.31212 .39982 m
.32672 .39466 L
s
.70267 .49122 m
.711 .50618 L
s
.3555 .34554 m
.37205 .34258 L
s
.70107 .46972 m
.71321 .47749 L
s
.7024 .5217 m
.70775 .53833 L
s
.70419 .49234 m
.71656 .49357 L
s
.70437 .485 m
.71353 .49901 L
s
.33446 .36439 m
.35025 .36012 L
s
.7028 .47012 m
.71451 .47926 L
s
.29388 .43443 m
.30721 .42926 L
s
.70415 .47197 m
.71535 .48246 L
s
.70509 .47958 m
.71501 .49252 L
s
.70496 .47518 m
.71557 .48693 L
s
.706 .48618 m
.71821 .48871 L
s
.41048 .30422 m
.42779 .30537 L
s
.70732 .51382 m
.71358 .52984 L
s
.31539 .38474 m
.33024 .37947 L
s
.70788 .48159 m
.7199 .48548 L
s
.38543 .31618 m
.40258 .31539 L
s
.29589 .42035 m
.30943 .41472 L
s
.36162 .33152 m
.37832 .32897 L
s
.70977 .47861 m
.72155 .48391 L
s
.711 .50618 m
.71814 .52145 L
s
.70775 .53833 m
.71185 .55508 L
s
.3395 .34959 m
.3555 .34554 L
s
.27741 .47558 m
.2893 .47221 L
s
.27617 .48512 m
.28793 .48277 L
s
.71158 .47725 m
.72306 .48398 L
s
.29833 .40579 m
.31212 .39982 L
s
.27866 .46482 m
.29069 .46053 L
s
.71353 .49901 m
.72151 .51337 L
s
.27488 .4933 m
.28652 .49208 L
s
.31936 .36966 m
.33446 .36439 L
s
.27999 .45297 m
.29218 .44788 L
s
.71321 .47749 m
.72431 .48565 L
s
.27352 .5 m
.28503 .5 L
s
.71497 .5 m
.72648 .5 L
s
.71501 .49252 m
.72377 .50584 L
s
.39336 .30434 m
.41048 .30422 L
s
.71451 .47926 m
.72515 .48882 L
s
.71358 .52984 m
.71857 .54604 L
s
.71557 .48693 m
.72504 .4991 L
s
.71535 .48246 m
.72545 .49336 L
s
.28149 .4402 m
.29388 .43443 L
s
.36863 .31821 m
.38543 .31618 L
s
.71656 .49357 m
.72792 .49488 L
s
.30135 .39093 m
.31539 .38474 L
s
.34543 .33524 m
.36162 .33152 L
s
.71821 .48871 m
.72941 .4914 L
s
.71185 .55508 m
.71464 .57184 L
s
.28329 .42668 m
.29589 .42035 L
s
.71814 .52145 m
.72401 .53695 L
s
.32416 .35475 m
.3395 .34959 L
s
.7199 .48548 m
.73088 .48961 L
s
.72151 .51337 m
.72822 .52802 L
s
.72155 .48391 m
.73226 .48951 L
s
.28549 .41257 m
.29833 .40579 L
s
.30505 .37595 m
.31936 .36966 L
s
.37655 .30577 m
.39336 .30434 L
s
.71857 .54604 m
.72221 .56233 L
s
.72306 .48398 m
.73343 .49106 L
s
.72377 .50584 m
.73127 .5195 L
s
.2666 .47925 m
.27741 .47558 L
s
.2677 .4695 m
.27866 .46482 L
s
.3523 .32152 m
.36863 .31821 L
s
.26549 .48766 m
.27617 .48512 L
s
.72431 .48565 m
.73427 .49418 L
s
.26886 .45855 m
.27999 .45297 L
s
.72504 .4991 m
.73327 .51163 L
s
.26433 .49462 m
.27488 .4933 L
s
.72515 .48882 m
.73462 .49877 L
s
.72545 .49336 m
.73434 .50465 L
s
.32986 .34018 m
.34543 .33524 L
s
.71464 .57184 m
.71606 .58854 L
s
.26311 .5 m
.27352 .5 L
s
.72648 .5 m
.73689 .5 L
s
.27017 .44658 m
.28149 .4402 L
s
.28823 .39804 m
.30135 .39093 L
s
.72401 .53695 m
.72852 .55261 L
s
.72792 .49488 m
.73817 .49627 L
s
.30958 .36103 m
.32416 .35475 L
s
.27174 .43372 m
.28329 .42668 L
s
.72941 .4914 m
.73946 .49425 L
s
.72822 .52802 m
.73357 .54289 L
s
.36015 .30856 m
.37655 .30577 L
s
.72221 .56233 m
.72445 .57862 L
s
.29165 .38328 m
.30505 .37595 L
s
.73088 .48961 m
.74069 .49396 L
s
.27369 .42016 m
.28549 .41257 L
s
.33655 .32612 m
.3523 .32152 L
s
.73127 .5195 m
.73742 .53343 L
s
.73226 .48951 m
.74177 .49538 L
s
.31502 .34634 m
.32986 .34018 L
s
.71606 .58854 m
.71603 .60508 L
s
.73327 .51163 m
.74017 .52447 L
s
.73343 .49106 m
.74258 .49845 L
s
.25792 .47456 m
.2677 .4695 L
s
.25698 .48319 m
.2666 .47925 L
s
.73427 .49418 m
.74297 .50305 L
s
.73434 .50465 m
.74191 .51627 L
s
.72852 .55261 m
.73159 .56834 L
s
.73462 .49877 m
.7428 .50906 L
s
.25891 .46462 m
.26886 .45855 L
s
.25601 .49039 m
.26549 .48766 L
s
.27616 .40607 m
.28823 .39804 L
s
.255 .49602 m
.26433 .49462 L
s
.29588 .36845 m
.30958 .36103 L
s
.26003 .45354 m
.27017 .44658 L
s
.25393 .5 m
.26311 .5 L
s
.73689 .5 m
.74607 .5 L
s
.34426 .31273 m
.36015 .30856 L
s
.73357 .54289 m
.73746 .5579 L
s
.26138 .44146 m
.27174 .43372 L
s
.72445 .57862 m
.7252 .59482 L
s
.73817 .49627 m
.74717 .49775 L
s
.32148 .33205 m
.33655 .32612 L
s
.27928 .39163 m
.29165 .38328 L
s
.73946 .49425 m
.74824 .49726 L
s
.73742 .53343 m
.74212 .54756 L
s
.26307 .42857 m
.27369 .42016 L
s
.71603 .60508 m
.71451 .62134 L
s
.30104 .35374 m
.31502 .34634 L
s
.74069 .49396 m
.74921 .49853 L
s
.74017 .52447 m
.74561 .53756 L
s
.73159 .56834 m
.73314 .58405 L
s
.74177 .49538 m
.74996 .50151 L
s
.74191 .51627 m
.74806 .52817 L
s
.74258 .49845 m
.75037 .50612 L
s
.26525 .41502 m
.27616 .40607 L
s
.28319 .37701 m
.29588 .36845 L
s
.7428 .50906 m
.74957 .51965 L
s
.74297 .50305 m
.75029 .51223 L
s
.24947 .48 m
.25792 .47456 L
s
.32902 .31833 m
.34426 .31273 L
s
.24868 .48741 m
.25698 .48319 L
s
.25028 .47117 m
.25891 .46462 L
s
.24787 .49329 m
.25601 .49039 L
s
.7252 .59482 m
.7244 .61082 L
s
.73746 .5579 m
.73982 .57297 L
s
.2512 .46108 m
.26003 .45354 L
s
.24701 .49751 m
.255 .49602 L
s
.30723 .33933 m
.32148 .33205 L
s
.25232 .44989 m
.26138 .44146 L
s
.26806 .40101 m
.27928 .39163 L
s
.24611 .5 m
.25393 .5 L
s
.74607 .5 m
.75389 .5 L
s
.71451 .62134 m
.71144 .63722 L
s
.74212 .54756 m
.74526 .56181 L
s
.28803 .3624 m
.30104 .35374 L
s
.74717 .49775 m
.75479 .4993 L
s
.25376 .43777 m
.26307 .42857 L
s
.73314 .58405 m
.73309 .59965 L
s
.74824 .49726 m
.75562 .5004 L
s
.74561 .53756 m
.74951 .55082 L
s
.74921 .49853 m
.7563 .50329 L
s
.27164 .38671 m
.28319 .37701 L
s
.31454 .32538 m
.32902 .31833 L
s
.74806 .52817 m
.75266 .54029 L
s
.25564 .42488 m
.26525 .41502 L
s
.74996 .50151 m
.7567 .50788 L
s
.7244 .61082 m
.72199 .62652 L
s
.74957 .51965 m
.75481 .53048 L
s
.75037 .50612 m
.75668 .51406 L
s
.75029 .51223 m
.7561 .52166 L
s
.73982 .57297 m
.74054 .58799 L
s
.29392 .34796 m
.30723 .33933 L
s
.24246 .48579 m
.24947 .48 L
s
.2431 .47818 m
.25028 .47117 L
s
.24184 .49189 m
.24868 .48741 L
s
.24381 .46919 m
.2512 .46108 L
s
.71144 .63722 m
.70678 .65258 L
s
.25813 .41141 m
.26806 .40101 L
s
.24119 .49636 m
.24787 .49329 L
s
.2447 .45899 m
.25232 .44989 L
s
.27614 .3723 m
.28803 .3624 L
s
.74526 .56181 m
.74675 .57608 L
s
.2405 .49908 m
.24701 .49751 L
s
.73309 .59965 m
.73137 .61501 L
s
.23979 .5 m
.24611 .5 L
s
.75389 .5 m
.76021 .5 L
s
.24587 .44774 m
.25376 .43777 L
s
.74951 .55082 m
.75174 .56418 L
s
.30096 .33389 m
.31454 .32538 L
s
.75479 .4993 m
.76089 .50092 L
s
.26137 .39753 m
.27164 .38671 L
s
.72199 .62652 m
.7179 .64178 L
s
.75562 .5004 m
.76146 .50368 L
s
.24746 .43562 m
.25564 .42488 L
s
.75266 .54029 m
.75559 .55256 L
s
.28169 .35796 m
.29392 .34796 L
s
.74054 .58799 m
.73955 .60286 L
s
.7563 .50329 m
.76182 .50822 L
s
.75481 .53048 m
.7584 .54151 L
s
.7567 .50788 m
.76184 .51445 L
s
.70678 .65258 m
.70048 .66731 L
s
.7561 .52166 m
.76028 .5313 L
s
.75668 .51406 m
.76138 .5222 L
s
.24962 .4228 m
.25813 .41141 L
s
.2655 .38344 m
.27614 .3723 L
s
.2375 .48563 m
.2431 .47818 L
s
.23705 .49193 m
.24246 .48579 L
s
.23801 .47784 m
.24381 .46919 L
s
.74675 .57608 m
.74649 .59028 L
s
.2366 .49662 m
.24184 .49189 L
s
.73137 .61501 m
.72792 .63002 L
s
.23866 .46874 m
.2447 .45899 L
s
.23613 .49958 m
.24119 .49636 L
s
.28841 .34387 m
.30096 .33389 L
s
.23956 .45847 m
.24587 .44774 L
s
.23562 .50073 m
.2405 .49908 L
s
.25249 .40946 m
.26137 .39753 L
s
.75174 .56418 m
.75221 .57754 L
s
.7179 .64178 m
.71209 .65647 L
s
.23511 .5 m
.23979 .5 L
s
.76021 .5 m
.76489 .5 L
s
.27068 .36931 m
.28169 .35796 L
s
.24085 .44721 m
.24746 .43562 L
s
.73955 .60286 m
.73677 .61747 L
s
.76089 .50092 m
.76533 .50261 L
s
.75559 .55256 m
.75676 .56489 L
s
.70048 .66731 m
.69251 .68126 L
s
.76146 .50368 m
.76562 .50707 L
s
.7584 .54151 m
.76022 .55264 L
s
.25625 .3958 m
.2655 .38344 L
s
.76182 .50822 m
.76564 .51331 L
s
.24266 .43515 m
.24962 .4228 L
s
.76028 .5313 m
.7627 .54109 L
s
.76184 .51445 m
.76526 .52118 L
s
.76138 .5222 m
.76433 .53052 L
s
.72792 .63002 m
.72268 .64456 L
s
.74649 .59028 m
.74441 .60431 L
s
.23362 .49349 m
.2375 .48563 L
s
.23391 .487 m
.23801 .47784 L
s
.27705 .35532 m
.28841 .34387 L
s
.23337 .49839 m
.23705 .49193 L
s
.23433 .47909 m
.23866 .46874 L
s
.23311 .50158 m
.2366 .49662 L
s
.24517 .42246 m
.25249 .40946 L
s
.71209 .65647 m
.70453 .67047 L
s
.23496 .4699 m
.23956 .45847 L
s
.75221 .57754 m
.75082 .59079 L
s
.23281 .50295 m
.23613 .49958 L
s
.26103 .38198 m
.27068 .36931 L
s
.73677 .61747 m
.73213 .63168 L
s
.23251 .50244 m
.23562 .50073 L
s
.69251 .68126 m
.68286 .69429 L
s
.23593 .45962 m
.24085 .44721 L
s
.75676 .56489 m
.75605 .5772 L
s
.23222 .5 m
.23511 .5 L
s
.76489 .5 m
.76778 .5 L
s
.24852 .40933 m
.25625 .3958 L
s
.76533 .50261 m
.76796 .50435 L
s
.2374 .44842 m
.24266 .43515 L
s
.72268 .64456 m
.71559 .65848 L
s
.76022 .55264 m
.76015 .56382 L
s
.76562 .50707 m
.76795 .51056 L
s
.74441 .60431 m
.74041 .61804 L
s
.267 .3682 m
.27705 .35532 L
s
.7627 .54109 m
.76323 .55096 L
s
.76564 .51331 m
.76761 .51851 L
s
.76433 .53052 m
.7654 .53894 L
s
.76526 .52118 m
.76681 .52804 L
s
.70453 .67047 m
.69519 .68363 L
s
.23952 .43648 m
.24517 .42246 L
s
.23168 .49663 m
.23391 .487 L
s
.23161 .50172 m
.23362 .49349 L
s
.23184 .49 m
.23433 .47909 L
s
.25288 .39595 m
.26103 .38198 L
s
.23156 .50513 m
.23337 .49839 L
s
.75082 .59079 m
.74747 .60384 L
s
.23219 .48199 m
.23496 .4699 L
s
.68286 .69429 m
.67153 .70626 L
s
.73213 .63168 m
.72558 .64538 L
s
.23149 .50674 m
.23311 .50158 L
s
.23285 .47278 m
.23593 .45962 L
s
.2314 .50645 m
.23281 .50295 L
s
.24245 .424 m
.24852 .40933 L
s
.75605 .5772 m
.75335 .58938 L
s
.2313 .50421 m
.23251 .50244 L
s
.71559 .65848 m
.70663 .67164 L
s
.23396 .46254 m
.2374 .44842 L
s
.25843 .3825 m
.267 .3682 L
s
.23126 .5 m
.23222 .5 L
s
.76778 .5 m
.76874 .5 L
s
.74041 .61804 m
.73443 .63134 L
s
.76015 .56382 m
.75808 .57494 L
s
.69519 .68363 m
.68405 .69579 L
s
.76796 .50435 m
.76865 .50614 L
s
.76323 .55096 m
.76175 .56084 L
s
.23568 .45146 m
.23952 .43648 L
s
.24637 .41116 m
.25288 .39595 L
s
.76795 .51056 m
.76832 .51412 L
s
.7654 .53894 m
.76447 .54742 L
s
.76761 .51851 m
.7676 .52379 L
s
.67153 .70626 m
.65853 .71701 L
s
.76681 .52804 m
.76637 .53498 L
s
.23142 .50667 m
.23168 .49663 L
s
.23133 .50141 m
.23184 .49 L
s
.72558 .64538 m
.71707 .65841 L
s
.74747 .60384 m
.7421 .61656 L
s
.23158 .51028 m
.23161 .50172 L
s
.23139 .49467 m
.23219 .48199 L
s
.23175 .51212 m
.23156 .50513 L
s
.23818 .43973 m
.24245 .424 L
s
.23172 .48662 m
.23285 .47278 L
s
.2319 .51207 m
.23149 .50674 L
s
.70663 .67164 m
.69577 .6839 L
s
.25146 .39814 m
.25843 .3825 L
s
.75335 .58938 m
.74858 .60132 L
s
.23247 .47744 m
.23396 .46254 L
s
.23202 .51005 m
.2314 .50645 L
s
.73443 .63134 m
.72642 .64407 L
s
.68405 .69579 m
.67114 .70681 L
s
.23215 .50602 m
.2313 .50421 L
s
.24164 .42753 m
.24637 .41116 L
s
.75808 .57494 m
.75391 .5859 L
s
.23378 .46731 m
.23568 .45146 L
s
.65853 .71701 m
.64389 .72639 L
s
.23237 .5 m
.23126 .5 L
s
.76874 .5 m
.76763 .5 L
s
.76175 .56084 m
.75815 .57064 L
s
.71707 .65841 m
.70657 .67063 L
s
.76865 .50614 m
.76725 .50795 L
s
.7421 .61656 m
.73462 .62882 L
s
.76832 .51412 m
.76658 .51772 L
s
.76447 .54742 m
.76141 .55588 L
s
.23291 .51326 m
.23133 .50141 L
s
.23583 .45643 m
.23818 .43973 L
s
.23267 .50787 m
.23139 .49467 L
s
.23328 .51706 m
.23142 .50667 L
s
.7676 .52379 m
.76548 .52912 L
s
.76637 .53498 m
.76381 .54193 L
s
.23368 .51912 m
.23158 .51028 L
s
.23267 .50107 m
.23172 .48662 L
s
.24623 .41506 m
.25146 .39814 L
s
.69577 .6839 m
.68304 .6951 L
s
.23408 .51931 m
.23175 .51212 L
s
.23304 .49303 m
.23247 .47744 L
s
.67114 .70681 m
.65648 .71654 L
s
.74858 .60132 m
.74167 .6129 L
s
.23445 .51753 m
.2319 .51207 L
s
.72642 .64407 m
.71634 .6561 L
s
.2388 .44498 m
.24164 .42753 L
s
.64389 .72639 m
.62768 .73427 L
s
.23393 .48394 m
.23378 .46731 L
s
.23481 .51372 m
.23202 .51005 L
s
.75391 .5859 m
.74756 .59661 L
s
.70657 .67063 m
.69409 .68189 L
s
.23519 .50787 m
.23215 .50602 L
s
.23551 .474 m
.23583 .45643 L
s
.73462 .62882 m
.72501 .64048 L
s
.75815 .57064 m
.75235 .58027 L
s
.23567 .5 m
.23237 .5 L
s
.76763 .5 m
.76433 .5 L
s
.24287 .43316 m
.24623 .41506 L
s
.68304 .6951 m
.66844 .70509 L
s
.23615 .5215 m
.23267 .50787 L
s
.2367 .52546 m
.23291 .51326 L
s
.76725 .50795 m
.76364 .50979 L
s
.2358 .51602 m
.23267 .50107 L
s
.76141 .55588 m
.75613 .56423 L
s
.23735 .52773 m
.23328 .51706 L
s
.76658 .51772 m
.76262 .52134 L
s
.65648 .71654 m
.64013 .72482 L
s
.76381 .54193 m
.75901 .54885 L
s
.76548 .52912 m
.76112 .53445 L
s
.23577 .5092 m
.23304 .49303 L
s
.23802 .52817 m
.23368 .51912 L
s
.23797 .46339 m
.2388 .44498 L
s
.62768 .73427 m
.60997 .74049 L
s
.71634 .6561 m
.70419 .66728 L
s
.74167 .6129 m
.73255 .624 L
s
.23866 .52665 m
.23408 .51931 L
s
.23622 .50123 m
.23393 .48394 L
s
.23927 .52309 m
.23445 .51753 L
s
.69409 .68189 m
.67965 .69204 L
s
.23732 .4923 m
.23551 .474 L
s
.74756 .59661 m
.73895 .60693 L
s
.2415 .4523 m
.24287 .43316 L
s
.23987 .51745 m
.23481 .51372 L
s
.66844 .70509 m
.65205 .71371 L
s
.72501 .64048 m
.71324 .6514 L
s
.24052 .50973 m
.23519 .50787 L
s
.64013 .72482 m
.62217 .73151 L
s
.75235 .58027 m
.74425 .58962 L
s
.2419 .53543 m
.23615 .5215 L
s
.24118 .53134 m
.2358 .51602 L
s
.23925 .48262 m
.23797 .46339 L
s
.24278 .5379 m
.2367 .52546 L
s
.60997 .74049 m
.59087 .74493 L
s
.24075 .52581 m
.23577 .5092 L
s
.24129 .5 m
.23567 .5 L
s
.76433 .5 m
.75871 .5 L
s
.24373 .53859 m
.23735 .52773 L
s
.75613 .56423 m
.74853 .5724 L
s
.70419 .66728 m
.68997 .67745 L
s
.76364 .50979 m
.7577 .51162 L
s
.24074 .51903 m
.23622 .50123 L
s
.75901 .54885 m
.75188 .55564 L
s
.73255 .624 m
.7212 .63447 L
s
.24468 .53735 m
.23802 .52817 L
s
.76262 .52134 m
.75632 .52494 L
s
.76112 .53445 m
.75443 .53971 L
s
.67965 .69204 m
.6633 .70092 L
s
.24221 .47236 m
.2415 .4523 L
s
.24134 .5112 m
.23732 .4923 L
s
.24559 .53407 m
.23866 .52665 L
s
.65205 .71371 m
.63394 .72083 L
s
.73895 .60693 m
.72805 .61676 L
s
.62217 .73151 m
.60272 .73648 L
s
.24646 .5287 m
.23927 .52309 L
s
.71324 .6514 m
.69932 .66143 L
s
.24271 .50251 m
.23925 .48262 L
s
.59087 .74493 m
.57052 .74747 L
s
.24733 .52119 m
.23987 .51745 L
s
.24889 .54691 m
.24118 .53134 L
s
.24802 .54273 m
.24075 .52581 L
s
.25 .54956 m
.2419 .53543 L
s
.74425 .58962 m
.73382 .59857 L
s
.25123 .55048 m
.24278 .5379 L
s
.68997 .67745 m
.67375 .68646 L
s
.24754 .5372 m
.24074 .51903 L
s
.24825 .51159 m
.24052 .50973 L
s
.24507 .49316 m
.24221 .47236 L
s
.25249 .54953 m
.24373 .53859 L
s
.6633 .70092 m
.64512 .70838 L
s
.24761 .53052 m
.24134 .5112 L
s
.7212 .63447 m
.70762 .64418 L
s
.74853 .5724 m
.73855 .58028 L
s
.24932 .5 m
.24129 .5 L
s
.75871 .5 m
.75068 .5 L
s
.63394 .72083 m
.61422 .7263 L
s
.25374 .54657 m
.24468 .53735 L
s
.7577 .51162 m
.74934 .51343 L
s
.75188 .55564 m
.74235 .56225 L
s
.60272 .73648 m
.58191 .73961 L
s
.75632 .52494 m
.7476 .52848 L
s
.75443 .53971 m
.74532 .54486 L
s
.57052 .74747 m
.54909 .74801 L
s
.24841 .52289 m
.24271 .50251 L
s
.25493 .54151 m
.24559 .53407 L
s
.69932 .66143 m
.68328 .67043 L
s
.72805 .61676 m
.71485 .62595 L
s
.25763 .55979 m
.24802 .54273 L
s
.25895 .56258 m
.24889 .54691 L
s
.25665 .55556 m
.24754 .5372 L
s
.25608 .53429 m
.24646 .5287 L
s
.25014 .51451 m
.24507 .49316 L
s
.26046 .56374 m
.25 .54956 L
s
.67375 .68646 m
.65558 .69417 L
s
.25617 .55008 m
.24761 .53052 L
s
.64512 .70838 m
.62522 .71429 L
s
.26207 .56308 m
.25123 .55048 L
s
.73382 .59857 m
.72102 .60703 L
s
.25723 .52491 m
.24733 .52119 L
s
.61422 .7263 m
.59304 .73 L
s
.58191 .73961 m
.55991 .7408 L
s
.54909 .74801 m
.52675 .74647 L
s
.70762 .64418 m
.69184 .65299 L
s
.25636 .54356 m
.24841 .52289 L
s
.26368 .56046 m
.25249 .54953 L
s
.25845 .51344 m
.24825 .51159 L
s
.73855 .58028 m
.72617 .58778 L
s
.25983 .5 m
.24932 .5 L
s
.75068 .5 m
.74017 .5 L
s
.26524 .55575 m
.25374 .54657 L
s
.25743 .5362 m
.25014 .51451 L
s
.68328 .67043 m
.66521 .67825 L
s
.74235 .56225 m
.73038 .56858 L
s
.74934 .51343 m
.7385 .51521 L
s
.26957 .57681 m
.25763 .55979 L
s
.26806 .57391 m
.25665 .55556 L
s
.74532 .54486 m
.73375 .54983 L
s
.7476 .52848 m
.73641 .53192 L
s
.71485 .62595 m
.69937 .63437 L
s
.27136 .57818 m
.25895 .56258 L
s
.267 .56967 m
.25617 .55008 L
s
.65558 .69417 m
.63559 .70043 L
s
.26674 .54888 m
.25493 .54151 L
s
.62522 .71429 m
.60376 .71852 L
s
.55991 .7408 m
.53693 .73996 L
s
.59304 .73 m
.57058 .73183 L
s
.52675 .74647 m
.50372 .7428 L
s
.27331 .57781 m
.26046 .56374 L
s
.26656 .5643 m
.25636 .54356 L
s
.26819 .5398 m
.25608 .53429 L
s
.27531 .57555 m
.26207 .56308 L
s
.72102 .60703 m
.70588 .61485 L
s
.69184 .65299 m
.67393 .66076 L
s
.26694 .558 m
.25743 .5362 L
s
.26963 .52856 m
.25723 .52491 L
s
.27729 .57124 m
.26368 .56046 L
s
.28173 .59205 m
.26806 .57391 L
s
.28006 .58907 m
.267 .56967 L
s
.66521 .67825 m
.64521 .68475 L
s
.28379 .5936 m
.26957 .57681 L
s
.50372 .7428 m
.48024 .73698 L
s
.53693 .73996 m
.51319 .73705 L
s
.72617 .58778 m
.71138 .59478 L
s
.57058 .73183 m
.54705 .7317 L
s
.27896 .58488 m
.26656 .5643 L
s
.63559 .70043 m
.61394 .70512 L
s
.27115 .51524 m
.25845 .51344 L
s
.60376 .71852 m
.58092 .72097 L
s
.28609 .59352 m
.27136 .57818 L
s
.27919 .56477 m
.26524 .55575 L
s
.69937 .63437 m
.68168 .64189 L
s
.73038 .56858 m
.71596 .57455 L
s
.27285 .5 m
.25983 .5 L
s
.74017 .5 m
.72715 .5 L
s
.27862 .57967 m
.26694 .558 L
s
.2885 .59162 m
.27331 .57781 L
s
.73375 .54983 m
.71969 .55456 L
s
.7385 .51521 m
.72515 .51692 L
s
.73641 .53192 m
.72271 .53522 L
s
.28102 .55609 m
.26674 .54888 L
s
.48024 .73698 m
.45657 .72902 L
s
.51319 .73705 m
.48894 .73204 L
s
.29527 .60807 m
.28006 .58907 L
s
.29092 .58774 m
.27531 .57555 L
s
.29757 .60977 m
.28173 .59205 L
s
.67393 .66076 m
.65399 .66734 L
s
.29348 .60506 m
.27896 .58488 L
s
.54705 .7317 m
.52267 .72957 L
s
.70588 .61485 m
.68844 .62192 L
s
.30021 .60996 m
.28379 .5936 L
s
.58092 .72097 m
.55692 .72154 L
s
.29238 .60095 m
.27862 .57967 L
s
.28278 .54517 m
.26819 .5398 L
s
.64521 .68475 m
.62344 .6898 L
s
.61394 .70512 m
.5908 .70813 L
s
.29329 .58174 m
.27729 .57124 L
s
.30305 .60843 m
.28609 .59352 L
s
.45657 .72902 m
.43297 .71897 L
s
.48894 .73204 m
.46445 .72493 L
s
.28453 .53209 m
.26963 .52856 L
s
.30999 .6246 m
.29348 .60506 L
s
.71138 .59478 m
.69424 .60119 L
s
.31251 .62642 m
.29527 .60807 L
s
.30811 .6216 m
.29238 .60095 L
s
.52267 .72957 m
.49773 .72539 L
s
.68168 .64189 m
.66186 .64839 L
s
.30594 .605 m
.2885 .59162 L
s
.31548 .62685 m
.29757 .60977 L
s
.29556 .57352 m
.27919 .56477 L
s
.28636 .51697 m
.27115 .51524 L
s
.43297 .71897 m
.40971 .70691 L
s
.55692 .72154 m
.532 .72018 L
s
.71596 .57455 m
.69913 .58007 L
s
.31873 .62568 m
.30021 .60996 L
s
.46445 .72493 m
.44 .71578 L
s
.65399 .66734 m
.63218 .67262 L
s
.32834 .64326 m
.30999 .6246 L
s
.32564 .64136 m
.30811 .6216 L
s
.28837 .5 m
.27285 .5 L
s
.72715 .5 m
.71163 .5 L
s
.5908 .70813 m
.56641 .70937 L
s
.30882 .5995 m
.29092 .58774 L
s
.62344 .6898 m
.6001 .69329 L
s
.71969 .55456 m
.70319 .55897 L
s
.33161 .6439 m
.31251 .62642 L
s
.29772 .56304 m
.28102 .55609 L
s
.72515 .51692 m
.70931 .51854 L
s
.40971 .70691 m
.38709 .69295 L
s
.72271 .53522 m
.70654 .53833 L
s
.49773 .72539 m
.47249 .71919 L
s
.32212 .62271 m
.30305 .60843 L
s
.3448 .65998 m
.32564 .64136 L
s
.68844 .62192 m
.66881 .62813 L
s
.44 .71578 m
.41587 .70467 L
s
.33527 .64308 m
.31548 .62685 L
s
.34834 .66081 m
.32834 .64326 L
s
.38709 .69295 m
.36536 .67725 L
s
.36536 .67725 m
.3448 .65998 L
s
.532 .72018 m
.50644 .71687 L
s
.3116 .59182 m
.29329 .58174 L
s
.29981 .55033 m
.28278 .54517 L
s
.35239 .66029 m
.33161 .6439 L
s
.41587 .70467 m
.39237 .6917 L
s
.36977 .67702 m
.34834 .66081 L
s
.47249 .71919 m
.44726 .71099 L
s
.32553 .61776 m
.30594 .605 L
s
.33916 .64056 m
.31873 .62568 L
s
.39237 .6917 m
.36977 .67702 L
s
.56641 .70937 m
.54102 .70877 L
s
.66186 .64839 m
.64009 .65373 L
s
.69424 .60119 m
.67483 .60689 L
s
.35677 .65823 m
.33527 .64308 L
s
.37461 .67537 m
.35239 .66029 L
s
.30188 .53546 m
.28453 .53209 L
s
.6001 .69329 m
.5754 .69513 L
s
.44726 .71099 m
.42233 .70088 L
s
.63218 .67262 m
.6087 .67648 L
s
.31425 .58188 m
.29556 .57352 L
s
.50644 .71687 m
.48053 .71159 L
s
.34314 .63617 m
.32212 .62271 L
s
.39802 .68896 m
.37461 .67537 L
s
.32888 .61067 m
.30882 .5995 L
s
.42233 .70088 m
.39802 .68896 L
s
.69913 .58007 m
.67997 .58504 L
s
.30403 .51861 m
.28636 .51697 L
s
.36131 .6544 m
.33916 .64056 L
s
.37972 .6721 m
.35677 .65823 L
s
.54102 .70877 m
.51492 .70631 L
s
.48053 .71159 m
.45459 .70439 L
s
.66881 .62813 m
.64712 .63336 L
s
.31678 .56966 m
.29772 .56304 L
s
.30635 .5 m
.28837 .5 L
s
.71163 .5 m
.69365 .5 L
s
.70319 .55897 m
.68431 .563 L
s
.34709 .62973 m
.32553 .61776 L
s
.70931 .51854 m
.69102 .52006 L
s
.70654 .53833 m
.68796 .54119 L
s
.40388 .68453 m
.37972 .6721 L
s
.33209 .60135 m
.3116 .59182 L
s
.45459 .70439 m
.42893 .69533 L
s
.5754 .69513 m
.54962 .69525 L
s
.42893 .69533 m
.40388 .68453 L
s
.64009 .65373 m
.61654 .65782 L
s
.3659 .64862 m
.34314 .63617 L
s
.38495 .667 m
.36131 .6544 L
s
.6087 .67648 m
.58377 .67883 L
s
.51492 .70631 m
.48842 .70197 L
s
.31921 .5552 m
.29981 .55033 L
s
.67483 .60689 m
.65329 .61179 L
s
.35093 .6211 m
.32888 .61067 L
s
.33515 .58973 m
.31425 .58188 L
s
.40978 .6782 m
.38495 .667 L
s
.48842 .70197 m
.46185 .6958 L
s
.54962 .69525 m
.52306 .69362 L
s
.3216 .53862 m
.30188 .53546 L
s
.3704 .64073 m
.34709 .62973 L
s
.39015 .65989 m
.3659 .64862 L
s
.43552 .68784 m
.40978 .6782 L
s
.46185 .6958 m
.43552 .68784 L
s
.67997 .58504 m
.65862 .58939 L
s
.64712 .63336 m
.62358 .6375 L
s
.58377 .67883 m
.55768 .6796 L
s
.32405 .52013 m
.30403 .51861 L
s
.61654 .65782 m
.59146 .66055 L
s
.35459 .61018 m
.33209 .60135 L
s
.33804 .57582 m
.31678 .56966 L
s
.52306 .69362 m
.49604 .69022 L
s
.68431 .563 m
.66318 .56657 L
s
.41561 .66981 m
.39015 .65989 L
s
.69365 .5 m
.67333 .5 L
s
.32667 .5 m
.30635 .5 L
s
.68796 .54119 m
.66708 .54377 L
s
.69102 .52006 m
.67042 .52143 L
s
.37475 .63061 m
.35093 .6211 L
s
.39522 .65061 m
.3704 .64073 L
s
.49604 .69022 m
.46889 .68508 L
s
.65329 .61179 m
.62981 .61579 L
s
.44197 .67825 m
.41561 .66981 L
s
.34082 .5597 m
.31921 .5552 L
s
.55768 .6796 m
.53074 .67875 L
s
.35806 .59695 m
.33515 .58973 L
s
.46889 .68508 m
.44197 .67825 L
s
.62358 .6375 m
.59842 .64046 L
s
.59146 .66055 m
.56514 .66187 L
s
.42125 .65922 m
.39522 .65061 L
s
.34354 .54152 m
.3216 .53862 L
s
.37888 .61818 m
.35459 .61018 L
s
.65862 .58939 m
.63526 .59303 L
s
.53074 .67875 m
.50326 .67625 L
s
.40008 .63907 m
.37475 .63061 L
s
.36134 .58144 m
.33804 .57582 L
s
.44816 .66643 m
.42125 .65922 L
s
.34629 .52151 m
.32405 .52013 L
s
.50326 .67625 m
.47562 .67213 L
s
.66318 .56657 m
.63999 .56962 L
s
.56514 .66187 m
.53788 .66171 L
s
.47562 .67213 m
.44816 .66643 L
s
.62981 .61579 m
.60464 .6188 L
s
.67333 .5 m
.65081 .5 L
s
.34919 .5 m
.32667 .5 L
s
.66708 .54377 m
.64408 .54601 L
s
.38276 .60342 m
.35806 .59695 L
s
.67042 .52143 m
.64765 .52265 L
s
.59842 .64046 m
.57193 .64218 L
s
.42662 .64635 m
.40008 .63907 L
s
.36446 .56376 m
.34082 .5597 L
s
.40467 .62521 m
.37888 .61818 L
s
.53788 .66171 m
.51003 .66005 L
s
.63526 .59303 m
.61013 .59588 L
s
.45403 .65232 m
.42662 .64635 L
s
.36749 .5441 m
.34354 .54152 L
s
.38642 .58642 m
.36134 .58144 L
s
.51003 .66005 m
.48196 .65691 L
s
.57193 .64218 m
.54444 .6426 L
s
.48196 .65691 m
.45403 .65232 L
s
.60464 .6188 m
.57805 .62075 L
s
.43166 .63116 m
.40467 .62521 L
s
.63999 .56962 m
.61495 .57209 L
s
.40897 .60904 m
.38276 .60342 L
s
.37053 .52273 m
.34629 .52151 L
s
.64408 .54601 m
.61919 .54787 L
s
.65081 .5 m
.62632 .5 L
s
.37368 .5 m
.34919 .5 L
s
.38988 .56731 m
.36446 .56376 L
s
.64765 .52265 m
.62294 .52368 L
s
.54444 .6426 m
.51628 .6417 L
s
.45951 .63594 m
.43166 .63116 L
s
.61013 .59588 m
.58352 .59788 L
s
.57805 .62075 m
.55039 .62161 L
s
.41299 .59068 m
.38642 .58642 L
s
.51628 .6417 m
.48785 .63947 L
s
.43637 .61371 m
.40897 .60904 L
s
.48785 .63947 m
.45951 .63594 L
s
.39321 .54632 m
.36749 .5441 L
s
.61495 .57209 m
.58837 .57393 L
s
.55039 .62161 m
.522 .62133 L
s
.3965 .52376 m
.37053 .52273 L
s
.46459 .61735 m
.43637 .61371 L
s
.41677 .57029 m
.38988 .56731 L
s
.58352 .59788 m
.55575 .59899 L
s
.61919 .54787 m
.59268 .54932 L
s
.62632 .5 m
.60013 .5 L
s
.39987 .5 m
.37368 .5 L
s
.44074 .59413 m
.41299 .59068 L
s
.62294 .52368 m
.59657 .52451 L
s
.522 .62133 m
.49327 .6199 L
s
.49327 .6199 m
.46459 .61735 L
s
.42038 .54814 m
.39321 .54632 L
s
.58837 .57393 m
.56056 .57509 L
s
.55575 .59899 m
.52719 .59917 L
s
.46928 .59673 m
.44074 .59413 L
s
.44481 .57264 m
.41677 .57029 L
s
.4239 .52457 m
.3965 .52376 L
s
.59268 .54932 m
.5649 .55031 L
s
.52719 .59917 m
.49823 .59841 L
s
.49823 .59841 m
.46928 .59673 L
s
.60013 .5 m
.57255 .5 L
s
.42745 .5 m
.39987 .5 L
s
.59657 .52451 m
.56886 .52512 L
s
.56056 .57509 m
.5319 .57555 L
s
.44866 .54952 m
.42038 .54814 L
s
.47361 .57431 m
.44481 .57264 L
s
.5649 .55031 m
.5362 .55084 L
s
.5319 .57555 m
.50278 .57529 L
s
.45237 .52517 m
.4239 .52457 L
s
.50278 .57529 m
.47361 .57431 L
s
.56886 .52512 m
.54018 .5255 L
s
.45605 .5 m
.42745 .5 L
s
.57255 .5 m
.54395 .5 L
s
.47766 .55044 m
.44866 .54952 L
s
.5362 .55084 m
.50698 .55089 L
s
.50698 .55089 m
.47766 .55044 L
s
.48151 .52552 m
.45237 .52517 L
s
.54018 .5255 m
.51092 .52563 L
s
.54395 .5 m
.51472 .5 L
s
.48528 .5 m
.45605 .5 L
s
.51092 .52563 m
.48151 .52552 L
s
.51472 .5 m
.48528 .5 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001ZOolC01nSOol006Eoo`D07a=oo`D07iioo`00
HWoo0`0O7Goo1@0OVGoo001POol201l:Ool?01l<Ool401nEOol005ioo`807`Qoo`@07`moo`X07`Io
o`807i=oo`00G7oo0P0O1Goo1@0O7Goo100O17oo0`0OT7oo001JOol201l4Ool301lAOol501l@Ool2
01l5Ool201n>Ool005Qoo`807`Aoo`807`Yoo`X07`Eoo`X07`Qoo`@07`=oo`<07h]oo`00EWoo0P0O
17oo0P0O27oo100O6Goo1@0O1goo100O0Woo0P0ORGoo001EOol00`0OOomoo`02Ool201l5Ool501lR
Ool401l7Ool201l2Ool201n7Ool005=oo`807`=oo`807`Aoo`<07`aooa@07`]oo`807`Moo`807`9o
o`807hEoo`00DWoo00@07gooOomoo`807`Aoo`807`]oo`@07aAoo`D07`Qoo`@07`Eoo`807`9oo`80
7h=oo`00DGoo00<07gooOol00P0O17oo0P0O27oo1@0O7Goo1P0O1Woo100O0goo0P0O0Woo00<07goo
Ool0P7oo001@Ool0100OOomoo`0O17oo0P0O1Woo100O:7oo1@0O1Goo0P0O0goo0P0O00=oo`0O01l0
P7oo001?Ool0100OOol07`0O0goo0P0O17oo100O37oo6@0O37oo100O0goo0`0O0Woo0P0O00=oo`0O
01l0OWoo001>Ool00`0OOol07`04Ool00`0OOomoo`02Ool201l;Ool501lIOol501l;Ool201l4Ool2
01l2Ool201l00goo01l07`1lOol004eoo`0301moo`0O00=oo`807`=oo`807`Qoo`D07b=oo`D07`Qo
o`<07`=oo`807`9oo`0301moogoo00807gYoo`00CGoo0P0O0goo00@07gooOomoo`807`Moo`<07beo
o`D07`Ioo`807`=oo`807`03Ool07`0O009oo`0301moogoo07Moo`00C7oo0P0O0Woo0P0O0Woo0P0O
1goo0P0O2goo7P0O37oo100O17oo0`0O0Woo0P0O00Eoo`0OOomoo`0O07Qoo`00Bgoo0P0O0Woo00D0
7gooOomoo`0O00Ioo`<07`Uoo`@07aioo`H07`Yoo`807`Eoo`807`9oo`@07`03Ool07`0O07Ioo`00
Bgoo00@07gooOol07`=oo`0301moogoo009oo`<07`Moo`D07bQoo`D07`Moo`<07`Aoo`<07`03Ool0
7`0O00807`03Ool07goo07Aoo`00BWoo0P0O00=oo`0OOol00Woo00@07gooOomoo`807`Moo`<07c9o
o`D07`Eoo`807`Eoo`807`06Ool07`0O01moo`0OM7oo001:Ool01@0OOomoo`0OOol00P0O0Woo0P0O
1goo0P0O47oo7P0O37oo100O0goo0`0O17oo0P0O00Eoo`0O01moo`0O07=oo`00BGoo0P0O00Aoo`0O
01l07`=oo`0301moogoo00Eoo`807`Yoo`P07aioo`D07`]oo`807`Aoo`807`Aoo`0301moo`0O00<0
7g9oo`00BGoo00@07goo01l07`Aoo`0301moogoo00Aoo`807`Yoo`807b]oo`H07`Moo`@07`9oo`<0
7`9oo`807`04Ool07`0O01maOol004Qoo`<07`03Ool07goo009oo`0301moogoo00=oo`807`Qoo`@0
7c=oo`D07`Ioo`@07`03Ool07`0O009oo`0301moo`0O00807g1oo`00B7oo0P0O00=oo`0OOol00Woo
00<07gooOol00Woo0P0O1Woo100O3Goo7P0O4Goo100O1Woo0P0O00=oo`0O01l00`0O00=oo`0O01l0
Kgoo0018Ool01@0OOomoo`0OOol00P0O0goo0P0O1Goo0`0O37oo1@0O7Woo2P0O2goo0P0O1Woo0`0O
00=oo`0O01l00P0O00=oo`0OOol0KGoo0017Ool201l017oo01moo`0O0goo0P0O1Goo0P0O2goo100O
;Goo1@0O27oo100O1Goo0P0O00Ioo`0O01l07goo01m]Ool004Moo`0501moo`0OOol07`03Ool00`0O
Oomoo`03Ool201l8Ool501lfOol601l6Ool301l4Ool201l017oo01l07goo0P0OJgoo0016Ool301l2
Ool0100OOomoo`0O17oo0P0O1goo0`0O4Woo7P0O4Goo1@0O17oo0P0O17oo00<07goo01l0100OJWoo
0016Ool201l2Ool0100OOomoo`0O0goo0P0O1goo0P0O2goo2P0O7Woo2P0O37oo0`0O0goo0`0O0Woo
0P0O00=oo`0O01l00P0OJGoo0016Ool201l01Goo01moogoo01l00Woo0P0O1Woo0`0O2Goo100O<Woo
1@0O2Woo0P0O17oo0P0O0Woo1P0OJ7oo0015Ool201l00goo01moo`0201l2Ool00`0OOomoo`03Ool3
01l8Ool401lkOol501l7Ool301l3Ool301l00goo01l07`0301mWOol004Eoo`<07`04Ool07gooOol2
01l4Ool201l8Ool301lFOolI01lEOol501l5Ool201l4Ool201l00goo01l07`0201mVOol004Eoo`80
7`05Ool07gooOol07`05Ool00`0OOomoo`06Ool201l?Ool:01lIOol:01l@Ool401l3Ool401l2Ool2
01l017oo01l07`0OIGoo0015Ool201l017oo01moo`0O17oo0P0O1Woo0`0O3Goo100O;Goo2P0O2Woo
0P0O1Goo0`0O00=oo`0O01l00`0OI7oo0014Ool201l017oo01moo`0O0goo0P0O1Goo0`0O2goo1@0O
>goo1@0O1goo100O17oo0P0O00=oo`0O01l00P0OHgoo0014Ool201l00goo01l07`03Ool00`0OOomo
o`03Ool201l:Ool401lLOol?01lJOol501l6Ool301l3Ool601mROol004Aoo`@07`=oo`0301moogoo
009oo`807`Qoo`@07a5oo`l07`mooa007`moo`D07`Aoo`807`Aoo`D07f1oo`00@goo1@0O0Woo00@0
7gooOomoo`807`Ioo`@07`aoo`T07bioo`X07`Yoo`D07`03Ool07`0O00807`9oo`@07emoo`00@goo
100O0Woo00D07gooOomoo`0O00Eoo`<07`aoo`@07d5oo`@07`]oo`<07`9oo`L07eioo`00@goo0`0O
0Woo00<07gooOol00P0O17oo0P0O2goo100OBGoo1@0O2Goo0P0O0goo1@0OGGoo0013Ool301l01Goo
01moogoo01l017oo0P0O2Goo100O5Woo:00O57oo1@0O1Woo0`0O00=oo`0O01l00`0OG7oo0013Ool4
01l2Ool0100OOomoogoo0P0O1goo100O37oo3P0O:7oo3`0O2Woo100O1Goo200OFWoo0013Ool301l2
Ool00`0OOomoo`0201l5Ool401l;Ool501m5Ool401l:Ool501l3Ool601mIOol0049oo`H07`9oo`04
01moogooOol401l7Ool801m>Ool901l6Ool;01mGOol0049oo`@07`9oo`807`9oo`807`Moo`@07amo
ob<07aeoo`D07`Eoo`P07eIoo`00@Woo100O00=oo`0OOol00Woo00<07gooOol017oo0`0O47oo4`0O
8goo500O3Woo100O0Woo200OEGoo0012Ool501l2Ool201l3Ool401l;Ool801m:Ool901l9Ool401l0
0goo01moo`0501mCOol0049oo`@07`03Ool07`0O009oo`<07`Moo`P07e]oo`P07`Aoo`D07`03Ool0
7`0O00<07e5oo`00@Woo1@0O0Woo0P0O1Woo100OJgoo200O00=oo`0O01l01@0OD7oo0012Ool701l2
Ool601lDOomB01l>Ool201l00goo01l07`0201l00goo01l07`0301m>Ool0049oo`<07`04Ool07goo
Ool201l9OolA01mBOolA01l017oo01l07goo1`0OCGoo0012Ool701l2Ool901maOol00`0OOol07`07
01l00goo01l07`0301m;Ool0049oo`T07g]oo`0401moo`0OOol201l00goo01moo`0801m9Ool0049o
oi/07d=oo`00@Woo0P0O00=oo`0O01l0P7oo00H07goo01moo`0OOol201l2Ool301l017oo01l07goo
1@0O@goo0012Ool401l00goo01moo`1nOol01@0OOomoo`0OOol00P0O00=oo`0OOol00P0O00=oo`0O
Ool00P0O00=oo`0O01l00P0O@goo0012Ool701mnOol01`0OOomoo`0OOol07goo00807`9oo`807`04
Ool07`0OOol501m3Ool0049oo`807`05Ool07`0O01moo`0701mhOol01`0OOomoo`0OOol07goo0080
7`03Ool07`0O00T07d=oo`00@Woo1P0O27oo2P0OKWoo2P0O00Ioo`0O01moo`0OOol301l00goo01mo
o`12Ool004=oo`H07a5oo`d07dmooa@07`06Ool07gooOol07goo0P0O00Moo`0OOol07goo01moo`04
01m3Ool004=oo`P07aaoodl07a=oo`0701moogoo01moo`0OOol00P0O0Woo0P0O00=oo`0O01l0100O
@goo0013Ool601l2Ool401mkOol01@0OOol07goo01l00Woo0P0O00=oo`0O01l00`0O00Aoo`0O01l0
7d=oo`00A7oo1P0O1Goo1@0OMWoo00<07goo01l00Woo00<07goo01l00`0O00Eoo`0OOol07goo0080
7dAoo`00A7oo1`0O2Goo1@0OLWoo1`0O00Eoo`0OOol07goo00807`03Ool07`0O04Aoo`00AGoo1@0O
00Aoo`0O01l07`]oo`H07fUoo`H07`04Ool07gooOol201l00goo01moo`0501m4Ool004Ioo`D07`=o
o`807`moo`L07eeoo`D07`=oo`0501moo`0OOol07`02Ool201l00goo01l07`0501m4Ool004Ioo`H0
7`Aoo`@07a9oo`h07d5oo`h07`Qoo`0901moogoo01moo`0OOol07goo00<07`03Ool07`0O00807dAo
o`00Agoo1P0O1goo100O77oo6@0O4Goo5`0O5goo00H07goo01moo`0OOol301l00goo01moo`0401m4
Ool004Qoo`@07`03Ool07`0O00Uoo`807c=ooa407bioo`0401moo`0OOol201l00goo01l07`02Ool2
01l00goo01l07`14Ool004Qoo`D07`9oo`<07`Qoo`@07fioo`@07`03Ool07goo00807`9oo`807`03
Ool07goo04Aoo`00BGoo1@0O17oo0P0O2Woo1`0OHWoo1P0O0Woo00H07goo01moo`0OOol601m5Ool0
04Yoo`<07`03Ool07`0O00Aoo`<07`ioo`L07eIoo`D07`Eoo`0=01moogoo01moo`0OOol07goo01mo
o`0OOol00P0OAGoo001;Ool401l00goo01moo`05Ool201lCOol701m8Ool701l;Ool01P0OOol07goo
01moo`<07`03Ool07`0O00807dEoo`00Bgoo0`0O00=oo`0OOol00P0O1Woo0`0O5goo200O>Goo1`0O
4Woo00<07goo01l00`0O00Moo`0O01moo`0OOol07`16Ool004aoo`<07`04Ool07`0OOol301l6Ool4
01lKOolA01lIOol?01lHOol401l01Woo01moogoo01moo`@07dIoo`00CGoo0`0O0Woo0P0O0Woo0`0O
1goo100O:7oo6@0O9Goo0P0O00Ioo`0OOol07goo01l2Ool601m6Ool004ioo`<07`=oo`0301moogoo
009oo`807`Uoo`D07eeoo`@07`=oo`0301moo`0O009oo`<07`03Ool07`0O00807dIoo`00CWoo1@0O
0Woo0P0O17oo0P0O37oo100OEGoo100O1goo00@07goo01moo`807`03Ool07goo00<07dMoo`00Cgoo
0`0O00=oo`0OOol00Woo0P0O17oo0P0O3Woo1@0OCGoo0`0O2goo00T07goo01l07goo01moo`0OOol0
0`0OAgoo001@Ool301l00goo01moo`03Ool00`0OOomoo`03Ool301l@Ool801m0Ool501l>Ool401l0
0goo01moo`0501m7Ool0055oo`<07`03Ool07`0O00=oo`807`Ioo`<07aEoo`P07c5oo`L07a5oo`<0
7`9oo`0301moo`0O00807`03Ool07`0O04Qoo`00DWoo100O00=oo`0OOol00goo0P0O1goo0`0O6Woo
<@0O5Woo0P0O0Woo00L07gooOol07goo01moo`0401m8Ool0059oo`<07`04Ool07goo01l5Ool201l8
Ool401mJOol301l4Ool00`0OOomoo`0301l017oo01l07`0OBGoo001COol301l00goo01moo`0201l5
Ool201l:Ool501mBOol301l7Ool01`0OOol07`0OOol07goo00<07dUoo`00E7oo0`0O00Aoo`0O01mo
o`807`Eoo`807`eoo`H07dQoo`@07`Yoo`<07`04Ool07gooOol201m:Ool005Eoo`@07`04Ool07goo
Ool201l5Ool301l@Ool401lmOol701l=Ool201l01Goo01moo`0OOol00`0OBWoo001FOol201l00goo
01moo`0201l2Ool201l6Ool401l@Ool601l`Ool701lAOol301l01Goo01moo`0OOol0100OBgoo001G
Ool501l00goo01moo`02Ool201l8Ool301lCOol@01lIOol701lFOol201l4Ool00`0OOol07`0201l0
0goo01l07`1;Ool005Moo`@07`03Ool07goo00807`=oo`<07`Qoo`@07amooaT07aYoo`<07`Ioo`@0
7`03Ool07`0O04aoo`00F7oo100O00Aoo`0O01moo`807`Aoo`@07`Qoo`@07d]oo`<07`Uoo`0501mo
o`0O01moo`0201m<Ool005Uoo`D07`04Ool07gooOol301l5Ool301l9Ool401m3Ool401l:Ool201l2
Ool401m=Ool005Yoo`<07`03Ool07goo00807`=oo`807`Ioo`807`]oo`D07cMoo`L07`aoo`807`04
Ool07gooOol401m=Ool005]oo`H07`03Ool07goo00=oo`807`Ioo`807`ioo`T07bMoo`L07a5oo`80
7`=oo`0601moo`0O01moo`0OCWoo001LOol401l00goo01moo`0201l4Ool301l5Ool301lDOol801lH
Ool701lFOol201l5Ool601m>Ool005eoo`@07`04Ool07`0OOol201l5Ool201l6Ool401lHOolH01lJ
Ool301l6Ool00`0OOomoo`0301m?Ool005ioo`D07`04Ool07gooOol201l5Ool201l8Ool401m3Ool3
01l7Ool301l00goo01l07`0201m?Ool005moo`<07`03Ool07goo00807`9oo`0301moogoo00Aoo`<0
7`Uoo`@07c]oo`@07`Qoo`807`03Ool07goo00@07e1oo`00H7oo1P0O00Aoo`0OOomoo`807`Moo`80
7`]oo`H07bioo`L07`Yoo`807`=oo`D07e5oo`00HGoo0P0O00Eoo`0OOol07goo00807`9oo`807`Mo
o`807`moo`P07amoo`L07`moo`807`Aoo`807`03Ool07`0O059oo`00HWoo0P0O00=oo`0OOol00P0O
00=oo`0O01l00Woo0`0O1Woo0`0O57oo7`0O4goo0`0O1Goo0P0O00=oo`0O01l0Dgoo001SOol501l0
17oo01moogoo0P0O0goo0P0O1goo100O?goo0`0O1goo00D07goo01moo`0O05Aoo`00I7oo00H07goo
01moo`0OOol201l2Ool201l3Ool301l8Ool601lfOol301l8Ool201l2Ool301mDOol006Eoo`<07`05
Ool07`0OOol07`03Ool201l4Ool301l;Ool601l]Ool301l9Ool201l3Ool301mEOol006Moo`<07`03
Ool07goo00807`=oo`807`Eoo`@07`eoo`@07bAoo`D07`Uoo`<07`Aoo`<07eIoo`00J7oo00@07goo
01moo`807`03Ool07`0O00=oo`<07`Ioo`<07`ioo`h07`Qoo`h07`]oo`<07`Ioo`<07eMoo`00JGoo
100O00Aoo`0O01moo`807`Aoo`807`Moo`@07aQoo`P07aMoo`807`Moo`D07eMoo`00Jgoo0`0O0Woo
0P0O00=oo`0O01l017oo0P0O2Goo100O;Woo1@0O1goo0P0O00Aoo`0O01l07eQoo`00KGoo0`0O0Woo
00<07gooOol00P0O17oo0`0O2Woo100O97oo1P0O2Woo0P0O0Woo0`0OFGoo001_Ool201l2Ool201l2
Ool301l4Ool401l:Ool601lGOol701l>Ool201l3Ool301mJOol0071oo`<07`9oo`807`=oo`<07`Eo
o`@07`aooaL07a9oo`<07`=oo`@07e]oo`00LWoo0`0O0Woo0P0O17oo0P0O1goo100O;Woo0`0O17oo
0P0O00=oo`0O01l0G7oo001cOol401l2Ool201l4Ool201l9Ool601lTOol401l5Ool201l017oo01l0
7`0OGGoo001eOol0100OOol07`0O0Woo0P0O17oo0`0O37oo1`0O5Woo1`0O1goo0P0O0Woo0P0OGgoo
001fOol201l00goo01l07`02Ool201l5Ool401l?OolF01l:Ool401l2Ool301mPOol007Qoo`807`03
Ool07`0O009oo`<07`Ioo`D07bEoo`D07`=oo`D07f5oo`00NWoo0P0O00Aoo`0O01l07`9oo`@07`Mo
o`P07aYoo`<07`Eoo`<07`9oo`0301moogoo065oo`00O7oo0P0O0Woo0P0O17oo0`0O37oo1`0O1goo
300O1Goo0`0O0goo0P0OI7oo001nOol201l2Ool201l5Ool401l?Ool701l?Ool201l4Ool301mUOol0
081oo`807`9oo`<07`Ioo`D07aaoo`@07`=oo`@07fMoo`00PWoo0`0O0Woo100O1goo3P0O1goo1`0O
0goo100O00=oo`0O01l0J7oo0025Ool301l3Ool501l@Ool701l7Ool301l2Ool301mZOol008Qoo`<0
7`Eoo`L07a=oo`@07`=oo`807feoo`00Rgoo100O27oo4`0O0goo100OKgoo002?Ool501lCOol601mc
Ool009Aooa<07gUoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {505.875, 276.5}} -> {-0.399192, \
1.20546, 0.00348777, 0.00348777}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Clear[\[Theta]]\), "\[IndentingNewLine]", 
    \(\(ComponentFunct[Equ10, {0, R\ \ Cos[\[Phi]], R\ \ Sin[\[Phi]]}, 
        Red];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.591 .47486 m
.59696 .49481 L
s
.58446 .45507 m
.591 .47486 L
s
.57738 .43553 m
.58446 .45507 L
s
.59696 .49481 m
.60231 .51484 L
s
.56978 .41635 m
.57738 .43553 L
s
.60231 .51484 m
.60704 .53485 L
s
.56171 .3976 m
.56978 .41635 L
s
.60704 .53485 m
.61111 .55475 L
s
.55318 .37939 m
.56171 .3976 L
s
.61111 .55475 m
.61449 .57444 L
s
.54424 .36181 m
.55318 .37939 L
s
.61449 .57444 m
.61717 .59383 L
s
.53493 .34494 m
.54424 .36181 L
s
.61717 .59383 m
.61911 .6128 L
s
.52528 .32889 m
.53493 .34494 L
s
.61911 .6128 m
.6203 .63127 L
s
.51535 .31376 m
.52528 .32889 L
s
.6203 .63127 m
.62072 .64913 L
s
.50517 .29963 m
.51535 .31376 L
s
.62072 .64913 m
.62035 .66627 L
s
.49479 .28662 m
.50517 .29963 L
s
.62035 .66627 m
.61916 .68257 L
s
.48427 .27481 m
.49479 .28662 L
s
.61916 .68257 m
.61715 .69793 L
s
.47367 .26432 m
.48427 .27481 L
s
.61715 .69793 m
.61431 .71224 L
s
.46303 .25523 m
.47367 .26432 L
s
.61431 .71224 m
.61062 .72537 L
s
.45244 .24765 m
.46303 .25523 L
s
.61062 .72537 m
.6061 .73721 L
s
.44195 .24167 m
.45244 .24765 L
s
.6061 .73721 m
.60072 .74764 L
s
.43164 .23738 m
.44195 .24167 L
s
.60072 .74764 m
.59452 .75655 L
s
.42159 .23488 m
.43164 .23738 L
s
.59452 .75655 m
.58749 .76382 L
s
.41186 .23423 m
.42159 .23488 L
s
.58749 .76382 m
.57966 .76935 L
s
.40256 .23551 m
.41186 .23423 L
s
.57966 .76935 m
.57107 .77302 L
s
.39376 .23878 m
.40256 .23551 L
s
.57107 .77302 m
.56174 .77475 L
s
.38554 .24409 m
.39376 .23878 L
s
.56174 .77475 m
.55173 .77446 L
s
.378 .25145 m
.38554 .24409 L
s
.55173 .77446 m
.54109 .77207 L
s
.37122 .26089 m
.378 .25145 L
s
.54109 .77207 m
.52989 .76754 L
s
.36529 .2724 m
.37122 .26089 L
s
.52989 .76754 m
.51822 .76082 L
s
.36028 .28593 m
.36529 .2724 L
s
.51822 .76082 m
.50615 .75191 L
s
.35628 .30143 m
.36028 .28593 L
s
.50615 .75191 m
.49379 .74083 L
s
.35334 .31882 m
.35628 .30143 L
s
.49379 .74083 m
.48124 .7276 L
s
.35153 .33799 m
.35334 .31882 L
s
.48124 .7276 m
.46863 .71231 L
s
.35089 .35879 m
.35153 .33799 L
s
.46863 .71231 m
.45606 .69504 L
s
.35146 .38106 m
.35089 .35879 L
s
.45606 .69504 m
.44368 .67592 L
s
.35327 .40459 m
.35146 .38106 L
s
.44368 .67592 m
.4316 .65512 L
s
.3563 .42919 m
.35327 .40459 L
s
.4316 .65512 m
.41996 .63281 L
s
.36055 .45459 m
.3563 .42919 L
s
.41996 .63281 m
.40889 .60921 L
s
.366 .48056 m
.36055 .45459 L
s
.40889 .60921 m
.39851 .58456 L
s
.37259 .50682 m
.366 .48056 L
s
.39851 .58456 m
.38893 .55909 L
s
.38026 .53309 m
.37259 .50682 L
s
.38893 .55909 m
.38026 .53309 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol007=oo`Ml0:Io
o`00LGoo0W`01goo0g`0Xgoo001_Ool2O00<Ool2O02QOol006ioo`03O01oogoo00ioo`9l09moo`00
KGoo00=l07ooOol04Goo00=l07ooOol0W7oo001/Ool00g`0Oomoo`0COol2O02LOol006]oo`03O01o
ogoo01Ioo`03O01oogoo09Uoo`00JWoo00=l07ooOol067oo0W`0VGoo001YOol00g`0Oomoo`0KOol0
0g`0Oomoo`2FOol006Uoo`03O01oogoo01aoo`03O01oogoo09Eoo`00J7oo00=l07ooOol07Woo00=l
07ooOol0U7oo001XOol00g`0Oomoo`0OOol00g`0Oomoo`2COol006Qoo`03O01oogoo021oo`03O01o
ogoo099oo`00Igoo00=l07ooOol08Woo00=l07ooOol0TGoo001WOol00g`0Oomoo`0SOol00g`0Oomo
o`2@Ool006Moo`03O01oogoo02Aoo`03O01oogoo08moo`00Igoo00=l07ooOol09Goo00=l07ooOol0
SWoo001VOol00g`0Oomoo`0VOol00g`0Oomoo`2>Ool006Ioo`03O01oogoo02Moo`03O01oogoo08eo
o`00IWoo00=l07ooOol0:7oo00=l07ooOol0S7oo001VOol00g`0Oomoo`0XOol00g`0Oomoo`2<Ool0
06Ioo`03O01oogoo02Uoo`03O01oogoo08]oo`00IGoo00=l07ooOol0:Woo00=l07ooOol0Rgoo001U
Ool00g`0Oomoo`0[Ool00g`0Oomoo`2:Ool006Eoo`03O01oogoo02aoo`03O01oogoo08Uoo`00IGoo
00=l07ooOol0;7oo00=l07ooOol0RGoo001UOol00g`0Oomoo`0]Ool00g`0Oomoo`28Ool006Aoo`03
O01oogoo02moo`03O01oogoo08Moo`00I7oo00=l07ooOol0<7oo00=l07ooOol0QWoo001TOol00g`0
Oomoo`0`Ool00g`0Oomoo`26Ool006Aoo`03O01oogoo035oo`03O01oogoo08Eoo`00I7oo00=l07oo
Ool0<Woo00=l07ooOol0Q7oo001TOol00g`0Oomoo`0cOol00g`0Oomoo`23Ool006Aoo`03O01oogoo
03=oo`03O01oogoo08=oo`00I7oo00=l07ooOol0=7oo00=l07ooOol0PWoo001TOol00g`0Oomoo`0d
Ool00g`0Oomoo`22Ool006Aoo`03O01oogoo03Eoo`03O01oogoo085oo`00I7oo00=l07ooOol0=Goo
00=l07ooOol0PGoo001TOol00g`0Oomoo`0fOol00g`0Oomoo`20Ool006Aoo`03O01oogoo03Ioo`03
O01oogoo081oo`00I7oo00=l07ooOol0=goo00=l07ooOol0Ogoo001TOol00g`0Oomoo`0gOol00g`0
Oomoo`1oOol006Aoo`03O01oogoo03Moo`03O01oogoo07moo`00I7oo00=l07ooOol0>7oo00=l07oo
Ool0OWoo001TOol00g`0Oomoo`0hOol00g`0Oomoo`1nOol006Aoo`03O01oogoo03Uoo`03O01oogoo
07eoo`00IGoo00=l07ooOol0>7oo00=l07ooOol0OGoo001UOol00g`0Oomoo`0iOol00g`0Oomoo`1l
Ool006Eoo`03O01oogoo03Uoo`03O01oogoo07aoo`00IGoo00=l07ooOol0>Woo00=l07ooOol0Ngoo
001UOol00g`0Oomoo`0jOol00g`0Oomoo`1kOol006Eoo`03O01oogoo03]oo`03O01oogoo07Yoo`00
IGoo00=l07ooOol0>goo00=l07ooOol0NWoo001VOol00g`0Oomoo`0jOol00g`0Oomoo`1jOol006Io
o`03O01oogoo03]oo`03O01oogoo07Uoo`00IWoo00=l07ooOol0>goo00=l07ooOol0NGoo001VOol0
0g`0Oomoo`0lOol00g`0Oomoo`1hOol006Ioo`03O01oogoo03aoo`03O01oogoo07Qoo`00IWoo00=l
07ooOol0?7oo00=l07ooOol0N7oo001VOol00g`0Oomoo`0mOol00g`0Oomoo`1gOol006Moo`03O01o
ogoo03aoo`03O01oogoo07Moo`00Igoo00=l07ooOol0?7oo00=l07ooOol0Mgoo001WOol00g`0Oomo
o`0mOol00g`0Oomoo`1fOol006Moo`03O01oogoo03eoo`03O01oogoo07Ioo`00Igoo00=l07ooOol0
?Goo00=l07ooOol0MWoo001XOol00g`0Oomoo`0mOol00g`0Oomoo`1eOol006Qoo`03O01oogoo03eo
o`03O01oogoo07Eoo`00J7oo00=l07ooOol0?Goo00=l07ooOol0MGoo001XOol00g`0Oomoo`0nOol0
0g`0Oomoo`1dOol006Uoo`03O01oogoo03eoo`03O01oogoo07Aoo`00JGoo00=l07ooOol0?Goo00=l
07ooOol0M7oo001YOol00g`0Oomoo`0nOol00g`0Oomoo`1cOol006Uoo`03O01oogoo03ioo`03O01o
ogoo07=oo`00JGoo00=l07ooOol0?Woo00=l07ooOol0Lgoo001YOol00g`0Oomoo`0oOol00g`0Oomo
o`1bOol006Yoo`03O01oogoo03ioo`03O01oogoo079oo`00JWoo00=l07ooOol0?Woo00=l07ooOol0
LWoo001ZOol00g`0Oomoo`0nOol00g`0Oomoo`1bOol006Yoo`03O01oogoo03moo`03O01oogoo075o
o`00JWoo00=l07ooOol0?goo00=l07ooOol0LGoo001[Ool00g`0Oomoo`0nOol00g`0Oomoo`1aOol0
06]oo`03O01oogoo03ioo`03O01oogoo075oo`00K7oo00=l07ooOol0?Woo00=l07ooOol0L7oo001/
Ool00g`0Oomoo`0nOol00g`0Oomoo`1`Ool006eoo`03O01oogoo03eoo`03O01oogoo071oo`00KGoo
00=l07ooOol0?Woo00=l07ooOol0Kgoo001]Ool00g`0Oomoo`0nOol00g`0Oomoo`1_Ool006eoo`03
O01oogoo03ioo`03O01oogoo06moo`00KWoo00=l07ooOol0?Goo00=l07ooOol0Kgoo001^Ool00g`0
Oomoo`0mOol00g`0Oomoo`1_Ool006ioo`03O01oogoo03ioo`03O01oogoo06ioo`00KWoo00=l07oo
Ool0?Woo00=l07ooOol0KWoo001_Ool00g`0Oomoo`0mOol00g`0Oomoo`1^Ool006moo`03O01oogoo
03eoo`03O01oogoo06ioo`00Kgoo00=l07ooOol0?Goo00=l07ooOol0KWoo001`Ool00g`0Oomoo`0m
Ool00g`0Oomoo`1]Ool0071oo`03O01oogoo03eoo`03O01oogoo06eoo`00LGoo00=l07ooOol0?7oo
00=l07ooOol0KGoo001aOol00g`0Oomoo`0lOol00g`0Oomoo`1]Ool0079oo`03O01oogoo03]oo`03
O01oogoo06eoo`00LWoo00=l07ooOol0>goo00=l07ooOol0KGoo001bOol00g`0Oomoo`0lOol00g`0
Oomoo`1/Ool007=oo`03O01oogoo03]oo`03O01oogoo06aoo`00Lgoo00=l07ooOol0>goo00=l07oo
Ool0K7oo001dOol00g`0Oomoo`0jOol00g`0Oomoo`1/Ool007Aoo`03O01oogoo03Yoo`03O01oogoo
06aoo`00MGoo00=l07ooOol0>Goo00=l07ooOol0K7oo001eOol00g`0Oomoo`0iOol00g`0Oomoo`1/
Ool007Eoo`03O01oogoo03Uoo`03O01oogoo06aoo`00MWoo00=l07ooOol0>7oo00=l07ooOol0K7oo
001fOol00g`0Oomoo`0hOol00g`0Oomoo`1/Ool007Moo`03O01oogoo03Moo`03O01oogoo06aoo`00
Mgoo00=l07ooOol0>7oo00=l07ooOol0Jgoo001hOol00g`0Oomoo`0gOol00g`0Oomoo`1[Ool007Qo
o`03O01oogoo03Moo`03O01oogoo06]oo`00N7oo00=l07ooOol0=goo00=l07ooOol0Jgoo001iOol0
0g`0Oomoo`0fOol00g`0Oomoo`1[Ool007Uoo`03O01oogoo03Ioo`03O01oogoo06]oo`00NWoo00=l
07ooOol0=Goo00=l07ooOol0Jgoo001jOol00g`0Oomoo`0eOol00g`0Oomoo`1[Ool007]oo`03O01o
ogoo03Aoo`03O01oogoo06]oo`00Ngoo00=l07ooOol0=7oo00=l07ooOol0Jgoo001lOol00g`0Oomo
o`0cOol00g`0Oomoo`1[Ool007eoo`03O01oogoo039oo`03O01oogoo06]oo`00OGoo00=l07ooOol0
<Woo00=l07ooOol0Jgoo001nOol00g`0Oomoo`0aOol00g`0Oomoo`1[Ool007moo`03O01oogoo02mo
o`03O01oogoo06aoo`00Ogoo00=l07ooOol0;goo00=l07ooOol0K7oo0020Ool00g`0Oomoo`0^Ool0
0g`0Oomoo`1/Ool0081oo`03O01oogoo02ioo`03O01oogoo06aoo`00PGoo00=l07ooOol0;Goo00=l
07ooOol0K7oo0021Ool00g`0Oomoo`0]Ool00g`0Oomoo`1/Ool0089oo`03O01oogoo02aoo`03O01o
ogoo06aoo`00Pgoo00=l07ooOol0:goo00=l07ooOol0K7oo0024Ool00g`0Oomoo`0ZOol00g`0Oomo
o`1/Ool008Aoo`03O01oogoo02Uoo`03O01oogoo06eoo`00QGoo00=l07ooOol0:7oo00=l07ooOol0
KGoo0026Ool00g`0Oomoo`0WOol00g`0Oomoo`1]Ool008Moo`03O01oogoo02Ioo`03O01oogoo06eo
o`00R7oo00=l07ooOol097oo00=l07ooOol0KWoo0029Ool00g`0Oomoo`0SOol00g`0Oomoo`1^Ool0
08Yoo`03O01oogoo029oo`03O01oogoo06ioo`00Rgoo00=l07ooOol087oo00=l07ooOol0Kgoo002;
Ool00g`0Oomoo`0POol00g`0Oomoo`1_Ool008aoo`03O01oogoo01ioo`03O01oogoo071oo`00SGoo
00=l07ooOol07Goo00=l07ooOol0L7oo002>Ool00g`0Oomoo`0KOol00g`0Oomoo`1aOol008moo`9l
01]oo`03O01oogoo075oo`00TGoo00=l07ooOol05goo00=l07ooOol0LWoo002BOol00g`0Oomoo`0F
Ool00g`0Oomoo`1bOol009=oo`03O01oogoo01Aoo`03O01oogoo07=oo`00U7oo00=l07ooOol04Woo
00=l07ooOol0M7oo002EOol2O00AOol00g`0Oomoo`1eOol009Moo`=l00]oo`=l07Qoo`00VWoo0g`0
1Woo0W`0Ngoo002MOol6O01mOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.58865 .45416 m
.59759 .47718 L
s
.57915 .43141 m
.58865 .45416 L
s
.59759 .47718 m
.60591 .50037 L
s
.56911 .40905 m
.57915 .43141 L
s
.60591 .50037 m
.61358 .52362 L
s
.5586 .38718 m
.56911 .40905 L
s
.61358 .52362 m
.62055 .54682 L
s
.54765 .3659 m
.5586 .38718 L
s
.62055 .54682 m
.62679 .56985 L
s
.53631 .34534 m
.54765 .3659 L
s
.62679 .56985 m
.63227 .59261 L
s
.52463 .32559 m
.53631 .34534 L
s
.63227 .59261 m
.63693 .61498 L
s
.51267 .30677 m
.52463 .32559 L
s
.63693 .61498 m
.64076 .63684 L
s
.50048 .28898 m
.51267 .30677 L
s
.64076 .63684 m
.6437 .65808 L
s
.48813 .27235 m
.50048 .28898 L
s
.6437 .65808 m
.64574 .67856 L
s
.47567 .25699 m
.48813 .27235 L
s
.64574 .67856 m
.64684 .69815 L
s
.46318 .24301 m
.47567 .25699 L
s
.64684 .69815 m
.64698 .71674 L
s
.45071 .23052 m
.46318 .24301 L
s
.64698 .71674 m
.64611 .73419 L
s
.43835 .21964 m
.45071 .23052 L
s
.64611 .73419 m
.64424 .75036 L
s
.42618 .21048 m
.43835 .21964 L
s
.64424 .75036 m
.64133 .76512 L
s
.41427 .20316 m
.42618 .21048 L
s
.64133 .76512 m
.63737 .77833 L
s
.40271 .19776 m
.41427 .20316 L
s
.63737 .77833 m
.63236 .78986 L
s
.3916 .19441 m
.40271 .19776 L
s
.63236 .78986 m
.6263 .79958 L
s
.38101 .19317 m
.3916 .19441 L
s
.6263 .79958 m
.61919 .80735 L
s
.37105 .19415 m
.38101 .19317 L
s
.61919 .80735 m
.61105 .81306 L
s
.36182 .19739 m
.37105 .19415 L
s
.61105 .81306 m
.60191 .81659 L
s
.3534 .20297 m
.36182 .19739 L
s
.60191 .81659 m
.59179 .81784 L
s
.34589 .21091 m
.3534 .20297 L
s
.59179 .81784 m
.58076 .81672 L
s
.33939 .22122 m
.34589 .21091 L
s
.58076 .81672 m
.56886 .81316 L
s
.33398 .23391 m
.33939 .22122 L
s
.56886 .81316 m
.55617 .80711 L
s
.32975 .24894 m
.33398 .23391 L
s
.55617 .80711 m
.54278 .79854 L
s
.32677 .26624 m
.32975 .24894 L
s
.54278 .79854 m
.52878 .78744 L
s
.32511 .28573 m
.32677 .26624 L
s
.52878 .78744 m
.51428 .77386 L
s
.32481 .30729 m
.32511 .28573 L
s
.51428 .77386 m
.49941 .75784 L
s
.32592 .33076 m
.32481 .30729 L
s
.49941 .75784 m
.4843 .73947 L
s
.32846 .35596 m
.32592 .33076 L
s
.4843 .73947 m
.46909 .71889 L
s
.33243 .38267 m
.32846 .35596 L
s
.46909 .71889 m
.45393 .69624 L
s
.33783 .41066 m
.33243 .38267 L
s
.45393 .69624 m
.43898 .67173 L
s
.34462 .43966 m
.33783 .41066 L
s
.43898 .67173 m
.42439 .64557 L
s
.35274 .46938 m
.34462 .43966 L
s
.42439 .64557 m
.41032 .61801 L
s
.36213 .49952 m
.35274 .46938 L
s
.41032 .61801 m
.39692 .58932 L
s
.3727 .52977 m
.36213 .49952 L
s
.39692 .58932 m
.38434 .55981 L
s
.38434 .55981 m
.3727 .52977 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol006Uoo`Ul0:ioo`00Igoo0W`02Goo0W`0[7oo001VOol00g`0Oomoo`0;Ool2
O02ZOol006Eoo`03O01oogoo00ioo`03O01oogoo0:Moo`00I7oo00=l07ooOol047oo0W`0Ygoo001S
Ool00g`0Oomoo`0COol2O02UOol0069oo`03O01oogoo01Ioo`03O01oogoo0:9oo`00HWoo00=l07oo
Ool05goo00=l07ooOol0XGoo001QOol00g`0Oomoo`0IOol00g`0Oomoo`2POol0061oo`03O01oogoo
01]oo`03O01oogoo09moo`00H7oo00=l07ooOol077oo0W`0Wgoo001OOol00g`0Oomoo`0OOol00g`0
Oomoo`2LOol005moo`03O01oogoo021oo`03O01oogoo09]oo`00Ggoo00=l07ooOol08Goo00=l07oo
Ool0VWoo001NOol00g`0Oomoo`0SOol00g`0Oomoo`2IOol005ioo`03O01oogoo02Aoo`03O01oogoo
09Qoo`00GWoo00=l07ooOol09Goo00=l07ooOol0Ugoo001NOol00g`0Oomoo`0VOol00g`0Oomoo`2F
Ool005ioo`03O01oogoo02Moo`03O01oogoo09Eoo`00GGoo00=l07ooOol0:Goo00=l07ooOol0U7oo
001MOol00g`0Oomoo`0ZOol00g`0Oomoo`2COol005eoo`03O01oogoo02Yoo`03O01oogoo09=oo`00
GGoo00=l07ooOol0:goo00=l07ooOol0TWoo001MOol00g`0Oomoo`0/Ool00g`0Oomoo`2AOol005eo
o`03O01oogoo02eoo`03O01oogoo091oo`00GGoo00=l07ooOol0;Goo00=l07ooOol0T7oo001MOol0
0g`0Oomoo`0^Ool00g`0Oomoo`2?Ool005eoo`03O01oogoo02moo`03O01oogoo08ioo`00GGoo00=l
07ooOol0<7oo00=l07ooOol0SGoo001MOol00g`0Oomoo`0`Ool00g`0Oomoo`2=Ool005eoo`03O01o
ogoo035oo`03O01oogoo08aoo`00GGoo00=l07ooOol0<Woo00=l07ooOol0Rgoo001MOol00g`0Oomo
o`0bOol00g`0Oomoo`2;Ool005eoo`03O01oogoo03=oo`03O01oogoo08Yoo`00GGoo00=l07ooOol0
=7oo00=l07ooOol0RGoo001MOol00g`0Oomoo`0dOol00g`0Oomoo`29Ool005eoo`03O01oogoo03Eo
o`03O01oogoo08Qoo`00GGoo00=l07ooOol0=Goo00=l07ooOol0R7oo001MOol00g`0Oomoo`0fOol0
0g`0Oomoo`27Ool005eoo`03O01oogoo03Ioo`03O01oogoo08Moo`00GGoo00=l07ooOol0=goo00=l
07ooOol0QWoo001MOol00g`0Oomoo`0gOol00g`0Oomoo`26Ool005eoo`03O01oogoo03Qoo`03O01o
ogoo08Eoo`00GGoo00=l07ooOol0>7oo00=l07ooOol0QGoo001NOol00g`0Oomoo`0hOol00g`0Oomo
o`24Ool005ioo`03O01oogoo03Uoo`03O01oogoo08=oo`00GWoo00=l07ooOol0>Goo00=l07ooOol0
Pgoo001NOol00g`0Oomoo`0jOol00g`0Oomoo`22Ool005ioo`03O01oogoo03]oo`03O01oogoo085o
o`00GWoo00=l07ooOol0>goo00=l07ooOol0PGoo001NOol00g`0Oomoo`0lOol00g`0Oomoo`20Ool0
05moo`03O01oogoo03]oo`03O01oogoo081oo`00Ggoo00=l07ooOol0?7oo00=l07ooOol0Ogoo001O
Ool00g`0Oomoo`0lOol00g`0Oomoo`1oOol005moo`03O01oogoo03eoo`03O01oogoo07ioo`00Ggoo
00=l07ooOol0?Goo00=l07ooOol0OWoo001OOol00g`0Oomoo`0nOol00g`0Oomoo`1mOol005moo`03
O01oogoo03ioo`03O01oogoo07eoo`00Ggoo00=l07ooOol0?goo00=l07ooOol0O7oo001POol00g`0
Oomoo`0nOol00g`0Oomoo`1lOol0061oo`03O01oogoo03moo`03O01oogoo07]oo`00H7oo00=l07oo
Ool0?goo00=l07ooOol0Ngoo001POol00g`0Oomoo`10Ool00g`0Oomoo`1jOol0061oo`03O01oogoo
041oo`03O01oogoo07Yoo`00H7oo00=l07ooOol0@Goo00=l07ooOol0NGoo001QOol00g`0Oomoo`10
Ool00g`0Oomoo`1iOol0065oo`03O01oogoo045oo`03O01oogoo07Qoo`00HGoo00=l07ooOol0@Goo
00=l07ooOol0N7oo001QOol00g`0Oomoo`12Ool00g`0Oomoo`1gOol0069oo`03O01oogoo045oo`03
O01oogoo07Moo`00HWoo00=l07ooOol0@Woo00=l07ooOol0MWoo001ROol00g`0Oomoo`12Ool00g`0
Oomoo`1fOol0069oo`03O01oogoo049oo`03O01oogoo07Ioo`00Hgoo00=l07ooOol0@Goo00=l07oo
Ool0MWoo001SOol00g`0Oomoo`12Ool00g`0Oomoo`1eOol006=oo`03O01oogoo049oo`03O01oogoo
07Eoo`00I7oo00=l07ooOol0@Goo00=l07ooOol0MGoo001TOol00g`0Oomoo`12Ool00g`0Oomoo`1d
Ool006Eoo`03O01oogoo045oo`03O01oogoo07Aoo`00IGoo00=l07ooOol0@Woo00=l07ooOol0Lgoo
001UOol00g`0Oomoo`12Ool00g`0Oomoo`1cOol006Eoo`03O01oogoo04=oo`03O01oogoo079oo`00
IWoo00=l07ooOol0@Woo00=l07ooOol0LWoo001VOol00g`0Oomoo`13Ool00g`0Oomoo`1aOol006Io
o`03O01oogoo04=oo`03O01oogoo075oo`00IWoo00=l07ooOol0@goo00=l07ooOol0LGoo001WOol0
0g`0Oomoo`12Ool00g`0Oomoo`1aOol006Moo`03O01oogoo04=oo`03O01oogoo071oo`00Igoo00=l
07ooOol0@goo00=l07ooOol0L7oo001WOol00g`0Oomoo`13Ool00g`0Oomoo`1`Ool006Qoo`03O01o
ogoo04=oo`03O01oogoo06moo`00J7oo00=l07ooOol0@goo00=l07ooOol0Kgoo001XOol00g`0Oomo
o`14Ool00g`0Oomoo`1^Ool006Uoo`03O01oogoo04=oo`03O01oogoo06ioo`00JGoo00=l07ooOol0
A7oo00=l07ooOol0KGoo001YOol00g`0Oomoo`14Ool00g`0Oomoo`1]Ool006Yoo`03O01oogoo04=o
o`03O01oogoo06eoo`00JWoo00=l07ooOol0A7oo00=l07ooOol0K7oo001ZOol00g`0Oomoo`14Ool0
0g`0Oomoo`1/Ool006]oo`03O01oogoo04=oo`03O01oogoo06aoo`00Jgoo00=l07ooOol0A7oo00=l
07ooOol0Jgoo001/Ool00g`0Oomoo`13Ool00g`0Oomoo`1[Ool006aoo`03O01oogoo04=oo`03O01o
ogoo06]oo`00KGoo00=l07ooOol0@Woo00=l07ooOol0Jgoo001]Ool00g`0Oomoo`12Ool00g`0Oomo
o`1[Ool006ioo`03O01oogoo049oo`03O01oogoo06Yoo`00KWoo00=l07ooOol0@Woo00=l07ooOol0
JWoo001_Ool00g`0Oomoo`11Ool00g`0Oomoo`1ZOol006moo`03O01oogoo045oo`03O01oogoo06Yo
o`00Kgoo00=l07ooOol0@Goo00=l07ooOol0JWoo001`Ool00g`0Oomoo`11Ool00g`0Oomoo`1YOol0
071oo`03O01oogoo045oo`03O01oogoo06Uoo`00L7oo00=l07ooOol0@Goo00=l07ooOol0JGoo001a
Ool00g`0Oomoo`10Ool00g`0Oomoo`1YOol0075oo`03O01oogoo045oo`03O01oogoo06Qoo`00LGoo
00=l07ooOol0@Goo00=l07ooOol0J7oo001bOol00g`0Oomoo`10Ool00g`0Oomoo`1XOol0079oo`03
O01oogoo041oo`03O01oogoo06Qoo`00Lgoo00=l07ooOol0?goo00=l07ooOol0J7oo001cOol00g`0
Oomoo`10Ool00g`0Oomoo`1WOol007Aoo`03O01oogoo03moo`03O01oogoo06Moo`00M7oo00=l07oo
Ool0?goo00=l07ooOol0Igoo001eOol00g`0Oomoo`0nOol00g`0Oomoo`1WOol007Eoo`03O01oogoo
03ioo`03O01oogoo06Moo`00MWoo00=l07ooOol0?Goo00=l07ooOol0Igoo001fOol00g`0Oomoo`0n
Ool00g`0Oomoo`1VOol007Moo`03O01oogoo03eoo`03O01oogoo06Ioo`00Mgoo00=l07ooOol0?Goo
00=l07ooOol0IWoo001hOol00g`0Oomoo`0lOol00g`0Oomoo`1VOol007Qoo`03O01oogoo03aoo`03
O01oogoo06Ioo`00NGoo00=l07ooOol0>goo00=l07ooOol0IWoo001jOol00g`0Oomoo`0kOol00g`0
Oomoo`1UOol007Yoo`03O01oogoo03]oo`03O01oogoo06Eoo`00Ngoo00=l07ooOol0>Woo00=l07oo
Ool0IGoo001kOol00g`0Oomoo`0jOol00g`0Oomoo`1UOol007aoo`03O01oogoo03Uoo`03O01oogoo
06Eoo`00O7oo00=l07ooOol0>Goo00=l07ooOol0IGoo001mOol00g`0Oomoo`0iOol00g`0Oomoo`1T
Ool007ioo`03O01oogoo03Qoo`03O01oogoo06Aoo`00OWoo00=l07ooOol0>7oo00=l07ooOol0I7oo
001oOol00g`0Oomoo`0gOol00g`0Oomoo`1TOol0081oo`03O01oogoo03Ioo`03O01oogoo06Aoo`00
PGoo00=l07ooOol0=Goo00=l07ooOol0I7oo0021Ool00g`0Oomoo`0eOol00g`0Oomoo`1TOol0089o
o`03O01oogoo03Aoo`03O01oogoo06Aoo`00Pgoo00=l07ooOol0<goo00=l07ooOol0I7oo0023Ool0
0g`0Oomoo`0cOol00g`0Oomoo`1TOol008Aoo`03O01oogoo039oo`03O01oogoo06Aoo`00Q7oo00=l
07ooOol0<Woo00=l07ooOol0I7oo0025Ool00g`0Oomoo`0aOol00g`0Oomoo`1TOol008Eoo`03O01o
ogoo035oo`03O01oogoo06Aoo`00QWoo00=l07ooOol0<7oo00=l07ooOol0I7oo0027Ool00g`0Oomo
o`0_Ool00g`0Oomoo`1TOol008Moo`03O01oogoo02moo`03O01oogoo06Aoo`00R7oo00=l07ooOol0
;Woo00=l07ooOol0I7oo0029Ool00g`0Oomoo`0]Ool00g`0Oomoo`1TOol008Uoo`03O01oogoo02eo
o`03O01oogoo06Aoo`00RWoo00=l07ooOol0;7oo00=l07ooOol0I7oo002;Ool00g`0Oomoo`0ZOol0
0g`0Oomoo`1UOol008aoo`03O01oogoo02Uoo`03O01oogoo06Eoo`00SGoo00=l07ooOol0:7oo00=l
07ooOol0IGoo002>Ool00g`0Oomoo`0WOol00g`0Oomoo`1UOol008moo`03O01oogoo02Ioo`03O01o
ogoo06Eoo`00T7oo00=l07ooOol09Goo00=l07ooOol0IGoo002AOol00g`0Oomoo`0TOol00g`0Oomo
o`1UOol0095oo`03O01oogoo02=oo`03O01oogoo06Ioo`00TWoo00=l07ooOol08Woo00=l07ooOol0
IWoo002COol00g`0Oomoo`0POol00g`0Oomoo`1WOol009Aoo`03O01oogoo01moo`03O01oogoo06Mo
o`00UGoo0W`07goo00=l07ooOol0Igoo002GOol00g`0Oomoo`0KOol00g`0Oomoo`1XOol009Qoo`03
O01oogoo01Yoo`03O01oogoo06Qoo`00VGoo00=l07ooOol067oo00=l07ooOol0JGoo002JOol00g`0
Oomoo`0GOol00g`0Oomoo`1YOol009]oo`03O01oogoo01Eoo`03O01oogoo06Yoo`00W7oo0W`057oo
00=l07ooOol0Jgoo002NOol2O00AOol00g`0Oomoo`1/Ool00:1oo`9l00ioo`03O01oogoo06eoo`00
XWoo0g`02Goo0W`0L7oo002UOol9O01bOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.57862 .46189 m
.5888 .48433 L
s
.56794 .43969 m
.57862 .46189 L
s
.5888 .48433 m
.59843 .5069 L
s
.5568 .41783 m
.56794 .43969 L
s
.59843 .5069 m
.60746 .52951 L
s
.54527 .39642 m
.5568 .41783 L
s
.60746 .52951 m
.61586 .55204 L
s
.53339 .37557 m
.54527 .39642 L
s
.61586 .55204 m
.62357 .57438 L
s
.52121 .35537 m
.53339 .37557 L
s
.62357 .57438 m
.63054 .59644 L
s
.50879 .33593 m
.52121 .35537 L
s
.63054 .59644 m
.63674 .61808 L
s
.49619 .31736 m
.50879 .33593 L
s
.63674 .61808 m
.64211 .63921 L
s
.48347 .29976 m
.49619 .31736 L
s
.64211 .63921 m
.64662 .65969 L
s
.47068 .28325 m
.48347 .29976 L
s
.64662 .65969 m
.65023 .67941 L
s
.45791 .26794 m
.47068 .28325 L
s
.65023 .67941 m
.65289 .69825 L
s
.44522 .25393 m
.45791 .26794 L
s
.65289 .69825 m
.65457 .71607 L
s
.43267 .24134 m
.44522 .25393 L
s
.65457 .71607 m
.65523 .73275 L
s
.42036 .23027 m
.43267 .24134 L
s
.65523 .73275 m
.65484 .74816 L
s
.40835 .22085 m
.42036 .23027 L
s
.65484 .74816 m
.65337 .76216 L
s
.39673 .21316 m
.40835 .22085 L
s
.65337 .76216 m
.65079 .77462 L
s
.38559 .20733 m
.39673 .21316 L
s
.65079 .77462 m
.64709 .78541 L
s
.37502 .20344 m
.38559 .20733 L
s
.64709 .78541 m
.64225 .7944 L
s
.3651 .20159 m
.37502 .20344 L
s
.64225 .7944 m
.63628 .80146 L
s
.35594 .20186 m
.3651 .20159 L
s
.63628 .80146 m
.62916 .80647 L
s
.34762 .20432 m
.35594 .20186 L
s
.62916 .80647 m
.62092 .80933 L
s
.34023 .20904 m
.34762 .20432 L
s
.62092 .80933 m
.61159 .80994 L
s
.33388 .21604 m
.34023 .20904 L
s
.61159 .80994 m
.60119 .80821 L
s
.32864 .22537 m
.33388 .21604 L
s
.60119 .80821 m
.58979 .80409 L
s
.3246 .23701 m
.32864 .22537 L
s
.58979 .80409 m
.57744 .79751 L
s
.32183 .25094 m
.3246 .23701 L
s
.57744 .79751 m
.56422 .78847 L
s
.3204 .26712 m
.32183 .25094 L
s
.56422 .78847 m
.55023 .77697 L
s
.32035 .28546 m
.3204 .26712 L
s
.55023 .77697 m
.53558 .76304 L
s
.32175 .30586 m
.32035 .28546 L
s
.53558 .76304 m
.52038 .74675 L
s
.3246 .32819 m
.32175 .30586 L
s
.52038 .74675 m
.50476 .72819 L
s
.32892 .35226 m
.3246 .32819 L
s
.50476 .72819 m
.48888 .70751 L
s
.3347 .37788 m
.32892 .35226 L
s
.48888 .70751 m
.47289 .68485 L
s
.34191 .40483 m
.3347 .37788 L
s
.47289 .68485 m
.45695 .66043 L
s
.3505 .43285 m
.34191 .40483 L
s
.45695 .66043 m
.44123 .63446 L
s
.3604 .46167 m
.3505 .43285 L
s
.44123 .63446 m
.42589 .60721 L
s
.37152 .49099 m
.3604 .46167 L
s
.42589 .60721 m
.41109 .57893 L
s
.38377 .52052 m
.37152 .49099 L
s
.41109 .57893 m
.397 .54993 L
s
.397 .54993 m
.38377 .52052 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001UOol5O02fOol006=oo`9l00Eoo`=l0;=oo`00
HGoo0W`02Woo0W`0/Goo001POol00g`0Oomoo`0<Ool2O02_Ool0061oo`03O01oogoo00ioo`03O01o
ogoo0:aoo`00Ggoo00=l07ooOol047oo0W`0[7oo001NOol00g`0Oomoo`0COol2O02ZOol005ioo`03
O01oogoo01Eoo`03O01oogoo0:Moo`00GWoo00=l07ooOol05Woo00=l07ooOol0YWoo001MOol00g`0
Oomoo`0HOol00g`0Oomoo`2UOol005eoo`03O01oogoo01Uoo`03O01oogoo0:Aoo`00GGoo00=l07oo
Ool06Woo0W`0Y7oo001MOol00g`0Oomoo`0LOol00g`0Oomoo`2QOol005aoo`03O01oogoo01ioo`03
O01oogoo0:1oo`00G7oo00=l07ooOol07goo00=l07ooOol0Wgoo001LOol00g`0Oomoo`0POol00g`0
Oomoo`2NOol005aoo`03O01oogoo025oo`03O01oogoo09eoo`00Fgoo00=l07ooOol08goo00=l07oo
Ool0W7oo001KOol00g`0Oomoo`0TOol00g`0Oomoo`2KOol005]oo`03O01oogoo02Eoo`03O01oogoo
09Yoo`00Fgoo00=l07ooOol09Woo00=l07ooOol0VGoo001KOol00g`0Oomoo`0WOol00g`0Oomoo`2H
Ool005]oo`03O01oogoo02Moo`03O01oogoo09Qoo`00Fgoo00=l07ooOol0:7oo00=l07ooOol0Ugoo
001KOol00g`0Oomoo`0YOol00g`0Oomoo`2FOol005]oo`03O01oogoo02Yoo`03O01oogoo09Eoo`00
Fgoo00=l07ooOol0:Woo00=l07ooOol0UGoo001KOol00g`0Oomoo`0[Ool00g`0Oomoo`2DOol005ao
o`03O01oogoo02Yoo`03O01oogoo09Aoo`00G7oo00=l07ooOol0:goo00=l07ooOol0Tgoo001LOol0
0g`0Oomoo`0/Ool00g`0Oomoo`2BOol005aoo`03O01oogoo02eoo`03O01oogoo095oo`00G7oo00=l
07ooOol0;Goo00=l07ooOol0TGoo001LOol00g`0Oomoo`0^Ool00g`0Oomoo`2@Ool005eoo`03O01o
ogoo02ioo`03O01oogoo08moo`00GGoo00=l07ooOol0;goo00=l07ooOol0SWoo001MOol00g`0Oomo
o`0`Ool00g`0Oomoo`2=Ool005eoo`03O01oogoo031oo`03O01oogoo08eoo`00GGoo00=l07ooOol0
<Goo00=l07ooOol0S7oo001MOol00g`0Oomoo`0bOol00g`0Oomoo`2;Ool005eoo`03O01oogoo03=o
o`03O01oogoo08Yoo`00GWoo00=l07ooOol0<Woo00=l07ooOol0RWoo001NOol00g`0Oomoo`0cOol0
0g`0Oomoo`29Ool005ioo`03O01oogoo03=oo`03O01oogoo08Uoo`00GWoo00=l07ooOol0=7oo00=l
07ooOol0R7oo001NOol00g`0Oomoo`0eOol00g`0Oomoo`27Ool005moo`03O01oogoo03Aoo`03O01o
ogoo08Moo`00Ggoo00=l07ooOol0=Goo00=l07ooOol0QWoo001OOol00g`0Oomoo`0fOol00g`0Oomo
o`25Ool005moo`03O01oogoo03Ioo`03O01oogoo08Eoo`00H7oo00=l07ooOol0=Woo00=l07ooOol0
Q7oo001POol00g`0Oomoo`0fOol00g`0Oomoo`24Ool0061oo`03O01oogoo03Moo`03O01oogoo08=o
o`00H7oo00=l07ooOol0=goo00=l07ooOol0Pgoo001QOol00g`0Oomoo`0gOol00g`0Oomoo`22Ool0
065oo`03O01oogoo03Moo`03O01oogoo089oo`00HGoo00=l07ooOol0>7oo00=l07ooOol0PGoo001Q
Ool00g`0Oomoo`0hOol00g`0Oomoo`21Ool0069oo`03O01oogoo03Qoo`03O01oogoo081oo`00HWoo
00=l07ooOol0>7oo00=l07ooOol0P7oo001ROol00g`0Oomoo`0iOol00g`0Oomoo`1oOol0069oo`03
O01oogoo03Uoo`03O01oogoo07moo`00Hgoo00=l07ooOol0>Goo00=l07ooOol0OWoo001SOol00g`0
Oomoo`0jOol00g`0Oomoo`1mOol006=oo`03O01oogoo03Yoo`03O01oogoo07eoo`00Hgoo00=l07oo
Ool0>goo00=l07ooOol0O7oo001TOol00g`0Oomoo`0jOol00g`0Oomoo`1lOol006Aoo`03O01oogoo
03]oo`03O01oogoo07]oo`00I7oo00=l07ooOol0>goo00=l07ooOol0Ngoo001UOol00g`0Oomoo`0k
Ool00g`0Oomoo`1jOol006Eoo`03O01oogoo03]oo`03O01oogoo07Yoo`00IGoo00=l07ooOol0?7oo
00=l07ooOol0NGoo001VOol00g`0Oomoo`0kOol00g`0Oomoo`1iOol006Ioo`03O01oogoo03aoo`03
O01oogoo07Qoo`00Igoo00=l07ooOol0>goo00=l07ooOol0N7oo001WOol00g`0Oomoo`0lOol00g`0
Oomoo`1gOol006Moo`03O01oogoo03aoo`03O01oogoo07Moo`00J7oo00=l07ooOol0?7oo00=l07oo
Ool0MWoo001XOol00g`0Oomoo`0lOol00g`0Oomoo`1fOol006Qoo`03O01oogoo03aoo`03O01oogoo
07Ioo`00JGoo00=l07ooOol0>goo00=l07ooOol0MWoo001YOol00g`0Oomoo`0lOol00g`0Oomoo`1e
Ool006Yoo`03O01oogoo03]oo`03O01oogoo07Eoo`00JWoo00=l07ooOol0>goo00=l07ooOol0MGoo
001ZOol00g`0Oomoo`0lOol00g`0Oomoo`1dOol006]oo`03O01oogoo03]oo`03O01oogoo07Aoo`00
Jgoo00=l07ooOol0?7oo00=l07ooOol0Lgoo001/Ool00g`0Oomoo`0kOol00g`0Oomoo`1cOol006ao
o`03O01oogoo03aoo`03O01oogoo079oo`00KGoo00=l07ooOol0>goo00=l07ooOol0LWoo001]Ool0
0g`0Oomoo`0lOol00g`0Oomoo`1aOol006ioo`03O01oogoo03]oo`03O01oogoo075oo`00KWoo00=l
07ooOol0?7oo00=l07ooOol0L7oo001^Ool00g`0Oomoo`0lOol00g`0Oomoo`1`Ool006moo`03O01o
ogoo03aoo`03O01oogoo06moo`00Kgoo00=l07ooOol0?7oo00=l07ooOol0Kgoo001_Ool00g`0Oomo
o`0mOol00g`0Oomoo`1^Ool0071oo`03O01oogoo03aoo`03O01oogoo06ioo`00L7oo00=l07ooOol0
?7oo00=l07ooOol0KWoo001aOol00g`0Oomoo`0kOol00g`0Oomoo`1^Ool0075oo`03O01oogoo03ao
o`03O01oogoo06eoo`00LGoo00=l07ooOol0?7oo00=l07ooOol0KGoo001bOol00g`0Oomoo`0kOol0
0g`0Oomoo`1]Ool0079oo`03O01oogoo03aoo`03O01oogoo06aoo`00Lgoo00=l07ooOol0>goo00=l
07ooOol0K7oo001cOol00g`0Oomoo`0kOol00g`0Oomoo`1/Ool007Aoo`03O01oogoo03]oo`03O01o
ogoo06]oo`00M7oo00=l07ooOol0>goo00=l07ooOol0Jgoo001eOol00g`0Oomoo`0jOol00g`0Oomo
o`1[Ool007Eoo`03O01oogoo03]oo`03O01oogoo06Yoo`00MWoo00=l07ooOol0>Woo00=l07ooOol0
JWoo001fOol00g`0Oomoo`0jOol00g`0Oomoo`1ZOol007Moo`03O01oogoo03Uoo`03O01oogoo06Yo
o`00Mgoo00=l07ooOol0>Woo00=l07ooOol0JGoo001hOol00g`0Oomoo`0iOol00g`0Oomoo`1YOol0
07Uoo`03O01oogoo03Qoo`03O01oogoo06Uoo`00NGoo00=l07ooOol0>Goo00=l07ooOol0J7oo001j
Ool00g`0Oomoo`0hOol00g`0Oomoo`1XOol007Yoo`03O01oogoo03Qoo`03O01oogoo06Qoo`00Ngoo
00=l07ooOol0>7oo00=l07ooOol0Igoo001kOol00g`0Oomoo`0hOol00g`0Oomoo`1WOol007aoo`03
O01oogoo03Moo`03O01oogoo06Moo`00O7oo00=l07ooOol0>7oo00=l07ooOol0IWoo001mOol00g`0
Oomoo`0gOol00g`0Oomoo`1VOol007eoo`03O01oogoo03Moo`03O01oogoo06Ioo`00OWoo00=l07oo
Ool0=goo00=l07ooOol0IGoo001oOol00g`0Oomoo`0fOol00g`0Oomoo`1UOol007moo`03O01oogoo
03Ioo`03O01oogoo06Eoo`00P7oo00=l07ooOol0=Goo00=l07ooOol0IGoo0021Ool00g`0Oomoo`0d
Ool00g`0Oomoo`1UOol0089oo`03O01oogoo03Aoo`03O01oogoo06Aoo`00PWoo00=l07ooOol0=7oo
00=l07ooOol0I7oo0023Ool00g`0Oomoo`0cOol00g`0Oomoo`1TOol008Aoo`03O01oogoo039oo`03
O01oogoo06Aoo`00Q7oo00=l07ooOol0<Woo00=l07ooOol0I7oo0025Ool00g`0Oomoo`0bOol00g`0
Oomoo`1SOol008Eoo`03O01oogoo039oo`03O01oogoo06=oo`00QWoo00=l07ooOol0<Goo00=l07oo
Ool0Hgoo0026Ool00g`0Oomoo`0aOol00g`0Oomoo`1SOol008Moo`03O01oogoo031oo`03O01oogoo
06=oo`00R7oo00=l07ooOol0;goo00=l07ooOol0Hgoo0028Ool00g`0Oomoo`0`Ool00g`0Oomoo`1R
Ool008Uoo`03O01oogoo02moo`03O01oogoo069oo`00RWoo00=l07ooOol0;Woo00=l07ooOol0HWoo
002;Ool00g`0Oomoo`0]Ool00g`0Oomoo`1ROol008]oo`03O01oogoo02eoo`03O01oogoo069oo`00
S7oo00=l07ooOol0;7oo00=l07ooOol0HWoo002=Ool00g`0Oomoo`0[Ool00g`0Oomoo`1ROol008io
o`03O01oogoo02Yoo`03O01oogoo069oo`00SWoo00=l07ooOol0:Woo00=l07ooOol0HWoo002?Ool0
0g`0Oomoo`0YOol00g`0Oomoo`1ROol0091oo`03O01oogoo02Uoo`03O01oogoo065oo`00TGoo00=l
07ooOol0:7oo00=l07ooOol0HGoo002BOol00g`0Oomoo`0WOol00g`0Oomoo`1QOol0099oo`03O01o
ogoo02Moo`03O01oogoo065oo`00Tgoo00=l07ooOol09Goo00=l07ooOol0HWoo002DOol00g`0Oomo
o`0TOol00g`0Oomoo`1ROol009Eoo`03O01oogoo02=oo`03O01oogoo069oo`00UWoo00=l07ooOol0
8Woo00=l07ooOol0HWoo002GOol00g`0Oomoo`0QOol00g`0Oomoo`1ROol009Qoo`03O01oogoo021o
o`03O01oogoo069oo`00VGoo00=l07ooOol07goo00=l07ooOol0HWoo002JOol00g`0Oomoo`0NOol0
0g`0Oomoo`1ROol009]oo`03O01oogoo01aoo`03O01oogoo06=oo`00W7oo00=l07ooOol06goo00=l
07ooOol0Hgoo002MOol00g`0Oomoo`0JOol00g`0Oomoo`1SOol009ioo`03O01oogoo01Uoo`03O01o
ogoo06=oo`00Wgoo00=l07ooOol05goo00=l07ooOol0I7oo002POol00g`0Oomoo`0FOol00g`0Oomo
o`1TOol00:5oo`03O01oogoo01Aoo`03O01oogoo06Eoo`00XWoo0W`057oo00=l07ooOol0IGoo002T
Ool2O00AOol00g`0Oomoo`1VOol00:Ioo`9l00moo`03O01oogoo06Ioo`00Z7oo0g`02goo00=l07oo
Ool0Igoo002[Ool3O006Ool2O01ZOol00:ioo`Il06aoo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.57029 .46962 m
.58177 .49136 L
s
.55837 .44808 m
.57029 .46962 L
s
.54607 .42685 m
.55837 .44808 L
s
.58177 .49136 m
.59275 .5132 L
s
.53344 .40601 m
.54607 .42685 L
s
.59275 .5132 m
.60318 .53505 L
s
.52054 .38569 m
.53344 .40601 L
s
.60318 .53505 m
.61302 .5568 L
s
.50742 .36596 m
.52054 .38569 L
s
.61302 .5568 m
.6222 .57834 L
s
.49415 .34694 m
.50742 .36596 L
s
.6222 .57834 m
.63067 .59956 L
s
.48079 .32872 m
.49415 .34694 L
s
.63067 .59956 m
.63839 .62037 L
s
.4674 .31142 m
.48079 .32872 L
s
.63839 .62037 m
.64529 .64064 L
s
.45406 .29513 m
.4674 .31142 L
s
.64529 .64064 m
.65134 .66027 L
s
.44083 .27995 m
.45406 .29513 L
s
.65134 .66027 m
.65647 .67912 L
s
.42779 .26601 m
.44083 .27995 L
s
.65647 .67912 m
.66064 .69709 L
s
.41501 .2534 m
.42779 .26601 L
s
.66064 .69709 m
.6638 .71405 L
s
.40258 .24222 m
.41501 .2534 L
s
.6638 .71405 m
.66591 .72987 L
s
.39057 .2326 m
.40258 .24222 L
s
.66591 .72987 m
.66691 .74442 L
s
.37907 .22463 m
.39057 .2326 L
s
.66691 .74442 m
.66678 .75757 L
s
.36818 .21841 m
.37907 .22463 L
s
.66678 .75757 m
.66547 .76921 L
s
.35797 .21404 m
.36818 .21841 L
s
.66547 .76921 m
.66296 .77918 L
s
.34855 .21162 m
.35797 .21404 L
s
.66296 .77918 m
.65922 .78738 L
s
.34001 .21122 m
.34855 .21162 L
s
.65922 .78738 m
.65423 .79368 L
s
.33243 .21292 m
.34001 .21122 L
s
.65423 .79368 m
.64799 .79797 L
s
.32592 .21679 m
.33243 .21292 L
s
.64799 .79797 m
.64051 .80014 L
s
.32055 .22286 m
.32592 .21679 L
s
.64051 .80014 m
.63179 .80011 L
s
.31642 .23118 m
.32055 .22286 L
s
.63179 .80011 m
.62187 .79778 L
s
.3136 .24174 m
.31642 .23118 L
s
.62187 .79778 m
.61078 .79311 L
s
.31215 .25453 m
.3136 .24174 L
s
.61078 .79311 m
.59859 .78606 L
s
.31214 .26952 m
.31215 .25453 L
s
.59859 .78606 m
.58536 .77661 L
s
.31362 .28663 m
.31214 .26952 L
s
.58536 .77661 m
.5712 .76478 L
s
.31661 .30579 m
.31362 .28663 L
s
.5712 .76478 m
.55619 .7506 L
s
.32112 .32685 m
.31661 .30579 L
s
.55619 .7506 m
.54047 .73415 L
s
.32717 .34967 m
.32112 .32685 L
s
.54047 .73415 m
.52418 .71554 L
s
.33471 .37406 m
.32717 .34967 L
s
.52418 .71554 m
.50745 .6949 L
s
.34371 .39981 m
.33471 .37406 L
s
.50745 .6949 m
.49046 .6724 L
s
.35411 .42668 m
.34371 .39981 L
s
.49046 .6724 m
.47337 .64824 L
s
.36581 .45442 m
.35411 .42668 L
s
.47337 .64824 m
.45636 .62265 L
s
.37871 .48273 m
.36581 .45442 L
s
.45636 .62265 m
.43962 .59588 L
s
.39269 .51134 m
.37871 .48273 L
s
.43962 .59588 m
.42331 .56822 L
s
.40761 .53994 m
.39269 .51134 L
s
.42331 .56822 m
.40761 .53994 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001QOol4
O02kOol005moo`9l00Aoo`=l0;Qoo`00GGoo0W`02Goo0W`0]Woo001LOol00g`0Oomoo`0;Ool2O02d
Ool005]oo`03O01oogoo00ioo`03O01oogoo0;5oo`00Fgoo00=l07ooOol03goo0W`0/Goo001JOol0
0g`0Oomoo`0BOol2O02_Ool005Yoo`03O01oogoo01Aoo`03O01oogoo0:aoo`00FWoo00=l07ooOol0
5Goo00=l07ooOol0Zgoo001JOol00g`0Oomoo`0FOol00g`0Oomoo`2ZOol005Yoo`03O01oogoo01Mo
o`03O01oogoo0:Uoo`00FGoo00=l07ooOol06Goo0W`0ZGoo001IOol00g`0Oomoo`0KOol00g`0Oomo
o`2VOol005Uoo`03O01oogoo01aoo`03O01oogoo0:Eoo`00FGoo00=l07ooOol077oo00=l07ooOol0
YGoo001IOol00g`0Oomoo`0MOol00g`0Oomoo`2TOol005Uoo`03O01oogoo01ioo`03O01oogoo0:=o
o`00FGoo00=l07ooOol07goo00=l07ooOol0XWoo001IOol00g`0Oomoo`0POol00g`0Oomoo`2QOol0
05Uoo`03O01oogoo025oo`03O01oogoo0:1oo`00FWoo00=l07ooOol08Goo00=l07ooOol0Wgoo001J
Ool00g`0Oomoo`0ROol00g`0Oomoo`2NOol005Yoo`03O01oogoo02=oo`03O01oogoo09eoo`00FWoo
00=l07ooOol097oo00=l07ooOol0W7oo001JOol00g`0Oomoo`0UOol00g`0Oomoo`2KOol005Yoo`03
O01oogoo02Ioo`03O01oogoo09Yoo`00FWoo00=l07ooOol09goo00=l07ooOol0VGoo001JOol00g`0
Oomoo`0WOol00g`0Oomoo`2IOol005Yoo`03O01oogoo02Qoo`03O01oogoo09Qoo`00Fgoo00=l07oo
Ool0:7oo00=l07ooOol0Ugoo001KOol00g`0Oomoo`0YOol00g`0Oomoo`2FOol005]oo`03O01oogoo
02Uoo`03O01oogoo09Ioo`00G7oo00=l07ooOol0:Goo00=l07ooOol0UGoo001LOol00g`0Oomoo`0Y
Ool00g`0Oomoo`2EOol005aoo`03O01oogoo02Yoo`03O01oogoo09Aoo`00G7oo00=l07ooOol0:goo
00=l07ooOol0Tgoo001LOol00g`0Oomoo`0/Ool00g`0Oomoo`2BOol005eoo`03O01oogoo02]oo`03
O01oogoo099oo`00GGoo00=l07ooOol0;7oo00=l07ooOol0TGoo001MOol00g`0Oomoo`0]Ool00g`0
Oomoo`2@Ool005eoo`03O01oogoo02ioo`03O01oogoo08moo`00GGoo00=l07ooOol0;Woo00=l07oo
Ool0Sgoo001NOol00g`0Oomoo`0^Ool00g`0Oomoo`2>Ool005ioo`03O01oogoo02moo`03O01oogoo
08eoo`00Ggoo00=l07ooOol0;Woo00=l07ooOol0SGoo001OOol00g`0Oomoo`0_Ool00g`0Oomoo`2<
Ool0061oo`03O01oogoo02moo`03O01oogoo08]oo`00H7oo00=l07ooOol0<7oo00=l07ooOol0RWoo
001POol00g`0Oomoo`0`Ool00g`0Oomoo`2:Ool0065oo`03O01oogoo031oo`03O01oogoo08Uoo`00
HGoo00=l07ooOol0<Goo00=l07ooOol0R7oo001QOol00g`0Oomoo`0bOol00g`0Oomoo`27Ool0065o
o`03O01oogoo039oo`03O01oogoo08Moo`00HWoo00=l07ooOol0<Woo00=l07ooOol0QWoo001ROol0
0g`0Oomoo`0cOol00g`0Oomoo`25Ool0069oo`03O01oogoo03=oo`03O01oogoo08Eoo`00Hgoo00=l
07ooOol0<goo00=l07ooOol0Q7oo001SOol00g`0Oomoo`0cOol00g`0Oomoo`24Ool006=oo`03O01o
ogoo03Aoo`03O01oogoo08=oo`00I7oo00=l07ooOol0<goo00=l07ooOol0Pgoo001TOol00g`0Oomo
o`0dOol00g`0Oomoo`22Ool006Eoo`03O01oogoo03=oo`03O01oogoo089oo`00IGoo00=l07ooOol0
=7oo00=l07ooOol0PGoo001UOol00g`0Oomoo`0eOol00g`0Oomoo`20Ool006Ioo`03O01oogoo03Ao
o`03O01oogoo081oo`00IWoo00=l07ooOol0=Goo00=l07ooOol0Ogoo001VOol00g`0Oomoo`0fOol0
0g`0Oomoo`1nOol006Moo`03O01oogoo03Eoo`03O01oogoo07ioo`00Igoo00=l07ooOol0=Woo00=l
07ooOol0OGoo001XOol00g`0Oomoo`0eOol00g`0Oomoo`1mOol006Qoo`03O01oogoo03Ioo`03O01o
ogoo07aoo`00J7oo00=l07ooOol0=Woo00=l07ooOol0O7oo001YOol00g`0Oomoo`0fOol00g`0Oomo
o`1kOol006Uoo`03O01oogoo03Ioo`03O01oogoo07]oo`00JWoo00=l07ooOol0=Woo00=l07ooOol0
NWoo001ZOol00g`0Oomoo`0fOol00g`0Oomoo`1jOol006]oo`03O01oogoo03Ioo`03O01oogoo07Uo
o`00Jgoo00=l07ooOol0=Woo00=l07ooOol0NGoo001/Ool00g`0Oomoo`0fOol00g`0Oomoo`1hOol0
06aoo`03O01oogoo03Ioo`03O01oogoo07Qoo`00KGoo00=l07ooOol0=Woo00=l07ooOol0Mgoo001]
Ool00g`0Oomoo`0fOol00g`0Oomoo`1gOol006ioo`03O01oogoo03Ioo`03O01oogoo07Ioo`00KWoo
00=l07ooOol0=Woo00=l07ooOol0MWoo001_Ool00g`0Oomoo`0fOol00g`0Oomoo`1eOol006moo`03
O01oogoo03Moo`03O01oogoo07Aoo`00L7oo00=l07ooOol0=Woo00=l07ooOol0M7oo001`Ool00g`0
Oomoo`0gOol00g`0Oomoo`1cOol0075oo`03O01oogoo03Ioo`03O01oogoo07=oo`00LGoo00=l07oo
Ool0=goo00=l07ooOol0LWoo001bOol00g`0Oomoo`0fOol00g`0Oomoo`1bOol0079oo`03O01oogoo
03Moo`03O01oogoo075oo`00Lgoo00=l07ooOol0=Woo00=l07ooOol0LGoo001cOol00g`0Oomoo`0g
Ool00g`0Oomoo`1`Ool007Aoo`03O01oogoo03Ioo`03O01oogoo071oo`00MGoo00=l07ooOol0=Woo
00=l07ooOol0Kgoo001eOol00g`0Oomoo`0fOol00g`0Oomoo`1_Ool007Ioo`03O01oogoo03Eoo`03
O01oogoo06moo`00MWoo00=l07ooOol0=Woo00=l07ooOol0KWoo001gOol00g`0Oomoo`0eOol00g`0
Oomoo`1^Ool007Moo`03O01oogoo03Eoo`03O01oogoo06ioo`00N7oo00=l07ooOol0=Goo00=l07oo
Ool0KGoo001hOol00g`0Oomoo`0eOol00g`0Oomoo`1]Ool007Uoo`03O01oogoo03Eoo`03O01oogoo
06aoo`00NWoo00=l07ooOol0=7oo00=l07ooOol0K7oo001jOol00g`0Oomoo`0eOol00g`0Oomoo`1[
Ool007]oo`03O01oogoo03Aoo`03O01oogoo06]oo`00Ngoo00=l07ooOol0=Goo00=l07ooOol0JWoo
001lOol00g`0Oomoo`0dOol00g`0Oomoo`1ZOol007eoo`03O01oogoo03Aoo`03O01oogoo06Uoo`00
OGoo00=l07ooOol0=7oo00=l07ooOol0JGoo001nOol00g`0Oomoo`0dOol00g`0Oomoo`1XOol007mo
o`03O01oogoo03=oo`03O01oogoo06Qoo`00Ogoo00=l07ooOol0<goo00=l07ooOol0J7oo0020Ool0
0g`0Oomoo`0cOol00g`0Oomoo`1WOol0081oo`03O01oogoo03=oo`03O01oogoo06Moo`00PGoo00=l
07ooOol0<Woo00=l07ooOol0Igoo0021Ool00g`0Oomoo`0cOol00g`0Oomoo`1VOol0089oo`03O01o
ogoo039oo`03O01oogoo06Ioo`00Pgoo00=l07ooOol0<Goo00=l07ooOol0IWoo0023Ool00g`0Oomo
o`0bOol00g`0Oomoo`1UOol008Aoo`03O01oogoo035oo`03O01oogoo06Eoo`00Q7oo00=l07ooOol0
<Woo00=l07ooOol0I7oo0025Ool00g`0Oomoo`0aOol00g`0Oomoo`1TOol008Ioo`03O01oogoo031o
o`03O01oogoo06Aoo`00QWoo00=l07ooOol0<7oo00=l07ooOol0I7oo0027Ool00g`0Oomoo`0_Ool0
0g`0Oomoo`1TOol008Qoo`03O01oogoo02moo`03O01oogoo06=oo`00RGoo00=l07ooOol0;Woo00=l
07ooOol0Hgoo0029Ool00g`0Oomoo`0^Ool00g`0Oomoo`1SOol008Yoo`03O01oogoo02eoo`03O01o
ogoo06=oo`00Rgoo00=l07ooOol0;Goo00=l07ooOol0HWoo002<Ool00g`0Oomoo`0/Ool00g`0Oomo
o`1ROol008eoo`03O01oogoo02aoo`03O01oogoo065oo`00SGoo00=l07ooOol0;7oo00=l07ooOol0
HGoo002>Ool00g`0Oomoo`0[Ool00g`0Oomoo`1QOol008moo`03O01oogoo02Yoo`03O01oogoo065o
o`00T7oo00=l07ooOol0:Goo00=l07ooOol0HGoo002@Ool00g`0Oomoo`0ZOol00g`0Oomoo`1POol0
095oo`03O01oogoo02Uoo`03O01oogoo061oo`00TWoo00=l07ooOol0:7oo00=l07ooOol0H7oo002C
Ool00g`0Oomoo`0WOol00g`0Oomoo`1POol009=oo`03O01oogoo02Moo`03O01oogoo061oo`00U7oo
00=l07ooOol09goo00=l07ooOol0Ggoo002EOol00g`0Oomoo`0VOol00g`0Oomoo`1OOol009Ioo`03
O01oogoo02Eoo`03O01oogoo05moo`00Ugoo00=l07ooOol097oo00=l07ooOol0Ggoo002HOol00g`0
Oomoo`0TOol00g`0Oomoo`1NOol009Uoo`03O01oogoo02=oo`03O01oogoo05ioo`00VWoo00=l07oo
Ool08Woo00=l07ooOol0GWoo002KOol00g`0Oomoo`0QOol00g`0Oomoo`1NOol009aoo`03O01oogoo
021oo`03O01oogoo05ioo`00WGoo00=l07ooOol07goo00=l07ooOol0GWoo002MOol00g`0Oomoo`0O
Ool00g`0Oomoo`1NOol009ioo`03O01oogoo01ioo`03O01oogoo05ioo`00Wgoo00=l07ooOol07Goo
00=l07ooOol0GWoo002POol00g`0Oomoo`0LOol00g`0Oomoo`1NOol00:5oo`03O01oogoo01]oo`03
O01oogoo05ioo`00XWoo00=l07ooOol06Woo00=l07ooOol0GWoo002SOol00g`0Oomoo`0HOol00g`0
Oomoo`1OOol00:Aoo`9l01Qoo`03O01oogoo05moo`00YWoo0W`05Woo00=l07ooOol0Ggoo002XOol0
0g`0Oomoo`0COol00g`0Oomoo`1OOol00:Uoo`03O01oogoo019oo`03O01oogoo05moo`00ZWoo00=l
07ooOol047oo00=l07ooOol0H7oo002[Ool00g`0Oomoo`0?Ool00g`0Oomoo`1POol00:aoo`9l00io
o`03O01oogoo065oo`00[Woo0g`02Woo00=l07ooOol0HWoo002aOol3O006Ool00g`0Oomoo`1SOol0
0;Aoo`Il06Ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.55055 .45638 m
.56374 .47713 L
s
.53703 .43589 m
.55055 .45638 L
s
.56374 .47713 m
.57653 .49805 L
s
.52324 .41576 m
.53703 .43589 L
s
.57653 .49805 m
.58888 .51903 L
s
.50925 .39608 m
.52324 .41576 L
s
.58888 .51903 m
.60072 .54 L
s
.49512 .37695 m
.50925 .39608 L
s
.60072 .54 m
.61199 .56083 L
s
.48091 .35847 m
.49512 .37695 L
s
.61199 .56083 m
.62263 .58145 L
s
.4667 .34073 m
.48091 .35847 L
s
.62263 .58145 m
.63257 .60173 L
s
.45254 .32383 m
.4667 .34073 L
s
.63257 .60173 m
.64177 .62158 L
s
.43852 .30787 m
.45254 .32383 L
s
.64177 .62158 m
.65016 .64088 L
s
.42472 .29295 m
.43852 .30787 L
s
.65016 .64088 m
.65768 .65954 L
s
.41119 .27918 m
.42472 .29295 L
s
.65768 .65954 m
.66427 .67742 L
s
.39804 .26665 m
.41119 .27918 L
s
.66427 .67742 m
.66987 .69442 L
s
.38534 .25547 m
.39804 .26665 L
s
.66987 .69442 m
.67442 .71042 L
s
.37318 .24574 m
.38534 .25547 L
s
.67442 .71042 m
.67787 .72529 L
s
.36164 .23757 m
.37318 .24574 L
s
.67787 .72529 m
.68017 .7389 L
s
.35082 .23105 m
.36164 .23757 L
s
.68017 .7389 m
.68125 .75115 L
s
.34082 .22628 m
.35082 .23105 L
s
.68125 .75115 m
.68109 .76189 L
s
.33172 .22334 m
.34082 .22628 L
s
.68109 .76189 m
.67963 .77101 L
s
.32362 .22234 m
.33172 .22334 L
s
.67963 .77101 m
.67684 .77838 L
s
.31661 .22332 m
.32362 .22234 L
s
.67684 .77838 m
.67269 .7839 L
s
.31079 .22637 m
.31661 .22332 L
s
.67269 .7839 m
.66717 .78745 L
s
.30625 .23153 m
.31079 .22637 L
s
.66717 .78745 m
.66026 .78894 L
s
.30305 .23884 m
.30625 .23153 L
s
.66026 .78894 m
.65199 .78828 L
s
.30128 .24831 m
.30305 .23884 L
s
.65199 .78828 m
.64236 .7854 L
s
.30101 .25994 m
.30128 .24831 L
s
.64236 .7854 m
.63141 .78024 L
s
.30228 .2737 m
.30101 .25994 L
s
.63141 .78024 m
.61919 .77279 L
s
.30513 .28953 m
.30228 .2737 L
s
.61919 .77279 m
.60578 .76302 L
s
.30959 .30735 m
.30513 .28953 L
s
.60578 .76302 m
.59125 .75097 L
s
.31567 .32705 m
.30959 .30735 L
s
.59125 .75097 m
.57573 .73667 L
s
.32334 .3485 m
.31567 .32705 L
s
.57573 .73667 m
.55932 .72021 L
s
.33257 .37153 m
.32334 .3485 L
s
.55932 .72021 m
.54217 .7017 L
s
.34331 .39593 m
.33257 .37153 L
s
.54217 .7017 m
.52445 .68127 L
s
.35547 .42149 m
.34331 .39593 L
s
.52445 .68127 m
.50631 .65911 L
s
.36896 .44796 m
.35547 .42149 L
s
.50631 .65911 m
.48794 .63541 L
s
.38364 .47508 m
.36896 .44796 L
s
.48794 .63541 m
.46954 .6104 L
s
.39938 .50257 m
.38364 .47508 L
s
.46954 .6104 m
.45129 .58434 L
s
.41602 .53014 m
.39938 .50257 L
s
.45129 .58434 m
.43338 .55749 L
s
.43338 .55749 m
.41602 .53014 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.54451 .46434 m
.55898 .48417 L
s
.52975 .44473 m
.54451 .46434 L
s
.55898 .48417 m
.5731 .50413 L
s
.51478 .42544 m
.52975 .44473 L
s
.5731 .50413 m
.5868 .52414 L
s
.49966 .40655 m
.51478 .42544 L
s
.5868 .52414 m
.60002 .54409 L
s
.48446 .38815 m
.49966 .40655 L
s
.60002 .54409 m
.61269 .56389 L
s
.46925 .37034 m
.48446 .38815 L
s
.61269 .56389 m
.62474 .58345 L
s
.45411 .3532 m
.46925 .37034 L
s
.62474 .58345 m
.63611 .60267 L
s
.43911 .33684 m
.45411 .3532 L
s
.63611 .60267 m
.64672 .62145 L
s
.42432 .32134 m
.43911 .33684 L
s
.64672 .62145 m
.65652 .63968 L
s
.40983 .3068 m
.42432 .32134 L
s
.65652 .63968 m
.66543 .65726 L
s
.39571 .29333 m
.40983 .3068 L
s
.66543 .65726 m
.67338 .67408 L
s
.38206 .281 m
.39571 .29333 L
s
.67338 .67408 m
.68031 .69002 L
s
.36896 .26994 m
.38206 .281 L
s
.68031 .69002 m
.68614 .70497 L
s
.35651 .26022 m
.36896 .26994 L
s
.68614 .70497 m
.69082 .71882 L
s
.34478 .25196 m
.35651 .26022 L
s
.69082 .71882 m
.69427 .73144 L
s
.33389 .24524 m
.34478 .25196 L
s
.69427 .73144 m
.69644 .74272 L
s
.32392 .24015 m
.33389 .24524 L
s
.69644 .74272 m
.69727 .75253 L
s
.31498 .2368 m
.32392 .24015 L
s
.69727 .75253 m
.69671 .76076 L
s
.30716 .23526 m
.31498 .2368 L
s
.69671 .76076 m
.69471 .7673 L
s
.30055 .2356 m
.30716 .23526 L
s
.69471 .7673 m
.69123 .77204 L
s
.29524 .23788 m
.30055 .2356 L
s
.69123 .77204 m
.68626 .77487 L
s
.29133 .24218 m
.29524 .23788 L
s
.68626 .77487 m
.67976 .77571 L
s
.2889 .24851 m
.29133 .24218 L
s
.67976 .77571 m
.67176 .77447 L
s
.28801 .2569 m
.2889 .24851 L
s
.67176 .77447 m
.66224 .7711 L
s
.28874 .26736 m
.28801 .2569 L
s
.66224 .7711 m
.65125 .76556 L
s
.29112 .27986 m
.28874 .26736 L
s
.65125 .76556 m
.63884 .7578 L
s
.29519 .29437 m
.29112 .27986 L
s
.63884 .7578 m
.62506 .74784 L
s
.30098 .3108 m
.29519 .29437 L
s
.62506 .74784 m
.61002 .73571 L
s
.30847 .32907 m
.30098 .3108 L
s
.61002 .73571 m
.59381 .72145 L
s
.31765 .34905 m
.30847 .32907 L
s
.59381 .72145 m
.57656 .70515 L
s
.32846 .37059 m
.31765 .34905 L
s
.57656 .70515 m
.55843 .68692 L
s
.34083 .39351 m
.32846 .37059 L
s
.55843 .68692 m
.53958 .66691 L
s
.35468 .41761 m
.34083 .39351 L
s
.53958 .66691 m
.52019 .64529 L
s
.36989 .44265 m
.35468 .41761 L
s
.52019 .64529 m
.50045 .62227 L
s
.38631 .46838 m
.36989 .44265 L
s
.50045 .62227 m
.48056 .59806 L
s
.40379 .49456 m
.38631 .46838 L
s
.48056 .59806 m
.46075 .57292 L
s
.42216 .52089 m
.40379 .49456 L
s
.46075 .57292 m
.44121 .54711 L
s
.44121 .54711 m
.42216 .52089 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol005Ioo`El0<Eo
o`00E7oo0W`01Goo0W`0`goo001COol00g`0Oomoo`07Ool2O031Ool0059oo`03O01oogoo00Yoo`03
O01oogoo0;ioo`00DWoo00=l07ooOol02goo0W`0_Woo001BOol00g`0Oomoo`0=Ool00g`0Oomoo`2k
Ool0059oo`03O01oogoo00ioo`9l0;]oo`00DWoo00=l07ooOol047oo0W`0^Goo001BOol00g`0Oomo
o`0BOol00g`0Oomoo`2fOol0059oo`03O01oogoo01=oo`03O01oogoo0;Eoo`00DWoo00=l07ooOol0
57oo00=l07ooOol0]7oo001BOol00g`0Oomoo`0EOol00g`0Oomoo`2cOol005=oo`03O01oogoo01Eo
o`9l0;=oo`00Dgoo00=l07ooOol05goo00=l07ooOol0/7oo001COol00g`0Oomoo`0HOol00g`0Oomo
o`2_Ool005=oo`03O01oogoo01Uoo`03O01oogoo0:ioo`00E7oo00=l07ooOol06Goo00=l07ooOol0
[Goo001DOol00g`0Oomoo`0JOol00g`0Oomoo`2/Ool005Aoo`03O01oogoo01]oo`03O01oogoo0:]o
o`00EGoo00=l07ooOol06goo00=l07ooOol0ZWoo001EOol00g`0Oomoo`0LOol00g`0Oomoo`2YOol0
05Ioo`03O01oogoo01aoo`03O01oogoo0:Qoo`00EWoo00=l07ooOol07Goo00=l07ooOol0Ygoo001F
Ool00g`0Oomoo`0NOol00g`0Oomoo`2VOol005Moo`03O01oogoo01ioo`03O01oogoo0:Eoo`00Egoo
00=l07ooOol07goo00=l07ooOol0Y7oo001HOol00g`0Oomoo`0OOol00g`0Oomoo`2SOol005Qoo`03
O01oogoo021oo`9l0:=oo`00F7oo00=l07ooOol08Woo00=l07ooOol0X7oo001IOol00g`0Oomoo`0R
Ool00g`0Oomoo`2OOol005Uoo`03O01oogoo02=oo`03O01oogoo09ioo`00FWoo00=l07ooOol08goo
00=l07ooOol0WGoo001JOol00g`0Oomoo`0SOol00g`0Oomoo`2MOol005]oo`03O01oogoo02=oo`03
O01oogoo09aoo`00Fgoo00=l07ooOol097oo00=l07ooOol0Vgoo001LOol00g`0Oomoo`0TOol00g`0
Oomoo`2JOol005aoo`03O01oogoo02Eoo`03O01oogoo09Uoo`00GGoo00=l07ooOol097oo00=l07oo
Ool0VGoo001MOol00g`0Oomoo`0UOol00g`0Oomoo`2HOol005ioo`03O01oogoo02Eoo`03O01oogoo
09Moo`00GWoo00=l07ooOol09Woo00=l07ooOol0UWoo001OOol00g`0Oomoo`0VOol00g`0Oomoo`2E
Ool005moo`03O01oogoo02Moo`03O01oogoo09Aoo`00H7oo00=l07ooOol09goo00=l07ooOol0Tgoo
001POol00g`0Oomoo`0XOol00g`0Oomoo`2BOol0065oo`03O01oogoo02Qoo`03O01oogoo095oo`00
HWoo00=l07ooOol0:7oo00=l07ooOol0T7oo001ROol00g`0Oomoo`0XOol00g`0Oomoo`2@Ool006=o
o`03O01oogoo02Qoo`03O01oogoo08moo`00Hgoo00=l07ooOol0:Goo00=l07ooOol0SWoo001TOol0
0g`0Oomoo`0YOol00g`0Oomoo`2=Ool006Aoo`03O01oogoo02Uoo`03O01oogoo08eoo`00IGoo00=l
07ooOol0:Goo00=l07ooOol0S7oo001VOol00g`0Oomoo`0YOol00g`0Oomoo`2;Ool006Ioo`03O01o
ogoo02Uoo`03O01oogoo08]oo`00Igoo00=l07ooOol0:Goo00=l07ooOol0RWoo001WOol00g`0Oomo
o`0ZOol00g`0Oomoo`29Ool006Qoo`03O01oogoo02Yoo`03O01oogoo08Qoo`00JGoo00=l07ooOol0
:Woo00=l07ooOol0Qgoo001YOol00g`0Oomoo`0[Ool00g`0Oomoo`26Ool006Yoo`03O01oogoo02]o
o`03O01oogoo08Eoo`00Jgoo00=l07ooOol0:goo00=l07ooOol0Q7oo001[Ool00g`0Oomoo`0[Ool0
0g`0Oomoo`24Ool006aoo`03O01oogoo02]oo`03O01oogoo08=oo`00K7oo00=l07ooOol0;7oo00=l
07ooOol0PWoo001]Ool00g`0Oomoo`0[Ool00g`0Oomoo`22Ool006eoo`03O01oogoo02aoo`03O01o
ogoo085oo`00KWoo00=l07ooOol0;7oo00=l07ooOol0P7oo001_Ool00g`0Oomoo`0/Ool00g`0Oomo
o`1oOol006moo`03O01oogoo02aoo`03O01oogoo07moo`00L7oo00=l07ooOol0;7oo00=l07ooOol0
OWoo001aOol00g`0Oomoo`0/Ool00g`0Oomoo`1mOol0079oo`03O01oogoo02aoo`03O01oogoo07ao
o`00LWoo00=l07ooOol0;7oo00=l07ooOol0O7oo001cOol00g`0Oomoo`0/Ool00g`0Oomoo`1kOol0
07Aoo`03O01oogoo02aoo`03O01oogoo07Yoo`00M7oo00=l07ooOol0;7oo00=l07ooOol0NWoo001e
Ool00g`0Oomoo`0/Ool00g`0Oomoo`1iOol007Ioo`03O01oogoo02aoo`03O01oogoo07Qoo`00Mgoo
00=l07ooOol0:goo00=l07ooOol0N7oo001gOol00g`0Oomoo`0/Ool00g`0Oomoo`1gOol007Qoo`03
O01oogoo02aoo`03O01oogoo07Ioo`00NGoo00=l07ooOol0:goo00=l07ooOol0MWoo001jOol00g`0
Oomoo`0[Ool00g`0Oomoo`1eOol007Yoo`03O01oogoo02aoo`03O01oogoo07Aoo`00Ngoo00=l07oo
Ool0:goo00=l07ooOol0M7oo001kOol00g`0Oomoo`0/Ool00g`0Oomoo`1cOol007aoo`03O01oogoo
02aoo`03O01oogoo079oo`00OGoo00=l07ooOol0:goo00=l07ooOol0LWoo001mOol00g`0Oomoo`0/
Ool00g`0Oomoo`1aOol007ioo`03O01oogoo02aoo`03O01oogoo071oo`00Ogoo00=l07ooOol0:goo
00=l07ooOol0L7oo0020Ool00g`0Oomoo`0[Ool00g`0Oomoo`1_Ool0085oo`03O01oogoo02Yoo`03
O01oogoo06moo`00PGoo00=l07ooOol0:goo00=l07ooOol0KWoo0022Ool00g`0Oomoo`0[Ool00g`0
Oomoo`1]Ool008=oo`03O01oogoo02Yoo`03O01oogoo06eoo`00Q7oo00=l07ooOol0:Woo00=l07oo
Ool0K7oo0025Ool00g`0Oomoo`0ZOol00g`0Oomoo`1[Ool008Eoo`03O01oogoo02Yoo`03O01oogoo
06]oo`00QWoo00=l07ooOol0:Woo00=l07ooOol0JWoo0027Ool00g`0Oomoo`0ZOol00g`0Oomoo`1Y
Ool008Qoo`03O01oogoo02Uoo`03O01oogoo06Uoo`00R7oo00=l07ooOol0:Woo00=l07ooOol0J7oo
0029Ool00g`0Oomoo`0YOol00g`0Oomoo`1XOol008Yoo`03O01oogoo02Uoo`03O01oogoo06Moo`00
Rgoo00=l07ooOol0:7oo00=l07ooOol0Igoo002<Ool00g`0Oomoo`0XOol00g`0Oomoo`1VOol008ao
o`03O01oogoo02Qoo`03O01oogoo06Ioo`00SGoo00=l07ooOol0:7oo00=l07ooOol0IGoo002>Ool0
0g`0Oomoo`0WOol00g`0Oomoo`1UOol008moo`03O01oogoo02Moo`03O01oogoo06Aoo`00T7oo00=l
07ooOol09goo00=l07ooOol0Hgoo002AOol00g`0Oomoo`0VOol00g`0Oomoo`1SOol0099oo`03O01o
ogoo02Ioo`03O01oogoo069oo`00TWoo00=l07ooOol09Woo00=l07ooOol0HWoo002COol00g`0Oomo
o`0VOol00g`0Oomoo`1QOol009Aoo`03O01oogoo02Eoo`03O01oogoo065oo`00UGoo00=l07ooOol0
9Goo00=l07ooOol0H7oo002FOol00g`0Oomoo`0TOol00g`0Oomoo`1POol009Moo`03O01oogoo02Ao
o`03O01oogoo05moo`00Ugoo00=l07ooOol097oo00=l07ooOol0Ggoo002HOol00g`0Oomoo`0TOol0
0g`0Oomoo`1NOol009Uoo`03O01oogoo02=oo`03O01oogoo05ioo`00VWoo00=l07ooOol08goo00=l
07ooOol0GGoo002KOol00g`0Oomoo`0ROol00g`0Oomoo`1MOol009aoo`03O01oogoo029oo`03O01o
ogoo05aoo`00WGoo00=l07ooOol08Goo00=l07ooOol0G7oo002NOol00g`0Oomoo`0QOol00g`0Oomo
o`1KOol009moo`03O01oogoo021oo`03O01oogoo05]oo`00X7oo00=l07ooOol087oo00=l07ooOol0
FWoo002QOol00g`0Oomoo`0OOol00g`0Oomoo`1JOol00:9oo`03O01oogoo01ioo`03O01oogoo05Yo
o`00Xgoo00=l07ooOol07Goo00=l07ooOol0FWoo002TOol00g`0Oomoo`0MOol00g`0Oomoo`1IOol0
0:Eoo`03O01oogoo01aoo`03O01oogoo05Uoo`00YWoo00=l07ooOol06goo00=l07ooOol0FGoo002W
Ool00g`0Oomoo`0KOol00g`0Oomoo`1HOol00:Qoo`03O01oogoo01Yoo`03O01oogoo05Qoo`00ZGoo
00=l07ooOol06Woo00=l07ooOol0Egoo002ZOol00g`0Oomoo`0IOol00g`0Oomoo`1GOol00:]oo`03
O01oogoo01Uoo`03O01oogoo05Ioo`00[7oo0W`06Goo00=l07ooOol0EWoo002^Ool00g`0Oomoo`0F
Ool00g`0Oomoo`1FOol00:moo`03O01oogoo01Eoo`03O01oogoo05Ioo`00/7oo00=l07ooOol057oo
00=l07ooOol0EWoo002aOol2O00DOol00g`0Oomoo`1FOol00;=oo`03O01oogoo015oo`03O01oogoo
05Ioo`00]7oo00=l07ooOol04Goo00=l07ooOol0EGoo002eOol2O00AOol00g`0Oomoo`1EOol00;Mo
o`03O01oogoo00eoo`03O01oogoo05Ioo`00^7oo0W`03Goo00=l07ooOol0EWoo002jOol00g`0Oomo
o`0:Ool00g`0Oomoo`1FOol00;]oo`9l00Yoo`03O01oogoo05Ioo`00_Goo0W`01goo00=l07ooOol0
Egoo002oOol7O01JOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.54026 .47171 m
.556 .49049 L
s
.52427 .45311 m
.54026 .47171 L
s
.50811 .43478 m
.52427 .45311 L
s
.556 .49049 m
.57142 .50937 L
s
.49184 .41681 m
.50811 .43478 L
s
.57142 .50937 m
.58644 .52827 L
s
.47554 .39928 m
.49184 .41681 L
s
.58644 .52827 m
.601 .54709 L
s
.4593 .38227 m
.47554 .39928 L
s
.601 .54709 m
.61501 .56574 L
s
.44317 .36588 m
.4593 .38227 L
s
.61501 .56574 m
.62841 .58415 L
s
.42725 .35019 m
.44317 .36588 L
s
.62841 .58415 m
.64113 .6022 L
s
.41162 .33529 m
.42725 .35019 L
s
.64113 .6022 m
.65308 .61981 L
s
.39636 .32127 m
.41162 .33529 L
s
.65308 .61981 m
.66419 .63688 L
s
.38156 .30822 m
.39636 .32127 L
s
.66419 .63688 m
.67439 .6533 L
s
.36731 .29624 m
.38156 .30822 L
s
.67439 .6533 m
.68359 .66897 L
s
.35369 .28541 m
.36731 .29624 L
s
.68359 .66897 m
.69173 .68379 L
s
.34082 .27583 m
.35369 .28541 L
s
.69173 .68379 m
.69872 .69764 L
s
.32877 .26759 m
.34082 .27583 L
s
.69872 .69764 m
.70448 .71042 L
s
.31766 .26079 m
.32877 .26759 L
s
.70448 .71042 m
.70895 .72201 L
s
.30757 .25551 m
.31766 .26079 L
s
.70895 .72201 m
.71205 .7323 L
s
.29862 .25184 m
.30757 .25551 L
s
.71205 .7323 m
.71372 .74117 L
s
.2909 .24985 m
.29862 .25184 L
s
.71372 .74117 m
.7139 .74853 L
s
.28451 .24963 m
.2909 .24985 L
s
.7139 .74853 m
.71252 .75425 L
s
.27955 .25123 m
.28451 .24963 L
s
.71252 .75425 m
.70955 .75824 L
s
.27609 .25472 m
.27955 .25123 L
s
.70955 .75824 m
.70495 .7604 L
s
.27424 .26013 m
.27609 .25472 L
s
.70495 .7604 m
.6987 .76066 L
s
.27405 .26748 m
.27424 .26013 L
s
.6987 .76066 m
.69078 .75894 L
s
.27558 .2768 m
.27405 .26748 L
s
.69078 .75894 m
.68121 .75518 L
s
.2789 .28805 m
.27558 .2768 L
s
.68121 .75518 m
.67001 .74935 L
s
.28402 .30122 m
.2789 .28805 L
s
.67001 .74935 m
.65723 .74143 L
s
.29096 .31624 m
.28402 .30122 L
s
.65723 .74143 m
.64293 .73143 L
s
.29971 .33303 m
.29096 .31624 L
s
.64293 .73143 m
.62721 .71938 L
s
.31024 .35148 m
.29971 .33303 L
s
.62721 .71938 m
.61018 .70533 L
s
.32249 .37145 m
.31024 .35148 L
s
.61018 .70533 m
.59196 .68938 L
s
.33639 .39279 m
.32249 .37145 L
s
.59196 .68938 m
.57272 .67163 L
s
.35182 .41529 m
.33639 .39279 L
s
.57272 .67163 m
.55264 .65224 L
s
.36866 .43876 m
.35182 .41529 L
s
.55264 .65224 m
.5319 .63138 L
s
.38675 .46297 m
.36866 .43876 L
s
.5319 .63138 m
.51071 .60924 L
s
.40592 .48766 m
.38675 .46297 L
s
.51071 .60924 m
.4893 .58604 L
s
.42598 .51257 m
.40592 .48766 L
s
.4893 .58604 m
.46789 .56203 L
s
.4467 .53745 m
.42598 .51257 L
s
.46789 .56203 m
.4467 .53745 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00DGoo0g`0c7oo001@Ool017`0Oomoogoo0g`0bGoo001?Ool0
0g`0Oomoo`05Ool3O036Ool004ioo`03O01oogoo00Uoo`9l0<Aoo`00CWoo00=l07ooOol02goo0W`0
`Woo001>Ool00g`0Oomoo`0=Ool00g`0Oomoo`2oOol004ioo`03O01oogoo00ioo`03O01oogoo0;io
o`00Cgoo00=l07ooOol03Woo00=l07ooOol0_Goo001?Ool00g`0Oomoo`0?Ool00g`0Oomoo`2lOol0
04moo`03O01oogoo011oo`9l0;aoo`00D7oo00=l07ooOol04Goo0W`0^Woo001@Ool00g`0Oomoo`0C
Ool00g`0Oomoo`2gOol0051oo`03O01oogoo01Aoo`03O01oogoo0;Ioo`00D7oo00=l07ooOol05Goo
00=l07ooOol0]Goo001AOol00g`0Oomoo`0EOol00g`0Oomoo`2dOol0055oo`03O01oogoo01Ioo`03
O01oogoo0;=oo`00DGoo00=l07ooOol05goo0W`0/goo001BOol00g`0Oomoo`0HOol00g`0Oomoo`2`
Ool0059oo`03O01oogoo01Uoo`03O01oogoo0:moo`00Dgoo00=l07ooOol06Goo00=l07ooOol0[Woo
001DOol00g`0Oomoo`0IOol00g`0Oomoo`2]Ool005Aoo`03O01oogoo01Yoo`03O01oogoo0:aoo`00
EGoo00=l07ooOol06Woo00=l07ooOol0Zgoo001EOol00g`0Oomoo`0KOol2O02[Ool005Ioo`03O01o
ogoo01aoo`03O01oogoo0:Qoo`00Egoo00=l07ooOol077oo00=l07ooOol0Ygoo001GOol00g`0Oomo
o`0MOol00g`0Oomoo`2VOol005Qoo`03O01oogoo01eoo`03O01oogoo0:Eoo`00F7oo00=l07ooOol0
7Woo00=l07ooOol0Y7oo001IOol00g`0Oomoo`0NOol00g`0Oomoo`2SOol005Uoo`03O01oogoo01mo
o`03O01oogoo0:9oo`00FWoo00=l07ooOol07goo00=l07ooOol0XGoo001JOol00g`0Oomoo`0POol0
0g`0Oomoo`2POol005]oo`03O01oogoo021oo`03O01oogoo09moo`00Fgoo00=l07ooOol08Goo00=l
07ooOol0WWoo001LOol00g`0Oomoo`0QOol00g`0Oomoo`2MOol005eoo`03O01oogoo025oo`03O01o
ogoo09aoo`00GGoo00=l07ooOol08Woo00=l07ooOol0Vgoo001NOol00g`0Oomoo`0ROol00g`0Oomo
o`2JOol005moo`03O01oogoo029oo`03O01oogoo09Uoo`00Ggoo00=l07ooOol08goo00=l07ooOol0
V7oo001POol00g`0Oomoo`0SOol00g`0Oomoo`2GOol0065oo`03O01oogoo02=oo`03O01oogoo09Io
o`00HGoo00=l07ooOol097oo00=l07ooOol0UGoo001ROol00g`0Oomoo`0TOol00g`0Oomoo`2DOol0
069oo`03O01oogoo02Eoo`03O01oogoo09=oo`00Hgoo00=l07ooOol09Goo00=l07ooOol0TWoo001S
Ool00g`0Oomoo`0VOol00g`0Oomoo`2AOol006Aoo`03O01oogoo02Ioo`03O01oogoo091oo`00IGoo
00=l07ooOol09Woo00=l07ooOol0Sgoo001VOol00g`0Oomoo`0VOol00g`0Oomoo`2>Ool006Ioo`03
O01oogoo02Ioo`03O01oogoo08ioo`00Igoo00=l07ooOol09Woo00=l07ooOol0SGoo001XOol00g`0
Oomoo`0VOol00g`0Oomoo`2<Ool006Uoo`03O01oogoo02Ioo`03O01oogoo08]oo`00JWoo00=l07oo
Ool09Woo00=l07ooOol0RWoo001ZOol00g`0Oomoo`0VOol00g`0Oomoo`2:Ool006]oo`03O01oogoo
02Ioo`03O01oogoo08Uoo`00K7oo00=l07ooOol09Woo00=l07ooOol0R7oo001]Ool00g`0Oomoo`0V
Ool00g`0Oomoo`27Ool006eoo`03O01oogoo02Moo`03O01oogoo08Ioo`00KWoo00=l07ooOol09goo
00=l07ooOol0QGoo001_Ool00g`0Oomoo`0WOol00g`0Oomoo`24Ool0071oo`03O01oogoo02Moo`03
O01oogoo08=oo`00LGoo00=l07ooOol09goo00=l07ooOol0PWoo001aOol00g`0Oomoo`0XOol00g`0
Oomoo`21Ool0079oo`03O01oogoo02Qoo`03O01oogoo081oo`00Lgoo00=l07ooOol09goo00=l07oo
Ool0P7oo001dOol00g`0Oomoo`0WOol00g`0Oomoo`1oOol007Eoo`03O01oogoo02Moo`03O01oogoo
07ioo`00MGoo00=l07ooOol0:7oo00=l07ooOol0OGoo001fOol00g`0Oomoo`0WOol00g`0Oomoo`1m
Ool007Moo`03O01oogoo02Moo`03O01oogoo07aoo`00N7oo00=l07ooOol09goo00=l07ooOol0Ngoo
001hOol00g`0Oomoo`0WOol00g`0Oomoo`1kOol007Uoo`03O01oogoo02Moo`03O01oogoo07Yoo`00
NWoo00=l07ooOol09goo00=l07ooOol0NGoo001kOol00g`0Oomoo`0WOol00g`0Oomoo`1hOol007ao
o`03O01oogoo02Moo`03O01oogoo07Moo`00OGoo00=l07ooOol09goo00=l07ooOol0MWoo001mOol0
0g`0Oomoo`0XOol00g`0Oomoo`1eOol007ioo`03O01oogoo02Qoo`03O01oogoo07Aoo`00Ogoo00=l
07ooOol09goo00=l07ooOol0M7oo0020Ool00g`0Oomoo`0WOol00g`0Oomoo`1cOol0085oo`03O01o
ogoo02Moo`03O01oogoo079oo`00PWoo00=l07ooOol09Woo00=l07ooOol0LWoo0023Ool00g`0Oomo
o`0VOol00g`0Oomoo`1aOol008=oo`03O01oogoo02Moo`03O01oogoo071oo`00Q7oo00=l07ooOol0
9goo00=l07ooOol0Kgoo0025Ool00g`0Oomoo`0VOol00g`0Oomoo`1_Ool008Ioo`03O01oogoo02Io
o`03O01oogoo06ioo`00Qgoo00=l07ooOol09Woo00=l07ooOol0KGoo0028Ool00g`0Oomoo`0VOol0
0g`0Oomoo`1/Ool008Uoo`03O01oogoo02Ioo`03O01oogoo06]oo`00RGoo00=l07ooOol09Woo00=l
07ooOol0Jgoo002:Ool00g`0Oomoo`0VOol00g`0Oomoo`1ZOol008]oo`03O01oogoo02Ioo`03O01o
ogoo06Uoo`00S7oo00=l07ooOol09Woo00=l07ooOol0J7oo002=Ool00g`0Oomoo`0VOol00g`0Oomo
o`1WOol008ioo`03O01oogoo02Eoo`03O01oogoo06Moo`00Sgoo00=l07ooOol09Goo00=l07ooOol0
IWoo002@Ool00g`0Oomoo`0UOol00g`0Oomoo`1UOol0095oo`03O01oogoo02Eoo`03O01oogoo06Ao
o`00TWoo00=l07ooOol097oo00=l07ooOol0I7oo002COol00g`0Oomoo`0TOol00g`0Oomoo`1SOol0
09Aoo`03O01oogoo02=oo`03O01oogoo06=oo`00UGoo00=l07ooOol08goo00=l07ooOol0HWoo002E
Ool00g`0Oomoo`0TOol00g`0Oomoo`1QOol009Ioo`03O01oogoo02=oo`03O01oogoo065oo`00Ugoo
00=l07ooOol08goo00=l07ooOol0H7oo002HOol00g`0Oomoo`0ROol00g`0Oomoo`1POol009Uoo`03
O01oogoo029oo`03O01oogoo05moo`00VWoo00=l07ooOol08Woo00=l07ooOol0GWoo002KOol00g`0
Oomoo`0QOol00g`0Oomoo`1NOol009aoo`03O01oogoo025oo`03O01oogoo05eoo`00WGoo00=l07oo
Ool087oo00=l07ooOol0GGoo002NOol00g`0Oomoo`0POol00g`0Oomoo`1LOol009moo`03O01oogoo
021oo`03O01oogoo05]oo`00X7oo00=l07ooOol07goo00=l07ooOol0Fgoo002QOol2O00POol00g`0
Oomoo`1JOol00:=oo`03O01oogoo01ioo`03O01oogoo05Uoo`00Y7oo00=l07ooOol07Goo00=l07oo
Ool0FGoo002UOol00g`0Oomoo`0MOol00g`0Oomoo`1HOol00:Ioo`03O01oogoo01aoo`03O01oogoo
05Qoo`00Ygoo00=l07ooOol077oo00=l07ooOol0Egoo002XOol00g`0Oomoo`0KOol00g`0Oomoo`1G
Ool00:Uoo`03O01oogoo01Yoo`03O01oogoo05Moo`00ZWoo00=l07ooOol06Woo00=l07ooOol0EWoo
002[Ool00g`0Oomoo`0IOol00g`0Oomoo`1FOol00:aoo`9l01Yoo`03O01oogoo05Eoo`00[Woo00=l
07ooOol067oo00=l07ooOol0E7oo002_Ool00g`0Oomoo`0GOol00g`0Oomoo`1DOol00;1oo`03O01o
ogoo01Moo`03O01oogoo05=oo`00/Goo0W`05goo00=l07ooOol0Dgoo002cOol00g`0Oomoo`0DOol0
0g`0Oomoo`1COol00;Aoo`03O01oogoo01Aoo`03O01oogoo059oo`00]Goo00=l07ooOol04goo00=l
07ooOol0DWoo002fOol2O00COol00g`0Oomoo`1BOol00;Qoo`03O01oogoo015oo`03O01oogoo055o
o`00^Goo00=l07ooOol047oo00=l07ooOol0DGoo002jOol2O00@Ool00g`0Oomoo`1AOol00;aoo`03
O01oogoo00eoo`03O01oogoo055oo`00_Goo00=l07ooOol037oo00=l07ooOol0DGoo002nOol2O00<
Ool00g`0Oomoo`1AOol00<1oo`9l00Yoo`03O01oogoo055oo`00`Woo0g`01goo00=l07ooOol0DGoo
0035Ool2O004Ool00g`0Oomoo`1BOol00<Moo`Al05Eoo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.53777 .47822 m
.55474 .49583 L
s
.52057 .46076 m
.53777 .47822 L
s
.50323 .44353 m
.52057 .46076 L
s
.55474 .49583 m
.57141 .51351 L
s
.48582 .42661 m
.50323 .44353 L
s
.57141 .51351 m
.58769 .53119 L
s
.46842 .41008 m
.48582 .42661 L
s
.58769 .53119 m
.60352 .54877 L
s
.45111 .39402 m
.46842 .41008 L
s
.60352 .54877 m
.61881 .56618 L
s
.43398 .37851 m
.45111 .39402 L
s
.61881 .56618 m
.63348 .58332 L
s
.4171 .36364 m
.43398 .37851 L
s
.63348 .58332 m
.64744 .60012 L
s
.40058 .34948 m
.4171 .36364 L
s
.64744 .60012 m
.66063 .61648 L
s
.38449 .33612 m
.40058 .34948 L
s
.66063 .61648 m
.67295 .63231 L
s
.36892 .32364 m
.38449 .33612 L
s
.67295 .63231 m
.68431 .64751 L
s
.35398 .31213 m
.36892 .32364 L
s
.68431 .64751 m
.69465 .66199 L
s
.33975 .30168 m
.35398 .31213 L
s
.69465 .66199 m
.70385 .67564 L
s
.32634 .29237 m
.33975 .30168 L
s
.70385 .67564 m
.71186 .68836 L
s
.31386 .2843 m
.32634 .29237 L
s
.71186 .68836 m
.71857 .70005 L
s
.30239 .27754 m
.31386 .2843 L
s
.71857 .70005 m
.7239 .71061 L
s
.29205 .27219 m
.30239 .27754 L
s
.7239 .71061 m
.72778 .71991 L
s
.28294 .26832 m
.29205 .27219 L
s
.72778 .71991 m
.73013 .72787 L
s
.27517 .266 m
.28294 .26832 L
s
.73013 .72787 m
.73088 .73438 L
s
.26883 .26533 m
.27517 .266 L
s
.73088 .73438 m
.72996 .73933 L
s
.26403 .26634 m
.26883 .26533 L
s
.72996 .73933 m
.72733 .74264 L
s
.26085 .26911 m
.26403 .26634 L
s
.72733 .74264 m
.72293 .74422 L
s
.25938 .27367 m
.26085 .26911 L
s
.72293 .74422 m
.71674 .744 L
s
.2597 .28006 m
.25938 .27367 L
s
.71674 .744 m
.70875 .7419 L
s
.26187 .28827 m
.2597 .28006 L
s
.70875 .7419 m
.69896 .73788 L
s
.26592 .29832 m
.26187 .28827 L
s
.69896 .73788 m
.6874 .73192 L
s
.2719 .31017 m
.26592 .29832 L
s
.6874 .73192 m
.6741 .72399 L
s
.27981 .32378 m
.2719 .31017 L
s
.6741 .72399 m
.65914 .71411 L
s
.28965 .33907 m
.27981 .32378 L
s
.65914 .71411 m
.64261 .70232 L
s
.30136 .35596 m
.28965 .33907 L
s
.64261 .70232 m
.62463 .68868 L
s
.3149 .37431 m
.30136 .35596 L
s
.62463 .68868 m
.60533 .67327 L
s
.33016 .39398 m
.3149 .37431 L
s
.60533 .67327 m
.5849 .65622 L
s
.34705 .41481 m
.33016 .39398 L
s
.5849 .65622 m
.5635 .63766 L
s
.36541 .43659 m
.34705 .41481 L
s
.5635 .63766 m
.54136 .61776 L
s
.38507 .45913 m
.36541 .43659 L
s
.54136 .61776 m
.51869 .59671 L
s
.40585 .48219 m
.38507 .45913 L
s
.51869 .59671 m
.49573 .57473 L
s
.42754 .50552 m
.40585 .48219 L
s
.49573 .57473 m
.47272 .55204 L
s
.4499 .52889 m
.42754 .50552 L
s
.47272 .55204 m
.4499 .52889 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool004]oo`El0=1oo`00BWoo00=l07ooOol00goo0W`0cWoo001:Ool00g`0Oomoo`05Ool3O03;Ool0
04Yoo`03O01oogoo00Qoo`9l0<Uoo`00BWoo00=l07ooOol02Woo0W`0agoo001:Ool00g`0Oomoo`0<
Ool2O035Ool004]oo`03O01oogoo00eoo`9l0<=oo`00Bgoo00=l07ooOol03goo00=l07ooOol0`7oo
001<Ool00g`0Oomoo`0?Ool00g`0Oomoo`2oOol004aoo`03O01oogoo011oo`9l0;moo`00C7oo00=l
07ooOol04Woo00=l07ooOol0_7oo001=Ool00g`0Oomoo`0BOol00g`0Oomoo`2kOol004eoo`03O01o
ogoo01=oo`9l0;]oo`00CWoo00=l07ooOol057oo00=l07ooOol0^7oo001?Ool00g`0Oomoo`0DOol0
0g`0Oomoo`2gOol004moo`03O01oogoo01Eoo`9l0;Moo`00D7oo00=l07ooOol05Woo00=l07ooOol0
]7oo001AOol00g`0Oomoo`0FOol00g`0Oomoo`2cOol0055oo`03O01oogoo01Moo`9l0;=oo`00DWoo
00=l07ooOol067oo00=l07ooOol0/7oo001BOol00g`0Oomoo`0IOol00g`0Oomoo`2_Ool005=oo`03
O01oogoo01Uoo`03O01oogoo0:ioo`00E7oo00=l07ooOol06Goo00=l07ooOol0[Goo001DOol00g`0
Oomoo`0JOol00g`0Oomoo`2/Ool005Eoo`03O01oogoo01Yoo`03O01oogoo0:]oo`00EGoo00=l07oo
Ool06goo00=l07ooOol0ZWoo001FOol00g`0Oomoo`0KOol2O02ZOol005Moo`03O01oogoo01aoo`03
O01oogoo0:Moo`00F7oo00=l07ooOol077oo00=l07ooOol0YWoo001HOol00g`0Oomoo`0MOol00g`0
Oomoo`2UOol005Uoo`03O01oogoo01eoo`9l0:Eoo`00FWoo00=l07ooOol07Woo00=l07ooOol0XWoo
001KOol00g`0Oomoo`0NOol00g`0Oomoo`2QOol005]oo`03O01oogoo01moo`03O01oogoo0:1oo`00
G7oo00=l07ooOol07goo00=l07ooOol0Wgoo001MOol00g`0Oomoo`0OOol00g`0Oomoo`2NOol005eo
o`03O01oogoo021oo`03O01oogoo09eoo`00GWoo00=l07ooOol087oo00=l07ooOol0W7oo001OOol0
0g`0Oomoo`0POol00g`0Oomoo`2KOol0061oo`03O01oogoo021oo`9l09]oo`00H7oo00=l07ooOol0
8Woo00=l07ooOol0V7oo001QOol00g`0Oomoo`0ROol00g`0Oomoo`2GOol0069oo`03O01oogoo029o
o`03O01oogoo09Ioo`00Hgoo00=l07ooOol08Woo00=l07ooOol0UGoo001TOol00g`0Oomoo`0ROol0
0g`0Oomoo`2DOol006Eoo`03O01oogoo029oo`03O01oogoo09=oo`00IGoo00=l07ooOol08goo00=l
07ooOol0TWoo001VOol00g`0Oomoo`0SOol00g`0Oomoo`2AOol006Moo`03O01oogoo02=oo`03O01o
ogoo091oo`00J7oo00=l07ooOol08goo00=l07ooOol0Sgoo001YOol00g`0Oomoo`0SOol00g`0Oomo
o`2>Ool006Yoo`03O01oogoo02=oo`03O01oogoo08eoo`00Jgoo00=l07ooOol08goo00=l07ooOol0
S7oo001/Ool00g`0Oomoo`0SOol00g`0Oomoo`2;Ool006eoo`03O01oogoo02=oo`03O01oogoo08Yo
o`00KWoo00=l07ooOol08goo00=l07ooOol0RGoo001_Ool00g`0Oomoo`0SOol00g`0Oomoo`28Ool0
071oo`03O01oogoo02=oo`03O01oogoo08Moo`00LGoo00=l07ooOol08goo00=l07ooOol0QWoo001a
Ool00g`0Oomoo`0TOol00g`0Oomoo`25Ool0079oo`03O01oogoo02Aoo`03O01oogoo08Aoo`00Lgoo
00=l07ooOol097oo00=l07ooOol0Pgoo001dOol00g`0Oomoo`0TOol00g`0Oomoo`22Ool007Eoo`03
O01oogoo02Aoo`03O01oogoo085oo`00MWoo00=l07ooOol097oo00=l07ooOol0P7oo001gOol00g`0
Oomoo`0TOol00g`0Oomoo`1oOol007Moo`03O01oogoo02Eoo`03O01oogoo07ioo`00N7oo00=l07oo
Ool09Goo00=l07ooOol0OGoo001iOol00g`0Oomoo`0UOol00g`0Oomoo`1lOol007Yoo`03O01oogoo
02Aoo`03O01oogoo07aoo`00Ngoo00=l07ooOol097oo00=l07ooOol0Ngoo001lOol00g`0Oomoo`0T
Ool00g`0Oomoo`1jOol007eoo`9l02Eoo`03O01oogoo07Uoo`00Ogoo00=l07ooOol08goo00=l07oo
Ool0N7oo0020Ool00g`0Oomoo`0SOol00g`0Oomoo`1gOol0085oo`03O01oogoo02=oo`03O01oogoo
07Ioo`00PWoo00=l07ooOol08goo00=l07ooOol0MGoo0023Ool00g`0Oomoo`0SOol00g`0Oomoo`1d
Ool008Aoo`03O01oogoo02=oo`03O01oogoo07=oo`00Q7oo00=l07ooOol097oo00=l07ooOol0LWoo
0025Ool00g`0Oomoo`0TOol00g`0Oomoo`1aOol008Ioo`03O01oogoo02Aoo`03O01oogoo071oo`00
Qgoo00=l07ooOol097oo00=l07ooOol0Kgoo0028Ool00g`0Oomoo`0TOol00g`0Oomoo`1^Ool008Uo
o`03O01oogoo02=oo`03O01oogoo06ioo`00RWoo0W`097oo00=l07ooOol0KGoo002<Ool00g`0Oomo
o`0ROol00g`0Oomoo`1/Ool008eoo`03O01oogoo029oo`03O01oogoo06]oo`00SWoo00=l07ooOol0
8Woo00=l07ooOol0JWoo002?Ool00g`0Oomoo`0QOol00g`0Oomoo`1ZOol0091oo`03O01oogoo025o
o`03O01oogoo06Uoo`00TGoo00=l07ooOol08Goo00=l07ooOol0J7oo002AOol00g`0Oomoo`0ROol0
0g`0Oomoo`1WOol0099oo`03O01oogoo029oo`03O01oogoo06Ioo`00Tgoo00=l07ooOol08Goo00=l
07ooOol0IWoo002DOol00g`0Oomoo`0QOol00g`0Oomoo`1UOol009Eoo`03O01oogoo025oo`03O01o
ogoo06Aoo`00UWoo00=l07ooOol08Goo00=l07ooOol0Hgoo002GOol2O00ROol00g`0Oomoo`1ROol0
09Uoo`03O01oogoo021oo`03O01oogoo065oo`00VWoo00=l07ooOol087oo00=l07ooOol0H7oo002K
Ool00g`0Oomoo`0POol00g`0Oomoo`1OOol009aoo`03O01oogoo021oo`03O01oogoo05ioo`00WGoo
00=l07ooOol07goo00=l07ooOol0GWoo002NOol00g`0Oomoo`0OOol00g`0Oomoo`1MOol009moo`03
O01oogoo01moo`03O01oogoo05aoo`00X7oo00=l07ooOol07goo00=l07ooOol0Fgoo002QOol00g`0
Oomoo`0NOol00g`0Oomoo`1KOol00:9oo`03O01oogoo01ioo`03O01oogoo05Yoo`00Xgoo00=l07oo
Ool07Woo00=l07ooOol0FGoo002TOol2O00OOol00g`0Oomoo`1HOol00:Ioo`03O01oogoo01aoo`03
O01oogoo05Qoo`00Ygoo00=l07ooOol077oo00=l07ooOol0Egoo002XOol00g`0Oomoo`0LOol00g`0
Oomoo`1FOol00:Uoo`03O01oogoo01aoo`03O01oogoo05Eoo`00ZWoo0W`077oo00=l07ooOol0EGoo
002/Ool00g`0Oomoo`0JOol00g`0Oomoo`1DOol00:eoo`03O01oogoo01Yoo`03O01oogoo05=oo`00
[Woo0W`06Woo00=l07ooOol0Dgoo002`Ool00g`0Oomoo`0HOol00g`0Oomoo`1BOol00;5oo`9l01Qo
o`03O01oogoo059oo`00/goo00=l07ooOol05Woo00=l07ooOol0DGoo002dOol00g`0Oomoo`0FOol0
0g`0Oomoo`1@Ool00;Eoo`9l01Ioo`03O01oogoo051oo`00]goo00=l07ooOol057oo00=l07ooOol0
Cgoo002hOol00g`0Oomoo`0COol00g`0Oomoo`1?Ool00;Uoo`9l01Aoo`03O01oogoo04ioo`00^goo
0W`04Woo00=l07ooOol0CWoo002mOol00g`0Oomoo`0?Ool00g`0Oomoo`1>Ool00;ioo`03O01oogoo
00moo`03O01oogoo04eoo`00_goo0W`03goo00=l07ooOol0CGoo0031Ool00g`0Oomoo`0<Ool00g`0
Oomoo`1=Ool00<9oo`03O01oogoo00aoo`03O01oogoo04aoo`00`goo0W`037oo00=l07ooOol0C7oo
0035Ool2O00:Ool00g`0Oomoo`1<Ool00<Moo`=l00Moo`03O01oogoo04aoo`00bWoo0W`01Goo00=l
07ooOol0C7oo003<Ool5O01?Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.51857 .46743 m
.53692 .48363 L
s
.50009 .45143 m
.51857 .46743 L
s
.53692 .48363 m
.55506 .49995 L
s
.48157 .4357 m
.50009 .45143 L
s
.55506 .49995 m
.57291 .51633 L
s
.46309 .42031 m
.48157 .4357 L
s
.57291 .51633 m
.59038 .53267 L
s
.44473 .40534 m
.46309 .42031 L
s
.59038 .53267 m
.60739 .54892 L
s
.42659 .39085 m
.44473 .40534 L
s
.60739 .54892 m
.62385 .56499 L
s
.40875 .37694 m
.42659 .39085 L
s
.62385 .56499 m
.63968 .58079 L
s
.3913 .36366 m
.40875 .37694 L
s
.63968 .58079 m
.65479 .59626 L
s
.37434 .35111 m
.3913 .36366 L
s
.65479 .59626 m
.66908 .61131 L
s
.35796 .33935 m
.37434 .35111 L
s
.66908 .61131 m
.68248 .62585 L
s
.34227 .32847 m
.35796 .33935 L
s
.68248 .62585 m
.69489 .63978 L
s
.32736 .31855 m
.34227 .32847 L
s
.69489 .63978 m
.7062 .65303 L
s
.31333 .30967 m
.32736 .31855 L
s
.7062 .65303 m
.71635 .66549 L
s
.3003 .3019 m
.31333 .30967 L
s
.71635 .66549 m
.72521 .67708 L
s
.28837 .29534 m
.3003 .3019 L
s
.72521 .67708 m
.73271 .68769 L
s
.27766 .29005 m
.28837 .29534 L
s
.73271 .68769 m
.73876 .69722 L
s
.26826 .28612 m
.27766 .29005 L
s
.73876 .69722 m
.74326 .70558 L
s
.26028 .28361 m
.26826 .28612 L
s
.74326 .70558 m
.74613 .71267 L
s
.25385 .28261 m
.26028 .28361 L
s
.74613 .71267 m
.74729 .7184 L
s
.24904 .28315 m
.25385 .28261 L
s
.74729 .7184 m
.74667 .72266 L
s
.24597 .28531 m
.24904 .28315 L
s
.74667 .72266 m
.74421 .72539 L
s
.24471 .28913 m
.24597 .28531 L
s
.74421 .72539 m
.73986 .72649 L
s
.24535 .29462 m
.24471 .28913 L
s
.73986 .72649 m
.73359 .72591 L
s
.24795 .30182 m
.24535 .29462 L
s
.73359 .72591 m
.72538 .72357 L
s
.25256 .31072 m
.24795 .30182 L
s
.72538 .72357 m
.71522 .71945 L
s
.25921 .3213 m
.25256 .31072 L
s
.71522 .71945 m
.70315 .71352 L
s
.2679 .33352 m
.25921 .3213 L
s
.70315 .71352 m
.68921 .70576 L
s
.27862 .34733 m
.2679 .33352 L
s
.68921 .70576 m
.67347 .6962 L
s
.29134 .36264 m
.27862 .34733 L
s
.67347 .6962 m
.65602 .68487 L
s
.30598 .37934 m
.29134 .36264 L
s
.65602 .68487 m
.637 .67184 L
s
.32246 .3973 m
.30598 .37934 L
s
.637 .67184 m
.61656 .65719 L
s
.34064 .41638 m
.32246 .3973 L
s
.61656 .65719 m
.59486 .64104 L
s
.36037 .43639 m
.34064 .41638 L
s
.59486 .64104 m
.57211 .62352 L
s
.38148 .45715 m
.36037 .43639 L
s
.57211 .62352 m
.54854 .60479 L
s
.40376 .47845 m
.38148 .45715 L
s
.54854 .60479 m
.52438 .58505 L
s
.42699 .50006 m
.40376 .47845 L
s
.52438 .58505 m
.49988 .56448 L
s
.45092 .52176 m
.42699 .50006 L
s
.49988 .56448 m
.4753 .54331 L
s
.4753 .54331 m
.45092 .52176 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.51814 .4729 m
.53757 .48772 L
s
.4986 .45824 m
.51814 .4729 L
s
.53757 .48772 m
.55679 .50265 L
s
.47902 .44383 m
.4986 .45824 L
s
.55679 .50265 m
.57572 .51761 L
s
.45951 .42971 m
.47902 .44383 L
s
.57572 .51761 m
.59427 .53253 L
s
.44015 .41596 m
.45951 .42971 L
s
.59427 .53253 m
.61235 .54736 L
s
.42102 .40265 m
.44015 .41596 L
s
.61235 .54736 m
.62986 .56201 L
s
.40223 .38984 m
.42102 .40265 L
s
.62986 .56201 m
.64672 .57641 L
s
.38387 .3776 m
.40223 .38984 L
s
.64672 .57641 m
.66284 .59049 L
s
.36604 .36601 m
.38387 .3776 L
s
.66284 .59049 m
.67811 .60418 L
s
.34883 .35513 m
.36604 .36601 L
s
.67811 .60418 m
.69245 .61739 L
s
.33235 .34504 m
.34883 .35513 L
s
.69245 .61739 m
.70574 .63004 L
s
.31671 .33581 m
.33235 .34504 L
s
.70574 .63004 m
.7179 .64204 L
s
.30202 .3275 m
.31671 .33581 L
s
.7179 .64204 m
.72882 .65332 L
s
.28837 .32021 m
.30202 .3275 L
s
.72882 .65332 m
.7384 .66378 L
s
.2759 .314 m
.28837 .32021 L
s
.7384 .66378 m
.74653 .67333 L
s
.2647 .30894 m
.2759 .314 L
s
.74653 .67333 m
.75313 .68189 L
s
.25491 .3051 m
.2647 .30894 L
s
.75313 .68189 m
.75809 .68936 L
s
.24661 .30256 m
.25491 .3051 L
s
.75809 .68936 m
.76132 .69565 L
s
.23994 .30136 m
.24661 .30256 L
s
.76132 .69565 m
.76274 .70068 L
s
.23499 .30158 m
.23994 .30136 L
s
.76274 .70068 m
.76227 .70436 L
s
.23186 .30327 m
.23499 .30158 L
s
.76227 .70436 m
.75984 .70662 L
s
.23065 .30646 m
.23186 .30327 L
s
.75984 .70662 m
.75539 .70738 L
s
.23144 .31118 m
.23065 .30646 L
s
.75539 .70738 m
.7489 .70658 L
s
.23429 .31746 m
.23144 .31118 L
s
.7489 .70658 m
.74033 .70418 L
s
.23926 .32529 m
.23429 .31746 L
s
.74033 .70418 m
.7297 .70012 L
s
.24638 .33467 m
.23926 .32529 L
s
.7297 .70012 m
.71701 .69441 L
s
.25566 .34557 m
.24638 .33467 L
s
.71701 .69441 m
.70233 .68702 L
s
.26708 .35792 m
.25566 .34557 L
s
.70233 .68702 m
.68572 .67798 L
s
.2806 .37167 m
.26708 .35792 L
s
.68572 .67798 m
.66729 .66733 L
s
.29616 .38672 m
.2806 .37167 L
s
.66729 .66733 m
.64717 .65512 L
s
.31365 .40295 m
.29616 .38672 L
s
.64717 .65512 m
.62553 .64145 L
s
.33295 .42024 m
.31365 .40295 L
s
.62553 .64145 m
.60255 .62641 L
s
.35389 .43841 m
.33295 .42024 L
s
.60255 .62641 m
.57845 .61015 L
s
.37628 .4573 m
.35389 .43841 L
s
.57845 .61015 m
.55346 .59282 L
s
.39992 .47673 m
.37628 .4573 L
s
.55346 .59282 m
.52785 .57458 L
s
.42456 .49649 m
.39992 .47673 L
s
.52785 .57458 m
.50187 .55562 L
s
.44994 .51636 m
.42456 .49649 L
s
.50187 .55562 m
.47581 .53614 L
s
.47581 .53614 m
.44994 .51636 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00@goo1G`0f7oo0012Ool00g`0Oomoo`03Ool2O03FOol0049o
o`03O01oogoo00Eoo`9l0=Aoo`00@Woo00=l07ooOol01goo0W`0dWoo0012Ool00g`0Oomoo`09Ool3
O03?Ool004=oo`03O01oogoo00]oo`9l0<eoo`00@goo00=l07ooOol03Goo0W`0bgoo0014Ool00g`0
Oomoo`0>Ool2O039Ool004Eoo`03O01oogoo00moo`03O01oogoo0<Ioo`00AGoo00=l07ooOol047oo
0W`0aWoo0016Ool00g`0Oomoo`0AOol00g`0Oomoo`33Ool004Moo`03O01oogoo015oo`9l0<=oo`00
B7oo00=l07ooOol04Woo0W`0`Goo0019Ool00g`0Oomoo`0COol2O02oOol004Yoo`03O01oogoo01Ao
o`9l0;eoo`00Bgoo00=l07ooOol05Goo0W`0^goo001<Ool00g`0Oomoo`0FOol00g`0Oomoo`2hOol0
04eoo`03O01oogoo01Ioo`9l0;Qoo`00CWoo00=l07ooOol05goo00=l07ooOol0]Goo001?Ool00g`0
Oomoo`0GOol00g`0Oomoo`2dOol0051oo`03O01oogoo01Moo`9l0;Aoo`00DGoo00=l07ooOol067oo
0W`0/Woo001BOol2O00JOol00g`0Oomoo`2_Ool005Aoo`03O01oogoo01Qoo`9l0:moo`00EGoo00=l
07ooOol06Goo0W`0[Goo001FOol00g`0Oomoo`0JOol00g`0Oomoo`2ZOol005Moo`03O01oogoo01Yo
o`03O01oogoo0:Uoo`00F7oo00=l07ooOol06Woo0W`0ZGoo001IOol00g`0Oomoo`0KOol00g`0Oomo
o`2VOol005Yoo`03O01oogoo01]oo`03O01oogoo0:Eoo`00Fgoo00=l07ooOol06goo0W`0YGoo001L
Ool00g`0Oomoo`0LOol00g`0Oomoo`2ROol005eoo`03O01oogoo01aoo`9l0:9oo`00GWoo00=l07oo
Ool07Goo00=l07ooOol0Wgoo001OOol00g`0Oomoo`0MOol00g`0Oomoo`2NOol0061oo`03O01oogoo
01eoo`9l09ioo`00HGoo00=l07ooOol07Woo00=l07ooOol0Vgoo001ROol2O00OOol00g`0Oomoo`2J
Ool006Aoo`03O01oogoo01eoo`9l09Yoo`00IGoo00=l07ooOol07Woo00=l07ooOol0Ugoo001VOol0
0g`0Oomoo`0NOol2O02GOol006Moo`03O01oogoo01moo`03O01oogoo09Aoo`00J7oo00=l07ooOol0
7goo0W`0U7oo001YOol00g`0Oomoo`0POol00g`0Oomoo`2AOol006Yoo`03O01oogoo021oo`9l095o
o`00Jgoo00=l07ooOol08Goo00=l07ooOol0SWoo001/Ool2O00ROol00g`0Oomoo`2=Ool006ioo`03
O01oogoo021oo`9l08eoo`00Kgoo00=l07ooOol08Goo00=l07ooOol0RWoo001`Ool2O00ROol00g`0
Oomoo`29Ool0079oo`03O01oogoo021oo`9l08Uoo`00Lgoo00=l07ooOol08Goo00=l07ooOol0QWoo
001dOol00g`0Oomoo`0QOol2O026Ool007Eoo`9l02=oo`03O01oogoo08=oo`00Mgoo00=l07ooOol0
8Goo00=l07ooOol0PWoo001hOol00g`0Oomoo`0QOol00g`0Oomoo`21Ool007Uoo`03O01oogoo025o
o`03O01oogoo081oo`00NWoo00=l07ooOol08Goo00=l07ooOol0Ogoo001kOol2O00ROol00g`0Oomo
o`1nOol007eoo`03O01oogoo021oo`9l07ioo`00OWoo00=l07ooOol08Goo00=l07ooOol0Ngoo001o
Ool2O00ROol2O01kOol0085oo`03O01oogoo025oo`03O01oogoo07Qoo`00PWoo0W`08Woo00=l07oo
Ool0Mgoo0024Ool00g`0Oomoo`0POol2O01gOol008Eoo`03O01oogoo025oo`03O01oogoo07Aoo`00
QWoo0W`08Woo00=l07ooOol0Lgoo0028Ool00g`0Oomoo`0POol00g`0Oomoo`1bOol008Uoo`03O01o
ogoo021oo`03O01oogoo075oo`00RWoo0W`08Goo00=l07ooOol0L7oo002<Ool00g`0Oomoo`0OOol0
0g`0Oomoo`1_Ool008eoo`03O01oogoo01moo`03O01oogoo06ioo`00SWoo0W`087oo00=l07ooOol0
KGoo002@Ool00g`0Oomoo`0NOol2O01]Ool0095oo`9l021oo`03O01oogoo06Yoo`00Tgoo00=l07oo
Ool07Woo00=l07ooOol0JGoo002DOol00g`0Oomoo`0NOol00g`0Oomoo`1XOol009Eoo`9l01moo`9l
06Qoo`00Ugoo00=l07ooOol07Woo00=l07ooOol0IGoo002HOol00g`0Oomoo`0NOol00g`0Oomoo`1T
Ool009Uoo`03O01oogoo01ioo`03O01oogoo06=oo`00VWoo0W`07goo0W`0Hgoo002LOol00g`0Oomo
o`0NOol00g`0Oomoo`1POol009eoo`03O01oogoo01ioo`03O01oogoo05moo`00WWoo00=l07ooOol0
7Woo00=l07ooOol0GWoo002OOol2O00OOol00g`0Oomoo`1MOol00:5oo`03O01oogoo01eoo`03O01o
ogoo05aoo`00XWoo0W`07Woo00=l07ooOol0Fgoo002TOol2O00MOol00g`0Oomoo`1JOol00:Ioo`03
O01oogoo01]oo`03O01oogoo05Uoo`00Ygoo0W`077oo00=l07ooOol0F7oo002YOol00g`0Oomoo`0J
Ool00g`0Oomoo`1GOol00:Yoo`9l01]oo`03O01oogoo05Ioo`00[7oo00=l07ooOol06Goo0W`0EWoo
002]Ool2O00KOol00g`0Oomoo`1COol00:moo`03O01oogoo01Uoo`03O01oogoo059oo`00/7oo00=l
07ooOol06Goo00=l07ooOol0DGoo002aOol2O00JOol00g`0Oomoo`1@Ool00;=oo`03O01oogoo01Qo
o`03O01oogoo04moo`00]7oo0W`06Goo00=l07ooOol0CWoo002fOol00g`0Oomoo`0GOol00g`0Oomo
o`1=Ool00;Moo`9l01Qoo`03O01oogoo04aoo`00^Goo00=l07ooOol05Woo00=l07ooOol0Bgoo002j
Ool2O00FOol00g`0Oomoo`1;Ool00;aoo`9l01Eoo`03O01oogoo04Yoo`00_Woo0W`057oo00=l07oo
Ool0BGoo0030Ool2O00COol00g`0Oomoo`18Ool00<9oo`9l019oo`03O01oogoo04Moo`00a7oo00=l
07ooOol047oo00=l07ooOol0AWoo0035Ool2O00AOol00g`0Oomoo`15Ool00<Moo`9l00moo`03O01o
ogoo04Eoo`00bGoo00=l07ooOol03Goo00=l07ooOol0A7oo003:Ool2O00=Ool00g`0Oomoo`14Ool0
0<aoo`=l00]oo`03O01oogoo04=oo`00cgoo0g`027oo00=l07ooOol0@goo003BOol2O006Ool00g`0
Oomoo`13Ool00=Aoo`=l00=oo`03O01oogoo04=oo`00egoo0g`0AWoo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.5191 .47695 m
.53949 .49028 L
s
.4986 .46376 m
.5191 .47695 L
s
.47807 .45078 m
.4986 .46376 L
s
.53949 .49028 m
.55967 .50371 L
s
.45762 .43806 m
.47807 .45078 L
s
.55967 .50371 m
.57955 .51717 L
s
.43732 .42567 m
.45762 .43806 L
s
.57955 .51717 m
.59905 .53059 L
s
.41728 .41367 m
.43732 .42567 L
s
.59905 .53059 m
.61805 .54392 L
s
.3976 .40212 m
.41728 .41367 L
s
.61805 .54392 m
.63648 .55709 L
s
.37837 .39107 m
.3976 .40212 L
s
.63648 .55709 m
.65423 .57004 L
s
.3597 .3806 m
.37837 .39107 L
s
.65423 .57004 m
.6712 .5827 L
s
.34168 .37076 m
.3597 .3806 L
s
.6712 .5827 m
.68729 .59499 L
s
.32443 .36162 m
.34168 .37076 L
s
.68729 .59499 m
.7024 .60685 L
s
.30805 .35324 m
.32443 .36162 L
s
.7024 .60685 m
.71643 .61821 L
s
.29266 .34569 m
.30805 .35324 L
s
.71643 .61821 m
.72927 .62898 L
s
.27837 .33904 m
.29266 .34569 L
s
.72927 .62898 m
.7408 .6391 L
s
.26529 .33335 m
.27837 .33904 L
s
.7408 .6391 m
.75093 .64847 L
s
.25356 .32869 m
.26529 .33335 L
s
.75093 .64847 m
.75955 .65702 L
s
.24328 .32511 m
.25356 .32869 L
s
.75955 .65702 m
.76654 .66466 L
s
.23457 .32269 m
.24328 .32511 L
s
.76654 .66466 m
.77181 .67132 L
s
.22755 .32148 m
.23457 .32269 L
s
.77181 .67132 m
.77526 .67692 L
s
.22233 .32153 m
.22755 .32148 L
s
.77526 .67692 m
.77679 .68136 L
s
.21901 .32289 m
.22233 .32153 L
s
.77679 .68136 m
.77633 .68459 L
s
.21769 .32559 m
.21901 .32289 L
s
.77633 .68459 m
.77379 .68652 L
s
.21847 .32968 m
.21769 .32559 L
s
.77379 .68652 m
.76914 .68709 L
s
.2214 .33516 m
.21847 .32968 L
s
.76914 .68709 m
.76231 .68625 L
s
.22654 .34204 m
.2214 .33516 L
s
.76231 .68625 m
.75329 .68395 L
s
.23394 .35032 m
.22654 .34204 L
s
.75329 .68395 m
.74208 .68016 L
s
.2436 .35996 m
.23394 .35032 L
s
.74208 .68016 m
.72871 .67486 L
s
.25551 .37093 m
.2436 .35996 L
s
.72871 .67486 m
.71322 .66805 L
s
.26963 .38316 m
.25551 .37093 L
s
.71322 .66805 m
.6957 .65975 L
s
.2859 .39658 m
.26963 .38316 L
s
.6957 .65975 m
.67626 .65 L
s
.3042 .41108 m
.2859 .39658 L
s
.67626 .65 m
.65504 .63885 L
s
.32441 .42655 m
.3042 .41108 L
s
.65504 .63885 m
.63221 .62638 L
s
.34636 .44284 m
.32441 .42655 L
s
.63221 .62638 m
.60797 .61269 L
s
.36985 .4598 m
.34636 .44284 L
s
.60797 .61269 m
.58256 .5979 L
s
.39466 .47727 m
.36985 .4598 L
s
.58256 .5979 m
.55622 .58216 L
s
.42055 .49506 m
.39466 .47727 L
s
.55622 .58216 m
.52923 .56562 L
s
.44724 .51298 m
.42055 .49506 L
s
.52923 .56562 m
.50187 .54845 L
s
.47444 .53084 m
.44724 .51298 L
s
.50187 .54845 m
.47444 .53084 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00?Woo1W`0g7oo000nOol00g`0Oomoo`03Ool3O03IOol003ioo`03O01oogoo00Io
o`=l0=Ioo`00?Woo00=l07ooOol02Goo0g`0dgoo000oOol00g`0Oomoo`0;Ool2O03AOol0041oo`03
O01oogoo00aoo`03O01oogoo0<ioo`00@Goo00=l07ooOol037oo0W`0cWoo0012Ool00g`0Oomoo`0=
Ool3O03;Ool004=oo`03O01oogoo00moo`9l0<Uoo`00A7oo00=l07ooOol047oo0g`0aWoo0014Ool0
0g`0Oomoo`0COol2O034Ool004Eoo`03O01oogoo01Aoo`9l0<9oo`00AWoo00=l07ooOol05Goo0W`0
`7oo0017Ool2O00GOol2O02nOol004Uoo`03O01oogoo01Ioo`03O01oogoo0;]oo`00BWoo00=l07oo
Ool05Woo0W`0^goo001;Ool2O00HOol2O02iOol004eoo`03O01oogoo01Moo`03O01oogoo0;Ioo`00
CWoo00=l07ooOol05goo0W`0]Woo001?Ool2O00IOol2O02dOol0055oo`03O01oogoo01Qoo`03O01o
ogoo0;5oo`00DWoo00=l07ooOol067oo0W`0/Goo001COol00g`0Oomoo`0IOol2O02_Ool005Aoo`9l
01]oo`9l0:eoo`00EWoo00=l07ooOol06Woo0W`0Zgoo001GOol00g`0Oomoo`0KOol2O02YOol005Qo
o`03O01oogoo01aoo`03O01oogoo0:Ioo`00FGoo00=l07ooOol077oo0W`0YWoo001JOol2O00NOol0
0g`0Oomoo`2SOol005aoo`03O01oogoo01aoo`9l0:=oo`00GGoo00=l07ooOol07Goo00=l07ooOol0
X7oo001NOol00g`0Oomoo`0MOol2O02POol005moo`03O01oogoo01ioo`9l09ioo`00H7oo0W`087oo
0W`0W7oo001ROol00g`0Oomoo`0OOol2O02JOol006=oo`03O01oogoo021oo`03O01oogoo09Moo`00
I7oo0W`08Goo0W`0Ugoo001VOol2O00QOol00g`0Oomoo`2DOol006Qoo`9l021oo`9l09Aoo`00JWoo
00=l07ooOol07goo00=l07ooOol0TGoo001[Ool2O00POol2O02AOol006eoo`03O01oogoo01moo`03
O01oogoo08ioo`00KWoo00=l07ooOol07goo0W`0SWoo001_Ool2O00QOol2O02<Ool0075oo`03O01o
ogoo021oo`03O01oogoo08Uoo`00LWoo00=l07ooOol087oo0W`0RGoo001cOol00g`0Oomoo`0QOol0
0g`0Oomoo`26Ool007Aoo`9l029oo`9l08Ioo`00MWoo00=l07ooOol08Goo00=l07ooOol0Pgoo001g
Ool00g`0Oomoo`0QOol2O023Ool007Qoo`03O01oogoo029oo`03O01oogoo081oo`00NGoo0W`08goo
0W`0P7oo001kOol00g`0Oomoo`0ROol00g`0Oomoo`1mOol007aoo`9l02=oo`9l07eoo`00OWoo0W`0
8goo00=l07ooOol0NWoo0020Ool00g`0Oomoo`0QOol2O01jOol0085oo`9l02=oo`03O01oogoo07Mo
o`00Pgoo00=l07ooOol08Goo00=l07ooOol0MWoo0024Ool2O00ROol2O01fOol008Ioo`9l029oo`03
O01oogoo07=oo`00R7oo00=l07ooOol087oo00=l07ooOol0LWoo0029Ool2O00QOol2O01bOol008]o
o`03O01oogoo021oo`03O01oogoo06moo`00S7oo0W`08Goo0W`0Kgoo002>Ool2O00QOol00g`0Oomo
o`1/Ool0091oo`03O01oogoo01moo`9l06aoo`00TGoo0W`08Goo0W`0JWoo002COol00g`0Oomoo`0P
Ool00g`0Oomoo`1WOol009Aoo`03O01oogoo021oo`03O01oogoo06Ioo`00UGoo0W`08Goo0W`0IWoo
002GOol00g`0Oomoo`0POol00g`0Oomoo`1SOol009Qoo`9l025oo`03O01oogoo069oo`00VWoo00=l
07ooOol07goo00=l07ooOol0HGoo002KOol2O00POol2O01QOol009eoo`9l021oo`03O01oogoo05io
o`00Wgoo00=l07ooOol07Woo00=l07ooOol0GGoo002POol2O00OOol2O01MOol00:9oo`9l01moo`9l
05]oo`00Y7oo0W`07goo00=l07ooOol0F7oo002VOol2O00NOol00g`0Oomoo`1GOol00:Qoo`9l01eo
o`03O01oogoo05Ioo`00ZWoo0W`077oo00=l07ooOol0EGoo002/Ool2O00KOol00g`0Oomoo`1DOol0
0:ioo`03O01oogoo01Uoo`03O01oogoo05=oo`00[goo0W`06Woo0W`0Dgoo002aOol2O00JOol00g`0
Oomoo`1@Ool00;=oo`9l01Uoo`03O01oogoo04moo`00]Goo00=l07ooOol05goo0W`0Cgoo002fOol2
O00IOol00g`0Oomoo`1<Ool00;Qoo`03O01oogoo01Moo`03O01oogoo04]oo`00^Goo0W`067oo00=l
07ooOol0BWoo002kOol2O00GOol00g`0Oomoo`19Ool00;eoo`9l01Ioo`03O01oogoo04Qoo`00_goo
0W`05Goo00=l07ooOol0Agoo0031Ool2O00DOol00g`0Oomoo`16Ool00<=oo`9l01=oo`03O01oogoo
04Eoo`00aGoo0W`04Woo00=l07ooOol0A7oo0037Ool2O00AOol00g`0Oomoo`13Ool00<Uoo`9l011o
o`03O01oogoo049oo`00bgoo0g`03Woo00=l07ooOol0@Goo003>Ool2O00=Ool00g`0Oomoo`10Ool0
0=1oo`9l00]oo`03O01oogoo041oo`00dWoo0W`02Woo00=l07ooOol0?goo003DOol2O008Ool00g`0
Oomoo`0oOol00=Ioo`El00=oo`03O01oogoo03moo`00fgoo17`0@Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.4999 .46771 m
.52126 .47936 L
s
.52126 .47936 m
.54251 .49114 L
s
.47851 .45625 m
.4999 .46771 L
s
.54251 .49114 m
.56354 .50301 L
s
.45719 .44504 m
.47851 .45625 L
s
.56354 .50301 m
.58426 .51491 L
s
.43604 .43411 m
.45719 .44504 L
s
.58426 .51491 m
.60458 .52679 L
s
.41515 .42353 m
.43604 .43411 L
s
.60458 .52679 m
.62439 .5386 L
s
.39463 .41335 m
.41515 .42353 L
s
.62439 .5386 m
.6436 .55027 L
s
.37457 .40363 m
.39463 .41335 L
s
.6436 .55027 m
.6621 .56175 L
s
.35509 .3944 m
.37457 .40363 L
s
.6621 .56175 m
.67979 .57299 L
s
.33628 .38574 m
.35509 .3944 L
s
.67979 .57299 m
.69657 .58391 L
s
.31826 .3777 m
.33628 .38574 L
s
.69657 .58391 m
.71233 .59445 L
s
.30114 .37033 m
.31826 .3777 L
s
.71233 .59445 m
.72695 .60456 L
s
.28503 .36369 m
.30114 .37033 L
s
.72695 .60456 m
.74033 .61415 L
s
.27006 .35784 m
.28503 .36369 L
s
.74033 .61415 m
.75234 .62316 L
s
.25635 .35283 m
.27006 .35784 L
s
.75234 .62316 m
.76289 .63153 L
s
.24401 .34874 m
.25635 .35283 L
s
.76289 .63153 m
.77185 .63917 L
s
.23318 .34559 m
.24401 .34874 L
s
.77185 .63917 m
.77911 .64601 L
s
.22396 .34347 m
.23318 .34559 L
s
.77911 .64601 m
.78456 .65198 L
s
.2165 .3424 m
.22396 .34347 L
s
.78456 .65198 m
.7881 .657 L
s
.21089 .34245 m
.2165 .3424 L
s
.7881 .657 m
.78964 .661 L
s
.20725 .34365 m
.21089 .34245 L
s
.78964 .661 m
.78907 .66392 L
s
.20569 .34604 m
.20725 .34365 L
s
.78907 .66392 m
.78633 .66569 L
s
.2063 .34965 m
.20569 .34604 L
s
.78633 .66569 m
.78136 .66626 L
s
.20914 .35448 m
.2063 .34965 L
s
.78136 .66626 m
.77411 .66556 L
s
.2143 .36055 m
.20914 .35448 L
s
.77411 .66556 m
.76456 .66356 L
s
.2218 .36786 m
.2143 .36055 L
s
.76456 .66356 m
.7527 .66024 L
s
.23166 .37637 m
.2218 .36786 L
s
.7527 .66024 m
.73858 .65557 L
s
.24388 .38607 m
.23166 .37637 L
s
.73858 .65557 m
.72223 .64955 L
s
.25841 .39688 m
.24388 .38607 L
s
.72223 .64955 m
.70376 .6422 L
s
.2752 .40874 m
.25841 .39688 L
s
.70376 .6422 m
.68327 .63355 L
s
.29413 .42157 m
.2752 .40874 L
s
.68327 .63355 m
.66093 .62365 L
s
.31508 .43526 m
.29413 .42157 L
s
.66093 .62365 m
.63691 .61258 L
s
.33786 .44969 m
.31508 .43526 L
s
.63691 .61258 m
.61143 .60042 L
s
.36229 .46472 m
.33786 .44969 L
s
.61143 .60042 m
.58474 .58729 L
s
.38813 .4802 m
.36229 .46472 L
s
.58474 .58729 m
.5571 .57331 L
s
.41513 .49598 m
.38813 .4802 L
s
.5571 .57331 m
.5288 .55862 L
s
.44299 .51188 m
.41513 .49598 L
s
.5288 .55862 m
.50014 .54337 L
s
.47143 .52774 m
.44299 .51188 L
s
.50014 .54337 m
.47143 .52774 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
>goo1W`0ggoo000kOol00g`0Oomoo`03Ool3O03LOol003]oo`03O01oogoo00Ioo`Al0=Qoo`00?7oo
00=l07ooOol02Goo0g`0eGoo000lOol00g`0Oomoo`0<Ool3O03BOol003eoo`03O01oogoo00ioo`9l
0=1oo`00?Woo00=l07ooOol03goo0g`0cGoo000oOol00g`0Oomoo`0AOol2O03;Ool0041oo`03O01o
ogoo019oo`=l0<Qoo`00@Goo00=l07ooOol057oo0W`0aWoo0012Ool00g`0Oomoo`0EOol3O033Ool0
04=oo`9l01Qoo`9l0<5oo`00AGoo00=l07ooOol05goo0W`0_goo0016Ool2O00IOol2O02mOol004Qo
o`9l01Uoo`9l0;]oo`00BWoo00=l07ooOol067oo0W`0^Goo001;Ool00g`0Oomoo`0IOol3O02fOol0
04aoo`03O01oogoo01]oo`9l0;Aoo`00CGoo00=l07ooOol077oo0W`0/Woo001>Ool00g`0Oomoo`0M
Ool2O02`Ool004moo`9l01moo`9l0:ioo`00DGoo0W`07goo0W`0[7oo001COol2O00OOol2O02ZOol0
05Eoo`9l01moo`9l0:Qoo`00Egoo00=l07ooOol07Woo0W`0YWoo001HOol2O00POol2O02TOol005Yo
o`03O01oogoo01moo`9l0:9oo`00Fgoo00=l07ooOol087oo0W`0X7oo001LOol00g`0Oomoo`0QOol2
O02NOol005eoo`9l02=oo`9l09aoo`00Ggoo00=l07ooOol08Woo0W`0VWoo001POol00g`0Oomoo`0S
Ool2O02HOol0065oo`9l02Eoo`9l09Ioo`00Hgoo0W`09Goo0W`0U7oo001UOol2O00UOol00g`0Oomo
o`2AOol006Moo`03O01oogoo02=oo`9l095oo`00J7oo0W`09Goo00=l07ooOol0SWoo001ZOol2O00T
Ool2O02>Ool006aoo`9l02Aoo`9l08aoo`00KWoo0W`097oo0W`0RWoo001`Ool2O00TOol2O028Ool0
079oo`03O01oogoo02=oo`9l08Ioo`00Lgoo0W`09Goo0W`0Q7oo001eOol2O00UOol2O022Ool007Mo
o`03O01oogoo02Aoo`03O01oogoo07moo`00N7oo0W`09Goo0W`0Ogoo001jOol2O00UOol00g`0Oomo
o`1lOol007aoo`9l02Aoo`9l07aoo`00OWoo0W`097oo0W`0NWoo0020Ool2O00TOol2O01hOol0089o
o`03O01oogoo02=oo`9l07Ioo`00Pgoo0W`09Goo00=l07ooOol0Lgoo0025Ool2O00TOol2O01cOol0
08Moo`03O01oogoo02=oo`03O01oogoo071oo`00R7oo0W`097oo0W`0L7oo002:Ool2O00TOol2O01^
Ool008aoo`9l02Aoo`9l06aoo`00SWoo0W`097oo0W`0JWoo002@Ool2O00TOol2O01XOol0099oo`03
O01oogoo02=oo`03O01oogoo06Eoo`00Tgoo0W`097oo0W`0IGoo002EOol2O00TOol00g`0Oomoo`1R
Ool009Moo`03O01oogoo029oo`9l069oo`00V7oo0W`097oo00=l07ooOol0Ggoo002JOol2O00SOol2
O01OOol009aoo`9l02=oo`9l05eoo`00WWoo0W`08goo00=l07ooOol0FWoo002POol2O00ROol00g`0
Oomoo`1IOol00:9oo`9l025oo`9l05Uoo`00Y7oo0W`08Goo00=l07ooOol0EWoo002VOol2O00POol2
O01FOol00:Qoo`9l021oo`9l05Aoo`00ZWoo0W`087oo00=l07ooOol0DGoo002/Ool2O00OOol00g`0
Oomoo`1@Ool00:ioo`=l01eoo`9l051oo`00/Goo0W`07Goo00=l07ooOol0CGoo002cOol2O00LOol0
0g`0Oomoo`1<Ool00;Eoo`=l01Yoo`9l04aoo`00^7oo0W`06Woo00=l07ooOol0BGoo002jOol2O00I
Ool2O019Ool00;aoo`=l01Qoo`03O01oogoo04Ioo`00_goo0W`05goo00=l07ooOol0AGoo0031Ool2
O00FOol00g`0Oomoo`14Ool00<=oo`9l01Eoo`03O01oogoo04=oo`00aGoo0W`057oo0W`0@goo0037
Ool2O00DOol00g`0Oomoo`10Ool00<Uoo`9l01=oo`03O01oogoo03moo`00bgoo0g`04Goo00=l07oo
Ool0?Woo003>Ool2O00@Ool00g`0Oomoo`0mOol00=1oo`9l00moo`03O01oogoo03aoo`00dWoo17`0
37oo00=l07ooOol0>goo003FOol4O008Ool00g`0Oomoo`0kOol00=Yoo`=l00Eoo`03O01oogoo03]o
o`00gGoo1G`0?Woo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.48016 .46014 m
.50227 .46999 L
s
.50227 .46999 m
.52435 .48001 L
s
.52435 .48001 m
.54631 .49018 L
s
.45811 .45052 m
.48016 .46014 L
s
.54631 .49018 m
.56803 .50043 L
s
.43622 .44116 m
.45811 .45052 L
s
.56803 .50043 m
.58943 .51074 L
s
.4146 .43212 m
.43622 .44116 L
s
.58943 .51074 m
.61041 .52104 L
s
.39335 .42343 m
.4146 .43212 L
s
.61041 .52104 m
.63087 .5313 L
s
.37256 .41515 m
.39335 .42343 L
s
.63087 .5313 m
.65069 .54146 L
s
.35235 .40732 m
.37256 .41515 L
s
.65069 .54146 m
.66979 .55147 L
s
.33283 .39998 m
.35235 .40732 L
s
.66979 .55147 m
.68804 .56129 L
s
.3141 .39318 m
.33283 .39998 L
s
.68804 .56129 m
.70535 .57086 L
s
.29628 .38697 m
.3141 .39318 L
s
.70535 .57086 m
.72159 .58012 L
s
.2795 .38141 m
.29628 .38697 L
s
.72159 .58012 m
.73665 .58902 L
s
.26387 .37653 m
.2795 .38141 L
s
.73665 .58902 m
.75042 .5975 L
s
.24951 .37238 m
.26387 .37653 L
s
.75042 .5975 m
.76278 .60549 L
s
.23656 .36902 m
.24951 .37238 L
s
.76278 .60549 m
.77361 .61293 L
s
.22515 .36649 m
.23656 .36902 L
s
.77361 .61293 m
.78278 .61976 L
s
.21538 .36484 m
.22515 .36649 L
s
.78278 .61976 m
.79018 .62591 L
s
.2074 .36411 m
.21538 .36484 L
s
.79018 .62591 m
.7957 .63132 L
s
.20133 .36434 m
.2074 .36411 L
s
.7957 .63132 m
.79923 .63591 L
s
.19728 .36557 m
.20133 .36434 L
s
.79923 .63591 m
.80066 .63963 L
s
.19536 .36781 m
.19728 .36557 L
s
.80066 .63963 m
.79991 .64242 L
s
.19567 .37111 m
.19536 .36781 L
s
.79991 .64242 m
.79689 .64421 L
s
.19829 .37547 m
.19567 .37111 L
s
.79689 .64421 m
.79153 .64495 L
s
.20329 .38089 m
.19829 .37547 L
s
.79153 .64495 m
.7838 .64459 L
s
.21072 .38737 m
.20329 .38089 L
s
.7838 .64459 m
.77367 .6431 L
s
.2206 .3949 m
.21072 .38737 L
s
.77367 .6431 m
.76115 .64045 L
s
.23293 .40343 m
.2206 .3949 L
s
.76115 .64045 m
.74626 .63663 L
s
.24768 .41293 m
.23293 .40343 L
s
.74626 .63663 m
.72906 .63162 L
s
.26478 .42333 m
.24768 .41293 L
s
.72906 .63162 m
.70964 .62543 L
s
.28413 .43456 m
.26478 .42333 L
s
.70964 .62543 m
.68815 .61811 L
s
.3056 .44652 m
.28413 .43456 L
s
.68815 .61811 m
.66473 .60968 L
s
.32902 .45911 m
.3056 .44652 L
s
.66473 .60968 m
.63959 .60021 L
s
.35418 .47221 m
.32902 .45911 L
s
.63959 .60021 m
.61295 .58978 L
s
.38084 .48569 m
.35418 .47221 L
s
.61295 .58978 m
.58507 .57848 L
s
.40875 .49942 m
.38084 .48569 L
s
.58507 .57848 m
.55624 .56643 L
s
.43761 .51323 m
.40875 .49942 L
s
.55624 .56643 m
.52675 .55373 L
s
.46711 .52699 m
.43761 .51323 L
s
.52675 .55373 m
.49693 .54054 L
s
.49693 .54054 m
.46711 .52699 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00>7oo1g`0hGoo000h
Ool00g`0Oomoo`04Ool6O03KOol003Qoo`03O01oogoo00Yoo`=l0=Qoo`00>7oo00=l07ooOol03Goo
0W`0eWoo000iOol00g`0Oomoo`0>Ool4O03BOol003Yoo`03O01oogoo015oo`Al0<ioo`00>goo00=l
07ooOol057oo0W`0c7oo000lOol00g`0Oomoo`0EOol4O038Ool003eoo`9l01Uoo`Al0<Aoo`00?goo
00=l07ooOol06Woo0W`0`Woo0010Ool2O00LOol3O02oOol0049oo`03O01oogoo01aoo`=l0;aoo`00
@goo0W`07goo0W`0^Woo0015Ool2O00OOol2O02hOol004Moo`03O01oogoo01ioo`9l0;Ioo`00B7oo
00=l07ooOol07goo0W`0]7oo0019Ool2O00QOol3O02aOol004]oo`03O01oogoo025oo`9l0:moo`00
C7oo0W`08goo0W`0[Goo001>Ool2O00SOol2O02[Ool0051oo`9l02=oo`=l0:Qoo`00DWoo0W`097oo
17`0Y7oo001DOol00g`0Oomoo`0UOol2O02ROol005Eoo`9l02Moo`9l0:1oo`00Egoo0W`09goo0W`0
WWoo001IOol2O00WOol2O02LOol005]oo`9l02Moo`9l09Yoo`00GGoo0W`09goo0W`0V7oo001OOol2
O00WOol3O02EOol0065oo`9l02Qoo`Al095oo`00Hgoo0W`0:Woo0W`0Sgoo001UOol00g`0Oomoo`0Y
Ool2O02=Ool006Ioo`9l02]oo`9l08]oo`00J7oo0W`0:goo0W`0RGoo001ZOol2O00[Ool2O027Ool0
06aoo`9l02]oo`9l08Eoo`00KWoo0W`0:goo0g`0PWoo001`Ool2O00/Ool2O020Ool0079oo`9l02ao
o`9l07ioo`00M7oo0W`0;7oo0W`0O7oo001fOol2O00/Ool2O01jOol007Qoo`9l02aoo`9l07Qoo`00
NWoo0W`0;7oo0W`0MWoo001lOol3O00[Ool2O01dOol007moo`9l02]oo`9l079oo`00PGoo0W`0:goo
0W`0L7oo0023Ool2O00[Ool2O01^Ool008Eoo`9l02]oo`9l06aoo`00Qgoo0W`0:goo0W`0JWoo0029
Ool2O00[Ool2O01XOol008]oo`9l02]oo`9l06Ioo`00SGoo0g`0:Woo00=l07ooOol0Hgoo002@Ool3
O00XOol2O01SOol009=oo`=l02Moo`9l065oo`00UWoo0W`09goo0W`0Ggoo002HOol2O00WOol2O01M
Ool009Yoo`9l02Moo`9l05]oo`00W7oo0W`09goo0W`0FGoo002NOol2O00WOol2O01GOol00:1oo`9l
02Moo`9l05Eoo`00XWoo0W`09goo0W`0Dgoo002TOol2O00WOol2O01AOol00:Ioo`=l02Ioo`03O01o
ogoo04ioo`00ZGoo0W`09Goo00=l07ooOol0CGoo002[Ool3O00SOol2O01=Ool00:ioo`=l029oo`03
O01oogoo04Yoo`00/Goo0W`08Goo0W`0BWoo002cOol3O00POol2O018Ool00;Ioo`=l01moo`9l04Io
o`00^Goo17`07Goo00=l07ooOol0@goo002mOol3O00KOol2O013Ool00<1oo`9l01]oo`9l045oo`00
`Woo0W`06goo00=l07ooOol0?Woo0034Ool3O00IOol00g`0Oomoo`0mOol00<Moo`=l01Moo`03O01o
ogoo03aoo`00bWoo0g`05Goo00=l07ooOol0>goo003=Ool3O00COol00g`0Oomoo`0jOol00=1oo`Al
011oo`03O01oogoo03Uoo`00e7oo17`03Goo00=l07ooOol0>7oo003HOol4O009Ool00g`0Oomoo`0h
Ool00=aoo`Il009oo`9l03Yoo`00hWoo0W`0?7oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.50545 .47044 m
.52811 .4788 L
s
.48274 .46225 m
.50545 .47044 L
s
.52811 .4788 m
.55063 .48732 L
s
.4601 .45428 m
.48274 .46225 L
s
.55063 .48732 m
.57291 .49594 L
s
.4376 .44657 m
.4601 .45428 L
s
.57291 .49594 m
.59485 .50463 L
s
.41536 .43914 m
.4376 .44657 L
s
.59485 .50463 m
.61635 .51336 L
s
.39349 .43204 m
.41536 .43914 L
s
.61635 .51336 m
.6373 .52208 L
s
.37207 .42531 m
.39349 .43204 L
s
.6373 .52208 m
.6576 .53075 L
s
.35123 .41897 m
.37207 .42531 L
s
.6576 .53075 m
.67714 .53934 L
s
.33107 .41308 m
.35123 .41897 L
s
.67714 .53934 m
.69581 .54779 L
s
.31171 .40766 m
.33107 .41308 L
s
.69581 .54779 m
.71351 .55606 L
s
.29326 .40275 m
.31171 .40766 L
s
.71351 .55606 m
.7301 .56411 L
s
.27584 .3984 m
.29326 .40275 L
s
.7301 .56411 m
.74547 .57189 L
s
.25959 .39465 m
.27584 .3984 L
s
.74547 .57189 m
.75951 .57934 L
s
.24461 .39153 m
.25959 .39465 L
s
.75951 .57934 m
.77209 .58641 L
s
.23106 .38908 m
.24461 .39153 L
s
.77209 .58641 m
.78308 .59305 L
s
.21905 .38734 m
.23106 .38908 L
s
.78308 .59305 m
.79235 .59919 L
s
.20871 .38635 m
.21905 .38734 L
s
.79235 .59919 m
.7998 .60479 L
s
.20018 .38614 m
.20871 .38635 L
s
.7998 .60479 m
.8053 .60979 L
s
.19359 .38674 m
.20018 .38614 L
s
.8053 .60979 m
.80872 .61412 L
s
.18905 .38818 m
.19359 .38674 L
s
.80872 .61412 m
.80998 .61772 L
s
.18668 .39048 m
.18905 .38818 L
s
.80998 .61772 m
.80897 .62055 L
s
.18659 .39366 m
.18668 .39048 L
s
.80897 .62055 m
.80561 .62254 L
s
.18887 .39773 m
.18659 .39366 L
s
.80561 .62254 m
.79983 .62366 L
s
.19359 .40269 m
.18887 .39773 L
s
.79983 .62366 m
.79159 .62385 L
s
.2008 .40853 m
.19359 .40269 L
s
.79159 .62385 m
.78086 .62307 L
s
.21055 .41523 m
.2008 .40853 L
s
.78086 .62307 m
.76766 .62131 L
s
.22282 .42277 m
.21055 .41523 L
s
.76766 .62131 m
.752 .61853 L
s
.23761 .4311 m
.22282 .42277 L
s
.752 .61853 m
.73396 .61474 L
s
.25484 .44017 m
.23761 .4311 L
s
.73396 .61474 m
.71364 .60993 L
s
.27442 .44991 m
.25484 .44017 L
s
.71364 .60993 m
.69118 .60412 L
s
.29622 .46024 m
.27442 .44991 L
s
.69118 .60412 m
.66675 .59736 L
s
.32008 .47107 m
.29622 .46024 L
s
.66675 .59736 m
.64055 .58967 L
s
.34578 .48229 m
.32008 .47107 L
s
.64055 .58967 m
.61283 .58113 L
s
.37308 .4938 m
.34578 .48229 L
s
.61283 .58113 m
.58387 .57182 L
s
.40172 .50547 m
.37308 .4938 L
s
.58387 .57182 m
.55396 .56182 L
s
.4314 .51718 m
.40172 .50547 L
s
.55396 .56182 m
.52342 .55124 L
s
.4618 .5288 m
.4314 .51718 L
s
.52342 .55124 m
.49259 .54019 L
s
.49259 .54019 m
.4618 .5288 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00=goo1W`0hgoo000fOol00g`0Oomoo`04
Ool7O03LOol003Eoo`03O01oogoo00aoo`Al0=Qoo`00=Goo00=l07ooOol047oo1G`0dgoo000fOol0
0g`0Oomoo`0DOol5O03>Ool003Moo`03O01oogoo01Qoo`El0<Uoo`00>7oo00=l07ooOol077oo17`0
aGoo000iOol00g`0Oomoo`0OOol3O032Ool003Yoo`9l029oo`=l0;moo`00?7oo00=l07ooOol08Woo
0W`0_Goo000mOol2O00TOol3O02jOol003moo`9l02Eoo`=l0;Moo`00@Goo0W`09Woo17`0/goo0013
Ool2O00XOol5O02^Ool004Eoo`9l02]oo`9l0:aoo`00Agoo0W`0:goo0W`0ZWoo0019Ool00g`0Oomo
o`0ZOol3O02WOol004Yoo`9l02eoo`=l0:Aoo`00C7oo0W`0;Woo0g`0XGoo001>Ool2O00_Ool4O02M
Ool0051oo`9l035oo`=l09Yoo`00DWoo0W`0<Woo0g`0Ugoo001DOol2O00cOol3O02DOol005Ioo`9l
03Aoo`9l099oo`00F7oo0W`0=7oo0W`0T7oo001JOol3O00cOol3O02=Ool005eoo`9l03Aoo`=l08Yo
o`00Ggoo0g`0=7oo0g`0Qgoo001ROol3O00dOol4O023Ool006Eoo`9l03Ioo`9l085oo`00Igoo0g`0
=Goo0W`0Ogoo001ZOol2O00eOol2O01mOol006aoo`9l03Eoo`=l07Yoo`00KWoo0W`0=Woo0g`0Mgoo
001`Ool2O00gOol2O01eOol0079oo`=l03Ioo`9l07=oo`00MGoo0W`0=Woo0W`0LGoo001gOol3O00e
Ool3O01^Ool007Yoo`=l03Eoo`=l06]oo`00OGoo0g`0=Goo0W`0JGoo0020Ool3O00dOol2O01WOol0
08=oo`=l03=oo`9l06Eoo`00QWoo0W`0<goo0g`0HWoo0028Ool2O00dOol3O01OOol008Yoo`9l03Eo
o`9l05eoo`00S7oo0g`0=7oo0W`0Fgoo002?Ool3O00cOol2O01IOol0099oo`=l039oo`9l05Moo`00
UGoo0g`0<Goo0W`0EGoo002HOol2O00aOol3O01BOol009Yoo`=l035oo`9l051oo`00WGoo0g`0<7oo
0W`0CWoo002POol3O00_Ool00g`0Oomoo`1;Ool00:=oo`=l02eoo`9l04]oo`00YWoo0g`0;7oo00=l
07ooOol0B7oo002YOol4O00YOol2O018Ool00:eoo`Al02Moo`9l04Ioo`00/Goo0W`09goo0W`0A7oo
002cOol3O00VOol2O012Ool00;Ioo`=l02Eoo`9l041oo`00^Goo17`08goo0W`0?Woo002mOol4O00Q
Ool2O00lOol00<5oo`Al01moo`03O01oogoo03Uoo`00aGoo0g`07Goo00=l07ooOol0>7oo0038Ool3
O00KOol00g`0Oomoo`0gOol00<]oo`Al01Qoo`03O01oogoo03Ioo`00cgoo1W`04goo00=l07ooOol0
=Goo003EOol5O00>Ool00g`0Oomoo`0eOol00=Yoo`Ql00=oo`Al03Moo`00hWoo0g`0>goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.50916 .46902 m
.53223 .4757 L
s
.48602 .46252 m
.50916 .46902 L
s
.46293 .45625 m
.48602 .46252 L
s
.53223 .4757 m
.55515 .48255 L
s
.43998 .45023 m
.46293 .45625 L
s
.55515 .48255 m
.57782 .48954 L
s
.41728 .44449 m
.43998 .45023 L
s
.57782 .48954 m
.60013 .49663 L
s
.39492 .43905 m
.41728 .44449 L
s
.60013 .49663 m
.62199 .5038 L
s
.37301 .43394 m
.39492 .43905 L
s
.62199 .5038 m
.64327 .51102 L
s
.35166 .4292 m
.37301 .43394 L
s
.64327 .51102 m
.66389 .51825 L
s
.33098 .42485 m
.35166 .4292 L
s
.66389 .51825 m
.68374 .52545 L
s
.31109 .42092 m
.33098 .42485 L
s
.68374 .52545 m
.70268 .5326 L
s
.2921 .41745 m
.31109 .42092 L
s
.70268 .5326 m
.72063 .53966 L
s
.27414 .41445 m
.2921 .41745 L
s
.72063 .53966 m
.73744 .54658 L
s
.25732 .41197 m
.27414 .41445 L
s
.73744 .54658 m
.753 .55333 L
s
.24179 .41002 m
.25732 .41197 L
s
.753 .55333 m
.76719 .55986 L
s
.22766 .40864 m
.24179 .41002 L
s
.76719 .55986 m
.77988 .56613 L
s
.21508 .40786 m
.22766 .40864 L
s
.77988 .56613 m
.79094 .5721 L
s
.20418 .40771 m
.21508 .40786 L
s
.79094 .5721 m
.80024 .5777 L
s
.19508 .4082 m
.20418 .40771 L
s
.80024 .5777 m
.80765 .5829 L
s
.18794 .40936 m
.19508 .4082 L
s
.80765 .5829 m
.81306 .58765 L
s
.18286 .41121 m
.18794 .40936 L
s
.81306 .58765 m
.81634 .59188 L
s
.17998 .41376 m
.18286 .41121 L
s
.81634 .59188 m
.81739 .59555 L
s
.17941 .41703 m
.17998 .41376 L
s
.81739 .59555 m
.81609 .59861 L
s
.18123 .42101 m
.17941 .41703 L
s
.81609 .59861 m
.81238 .60101 L
s
.18555 .4257 m
.18123 .42101 L
s
.81238 .60101 m
.80617 .6027 L
s
.19242 .43109 m
.18555 .4257 L
s
.80617 .6027 m
.79743 .60364 L
s
.20188 .43716 m
.19242 .43109 L
s
.79743 .60364 m
.78612 .60379 L
s
.21394 .44388 m
.20188 .43716 L
s
.78612 .60379 m
.77226 .60312 L
s
.22859 .45122 m
.21394 .44388 L
s
.77226 .60312 m
.75588 .60161 L
s
.24577 .45911 m
.22859 .45122 L
s
.75588 .60161 m
.73706 .59923 L
s
.2654 .4675 m
.24577 .45911 L
s
.73706 .59923 m
.7159 .59599 L
s
.28734 .47633 m
.2654 .4675 L
s
.7159 .59599 m
.69255 .5919 L
s
.31144 .4855 m
.28734 .47633 L
s
.69255 .5919 m
.66719 .58697 L
s
.33748 .49493 m
.31144 .4855 L
s
.66719 .58697 m
.64004 .58123 L
s
.36524 .50453 m
.33748 .49493 L
s
.64004 .58123 m
.61136 .57473 L
s
.39442 .51419 m
.36524 .50453 L
s
.61136 .57473 m
.58144 .56753 L
s
.42474 .52381 m
.39442 .51419 L
s
.58144 .56753 m
.55059 .5597 L
s
.45587 .53327 m
.42474 .52381 L
s
.55059 .5597 m
.51914 .55132 L
s
.48745 .54248 m
.45587 .53327 L
s
.51914 .55132 m
.48745 .54248 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000eOolBO03IOol003=oo`9l019oo`Yl0<moo`00
<goo00=l07ooOol06goo1G`0bWoo000dOol00g`0Oomoo`0OOol6O034Ool003Aoo`03O01oogoo02Eo
o`Al0<1oo`00=Goo00=l07ooOol0:7oo0g`0_Goo000fOol2O00[Ool5O02hOol003Qoo`03O01oogoo
02eoo`El0;=oo`00>Goo00=l07ooOol0<Goo0g`0/7oo000jOol2O00dOol4O02/Ool003aoo`9l03Io
o`El0:Moo`00?Woo0W`0>Goo17`0Xgoo0010Ool3O00jOol4O02OOol004=oo`9l03aoo`El09Yoo`00
AGoo0W`0?goo17`0UWoo0017Ool2O011Ool3O02COol004Uoo`9l049oo`Al08moo`00Bgoo0g`0@goo
0g`0S7oo001>Ool3O013Ool3O029Ool0055oo`=l04=oo`=l08Ioo`00E7oo0W`0A7oo17`0PWoo001F
Ool2O016Ool3O01oOol005Qoo`=l04Ioo`=l07aoo`00Fgoo0W`0Agoo0g`0NGoo001MOol2O018Ool4
O01eOol005moo`=l04Uoo`=l079oo`00HWoo17`0B7oo0g`0Kgoo001VOol4O017Ool3O01/Ool006Yo
o`=l04Moo`=l06Uoo`00KGoo0g`0Agoo0g`0IWoo001`Ool3O017Ool3O01SOol007=oo`9l04Qoo`=l
061oo`00MGoo0g`0B7oo0g`0GGoo001hOol3O018Ool3O01JOol007]oo`=l04Qoo`9l05Qoo`00OWoo
0g`0Agoo0g`0EGoo0021Ool4O016Ool2O01COol008Eoo`Al04Aoo`=l051oo`00RGoo17`0@goo0W`0
CWoo002=Ool3O012Ool3O01;Ool0091oo`=l049oo`9l04Uoo`00Tgoo17`0@7oo0W`0Agoo002GOol5
O00mOol2O015Ool009aoo`Al03]oo`9l04=oo`00X7oo17`0>Goo0W`0@Goo002TOol5O00fOol00g`0
Oomoo`0nOol00:Uoo`Al03=oo`9l03ioo`00[Goo17`0<Goo0W`0?7oo002aOol4O00_Ool2O00jOol0
0;Eoo`Al02eoo`03O01oogoo03Moo`00^Goo17`0:Woo00=l07ooOol0=Woo002mOol6O00UOol2O00f
Ool00<=oo`El029oo`03O01oogoo03=oo`00b7oo17`07Woo00=l07ooOol0<goo003<Ool:O00DOol0
0g`0Oomoo`0cOol00=Ioo`El00]oo`Al03Ioo`00fgoo2g`0>Woo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00348436, 0.00348436}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BFieldLHCP\  = \ 
        Show[Array[p, {Steps}], ViewPoint \[Rule] {0, 0, 2}];\)\)], "Input",
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.5 .49116 m
.5 .50884 L
s
.5 .47352 m
.5 .49116 L
s
.5 .50884 m
.5 .52648 L
s
.48459 .49343 m
.48465 .51112 L
s
.48462 .47577 m
.48459 .49343 L
s
.48465 .51112 m
.4848 .52877 L
s
.5 .45595 m
.5 .47352 L
s
.5 .52648 m
.5 .54405 L
s
.48474 .45818 m
.48462 .47577 L
s
.46929 .49579 m
.46953 .51349 L
s
.46923 .47809 m
.46929 .49579 L
s
.4848 .52877 m
.48504 .54633 L
s
.46953 .51349 m
.46994 .53116 L
s
.46934 .46046 m
.46923 .47809 L
s
.46994 .53116 m
.47053 .54874 L
s
.5 .4385 m
.5 .45595 L
s
.5 .54405 m
.5 .5615 L
s
.48495 .44071 m
.48474 .45818 L
s
.45424 .49831 m
.45478 .51606 L
s
.45397 .48056 m
.45424 .49831 L
s
.45478 .51606 m
.45557 .53375 L
s
.48504 .54633 m
.48537 .56376 L
s
.45397 .46287 m
.45397 .48056 L
s
.46964 .44294 m
.46934 .46046 L
s
.45557 .53375 m
.45664 .55135 L
s
.47053 .54874 m
.4713 .56617 L
s
.45423 .44529 m
.45397 .46287 L
s
.43961 .50108 m
.44056 .51888 L
s
.43901 .48328 m
.43961 .50108 L
s
.48525 .42342 m
.48495 .44071 L
s
.5 .42125 m
.5 .4385 L
s
.5 .5615 m
.5 .57875 L
s
.44056 .51888 m
.44185 .53661 L
s
.43877 .46552 m
.43901 .48328 L
s
.47012 .42559 m
.46964 .44294 L
s
.48537 .56376 m
.48578 .581 L
s
.45664 .55135 m
.45796 .56878 L
s
.44185 .53661 m
.4435 .55422 L
s
.43888 .44785 m
.43877 .46552 L
s
.45477 .42787 m
.45423 .44529 L
s
.4713 .56617 m
.47225 .58339 L
s
.42555 .50418 m
.42702 .52202 L
s
.42451 .48631 m
.42555 .50418 L
s
.42702 .52202 m
.42892 .53978 L
s
.42392 .46847 m
.42451 .48631 L
s
.48563 .40636 m
.48525 .42342 L
s
.4435 .55422 m
.44548 .57165 L
s
.5 .40423 m
.5 .42125 L
s
.5 .57875 m
.5 .59577 L
s
.47077 .40847 m
.47012 .42559 L
s
.43936 .43035 m
.43888 .44785 L
s
.45796 .56878 m
.45955 .586 L
s
.42892 .53978 m
.43125 .55739 L
s
.48578 .581 m
.48629 .59798 L
s
.42376 .45072 m
.42392 .46847 L
s
.45557 .41067 m
.45477 .42787 L
s
.47225 .58339 m
.47337 .60036 L
s
.41221 .50765 m
.41431 .52552 L
s
.41062 .48973 m
.41221 .50765 L
s
.41431 .52552 m
.41692 .54329 L
s
.43125 .55739 m
.434 .57481 L
s
.40956 .47182 m
.41062 .48973 L
s
.44548 .57165 m
.44782 .58885 L
s
.42406 .43311 m
.42376 .45072 L
s
.4402 .41305 m
.43936 .43035 L
s
.41692 .54329 m
.42003 .56089 L
s
.40902 .45397 m
.40956 .47182 L
s
.48611 .38959 m
.48563 .40636 L
s
.45955 .586 m
.4614 .60294 L
s
.5 .38752 m
.5 .40423 L
s
.5 .59577 m
.5 .61248 L
s
.47162 .39164 m
.47077 .40847 L
s
.48629 .59798 m
.48688 .61466 L
s
.434 .57481 m
.43718 .59197 L
s
.45666 .39376 m
.45557 .41067 L
s
.42003 .56089 m
.42364 .57826 L
s
.39972 .51153 m
.40255 .52941 L
s
.39749 .49358 m
.39972 .51153 L
s
.42481 .4157 m
.42406 .43311 L
s
.40255 .52941 m
.40596 .54715 L
s
.40902 .43625 m
.40902 .45397 L
s
.39585 .4756 m
.39749 .49358 L
s
.44782 .58885 m
.45049 .60575 L
s
.47337 .60036 m
.47467 .617 L
s
.40596 .54715 m
.40995 .5647 L
s
.44141 .39603 m
.4402 .41305 L
s
.39482 .45767 m
.39585 .4756 L
s
.42364 .57826 m
.42775 .59535 L
s
.4614 .60294 m
.4635 .61954 L
s
.40995 .5647 m
.4145 .58199 L
s
.40957 .41872 m
.40902 .43625 L
s
.48669 .37319 m
.48611 .38959 L
s
.43718 .59197 m
.44077 .60881 L
s
.47264 .37517 m
.47162 .39164 L
s
.5 .37117 m
.5 .38752 L
s
.5 .61248 m
.5 .62883 L
s
.38823 .51583 m
.39188 .53368 L
s
.38525 .49787 m
.38823 .51583 L
s
.42602 .39856 m
.42481 .4157 L
s
.39188 .53368 m
.39617 .55135 L
s
.39441 .43985 m
.39482 .45767 L
s
.45802 .37719 m
.45666 .39376 L
s
.38294 .47987 m
.38525 .49787 L
s
.48688 .61466 m
.48756 .63096 L
s
.39617 .55135 m
.40111 .5688 L
s
.45049 .60575 m
.45351 .6223 L
s
.4145 .58199 m
.41961 .59896 L
s
.38131 .46188 m
.38294 .47987 L
s
.44299 .37935 m
.44141 .39603 L
s
.42775 .59535 m
.43234 .61209 L
s
.47467 .617 m
.47615 .63325 L
s
.40111 .5688 m
.40667 .58595 L
s
.39464 .42219 m
.39441 .43985 L
s
.41066 .40144 m
.40957 .41872 L
s
.38238 .53829 m
.38764 .55584 L
s
.37784 .52053 m
.38238 .53829 L
s
.37403 .50263 m
.37784 .52053 L
s
.44077 .60881 m
.44478 .62527 L
s
.38039 .44397 m
.38131 .46188 L
s
.4635 .61954 m
.46587 .63573 L
s
.38764 .55584 m
.39358 .57312 L
s
.4277 .38175 m
.42602 .39856 L
s
.37095 .48463 m
.37403 .50263 L
s
.40667 .58595 m
.41284 .60274 L
s
.41961 .59896 m
.42527 .61555 L
s
.48735 .35721 m
.48669 .37319 L
s
.47386 .35911 m
.47264 .37517 L
s
.5 .35525 m
.5 .37117 L
s
.5 .62883 m
.5 .64475 L
s
.39358 .57312 m
.4002 .59005 L
s
.45967 .36104 m
.45802 .37719 L
s
.36863 .46662 m
.37095 .48463 L
s
.45351 .6223 m
.45686 .63841 L
s
.43234 .61209 m
.43741 .62841 L
s
.3955 .40477 m
.39464 .42219 L
s
.48756 .63096 m
.48834 .64682 L
s
.38018 .4262 m
.38039 .44397 L
s
.41232 .38448 m
.41066 .40144 L
s
.37416 .5432 m
.38041 .56054 L
s
.36866 .52559 m
.37416 .5432 L
s
.44494 .36308 m
.44299 .37935 L
s
.36394 .5078 m
.36866 .52559 L
s
.38041 .56054 m
.38741 .57757 L
s
.4002 .59005 m
.40747 .60658 L
s
.41284 .60274 m
.41961 .6191 L
s
.47615 .63325 m
.4778 .64905 L
s
.36709 .44864 m
.36863 .46662 L
s
.36002 .48987 m
.36394 .5078 L
s
.38741 .57757 m
.39512 .59421 L
s
.44478 .62527 m
.4492 .64126 L
s
.42527 .61555 m
.43147 .63168 L
s
.42985 .36534 m
.4277 .38175 L
s
.46587 .63573 m
.4685 .65145 L
s
.35692 .47188 m
.36002 .48987 L
s
.38069 .40864 m
.38018 .4262 L
s
.39512 .59421 m
.40352 .61039 L
s
.40747 .60658 m
.41539 .62265 L
s
.36725 .5483 m
.37455 .56535 L
s
.36074 .53094 m
.36725 .5483 L
s
.39701 .38766 m
.3955 .40477 L
s
.37455 .56535 m
.38262 .58203 L
s
.36634 .43078 m
.36709 .44864 L
s
.35506 .51333 m
.36074 .53094 L
s
.43741 .62841 m
.44296 .64425 L
s
.38262 .58203 m
.39143 .59828 L
s
.47526 .34355 m
.47386 .35911 L
s
.48811 .34173 m
.48735 .35721 L
s
.41961 .6191 m
.42697 .63497 L
s
.4616 .34537 m
.45967 .36104 L
s
.5 .33985 m
.5 .35525 L
s
.5 .64475 m
.5 .66015 L
s
.45686 .63841 m
.46055 .65402 L
s
.41454 .36792 m
.41232 .38448 L
s
.35024 .49555 m
.35506 .51333 L
s
.35467 .4539 m
.35692 .47188 L
s
.39143 .59828 m
.40097 .61402 L
s
.40352 .61039 m
.4126 .62606 L
s
.48834 .64682 m
.4892 .66216 L
s
.44728 .34729 m
.44494 .36308 L
s
.37005 .57014 m
.3792 .58637 L
s
.36169 .55348 m
.37005 .57014 L
s
.35415 .53646 m
.36169 .55348 L
s
.43147 .63168 m
.43819 .64728 L
s
.3792 .58637 m
.38911 .60212 L
s
.41539 .62265 m
.42394 .63817 L
s
.34629 .47766 m
.35024 .49555 L
s
.4492 .64126 m
.45403 .65673 L
s
.38195 .39137 m
.38069 .40864 L
s
.34748 .51914 m
.35415 .53646 L
s
.3664 .41311 m
.36634 .43078 L
s
.4778 .64905 m
.47963 .66431 L
s
.38911 .60212 m
.39974 .61731 L
s
.40097 .61402 m
.41118 .6292 L
s
.43248 .34941 m
.42985 .36534 L
s
.39919 .37092 m
.39701 .38766 L
s
.35328 .43599 m
.35467 .4539 L
s
.3771 .59042 m
.38807 .60556 L
s
.36688 .57474 m
.3771 .59042 L
s
.35747 .55859 m
.36688 .57474 L
s
.4126 .62606 m
.42232 .64114 L
s
.42697 .63497 m
.43491 .65026 L
s
.34169 .50159 m
.34748 .51914 L
s
.38807 .60556 m
.39977 .6201 L
s
.3489 .54202 m
.35747 .55859 L
s
.39974 .61731 m
.41106 .6319 L
s
.4685 .65145 m
.47139 .66661 L
s
.44296 .64425 m
.44898 .65951 L
s
.34324 .45973 m
.34629 .47766 L
s
.37624 .59401 m
.38822 .60843 L
s
.365 .579 m
.37624 .59401 L
s
.38822 .60843 m
.40092 .62222 L
s
.35456 .56346 m
.365 .579 L
s
.39977 .6201 m
.41214 .63399 L
s
.41118 .6292 m
.42205 .64374 L
s
.34121 .5251 m
.3489 .54202 L
s
.41734 .35182 m
.41454 .36792 L
s
.40092 .62222 m
.41426 .6353 L
s
.42394 .63817 m
.43308 .65307 L
s
.33683 .48388 m
.34169 .50159 L
s
.47685 .32856 m
.47526 .34355 L
s
.34497 .54746 m
.35456 .56346 L
s
.48896 .32683 m
.48811 .34173 L
s
.46055 .65402 m
.46458 .66905 L
s
.41106 .6319 m
.42304 .6458 L
s
.46381 .33028 m
.4616 .34537 L
s
.36729 .39569 m
.3664 .41311 L
s
.43819 .64728 m
.44544 .66228 L
s
.35279 .41823 m
.35328 .43599 L
s
.5 .32503 m
.5 .33985 L
s
.5 .66015 m
.5 .67497 L
s
.41426 .6353 m
.42822 .64763 L
s
.41214 .63399 m
.42515 .64715 L
s
.38396 .37445 m
.38195 .39137 L
s
.33444 .50789 m
.34121 .5251 L
s
.42232 .64114 m
.43266 .65556 L
s
.45001 .33207 m
.44728 .34729 L
s
.34114 .44182 m
.34324 .45973 L
s
.33627 .53105 m
.34497 .54746 L
s
.4892 .66216 m
.49016 .67689 L
s
.45403 .65673 m
.45925 .67159 L
s
.42205 .64374 m
.43355 .65757 L
s
.43491 .65026 m
.44339 .66491 L
s
.40204 .35464 m
.39919 .37092 L
s
.33293 .46608 m
.33683 .48388 L
s
.42822 .64763 m
.44273 .65915 L
s
.42304 .6458 m
.43563 .65895 L
s
.43559 .33403 m
.43248 .34941 L
s
.42515 .64715 m
.43875 .65952 L
s
.47963 .66431 m
.48164 .67894 L
s
.32863 .49046 m
.33444 .50789 L
s
.3285 .5143 m
.33627 .53105 L
s
.43308 .65307 m
.4428 .66729 L
s
.44898 .65951 m
.45545 .67413 L
s
.3532 .40069 m
.35279 .41823 L
s
.36903 .37861 m
.36729 .39569 L
s
.47139 .66661 m
.47454 .68113 L
s
.44273 .65915 m
.45775 .66979 L
s
.33999 .42402 m
.34114 .44182 L
s
.43266 .65556 m
.44358 .66925 L
s
.42072 .33628 m
.41734 .35182 L
s
.33002 .44825 m
.33293 .46608 L
s
.43875 .65952 m
.45289 .67105 L
s
.38674 .35798 m
.38396 .37445 L
s
.43355 .65757 m
.44563 .67063 L
s
.44544 .66228 m
.45318 .67659 L
s
.43563 .65895 m
.44878 .67129 L
s
.32381 .47288 m
.32863 .49046 L
s
.32171 .49727 m
.3285 .5143 L
s
.46458 .66905 m
.46893 .68342 L
s
.47863 .31423 m
.47685 .32856 L
s
.4899 .3126 m
.48896 .32683 L
s
.46632 .31584 m
.46381 .33028 L
s
.44339 .66491 m
.45242 .67884 L
s
.45775 .66979 m
.47321 .6795 L
s
.5 .31089 m
.5 .32503 L
s
.5 .67497 m
.5 .68911 L
s
.45312 .3175 m
.45001 .33207 L
s
.40557 .33891 m
.40204 .35464 L
s
.45925 .67159 m
.46487 .68574 L
s
.4428 .66729 m
.45308 .68073 L
s
.33983 .4064 m
.33999 .42402 L
s
.49016 .67689 m
.49121 .69093 L
s
.35455 .38345 m
.3532 .40069 L
s
.45289 .67105 m
.46752 .68166 L
s
.32814 .43048 m
.33002 .44825 L
s
.43919 .31931 m
.43559 .33403 L
s
.32005 .45523 m
.32381 .47288 L
s
.31596 .48003 m
.32171 .49727 L
s
.44358 .66925 m
.45507 .68212 L
s
.37162 .36194 m
.36903 .37861 L
s
.44878 .67129 m
.46247 .68273 L
s
.44563 .67063 m
.45826 .68284 L
s
.45545 .67413 m
.46237 .68802 L
s
.48164 .67894 m
.48382 .69287 L
s
.47321 .6795 m
.48907 .68821 L
s
.39031 .34204 m
.38674 .35798 L
s
.42469 .32137 m
.42072 .33628 L
s
.45318 .67659 m
.46142 .69013 L
s
.47454 .68113 m
.47794 .69492 L
s
.46752 .68166 m
.4826 .69129 L
s
.45242 .67884 m
.46195 .69194 L
s
.31129 .46265 m
.31596 .48003 L
s
.32731 .41284 m
.32814 .43048 L
s
.31736 .43757 m
.32005 .45523 L
s
.34068 .38905 m
.33983 .4064 L
s
.46893 .68342 m
.47361 .69702 L
s
.35685 .36661 m
.35455 .38345 L
s
.46247 .68273 m
.47663 .69322 L
s
.45308 .68073 m
.46388 .69332 L
s
.40979 .3238 m
.40557 .33891 L
s
.4806 .30065 m
.47863 .31423 L
s
.46912 .30214 m
.46632 .31584 L
s
.45826 .68284 m
.4714 .69411 L
s
.45507 .68212 m
.46708 .69409 L
s
.49094 .29913 m
.4899 .3126 L
s
.45663 .30367 m
.45312 .3175 L
s
.3751 .34579 m
.37162 .36194 L
s
.48907 .68821 m
.50525 .69586 L
s
.46487 .68574 m
.47088 .69911 L
s
.5 .29752 m
.5 .31089 L
s
.5 .68911 m
.5 .70248 L
s
.44329 .30533 m
.43919 .31931 L
s
.49121 .69093 m
.49234 .70419 L
s
.46237 .68802 m
.46972 .70107 L
s
.4826 .69129 m
.49805 .69987 L
s
.39466 .32672 m
.39031 .34204 L
s
.30774 .44521 m
.31129 .46265 L
s
.31579 .41999 m
.31736 .43757 L
s
.32758 .39542 m
.32731 .41284 L
s
.48382 .69287 m
.48618 .706 L
s
.42926 .30721 m
.42469 .32137 L
s
.46142 .69013 m
.47012 .7028 L
s
.34258 .37205 m
.34068 .38905 L
s
.47663 .69322 m
.49122 .70267 L
s
.36012 .35025 m
.35685 .36661 L
s
.46195 .69194 m
.47197 .70415 L
s
.50525 .69586 m
.5217 .7024 L
s
.47794 .69492 m
.48159 .70788 L
s
.4714 .69411 m
.485 .70437 L
s
.46388 .69332 m
.47518 .70496 L
s
.46708 .69409 m
.47958 .70509 L
s
.41472 .30943 m
.40979 .3238 L
s
.37947 .33024 m
.3751 .34579 L
s
.47361 .69702 m
.47861 .70977 L
s
.49805 .69987 m
.51382 .70732 L
s
.30537 .42779 m
.30774 .44521 L
s
.47221 .2893 m
.46912 .30214 L
s
.48277 .28793 m
.4806 .30065 L
s
.31539 .40258 m
.31579 .41999 L
s
.46053 .29069 m
.45663 .30367 L
s
.49208 .28652 m
.49094 .29913 L
s
.47088 .69911 m
.47725 .71158 L
s
.32897 .37832 m
.32758 .39542 L
s
.5 .28503 m
.5 .29752 L
s
.5 .70248 m
.5 .71497 L
s
.44788 .29218 m
.44329 .30533 L
s
.39982 .31212 m
.39466 .32672 L
s
.49122 .70267 m
.50618 .711 L
s
.34554 .3555 m
.34258 .37205 L
s
.46972 .70107 m
.47749 .71321 L
s
.5217 .7024 m
.53833 .70775 L
s
.49234 .70419 m
.49357 .71656 L
s
.485 .70437 m
.49901 .71353 L
s
.36439 .33446 m
.36012 .35025 L
s
.47012 .7028 m
.47926 .71451 L
s
.43443 .29388 m
.42926 .30721 L
s
.47197 .70415 m
.48246 .71535 L
s
.47958 .70509 m
.49252 .71501 L
s
.47518 .70496 m
.48693 .71557 L
s
.48618 .706 m
.48871 .71821 L
s
.30422 .41048 m
.30537 .42779 L
s
.51382 .70732 m
.52984 .71358 L
s
.38474 .31539 m
.37947 .33024 L
s
.48159 .70788 m
.48548 .7199 L
s
.31618 .38543 m
.31539 .40258 L
s
.42035 .29589 m
.41472 .30943 L
s
.33152 .36162 m
.32897 .37832 L
s
.47861 .70977 m
.48391 .72155 L
s
.50618 .711 m
.52145 .71814 L
s
.53833 .70775 m
.55508 .71185 L
s
.34959 .3395 m
.34554 .3555 L
s
.47558 .27741 m
.47221 .2893 L
s
.48512 .27617 m
.48277 .28793 L
s
.47725 .71158 m
.48398 .72306 L
s
.40579 .29833 m
.39982 .31212 L
s
.46482 .27866 m
.46053 .29069 L
s
.49901 .71353 m
.51337 .72151 L
s
.4933 .27488 m
.49208 .28652 L
s
.36966 .31936 m
.36439 .33446 L
s
.45297 .27999 m
.44788 .29218 L
s
.47749 .71321 m
.48565 .72431 L
s
.5 .27352 m
.5 .28503 L
s
.5 .71497 m
.5 .72648 L
s
.49252 .71501 m
.50584 .72377 L
s
.30434 .39336 m
.30422 .41048 L
s
.47926 .71451 m
.48882 .72515 L
s
.52984 .71358 m
.54604 .71857 L
s
.48693 .71557 m
.4991 .72504 L
s
.48246 .71535 m
.49336 .72545 L
s
.4402 .28149 m
.43443 .29388 L
s
.31821 .36863 m
.31618 .38543 L
s
.49357 .71656 m
.49488 .72792 L
s
.39093 .30135 m
.38474 .31539 L
s
.33524 .34543 m
.33152 .36162 L
s
.48871 .71821 m
.4914 .72941 L
s
.55508 .71185 m
.57184 .71464 L
s
.42668 .28329 m
.42035 .29589 L
s
.52145 .71814 m
.53695 .72401 L
s
.35475 .32416 m
.34959 .3395 L
s
.48548 .7199 m
.48961 .73088 L
s
.51337 .72151 m
.52802 .72822 L
s
.48391 .72155 m
.48951 .73226 L
s
.41257 .28549 m
.40579 .29833 L
s
.37595 .30505 m
.36966 .31936 L
s
.30577 .37655 m
.30434 .39336 L
s
.54604 .71857 m
.56233 .72221 L
s
.48398 .72306 m
.49106 .73343 L
s
.50584 .72377 m
.5195 .73127 L
s
.47925 .2666 m
.47558 .27741 L
s
.4695 .2677 m
.46482 .27866 L
s
.32152 .3523 m
.31821 .36863 L
s
.48766 .26549 m
.48512 .27617 L
s
.48565 .72431 m
.49418 .73427 L
s
.45855 .26886 m
.45297 .27999 L
s
.4991 .72504 m
.51163 .73327 L
s
.49462 .26433 m
.4933 .27488 L
s
.48882 .72515 m
.49877 .73462 L
s
.49336 .72545 m
.50465 .73434 L
s
.34018 .32986 m
.33524 .34543 L
s
.57184 .71464 m
.58854 .71606 L
s
.5 .26311 m
.5 .27352 L
s
.5 .72648 m
.5 .73689 L
s
.44658 .27017 m
.4402 .28149 L
s
.39804 .28823 m
.39093 .30135 L
s
.53695 .72401 m
.55261 .72852 L
s
.49488 .72792 m
.49627 .73817 L
s
.36103 .30958 m
.35475 .32416 L
s
.43372 .27174 m
.42668 .28329 L
s
.4914 .72941 m
.49425 .73946 L
s
.52802 .72822 m
.54289 .73357 L
s
.30856 .36015 m
.30577 .37655 L
s
.56233 .72221 m
.57862 .72445 L
s
.38328 .29165 m
.37595 .30505 L
s
.48961 .73088 m
.49396 .74069 L
s
.42016 .27369 m
.41257 .28549 L
s
.32612 .33655 m
.32152 .3523 L
s
.5195 .73127 m
.53343 .73742 L
s
.48951 .73226 m
.49538 .74177 L
s
.34634 .31502 m
.34018 .32986 L
s
.58854 .71606 m
.60508 .71603 L
s
.51163 .73327 m
.52447 .74017 L
s
.49106 .73343 m
.49845 .74258 L
s
.47456 .25792 m
.4695 .2677 L
s
.48319 .25698 m
.47925 .2666 L
s
.49418 .73427 m
.50305 .74297 L
s
.50465 .73434 m
.51627 .74191 L
s
.55261 .72852 m
.56834 .73159 L
s
.49877 .73462 m
.50906 .7428 L
s
.46462 .25891 m
.45855 .26886 L
s
.49039 .25601 m
.48766 .26549 L
s
.40607 .27616 m
.39804 .28823 L
s
.49602 .255 m
.49462 .26433 L
s
.36845 .29588 m
.36103 .30958 L
s
.45354 .26003 m
.44658 .27017 L
s
.5 .25393 m
.5 .26311 L
s
.5 .73689 m
.5 .74607 L
s
.31273 .34426 m
.30856 .36015 L
s
.54289 .73357 m
.5579 .73746 L
s
.44146 .26138 m
.43372 .27174 L
s
.57862 .72445 m
.59482 .7252 L
s
.49627 .73817 m
.49775 .74717 L
s
.33205 .32148 m
.32612 .33655 L
s
.39163 .27928 m
.38328 .29165 L
s
.49425 .73946 m
.49726 .74824 L
s
.53343 .73742 m
.54756 .74212 L
s
.42857 .26307 m
.42016 .27369 L
s
.60508 .71603 m
.62134 .71451 L
s
.35374 .30104 m
.34634 .31502 L
s
.49396 .74069 m
.49853 .74921 L
s
.52447 .74017 m
.53756 .74561 L
s
.56834 .73159 m
.58405 .73314 L
s
.49538 .74177 m
.50151 .74996 L
s
.51627 .74191 m
.52817 .74806 L
s
.49845 .74258 m
.50612 .75037 L
s
.41502 .26525 m
.40607 .27616 L
s
.37701 .28319 m
.36845 .29588 L
s
.50906 .7428 m
.51965 .74957 L
s
.50305 .74297 m
.51223 .75029 L
s
.48 .24947 m
.47456 .25792 L
s
.31833 .32902 m
.31273 .34426 L
s
.48741 .24868 m
.48319 .25698 L
s
.47117 .25028 m
.46462 .25891 L
s
.49329 .24787 m
.49039 .25601 L
s
.59482 .7252 m
.61082 .7244 L
s
.5579 .73746 m
.57297 .73982 L
s
.46108 .2512 m
.45354 .26003 L
s
.49751 .24701 m
.49602 .255 L
s
.33933 .30723 m
.33205 .32148 L
s
.44989 .25232 m
.44146 .26138 L
s
.40101 .26806 m
.39163 .27928 L
s
.5 .24611 m
.5 .25393 L
s
.5 .74607 m
.5 .75389 L
s
.62134 .71451 m
.63722 .71144 L
s
.54756 .74212 m
.56181 .74526 L
s
.3624 .28803 m
.35374 .30104 L
s
.49775 .74717 m
.4993 .75479 L
s
.43777 .25376 m
.42857 .26307 L
s
.58405 .73314 m
.59965 .73309 L
s
.49726 .74824 m
.5004 .75562 L
s
.53756 .74561 m
.55082 .74951 L
s
.49853 .74921 m
.50329 .7563 L
s
.38671 .27164 m
.37701 .28319 L
s
.32538 .31454 m
.31833 .32902 L
s
.52817 .74806 m
.54029 .75266 L
s
.42488 .25564 m
.41502 .26525 L
s
.50151 .74996 m
.50788 .7567 L
s
.61082 .7244 m
.62652 .72199 L
s
.51965 .74957 m
.53048 .75481 L
s
.50612 .75037 m
.51406 .75668 L
s
.51223 .75029 m
.52166 .7561 L
s
.57297 .73982 m
.58799 .74054 L
s
.34796 .29392 m
.33933 .30723 L
s
.48579 .24246 m
.48 .24947 L
s
.47818 .2431 m
.47117 .25028 L
s
.49189 .24184 m
.48741 .24868 L
s
.46919 .24381 m
.46108 .2512 L
s
.63722 .71144 m
.65258 .70678 L
s
.41141 .25813 m
.40101 .26806 L
s
.49636 .24119 m
.49329 .24787 L
s
.45899 .2447 m
.44989 .25232 L
s
.3723 .27614 m
.3624 .28803 L
s
.56181 .74526 m
.57608 .74675 L
s
.49908 .2405 m
.49751 .24701 L
s
.59965 .73309 m
.61501 .73137 L
s
.5 .23979 m
.5 .24611 L
s
.5 .75389 m
.5 .76021 L
s
.44774 .24587 m
.43777 .25376 L
s
.55082 .74951 m
.56418 .75174 L
s
.33389 .30096 m
.32538 .31454 L
s
.4993 .75479 m
.50092 .76089 L
s
.39753 .26137 m
.38671 .27164 L
s
.62652 .72199 m
.64178 .7179 L
s
.5004 .75562 m
.50368 .76146 L
s
.43562 .24746 m
.42488 .25564 L
s
.54029 .75266 m
.55256 .75559 L
s
.35796 .28169 m
.34796 .29392 L
s
.58799 .74054 m
.60286 .73955 L
s
.50329 .7563 m
.50822 .76182 L
s
.53048 .75481 m
.54151 .7584 L
s
.50788 .7567 m
.51445 .76184 L
s
.65258 .70678 m
.66731 .70048 L
s
.52166 .7561 m
.5313 .76028 L
s
.51406 .75668 m
.5222 .76138 L
s
.4228 .24962 m
.41141 .25813 L
s
.38344 .2655 m
.3723 .27614 L
s
.48563 .2375 m
.47818 .2431 L
s
.49193 .23705 m
.48579 .24246 L
s
.47784 .23801 m
.46919 .24381 L
s
.57608 .74675 m
.59028 .74649 L
s
.49662 .2366 m
.49189 .24184 L
s
.61501 .73137 m
.63002 .72792 L
s
.46874 .23866 m
.45899 .2447 L
s
.49958 .23613 m
.49636 .24119 L
s
.34387 .28841 m
.33389 .30096 L
s
.45847 .23956 m
.44774 .24587 L
s
.50073 .23562 m
.49908 .2405 L
s
.40946 .25249 m
.39753 .26137 L
s
.56418 .75174 m
.57754 .75221 L
s
.64178 .7179 m
.65647 .71209 L
s
.5 .23511 m
.5 .23979 L
s
.5 .76021 m
.5 .76489 L
s
.36931 .27068 m
.35796 .28169 L
s
.44721 .24085 m
.43562 .24746 L
s
.60286 .73955 m
.61747 .73677 L
s
.50092 .76089 m
.50261 .76533 L
s
.55256 .75559 m
.56489 .75676 L
s
.66731 .70048 m
.68126 .69251 L
s
.50368 .76146 m
.50707 .76562 L
s
.54151 .7584 m
.55264 .76022 L
s
.3958 .25625 m
.38344 .2655 L
s
.50822 .76182 m
.51331 .76564 L
s
.43515 .24266 m
.4228 .24962 L
s
.5313 .76028 m
.54109 .7627 L
s
.51445 .76184 m
.52118 .76526 L
s
.5222 .76138 m
.53052 .76433 L
s
.63002 .72792 m
.64456 .72268 L
s
.59028 .74649 m
.60431 .74441 L
s
.49349 .23362 m
.48563 .2375 L
s
.487 .23391 m
.47784 .23801 L
s
.35532 .27705 m
.34387 .28841 L
s
.49839 .23337 m
.49193 .23705 L
s
.47909 .23433 m
.46874 .23866 L
s
.50158 .23311 m
.49662 .2366 L
s
.42246 .24517 m
.40946 .25249 L
s
.65647 .71209 m
.67047 .70453 L
s
.4699 .23496 m
.45847 .23956 L
s
.57754 .75221 m
.59079 .75082 L
s
.50295 .23281 m
.49958 .23613 L
s
.38198 .26103 m
.36931 .27068 L
s
.61747 .73677 m
.63168 .73213 L
s
.50244 .23251 m
.50073 .23562 L
s
.68126 .69251 m
.69429 .68286 L
s
.45962 .23593 m
.44721 .24085 L
s
.56489 .75676 m
.5772 .75605 L
s
.5 .23222 m
.5 .23511 L
s
.5 .76489 m
.5 .76778 L
s
.40933 .24852 m
.3958 .25625 L
s
.50261 .76533 m
.50435 .76796 L
s
.44842 .2374 m
.43515 .24266 L
s
.64456 .72268 m
.65848 .71559 L
s
.55264 .76022 m
.56382 .76015 L
s
.50707 .76562 m
.51056 .76795 L
s
.60431 .74441 m
.61804 .74041 L
s
.3682 .267 m
.35532 .27705 L
s
.54109 .7627 m
.55096 .76323 L
s
.51331 .76564 m
.51851 .76761 L
s
.53052 .76433 m
.53894 .7654 L
s
.52118 .76526 m
.52804 .76681 L
s
.67047 .70453 m
.68363 .69519 L
s
.43648 .23952 m
.42246 .24517 L
s
.49663 .23168 m
.487 .23391 L
s
.50172 .23161 m
.49349 .23362 L
s
.49 .23184 m
.47909 .23433 L
s
.39595 .25288 m
.38198 .26103 L
s
.50513 .23156 m
.49839 .23337 L
s
.59079 .75082 m
.60384 .74747 L
s
.48199 .23219 m
.4699 .23496 L
s
.69429 .68286 m
.70626 .67153 L
s
.63168 .73213 m
.64538 .72558 L
s
.50674 .23149 m
.50158 .23311 L
s
.47278 .23285 m
.45962 .23593 L
s
.50645 .2314 m
.50295 .23281 L
s
.424 .24245 m
.40933 .24852 L
s
.5772 .75605 m
.58938 .75335 L
s
.50421 .2313 m
.50244 .23251 L
s
.65848 .71559 m
.67164 .70663 L
s
.46254 .23396 m
.44842 .2374 L
s
.3825 .25843 m
.3682 .267 L
s
.5 .23126 m
.5 .23222 L
s
.5 .76778 m
.5 .76874 L
s
.61804 .74041 m
.63134 .73443 L
s
.56382 .76015 m
.57494 .75808 L
s
.68363 .69519 m
.69579 .68405 L
s
.50435 .76796 m
.50614 .76865 L
s
.55096 .76323 m
.56084 .76175 L
s
.45146 .23568 m
.43648 .23952 L
s
.41116 .24637 m
.39595 .25288 L
s
.51056 .76795 m
.51412 .76832 L
s
.53894 .7654 m
.54742 .76447 L
s
.51851 .76761 m
.52379 .7676 L
s
.70626 .67153 m
.71701 .65853 L
s
.52804 .76681 m
.53498 .76637 L
s
.50667 .23142 m
.49663 .23168 L
s
.50141 .23133 m
.49 .23184 L
s
.64538 .72558 m
.65841 .71707 L
s
.60384 .74747 m
.61656 .7421 L
s
.51028 .23158 m
.50172 .23161 L
s
.49467 .23139 m
.48199 .23219 L
s
.51212 .23175 m
.50513 .23156 L
s
.43973 .23818 m
.424 .24245 L
s
.48662 .23172 m
.47278 .23285 L
s
.51207 .2319 m
.50674 .23149 L
s
.67164 .70663 m
.6839 .69577 L
s
.39814 .25146 m
.3825 .25843 L
s
.58938 .75335 m
.60132 .74858 L
s
.47744 .23247 m
.46254 .23396 L
s
.51005 .23202 m
.50645 .2314 L
s
.63134 .73443 m
.64407 .72642 L
s
.69579 .68405 m
.70681 .67114 L
s
.50602 .23215 m
.50421 .2313 L
s
.42753 .24164 m
.41116 .24637 L
s
.57494 .75808 m
.5859 .75391 L
s
.46731 .23378 m
.45146 .23568 L
s
.71701 .65853 m
.72639 .64389 L
s
.5 .23237 m
.5 .23126 L
s
.5 .76874 m
.5 .76763 L
s
.56084 .76175 m
.57064 .75815 L
s
.65841 .71707 m
.67063 .70657 L
s
.50614 .76865 m
.50795 .76725 L
s
.61656 .7421 m
.62882 .73462 L
s
.51412 .76832 m
.51772 .76658 L
s
.54742 .76447 m
.55588 .76141 L
s
.51326 .23291 m
.50141 .23133 L
s
.45643 .23583 m
.43973 .23818 L
s
.50787 .23267 m
.49467 .23139 L
s
.51706 .23328 m
.50667 .23142 L
s
.52379 .7676 m
.52912 .76548 L
s
.53498 .76637 m
.54193 .76381 L
s
.51912 .23368 m
.51028 .23158 L
s
.50107 .23267 m
.48662 .23172 L
s
.41506 .24623 m
.39814 .25146 L
s
.6839 .69577 m
.6951 .68304 L
s
.51931 .23408 m
.51212 .23175 L
s
.49303 .23304 m
.47744 .23247 L
s
.70681 .67114 m
.71654 .65648 L
s
.60132 .74858 m
.6129 .74167 L
s
.51753 .23445 m
.51207 .2319 L
s
.64407 .72642 m
.6561 .71634 L
s
.44498 .2388 m
.42753 .24164 L
s
.72639 .64389 m
.73427 .62768 L
s
.48394 .23393 m
.46731 .23378 L
s
.51372 .23481 m
.51005 .23202 L
s
.5859 .75391 m
.59661 .74756 L
s
.67063 .70657 m
.68189 .69409 L
s
.50787 .23519 m
.50602 .23215 L
s
.474 .23551 m
.45643 .23583 L
s
.62882 .73462 m
.64048 .72501 L
s
.57064 .75815 m
.58027 .75235 L
s
.5 .23567 m
.5 .23237 L
s
.5 .76763 m
.5 .76433 L
s
.43316 .24287 m
.41506 .24623 L
s
.6951 .68304 m
.70509 .66844 L
s
.5215 .23615 m
.50787 .23267 L
s
.52546 .2367 m
.51326 .23291 L
s
.50795 .76725 m
.50979 .76364 L
s
.51602 .2358 m
.50107 .23267 L
s
.55588 .76141 m
.56423 .75613 L
s
.52773 .23735 m
.51706 .23328 L
s
.51772 .76658 m
.52134 .76262 L
s
.71654 .65648 m
.72482 .64013 L
s
.54193 .76381 m
.54885 .75901 L
s
.52912 .76548 m
.53445 .76112 L
s
.5092 .23577 m
.49303 .23304 L
s
.52817 .23802 m
.51912 .23368 L
s
.46339 .23797 m
.44498 .2388 L
s
.73427 .62768 m
.74049 .60997 L
s
.6561 .71634 m
.66728 .70419 L
s
.6129 .74167 m
.624 .73255 L
s
.52665 .23866 m
.51931 .23408 L
s
.50123 .23622 m
.48394 .23393 L
s
.52309 .23927 m
.51753 .23445 L
s
.68189 .69409 m
.69204 .67965 L
s
.4923 .23732 m
.474 .23551 L
s
.59661 .74756 m
.60693 .73895 L
s
.4523 .2415 m
.43316 .24287 L
s
.51745 .23987 m
.51372 .23481 L
s
.70509 .66844 m
.71371 .65205 L
s
.64048 .72501 m
.6514 .71324 L
s
.50973 .24052 m
.50787 .23519 L
s
.72482 .64013 m
.73151 .62217 L
s
.58027 .75235 m
.58962 .74425 L
s
.53543 .2419 m
.5215 .23615 L
s
.53134 .24118 m
.51602 .2358 L
s
.48262 .23925 m
.46339 .23797 L
s
.5379 .24278 m
.52546 .2367 L
s
.74049 .60997 m
.74493 .59087 L
s
.52581 .24075 m
.5092 .23577 L
s
.5 .24129 m
.5 .23567 L
s
.5 .76433 m
.5 .75871 L
s
.53859 .24373 m
.52773 .23735 L
s
.56423 .75613 m
.5724 .74853 L
s
.66728 .70419 m
.67745 .68997 L
s
.50979 .76364 m
.51162 .7577 L
s
.51903 .24074 m
.50123 .23622 L
s
.54885 .75901 m
.55564 .75188 L
s
.624 .73255 m
.63447 .7212 L
s
.53735 .24468 m
.52817 .23802 L
s
.52134 .76262 m
.52494 .75632 L
s
.53445 .76112 m
.53971 .75443 L
s
.69204 .67965 m
.70092 .6633 L
s
.47236 .24221 m
.4523 .2415 L
s
.5112 .24134 m
.4923 .23732 L
s
.53407 .24559 m
.52665 .23866 L
s
.71371 .65205 m
.72083 .63394 L
s
.60693 .73895 m
.61676 .72805 L
s
.73151 .62217 m
.73648 .60272 L
s
.5287 .24646 m
.52309 .23927 L
s
.6514 .71324 m
.66143 .69932 L
s
.50251 .24271 m
.48262 .23925 L
s
.74493 .59087 m
.74747 .57052 L
s
.52119 .24733 m
.51745 .23987 L
s
.54691 .24889 m
.53134 .24118 L
s
.54273 .24802 m
.52581 .24075 L
s
.54956 .25 m
.53543 .2419 L
s
.58962 .74425 m
.59857 .73382 L
s
.55048 .25123 m
.5379 .24278 L
s
.67745 .68997 m
.68646 .67375 L
s
.5372 .24754 m
.51903 .24074 L
s
.51159 .24825 m
.50973 .24052 L
s
.49316 .24507 m
.47236 .24221 L
s
.54953 .25249 m
.53859 .24373 L
s
.70092 .6633 m
.70838 .64512 L
s
.53052 .24761 m
.5112 .24134 L
s
.63447 .7212 m
.64418 .70762 L
s
.5724 .74853 m
.58028 .73855 L
s
.5 .24932 m
.5 .24129 L
s
.5 .75871 m
.5 .75068 L
s
.72083 .63394 m
.7263 .61422 L
s
.54657 .25374 m
.53735 .24468 L
s
.51162 .7577 m
.51343 .74934 L
s
.55564 .75188 m
.56225 .74235 L
s
.73648 .60272 m
.73961 .58191 L
s
.52494 .75632 m
.52848 .7476 L
s
.53971 .75443 m
.54486 .74532 L
s
.74747 .57052 m
.74801 .54909 L
s
.52289 .24841 m
.50251 .24271 L
s
.54151 .25493 m
.53407 .24559 L
s
.66143 .69932 m
.67043 .68328 L
s
.61676 .72805 m
.62595 .71485 L
s
.55979 .25763 m
.54273 .24802 L
s
.56258 .25895 m
.54691 .24889 L
s
.55556 .25665 m
.5372 .24754 L
s
.53429 .25608 m
.5287 .24646 L
s
.51451 .25014 m
.49316 .24507 L
s
.56374 .26046 m
.54956 .25 L
s
.68646 .67375 m
.69417 .65558 L
s
.55008 .25617 m
.53052 .24761 L
s
.70838 .64512 m
.71429 .62522 L
s
.56308 .26207 m
.55048 .25123 L
s
.59857 .73382 m
.60703 .72102 L
s
.52491 .25723 m
.52119 .24733 L
s
.7263 .61422 m
.73 .59304 L
s
.73961 .58191 m
.7408 .55991 L
s
.74801 .54909 m
.74647 .52675 L
s
.64418 .70762 m
.65299 .69184 L
s
.54356 .25636 m
.52289 .24841 L
s
.56046 .26368 m
.54953 .25249 L
s
.51344 .25845 m
.51159 .24825 L
s
.58028 .73855 m
.58778 .72617 L
s
.5 .25983 m
.5 .24932 L
s
.5 .75068 m
.5 .74017 L
s
.55575 .26524 m
.54657 .25374 L
s
.5362 .25743 m
.51451 .25014 L
s
.67043 .68328 m
.67825 .66521 L
s
.56225 .74235 m
.56858 .73038 L
s
.51343 .74934 m
.51521 .7385 L
s
.57681 .26957 m
.55979 .25763 L
s
.57391 .26806 m
.55556 .25665 L
s
.54486 .74532 m
.54983 .73375 L
s
.52848 .7476 m
.53192 .73641 L
s
.62595 .71485 m
.63437 .69937 L
s
.57818 .27136 m
.56258 .25895 L
s
.56967 .267 m
.55008 .25617 L
s
.69417 .65558 m
.70043 .63559 L
s
.54888 .26674 m
.54151 .25493 L
s
.71429 .62522 m
.71852 .60376 L
s
.7408 .55991 m
.73996 .53693 L
s
.73 .59304 m
.73183 .57058 L
s
.74647 .52675 m
.7428 .50372 L
s
.57781 .27331 m
.56374 .26046 L
s
.5643 .26656 m
.54356 .25636 L
s
.5398 .26819 m
.53429 .25608 L
s
.57555 .27531 m
.56308 .26207 L
s
.60703 .72102 m
.61485 .70588 L
s
.65299 .69184 m
.66076 .67393 L
s
.558 .26694 m
.5362 .25743 L
s
.52856 .26963 m
.52491 .25723 L
s
.57124 .27729 m
.56046 .26368 L
s
.59205 .28173 m
.57391 .26806 L
s
.58907 .28006 m
.56967 .267 L
s
.67825 .66521 m
.68475 .64521 L
s
.5936 .28379 m
.57681 .26957 L
s
.7428 .50372 m
.73698 .48024 L
s
.73996 .53693 m
.73705 .51319 L
s
.58778 .72617 m
.59478 .71138 L
s
.73183 .57058 m
.7317 .54705 L
s
.58488 .27896 m
.5643 .26656 L
s
.70043 .63559 m
.70512 .61394 L
s
.51524 .27115 m
.51344 .25845 L
s
.71852 .60376 m
.72097 .58092 L
s
.59352 .28609 m
.57818 .27136 L
s
.56477 .27919 m
.55575 .26524 L
s
.63437 .69937 m
.64189 .68168 L
s
.56858 .73038 m
.57455 .71596 L
s
.5 .27285 m
.5 .25983 L
s
.5 .74017 m
.5 .72715 L
s
.57967 .27862 m
.558 .26694 L
s
.59162 .2885 m
.57781 .27331 L
s
.54983 .73375 m
.55456 .71969 L
s
.51521 .7385 m
.51692 .72515 L
s
.53192 .73641 m
.53522 .72271 L
s
.55609 .28102 m
.54888 .26674 L
s
.73698 .48024 m
.72902 .45657 L
s
.73705 .51319 m
.73204 .48894 L
s
.60807 .29527 m
.58907 .28006 L
s
.58774 .29092 m
.57555 .27531 L
s
.60977 .29757 m
.59205 .28173 L
s
.66076 .67393 m
.66734 .65399 L
s
.60506 .29348 m
.58488 .27896 L
s
.7317 .54705 m
.72957 .52267 L
s
.61485 .70588 m
.62192 .68844 L
s
.60996 .30021 m
.5936 .28379 L
s
.72097 .58092 m
.72154 .55692 L
s
.60095 .29238 m
.57967 .27862 L
s
.54517 .28278 m
.5398 .26819 L
s
.68475 .64521 m
.6898 .62344 L
s
.70512 .61394 m
.70813 .5908 L
s
.58174 .29329 m
.57124 .27729 L
s
.60843 .30305 m
.59352 .28609 L
s
.72902 .45657 m
.71897 .43297 L
s
.73204 .48894 m
.72493 .46445 L
s
.53209 .28453 m
.52856 .26963 L
s
.6246 .30999 m
.60506 .29348 L
s
.59478 .71138 m
.60119 .69424 L
s
.62642 .31251 m
.60807 .29527 L
s
.6216 .30811 m
.60095 .29238 L
s
.72957 .52267 m
.72539 .49773 L
s
.64189 .68168 m
.64839 .66186 L
s
.605 .30594 m
.59162 .2885 L
s
.62685 .31548 m
.60977 .29757 L
s
.57352 .29556 m
.56477 .27919 L
s
.51697 .28636 m
.51524 .27115 L
s
.71897 .43297 m
.70691 .40971 L
s
.72154 .55692 m
.72018 .532 L
s
.57455 .71596 m
.58007 .69913 L
s
.62568 .31873 m
.60996 .30021 L
s
.72493 .46445 m
.71578 .44 L
s
.66734 .65399 m
.67262 .63218 L
s
.64326 .32834 m
.6246 .30999 L
s
.64136 .32564 m
.6216 .30811 L
s
.5 .28837 m
.5 .27285 L
s
.5 .72715 m
.5 .71163 L
s
.70813 .5908 m
.70937 .56641 L
s
.5995 .30882 m
.58774 .29092 L
s
.6898 .62344 m
.69329 .6001 L
s
.55456 .71969 m
.55897 .70319 L
s
.6439 .33161 m
.62642 .31251 L
s
.56304 .29772 m
.55609 .28102 L
s
.51692 .72515 m
.51854 .70931 L
s
.70691 .40971 m
.69295 .38709 L
s
.53522 .72271 m
.53833 .70654 L
s
.72539 .49773 m
.71919 .47249 L
s
.62271 .32212 m
.60843 .30305 L
s
.65998 .3448 m
.64136 .32564 L
s
.62192 .68844 m
.62813 .66881 L
s
.71578 .44 m
.70467 .41587 L
s
.64308 .33527 m
.62685 .31548 L
s
.66081 .34834 m
.64326 .32834 L
s
.69295 .38709 m
.67725 .36536 L
s
.67725 .36536 m
.65998 .3448 L
s
.72018 .532 m
.71687 .50644 L
s
.59182 .3116 m
.58174 .29329 L
s
.55033 .29981 m
.54517 .28278 L
s
.66029 .35239 m
.6439 .33161 L
s
.70467 .41587 m
.6917 .39237 L
s
.67702 .36977 m
.66081 .34834 L
s
.71919 .47249 m
.71099 .44726 L
s
.61776 .32553 m
.605 .30594 L
s
.64056 .33916 m
.62568 .31873 L
s
.6917 .39237 m
.67702 .36977 L
s
.70937 .56641 m
.70877 .54102 L
s
.64839 .66186 m
.65373 .64009 L
s
.60119 .69424 m
.60689 .67483 L
s
.65823 .35677 m
.64308 .33527 L
s
.67537 .37461 m
.66029 .35239 L
s
.53546 .30188 m
.53209 .28453 L
s
.69329 .6001 m
.69513 .5754 L
s
.71099 .44726 m
.70088 .42233 L
s
.67262 .63218 m
.67648 .6087 L
s
.58188 .31425 m
.57352 .29556 L
s
.71687 .50644 m
.71159 .48053 L
s
.63617 .34314 m
.62271 .32212 L
s
.68896 .39802 m
.67537 .37461 L
s
.61067 .32888 m
.5995 .30882 L
s
.70088 .42233 m
.68896 .39802 L
s
.58007 .69913 m
.58504 .67997 L
s
.51861 .30403 m
.51697 .28636 L
s
.6544 .36131 m
.64056 .33916 L
s
.6721 .37972 m
.65823 .35677 L
s
.70877 .54102 m
.70631 .51492 L
s
.71159 .48053 m
.70439 .45459 L
s
.62813 .66881 m
.63336 .64712 L
s
.56966 .31678 m
.56304 .29772 L
s
.5 .30635 m
.5 .28837 L
s
.5 .71163 m
.5 .69365 L
s
.55897 .70319 m
.563 .68431 L
s
.62973 .34709 m
.61776 .32553 L
s
.51854 .70931 m
.52006 .69102 L
s
.53833 .70654 m
.54119 .68796 L
s
.68453 .40388 m
.6721 .37972 L
s
.60135 .33209 m
.59182 .3116 L
s
.70439 .45459 m
.69533 .42893 L
s
.69513 .5754 m
.69525 .54962 L
s
.69533 .42893 m
.68453 .40388 L
s
.65373 .64009 m
.65782 .61654 L
s
.64862 .3659 m
.63617 .34314 L
s
.667 .38495 m
.6544 .36131 L
s
.67648 .6087 m
.67883 .58377 L
s
.70631 .51492 m
.70197 .48842 L
s
.5552 .31921 m
.55033 .29981 L
s
.60689 .67483 m
.61179 .65329 L
s
.6211 .35093 m
.61067 .32888 L
s
.58973 .33515 m
.58188 .31425 L
s
.6782 .40978 m
.667 .38495 L
s
.70197 .48842 m
.6958 .46185 L
s
.69525 .54962 m
.69362 .52306 L
s
.53862 .3216 m
.53546 .30188 L
s
.64073 .3704 m
.62973 .34709 L
s
.65989 .39015 m
.64862 .3659 L
s
.68784 .43552 m
.6782 .40978 L
s
.6958 .46185 m
.68784 .43552 L
s
.58504 .67997 m
.58939 .65862 L
s
.63336 .64712 m
.6375 .62358 L
s
.67883 .58377 m
.6796 .55768 L
s
.52013 .32405 m
.51861 .30403 L
s
.65782 .61654 m
.66055 .59146 L
s
.61018 .35459 m
.60135 .33209 L
s
.57582 .33804 m
.56966 .31678 L
s
.69362 .52306 m
.69022 .49604 L
s
.563 .68431 m
.56657 .66318 L
s
.66981 .41561 m
.65989 .39015 L
s
.5 .69365 m
.5 .67333 L
s
.5 .32667 m
.5 .30635 L
s
.54119 .68796 m
.54377 .66708 L
s
.52006 .69102 m
.52143 .67042 L
s
.63061 .37475 m
.6211 .35093 L
s
.65061 .39522 m
.64073 .3704 L
s
.69022 .49604 m
.68508 .46889 L
s
.61179 .65329 m
.61579 .62981 L
s
.67825 .44197 m
.66981 .41561 L
s
.5597 .34082 m
.5552 .31921 L
s
.6796 .55768 m
.67875 .53074 L
s
.59695 .35806 m
.58973 .33515 L
s
.68508 .46889 m
.67825 .44197 L
s
.6375 .62358 m
.64046 .59842 L
s
.66055 .59146 m
.66187 .56514 L
s
.65922 .42125 m
.65061 .39522 L
s
.54152 .34354 m
.53862 .3216 L
s
.61818 .37888 m
.61018 .35459 L
s
.58939 .65862 m
.59303 .63526 L
s
.67875 .53074 m
.67625 .50326 L
s
.63907 .40008 m
.63061 .37475 L
s
.58144 .36134 m
.57582 .33804 L
s
.66643 .44816 m
.65922 .42125 L
s
.52151 .34629 m
.52013 .32405 L
s
.67625 .50326 m
.67213 .47562 L
s
.56657 .66318 m
.56962 .63999 L
s
.66187 .56514 m
.66171 .53788 L
s
.67213 .47562 m
.66643 .44816 L
s
.61579 .62981 m
.6188 .60464 L
s
.5 .67333 m
.5 .65081 L
s
.5 .34919 m
.5 .32667 L
s
.54377 .66708 m
.54601 .64408 L
s
.60342 .38276 m
.59695 .35806 L
s
.52143 .67042 m
.52265 .64765 L
s
.64046 .59842 m
.64218 .57193 L
s
.64635 .42662 m
.63907 .40008 L
s
.56376 .36446 m
.5597 .34082 L
s
.62521 .40467 m
.61818 .37888 L
s
.66171 .53788 m
.66005 .51003 L
s
.59303 .63526 m
.59588 .61013 L
s
.65232 .45403 m
.64635 .42662 L
s
.5441 .36749 m
.54152 .34354 L
s
.58642 .38642 m
.58144 .36134 L
s
.66005 .51003 m
.65691 .48196 L
s
.64218 .57193 m
.6426 .54444 L
s
.65691 .48196 m
.65232 .45403 L
s
.6188 .60464 m
.62075 .57805 L
s
.63116 .43166 m
.62521 .40467 L
s
.56962 .63999 m
.57209 .61495 L
s
.60904 .40897 m
.60342 .38276 L
s
.52273 .37053 m
.52151 .34629 L
s
.54601 .64408 m
.54787 .61919 L
s
.5 .65081 m
.5 .62632 L
s
.5 .37368 m
.5 .34919 L
s
.56731 .38988 m
.56376 .36446 L
s
.52265 .64765 m
.52368 .62294 L
s
.6426 .54444 m
.6417 .51628 L
s
.63594 .45951 m
.63116 .43166 L
s
.59588 .61013 m
.59788 .58352 L
s
.62075 .57805 m
.62161 .55039 L
s
.59068 .41299 m
.58642 .38642 L
s
.6417 .51628 m
.63947 .48785 L
s
.61371 .43637 m
.60904 .40897 L
s
.63947 .48785 m
.63594 .45951 L
s
.54632 .39321 m
.5441 .36749 L
s
.57209 .61495 m
.57393 .58837 L
s
.62161 .55039 m
.62133 .522 L
s
.52376 .3965 m
.52273 .37053 L
s
.61735 .46459 m
.61371 .43637 L
s
.57029 .41677 m
.56731 .38988 L
s
.59788 .58352 m
.59899 .55575 L
s
.54787 .61919 m
.54932 .59268 L
s
.5 .62632 m
.5 .60013 L
s
.5 .39987 m
.5 .37368 L
s
.59413 .44074 m
.59068 .41299 L
s
.52368 .62294 m
.52451 .59657 L
s
.62133 .522 m
.6199 .49327 L
s
.6199 .49327 m
.61735 .46459 L
s
.54814 .42038 m
.54632 .39321 L
s
.57393 .58837 m
.57509 .56056 L
s
.59899 .55575 m
.59917 .52719 L
s
.59673 .46928 m
.59413 .44074 L
s
.57264 .44481 m
.57029 .41677 L
s
.52457 .4239 m
.52376 .3965 L
s
.54932 .59268 m
.55031 .5649 L
s
.59917 .52719 m
.59841 .49823 L
s
.59841 .49823 m
.59673 .46928 L
s
.5 .60013 m
.5 .57255 L
s
.5 .42745 m
.5 .39987 L
s
.52451 .59657 m
.52512 .56886 L
s
.57509 .56056 m
.57555 .5319 L
s
.54952 .44866 m
.54814 .42038 L
s
.57431 .47361 m
.57264 .44481 L
s
.55031 .5649 m
.55084 .5362 L
s
.57555 .5319 m
.57529 .50278 L
s
.52517 .45237 m
.52457 .4239 L
s
.57529 .50278 m
.57431 .47361 L
s
.52512 .56886 m
.5255 .54018 L
s
.5 .45605 m
.5 .42745 L
s
.5 .57255 m
.5 .54395 L
s
.55044 .47766 m
.54952 .44866 L
s
.55084 .5362 m
.55089 .50698 L
s
.55089 .50698 m
.55044 .47766 L
s
.52552 .48151 m
.52517 .45237 L
s
.5255 .54018 m
.52563 .51092 L
s
.5 .54395 m
.5 .51472 L
s
.5 .48528 m
.5 .45605 L
s
.52563 .51092 m
.52552 .48151 L
s
.5 .51472 m
.5 .48528 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0026Ool?O02;Ool0081ooaMl
08Uoo`00O7oo57`000=oog`0O0001W`0Qgoo001iOolRO025Ool007Eoo`Ml009oo`=l009oo`03O01o
og`0009oo`03O01oog`000El009oo`Yl08Aoo`00Lgoo1g`00goo0g`00Woo00]l07ooOoml07ooO01o
og`0Ooml07oo015l089oo`00LGoo1W`000Aoog`0Oomoo`=l00=oo`06O01oogooO01oog`00Woo0W`0
00=oog`0Ool00W`00Woo00=l07ooOol02W`0PGoo001_Ool4O0001WooO01oogooO01oo`9l0003Ooml
07oo009oo`04O01oogooO002Ool027`0Ooml07ooO01oog`0Ool2O003Ool01G`0Oomoog`0Ool02G`0
Ogoo001]Ool2O0001GooO01oogooO0000Woo00=l07ooO0000goo00Al07ooOoml009oo`04O01oogoo
O002Ool017`0Ooml07oo0W`000=oog`0Ool00Woo00Al07ooOoml009oo`03O01oog`000Il07ioo`00
Jgoo0W`00Woo00El07ooOoml07oo009l009oo`04O01oogooO002Ool017`0Oomoog`00Woo00al07oo
Ooml07ooO01oog`0Ooml07ooO003Ool017`0Oomoog`00goo00=l07ooO0001g`0O7oo001YOol3O002
Ool01W`0Ooml07`0Ooml00=oo`04O01oogooO002Ool01G`0OomoogooO0000Woo00=l07ooO0000Woo
00Ml07ooO01oog`0Ooml0003Ool01G`0OomoogooO0000Woo00El07ooOoml07oo00Il07]oo`00J7oo
0W`00goo0g`00Woo00El07ooOomoog`0009oo`04O01oogooO003Ool017`0Oomoog`00Woo00Yl07oo
Ooml07ooO01oog`0Ooml00=oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo1W`0NWoo001VOol3
O002Ool3O003Ool01G`0OomoogooO0000Woo00Al07ooOoml00=oo`07O01oogooOoml07ooO0000Woo
00Ql07ooOoml07ooO01oog`00goo00El07ooOomoog`000=oo`07O01oogooO01oog`0Ool01W`0N7oo
001UOol00g`0Ooml0002Ool017`0Oomoog`00goo00Al07ooOoml009oo`05O01oogooOoml0003Ool0
17`0Oomoog`00Woo00Al07ooOoml009oo`05O01oog`0Ooml0003Ool01G`0OomoogooO0000goo00Al
07ooOoml009oo`04O01oog`0Ool4O01gOol006Aoo`03O01oog`0009oo`04O01oogooO003Ool017`0
Oomoog`00goo00Al07ooOoml00=oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo00El07ooO01o
og`000Aoo`05O01oogooOoml0003Ool017`0Oomoog`00Woo00Al07ooO01oo`Al07Ioo`00Hgoo00=l
07ooO0000goo00Al07ooOoml009oo`05O01oogooOoml0002Ool01G`0OomoogooO0000Woo00El07oo
Oomoog`0009oo`04O01oogooO002Ool01W`0Oomoog`0Ooml00Aoo`05O01oogooOoml0003Ool017`0
Oomoog`00Woo00Il07ooO01oog`0Ool3O01eOol0069oo`03O01oog`000=oo`04O01oogooO003Ool0
17`0Oomoog`00Woo00El07ooOomoog`000=oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo00Il
07ooOoml07ooO004Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`06O01oog`0Ooml07oo
17`0Lgoo001QOol017`0Oomoog`00Woo00Al07ooOoml00=oo`04O01oogooO003Ool01G`0Oomoogoo
O0000Woo00El07ooOomoog`000=oo`04O01oogooO002Ool01W`0Oomoog`0Ooml00Aoo`05O01oogoo
Ooml0003Ool01G`0OomoogooO0000Woo00=l07ooO0000Woo00=l07ooO0000g`0LWoo001POol017`0
Oomoog`00Woo00Al07ooOoml00=oo`05O01oogooOoml0002Ool01G`0OomoogooO0000goo00El07oo
Oomoog`000=oo`06O01oogooO01oog`00Woo00Al07ooOoml00Aoo`03O01oogoo009oo`05O01oogoo
Ooml0003Ool01W`0Oomoog`0Ooml009oo`03O01oog`000=l075oo`00H7oo00=l07ooO0000goo00=l
07ooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool017`0Oomoog`00goo00Al07oo
Ooml009oo`04O01oogooO002Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo
00Al07ooOoml009oo`03O01oogoo009l0004Ooml07`0O01`Ool005moo`04O01oogooO002Ool017`0
Oomoog`00goo00El07ooOomoog`0009oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00Al
07ooOoml009oo`04O01oogooO002Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO000
0goo00Ml07ooOomoog`0Ooml0002Ool017`0Ooml07oo0g`0Kgoo001NOol017`0Oomoog`00Woo00Al
07ooOoml00=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`04
O01oogooO002Ool017`0Oomoog`00Woo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`0
00Aoo`04O01oogooO002Ool01g`0Oomoog`0Ooml07oo00Al06eoo`00GWoo00Al07ooOoml009oo`04
O01oogooO003Ool01G`0OomoogooO0000Woo00=l07ooOol00Woo00El07ooOomoog`000=oo`07O01o
ogooOoml07ooO0000goo00Al07ooOoml009oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo
009oo`05O01oogooOoml0003Ool00g`0Ooml0003Ool01G`0Ooml07`0Ool00g`0K7oo001MOol017`0
Oomoog`00Woo00El07ooOomoog`0009oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00El
07ooOomoog`000=oo`04O01oogooO003Ool017`0Oomoog`00Woo00=l07ooOol00Woo00=l07ooOol0
0Woo00=l07ooOol00Woo00=l07ooOol00Woo00Al07ooOoml009oo`07O01oogooO01oog`0Ool01G`0
Jgoo001MOol017`0Oomoog`00Woo00Al07ooOoml00=oo`05O01oogooOoml0003Ool01G`0Oomoogoo
O0000goo00El07ooOomoog`000=oo`04O01oogooO003Ool017`0Oomoog`00Woo00=l07ooOol00Woo
00=l07ooOol00goo00=l07ooOol00Woo00El07ooOomoog`000=oo`03O01oog`000=oo`04O01oog`0
Ool5O01ZOol005aoo`04O01oogooO002Ool01G`0OomoogooO0000goo00Al07ooOoml00=oo`05O01o
ogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00El07ooOomoog`0009oo`04O01o
ogooO005Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00Al07ooOoml009o
o`03O01oogoo009l0003Ooml07`0009l06Uoo`00G7oo00Al07ooOoml009oo`04O01oogooO003Ool0
1G`0OomoogooO0000goo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0002Ool0
17`0Oomoog`00goo00Al07ooOoml00Eoo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo009o
o`07O01oogooOoml07ooO0000goo00Il07ooO01oog`0Ool4O01XOol005]oo`04O01oogooO002Ool0
1G`0OomoogooO0000goo00Al07ooOoml00Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo
00El07ooOomoog`0009oo`05O01oogooOoml0002Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0
Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00Al07ooOoml009oo`03O01oog`000El
06Moo`00Fgoo00Al07ooOoml009oo`05O01oogooOoml0002Ool01G`0OomoogooO00017oo00El07oo
Oomoog`0009oo`03O01oogoo009oo`05O01oogooOoml0003Ool017`0Oomoog`00goo00Al07ooOoml
00Eoo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo009oo`05O01oogooOoml0002Ool02W`0
OomoogooO01oog`0Ooml07oo1G`0IWoo001JOol017`0Oomoog`00goo00Al07ooOoml00=oo`05O01o
ogooOoml0004Ool017`0Oomoog`00goo00=l07ooOol00Woo00El07ooOomoog`000=oo`04O01oogoo
O003Ool017`0Oomoog`01Goo00=l07ooOol00Woo00=l07ooOol00goo00El07ooOomoog`000Aoo`04
O01oogooO002Ool01g`0Oomoog`0Ooml07oo00El06Eoo`00FWoo00Al07ooOoml00=oo`04O01oogoo
O003Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml
0003Ool017`0Oomoog`00goo00Al07ooOoml00Eoo`03O01oogoo00=oo`03O01oogoo009oo`03O01o
ogoo009oo`05O01oogooOoml0002Ool01g`0OomoogooO01oog`0009oo`9l0003Ooml07`0009l06Ao
o`00FGoo00El07ooOomoog`0009oo`05O01oogooOoml0003Ool017`0Oomoog`017oo00El07ooOomo
og`000=oo`03O01oogoo009oo`04O01oogooO003Ool01G`0OomoogooO0000goo00Al07ooOoml00Eo
o`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`05O01oogooOoml0003Ool017`0Oomo
og`00Woo00Il07ooO01oog`0Ool4O01SOol005Uoo`05O01oogooOoml0002Ool01G`0OomoogooO000
0Woo00El07ooOomoog`000Aoo`05O01oogooOoml0002Ool00g`0Oomoo`02Ool01G`0OomoogooO000
0goo00El07ooOomoog`000=oo`04O01oogooO005Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0
Oomoo`02Ool00g`0Oomoo`02Ool017`0Oomoog`00goo00=l07ooO0000Woo00=l07ooO0000W`000=o
og`0O000HWoo001IOol017`0Oomoog`00goo00El07ooOomoog`0009oo`05O01oogooOoml0003Ool0
1G`0OomoogooO0000goo00=l07ooOol00Woo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool0
17`0Oomoog`01Goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo
00El07ooOomoog`0009oo`04O01oogooO002Ool2O00017ooO01l07oo0W`0HGoo001IOol017`0Oomo
og`00goo00Al07ooOoml00=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00=l07ooOol0
0Woo00El07ooOomoog`000=oo`05O01oogooOoml0002Ool01G`0OomoogooO0001Goo00=l07ooOol0
0goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`000=oo`03O01o
og`0009oo`04O01oog`0Ool2O0000gooO01l001POol005Qoo`05O01oogooOoml0002Ool01G`0Oomo
ogooO0000goo00Al07ooOoml00=oo`03O01oogoo009oo`05O01oogooOoml0004Ool01G`0Oomoogoo
O0000Woo00El07ooOomoog`000=oo`05O01oogooOoml0005Ool00g`0Oomoo`03Ool00g`0Oomoo`03
Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00Al07ooOoml009oo`05O01o
og`0O01oo`03O01POol005Qoo`05O01oogooOoml0002Ool01G`0OomoogooO0000goo00Al07ooOoml
00=oo`03O01oogoo009oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00El07ooOomoog`0
00=oo`05O01oogooOoml0005Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0
Oomoo`02Ool01G`0OomoogooO0000goo00=l07ooO0000Woo00Il07ooO01oog`0Ool3O01OOol005Qo
o`04O01oogooO003Ool01G`0OomoogooO0000Woo00El07ooOomoog`000=oo`03O01oogoo009oo`04
O01oogooO004Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0006Ool0
0g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool0
17`0Oomoog`00Woo00Ml07ooOoml07ooO01oo`02O0000gooO01l001NOol005Qoo`04O01oogooO003
Ool017`0Oomoog`00goo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool0
1G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0006Ool00g`0Oomoo`03Ool0
0g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool01G`0OomoogooO0000Woo00Al07ooOoml
009oo`03O01oogoo009l0003Ooml07oo009l05eoo`00F7oo00Al07ooOoml00=oo`04O01oogooO003
Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0003
Ool01G`0OomoogooO0000goo00El07ooOomoog`000Ioo`03O01oogoo00=oo`03O01oogoo009oo`03
O01oogoo00=oo`03O01oogoo009oo`05O01oogooOoml0002Ool01G`0OomoogooO0000Woo00Il07oo
O01oog`0Ool2O0000gooO01oo`1KOol005Moo`05O01oogooOoml0002Ool01G`0OomoogooO0000goo
00Al07ooOoml00Aoo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00El
07ooOomoog`000=oo`05O01oogooOoml0006Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomo
o`03Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00Al07ooOoml009oo`05O01oogooO01oo`02
O0000gooO01l001LOol005Moo`05O01oogooOoml0002Ool01G`0OomoogooO0000goo00Al07ooOoml
00Aoo`05O01oogooOoml0003Ool01G`0OomoogooO00017oo00El07ooOomoog`000=oo`05O01oogoo
Ooml0003Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0
Oomoo`02Ool00g`0Oomoo`02Ool017`0Oomoog`00Woo00al07ooOomoog`0Ooml07ooO01oog`0Ool2
O01KOol005Moo`04O01oogooO003Ool01G`0OomoogooO0000Woo00El07ooOomoog`000Aoo`05O01o
ogooOoml0003Ool01G`0OomoogooO00017oo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool0
0g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool0
1G`0OomoogooO0000Woo00El07ooOomoog`0009oo`07O01oogooO01oog`0Ool00g`0Fgoo001GOol0
17`0Oomoog`00goo00Al07ooOoml00=oo`05O01oogooOoml0004Ool017`0Oomoog`017oo00El07oo
Oomoog`000Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00=l07ooOol017oo00=l07oo
Ool00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00El07ooOomoog`000=oo`04
O01oogooO003Ool00g`0Ooml0002Ool2O0000gooO01l001JOol005Moo`04O01oogooO003Ool017`0
Oomoog`00goo00El07ooOomoog`000=oo`05O01oogooOoml0004Ool01G`0OomoogooO00017oo00El
07ooOomoog`000=oo`05O01oogooOoml0003Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomo
o`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00El07ooOomoog`0009o
o`0:O01oogooO01oog`0Ooml07ooO01JOol005Moo`04O01oogooO003Ool017`0Oomoog`00goo00El
07ooOomoog`000=oo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00El
07ooOomoog`000=oo`05O01oogooOoml0006Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomo
o`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00Ml07ooOomoog`0Ooml
0002Ool2O0000gooO01l001IOol005Moo`04O01oogooO003Ool017`0Oomoog`00goo00El07ooOomo
og`000=oo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00El07ooOomo
og`000=oo`05O01oogooOoml0006Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool0
0g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00Al07ooOoml009oo`06O01oog`0
Ooml07oo0W`0F7oo001GOol017`0Oomoog`00goo00Al07ooOoml00=oo`05O01oogooOoml0003Ool0
1G`0OomoogooO0000goo00=l07ooOol00Woo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool0
1G`0OomoogooO0001Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol0
0Woo00=l07ooOol00Woo00=l07ooOol00Woo00Al07ooOoml00=oo`03O01oog`0009oo`9l009oo`03
O01oogoo05Ioo`00Egoo00Al07ooOoml00=oo`04O01oogooO003Ool01G`0OomoogooO0000goo00El
07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo00El
07ooOomoog`000Ioo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=o
o`05O01oogooOoml0004Ool017`0Oomoog`00goo00Ul07ooOoml07ooO01oog`0Ool00W`0Egoo001G
Ool017`0Oomoog`00goo00Al07ooOoml00=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo
00=l07ooOol00Woo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0003Ool00g`0
Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool00g`0
Oomoo`02Ool01G`0OomoogooO0000goo00Al07ooOoml009oo`07O01oogooO01oog`0Ool00W`0EWoo
001GOol017`0Oomoog`00Woo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0Oomoogoo
O0000goo00=l07ooOol00Woo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0003
Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02
Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`06O01oog`0Ooml07oo
0W`0EWoo001GOol017`0Oomoog`00Woo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0
OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo
00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo
00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`0009oo`04O01oogooO002Ool017`0Ooml
07oo0W`0EGoo001GOol017`0Oomoog`00Woo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool0
1G`0OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml0004Ool01G`0OomoogooO000
0goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol0
0Woo00=l07ooOol00goo00El07ooOomoog`000=oo`07O01oogooOoml07ooO0000Woo00Ml07ooO01o
og`0Ooml001DOol005Moo`04O01oogooO002Ool01G`0OomoogooO0000goo00El07ooOomoog`000=o
o`05O01oogooOoml0003Ool01G`0OomoogooO00017oo00El07ooOomoog`000Aoo`05O01oogooOoml
0003Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomo
o`02Ool00g`0Oomoo`03Ool01G`0OomoogooO00017oo00Al07ooOoml009oo`03O01oog`0009oo`04
O01oog`0O01DOol005Moo`04O01oogooO002Ool01G`0OomoogooO0000goo00El07ooOomoog`000=o
o`05O01oogooOoml0003Ool01G`0OomoogooO00017oo00El07ooOomoog`000=oo`03O01oogoo009o
o`05O01oogooOoml0006Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomo
o`03Ool00g`0Oomoo`02Ool01G`0OomoogooO00017oo00Al07ooOoml009oo`0:O01oogooO01oog`0
Ooml07ooO01COol005Moo`04O01oogooO003Ool017`0Oomoog`00goo00El07ooOomoog`000=oo`05
O01oogooOoml0003Ool01G`0OomoogooO00017oo00El07ooOomoog`000=oo`03O01oogoo009oo`05
O01oogooOoml0006Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03
Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00Il07ooOoml07ooO002Ool0
17`0Ooml07`0Dgoo001GOol017`0Oomoog`00goo00Al07ooOoml00=oo`05O01oogooOoml0003Ool0
1G`0OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool0
1G`0OomoogooO0001Woo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol0
0goo00=l07ooOol00goo00El07ooOomoog`000=oo`05O01oogooOoml0002Ool02W`0Oomoog`0Ooml
07ooO01oog`0DWoo001GOol01G`0OomoogooO0000Woo00Al07ooOoml00=oo`05O01oogooOoml0003
Ool01G`0OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool00g`0Oomoo`02
Ool01G`0OomoogooO0001Woo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07oo
Ool00Woo00=l07ooOol00goo00El07ooOomoog`000Aoo`04O01oogooO003Ool00g`0Ooml0002Ool0
17`0Ooml07`0DWoo001GOol01G`0OomoogooO0000Woo00Al07ooOoml00=oo`05O01oogooOoml0003
Ool01G`0OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool00g`0Oomoo`02
Ool01G`0OomoogooO0001Woo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l07oo
Ool00goo00=l07ooOol00Woo00El07ooOomoog`000Aoo`04O01oogooO003Ool00g`0Ooml0002Ool0
1G`0Ooml07ooO000DGoo001HOol017`0Oomoog`00Woo00Al07ooOoml00=oo`05O01oogooOoml0003
Ool01G`0OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool00g`0Oomoo`02
Ool01G`0OomoogooO0001Woo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l07oo
Ool00goo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`000=oo`04O01oogooO002Ool0
1G`0Oomoog`0Ool00W`0DGoo001HOol017`0Oomoog`00Woo00Al07ooOoml00=oo`05O01oogooOoml
0003Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml
0004Ool01G`0OomoogooO0001Woo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l
07ooOol00goo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`000=oo`04O01oogooO002
Ool027`0Oomoog`0Ooml07ooO01@Ool005Qoo`04O01oogooO002Ool017`0Oomoog`00goo00El07oo
Oomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00El07oo
Oomoog`000Aoo`05O01oogooOoml0006Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03
Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool017`0Oomoog`0
0goo00Al07ooOoml009oo`9l0003Ooml07oo04moo`00F7oo00Al07ooOoml009oo`04O01oogooO003
Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool00g`0Oomoo`02
Ool01G`0OomoogooO00017oo00El07ooOomoog`000Ioo`03O01oogoo00Aoo`03O01oogoo00Aoo`03
O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`05O01oogooOoml0004Ool017`0Oomoog`0
0goo00Al07ooOoml009oo`05O01oog`0Ooml001?Ool005Qoo`04O01oogooO002Ool01G`0Oomoogoo
O0000Woo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00=l07oo
Ool00Woo00El07ooOomoog`000Aoo`05O01oogooOoml0006Ool00g`0Oomoo`04Ool00g`0Oomoo`04
Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0Oomoogoo
O0000goo00Al07ooOoml00=oo`07O01oog`0Ooml07ooO000Cgoo001IOol00g`0Ooml0002Ool01G`0
OomoogooO0000Woo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo
00=l07ooOol00Woo00El07ooOomoog`000Aoo`05O01oogooOoml0006Ool00g`0Oomoo`04Ool00g`0
Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0
OomoogooO0000goo00Al07ooOoml00=oo`08O01oogooO01oog`0Ooml04ioo`00FGoo00=l07ooO000
0goo00Al07ooOoml009oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00El07ooOomoog`0
00=oo`03O01oogoo009oo`05O01oogooOoml0004Ool01G`0OomoogooO0001Woo00=l07ooOol017oo
00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00Woo
00El07ooOomoog`000=oo`05O01oogooOoml0002Ool027`0Oomoog`0Ooml07ooO01>Ool005Uoo`03
O01oog`000=oo`04O01oogooO002Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01o
ogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO00017oo00El07ooOomoog`000Ioo`03O01o
ogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo009oo`03O01o
ogoo009oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00=l07ooO0000Woo0W`0CWoo001I
Ool017`0Oomoog`00Woo00Al07ooOoml00=oo`04O01oogooO003Ool01G`0OomoogooO0000goo00El
07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0004Ool01G`0OomoogooO0001Woo00=l
07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00=l
07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`0009oo`07O01oogooOoml07ooO0000Woo00=l
07ooO000CGoo001IOol017`0Oomoog`00Woo00Al07ooOoml00=oo`04O01oogooO003Ool01G`0Oomo
ogooO0000goo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0004Ool01G`0Oomo
ogooO0001Woo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l
07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`0009oo`05O01oogooOoml
0002Ool01G`0Ooml07ooO000CGoo001JOol00g`0Ooml0002Ool01G`0OomoogooO0000Woo00Al07oo
Ooml00=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00El07ooOomo
og`000Aoo`05O01oogooOoml0006Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool0
0g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool01G`0OomoogooO0000goo00El07ooOomo
og`0009oo`04O01oogooO002Ool2O01=Ool005Yoo`03O01oog`000=oo`04O01oogooO002Ool017`0
Oomoog`00goo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0Oomo
ogooO00017oo00El07ooOomoog`000Ioo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Ao
o`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`05O01oogooOoml0003Ool01G`0Oomo
ogooO0000goo00=l07ooO0000Woo00=l07ooO000C7oo001JOol017`0Oomoog`00Woo00Al07ooOoml
009oo`05O01oogooOoml0002Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`03O01oogoo
009oo`05O01oogooOoml0004Ool01G`0OomoogooO0001Woo00=l07ooOol017oo00=l07ooOol017oo
00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00El07ooOomoog`0
00Aoo`04O01oogooO003Ool027`0Oomoog`0Ooml07ooO01<Ool005Yoo`04O01oogooO002Ool017`0
Oomoog`00goo00Al07ooOoml009oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00=l07oo
Ool00Woo00El07ooOomoog`000Aoo`05O01oogooOoml0006Ool00g`0Oomoo`04Ool00g`0Oomoo`04
Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0Oomoogoo
O00017oo00Al07ooOoml00=oo`08O01oogooO01oog`0Ooml04aoo`00Fgoo00Il07ooOoml07ooO002
Ool01G`0OomoogooO0000Woo00Al07ooOoml00Aoo`04O01oogooO003Ool01G`0OomoogooO00017oo
00El07ooOomoog`000Aoo`05O01oogooOoml0006Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0
Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0
OomoogooO0000goo00Al07ooOoml009oo`06O01oogooO01oog`0Bgoo001KOol017`0Oomoog`00Woo
00Al07ooOoml009oo`04O01oogooO003Ool01G`0OomoogooO0000Woo00El07ooOomoog`000=oo`03
O01oogoo009oo`05O01oogooOoml0004Ool01G`0OomoogooO0001Woo00=l07ooOol017oo00=l07oo
Ool01Goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00=l07oo
Ool00Woo00El07ooOomoog`000=oo`04O01oogooO002Ool01W`0Oomoog`0Ooml04]oo`00G7oo00=l
07ooO0000Woo00Al07ooOoml009oo`04O01oogooO003Ool01G`0OomoogooO0000Woo00El07ooOomo
og`000Aoo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0001Woo00=l07ooOol0
17oo00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol0
0Woo00=l07ooOol00Woo00=l07ooOol00Woo00Al07ooOoml009oo`09O01oogooOoml07ooO01oog`0
04]oo`00G7oo00=l07ooO0000goo00=l07ooO0000Woo00El07ooOomoog`0009oo`05O01oogooOoml
0002Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml
0006Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomo
o`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool017`0Oomoog`00goo00Ql07oo
Ooml07ooO01oog`0Bgoo001LOol017`0Oomoog`00Woo00=l07ooO0000goo00Al07ooOoml009oo`05
O01oogooOoml0003Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`03O01oogoo009oo`05
O01oogooOoml0006Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03
Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00El07oo
Oomoog`0009oo`03O01oog`0009oo`03O01oogoo04Qoo`00GGoo00=l07ooO0000Woo00=l07ooO000
0goo00Al07ooOoml009oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00El07ooOomoog`0
00=oo`03O01oogoo009oo`05O01oogooOoml0006Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool00g`0
Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0
OomoogooO0000goo00Al07ooOoml009oo`06O01oogooO01oog`0BWoo001MOol00g`0Ooml0002Ool0
17`0Oomoog`00Woo00Al07ooOoml009oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00El
07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0006Ool00g`0Oomoo`05Ool00g`0Oomo
o`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool00g`0Oomo
o`02Ool01G`0OomoogooO0000goo00Al07ooOoml009oo`06O01oogooO01oog`0BWoo001NOol2O003
Ool00g`0Ooml0002Ool017`0Oomoog`00goo00Al07ooOoml00=oo`05O01oogooOoml0003Ool01G`0
OomoogooO0000goo00=l07ooOol00Woo00El07ooOomoog`000Ioo`03O01oogoo00Eoo`03O01oogoo
00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo
009oo`05O01oogooOoml0003Ool017`0Oomoog`00Woo00Il07ooOoml07ooO01:Ool005ioo`03O01o
og`0009oo`03O01oog`0009oo`05O01oogooOoml0002Ool017`0Oomoog`00goo00El07ooOomoog`0
00=oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0001Woo00=l07ooOol01Goo
00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo
00=l07ooOol00Woo00=l07ooOol00Woo00Al07ooOoml009oo`09O01oogooOoml07ooO01oog`004Yo
o`00GWoo00=l07ooO0000Woo00=l07ooO0000goo00Al07ooOoml009oo`04O01oogooO003Ool01G`0
OomoogooO0000goo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0006Ool00g`0
Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0
Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool017`0Oomoog`00Woo00Ml07ooOomoog`0Ooml
0002Ool00g`0Oomoo`17Ool005moo`05O01oog`0Ooml0002Ool017`0Oomoog`00Woo00Al07ooOoml
00=oo`04O01oogooO003Ool01G`0OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml
0006Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomo
o`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool017`0Oomoog`00goo00Il07oo
Ooml07ooO002Ool00g`0Oomoo`17Ool005moo`03O01oog`0009oo`03O01oog`0009oo`04O01oogoo
O002Ool01G`0OomoogooO0000Woo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool00g`0Oomo
o`02Ool01G`0OomoogooO0001Woo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol00goo00=l
07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00Al
07ooOoml00=oo`06O01oogooO01oog`00Woo00=l07ooOol0Agoo001POol01G`0Ooml07ooO0000Woo
00=l07ooO0000Woo00El07ooOomoog`0009oo`04O01oogooO003Ool01G`0OomoogooO0000goo00El
07ooOomoog`000Aoo`05O01oogooOoml0006Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomo
o`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomo
o`02Ool017`0Oomoog`00goo00Al07ooOoml009oo`03O01oog`004Uoo`00H7oo00=l07ooO0000Woo
00=l07ooO0000Woo00Al07ooOoml009oo`04O01oogooO002Ool00g`0Oomoo`02Ool017`0Oomoog`0
0goo00El07ooOomoog`000Aoo`05O01oogooOoml0006Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool0
0g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool0
0g`0Oomoo`02Ool01G`0OomoogooO0000Woo00Al07ooOoml009oo`03O01oog`004Uoo`00HGoo00Ml
07ooO01oog`0Ooml0002Ool017`0Oomoog`00Woo00Al07ooOoml00=oo`05O01oogooOoml0002Ool0
1G`0OomoogooO0000goo00=l07ooOol00Woo00El07ooOomoog`000Ioo`03O01oogoo00Eoo`03O01o
ogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo009oo`03O01o
ogoo009oo`03O01oogoo009oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo00=l07ooO000BGoo
001QOol01G`0Ooml07ooO0000Woo00Il07ooOoml07ooO002Ool017`0Oomoog`00goo00El07ooOomo
og`0009oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0001Woo00=l07ooOol0
1Goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol0
0Woo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`0009oo`04O01oogooO002Ool00g`0
Ooml0019Ool0069oo`07O01oog`0Ooml07ooO0000Woo00=l07ooO0000Woo00El07ooOomoog`0009o
o`05O01oogooOoml0002Ool01G`0OomoogooO00017oo00El07ooOomoog`000=oo`03O01oogoo00Ao
o`03O01oogoo00Eoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=o
o`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo009oo`05O01oogooOoml0002Ool017`0Oomo
og`00Woo00=l07ooO000BGoo001ROol01G`0Ooml07ooO0000Woo00=l07ooO0000Woo00Al07ooOoml
009oo`04O01oogooO003Ool017`0Oomoog`017oo00El07ooOomoog`000=oo`05O01oogooOoml0006
Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03
Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00=l07oo
O0000Woo00=l07ooO000BGoo001SOol01g`0Ooml07ooO01oog`0009oo`03O01oog`0009oo`04O01o
ogooO002Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool00g`0
Oomoo`04Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0
Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool01G`0OomoogooO0000goo00Ml07ooOomoog`0
Ooml0002Ool00g`0Ooml0019Ool006=oo`07O01oog`0Ooml07ooO0000Woo00Il07ooOoml07ooO002
Ool01G`0OomoogooO0000Woo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0Oomoogoo
O0001Woo00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol017oo00=l07oo
Ool00goo00=l07ooOol00Woo00=l07ooOol00goo00El07ooOomoog`000=oo`07O01oogooOoml07oo
O0000Woo00=l07ooO000BGoo001TOol01g`0Ooml07ooO01oog`0009oo`05O01oog`0Ooml0002Ool0
1G`0OomoogooO0000Woo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO000
1Woo00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol0
0goo00=l07ooOol00Woo00=l07ooOol00goo00El07ooOomoog`000=oo`07O01oogooOoml07ooO000
0Woo00=l07ooO000BGoo001TOol01g`0Ooml07ooO01oog`0009oo`03O01oog`0009oo`04O01oogoo
O002Ool017`0Oomoog`00goo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool00g`0Oomoo`04
Ool00g`0Oomoo`04Ool00g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03
Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool01G`0OomoogooO0000goo00Ml07ooOomoog`0Ooml0002
Ool00g`0Ooml0019Ool006Eoo`0;O01oog`0Ooml07ooO01oog`0Ooml0002Ool017`0Oomoog`00Woo
00Al07ooOoml00=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00=l07ooOol017oo00=l
07ooOol017oo00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l
07ooOol00Woo00=l07ooOol00goo00El07ooOomoog`000=oo`05O01oogooOoml0002Ool01G`0Ooml
07ooO000BGoo001VOol2O00017ooO01oog`00Woo00=l07ooO0000Woo00=l07ooO0000Woo00El07oo
Oomoog`0009oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00=l07ooOol017oo00=l07oo
Ool017oo00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07oo
Ool00Woo00=l07ooOol00goo00El07ooOomoog`000=oo`05O01oogooOoml0002Ool01G`0Ooml07oo
O000BGoo001VOol017`0Ooml07oo0W`00Woo00=l07ooO0000Woo00=l07ooO0000goo00Al07ooOoml
009oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00=l07ooOol017oo00=l07ooOol017oo
00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo
00=l07ooOol00goo00El07ooOomoog`000=oo`04O01oogooO003Ool01G`0Ooml07ooO000BGoo001W
Ool01W`0Ooml07`0Ooml009oo`9l009oo`03O01oog`000=oo`04O01oogooO002Ool01G`0Oomoogoo
O0000goo00El07ooOomoog`000=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03
O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`03
O01oogoo009oo`05O01oogooOoml0002Ool02G`0OomoogooO01oog`0Ooml0019Ool006Moo`03O01o
ogoo00=l009oo`9l009oo`04O01oogooO002Ool017`0Oomoog`00Woo00El07ooOomoog`000=oo`05
O01oogooOoml0003Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04
Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02
Ool01G`0OomoogooO0000Woo00Ul07ooOomoog`0Ooml07ooO000BGoo001XOol02W`0Ooml07`0Ooml
07ooO01oog`00Woo00=l07ooO0000Woo00Al07ooOoml009oo`05O01oogooOoml0003Ool01G`0Oomo
ogooO0000goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l
07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00El
07ooOomoog`0009oo`06O01oogooOoml07oo0W`0BWoo001YOol00g`0Ooml0002O002Ool2O002Ool0
0g`0Ooml0002Ool01G`0OomoogooO0000Woo00Al07ooOoml00=oo`05O01oogooOoml0003Ool00g`0
Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0
Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo
00Al07ooOoml009oo`9l04Yoo`00JGoo00il07ooO01l07ooO01oog`0Ooml07ooO01oog`00goo00Al
07ooOoml009oo`04O01oogooO003Ool01G`0OomoogooO0000goo00=l07ooOol017oo00=l07ooOol0
17oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00Woo00=l07ooOol0
0goo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`0009oo`04O01oogooO002Ool2O01:
Ool006Yoo`03O01oog`0009l009oo`9l0005Ooml07ooOoml0002Ool017`0Oomoog`00Woo00Al07oo
Ooml00=oo`05O01oogooOoml0003Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool0
0g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool0
1G`0OomoogooO00017oo00Al07ooOoml009oo`03O01oogoo009l04Yoo`00Jgoo00Il07ooO01oog`0
Ool2O002Ool00g`0Ooml0002Ool017`0Oomoog`00Woo00Al07ooOoml00=oo`05O01oogooOoml0003
Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03
Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0OomoogooO00017oo00Al07oo
Ooml009oo`05O01oog`0Ooml001:Ool006aoo`=l0007Ooml07`0Ooml07ooO0000Woo00=l07ooO000
0Woo00El07ooOomoog`0009oo`04O01oogooO003Ool01G`0OomoogooO0001Woo00=l07ooOol017oo
00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo
00=l07ooOol00Woo00El07ooOomoog`000Aoo`04O01oogooO002Ool01G`0Ooml07ooO000BWoo001]
Ool3O00017ooO01l07`00Woo00=l07ooO0000Woo00Al07ooOoml009oo`04O01oogooO002Ool01G`0
OomoogooO0000goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo
00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00El07ooOomoog`0
00Aoo`04O01oogooO002Ool017`0Ooml07`0Bgoo001^Ool5O00017ooO01oog`00Woo00=l07ooO000
0Woo00Al07ooOoml009oo`04O01oogooO003Ool01G`0OomoogooO0001Woo00=l07ooOol017oo00=l
07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00=l
07ooOol00goo00El07ooOomoog`000=oo`07O01oogooOoml07ooO0000Woo0W`0Bgoo001_Ool2O000
17ooO01l07`00Woo00=l07ooO0000Woo00=l07ooO0000Woo00Al07ooOoml009oo`05O01oogooOoml
0003Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomo
o`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool01G`0OomoogooO0000goo00]l
07ooOomoog`0Ooml07ooO01oog`004]oo`00L7oo17`000Aoog`0Ooml009oo`05O01oog`0Ooml0002
Ool017`0Oomoog`00goo00Al07ooOoml00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo
00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo
00=oo`04O01oogooO004Ool02g`0OomoogooO01oog`0Ooml07ooO000Bgoo001aOol00g`0Ooml0002
O002Ool01g`0Ooml07ooO01oog`000=oo`04O01oogooO002Ool017`0Oomoog`00goo00=l07ooOol0
17oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol0
0Woo00=l07ooOol00goo00=l07ooOol00goo00Al07ooOoml00Aoo`04O01oogooO002Ool01G`0Ooml
07ooO000Bgoo001bOol02g`0Ooml07ooO01oog`0Ooml07ooO0000Woo00Al07ooOoml009oo`04O01o
ogooO002Ool01G`0OomoogooO0001Woo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo
00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00Al07ooOoml00Ao
o`04O01oogooO002Ool2O0000gooO01oo`1;Ool007=oo`=l0005Ooml07`0Ooml0002Ool00g`0Ooml
0002Ool017`0Oomoog`00Woo00Al07ooOoml00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01o
ogoo00Aoo`03O01oogoo00Aoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01o
ogoo009oo`05O01oogooOoml0004Ool02W`0Oomoog`0Ooml07ooO01oog`0C7oo001cOol5O00027oo
O01oog`0Ooml07ooO002Ool017`0Oomoog`00Woo00Al07ooOoml00=oo`03O01oogoo00Aoo`03O01o
ogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01o
ogoo00=oo`03O01oogoo009oo`05O01oogooOoml0003Ool027`0OomoogooO01oog`0Ool2O01=Ool0
07Aoo`Il0006Ooml07ooO01oog`00Woo00Al07ooOoml009oo`04O01oogooO003Ool00g`0Oomoo`04
Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03
Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool01G`0OomoogooO0000goo00Al07ooOomoo`9l009oo`9l
04eoo`00MGoo17`000Moog`0O01oog`0Ooml0003Ool00g`0Ooml0002Ool017`0Oomoog`00goo00=l
07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l
07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo00El07ooOomoog`000=oo`07O01oogooO01o
og`0Ool00W`0CWoo001fOol6O002Ool00g`0Ooml0002Ool00g`0Ooml0002Ool017`0Oomoog`00goo
00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo
00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo00Al07ooOoml00Aoo`07O01oogooO01o
og`0Ool00W`0CWoo001gOol4O0001WooO01oog`0Ooml009oo`03O01oog`0009oo`04O01oogooO003
Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03
Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0OomoogooO00017oo00=l07oo
Ool00W`00Woo00=l07ooOol0CGoo001hOol5O002Ool2O002Ool00g`0Ooml0003Ool017`0Oomoog`0
0Woo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol0
0Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00El07ooOomoog`000=oo`07O01o
ogooO01oog`0Ool00W`0Cgoo001iOol3O0000gooO01oo`02O002Ool017`0Oomoog`00Woo00Al07oo
Ooml009oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01o
ogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`05O01oogooOoml0003Ool0
27`0Oomoog`0Ooml07ooO01@Ool007Yoo`Al0004Ooml07ooO002Ool00g`0Ooml0002Ool017`0Oomo
og`00Woo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07oo
Ool00goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00El07oo
Oomoog`0009oo`9l0003Ooml07oo051oo`00Ngoo17`000=oog`0O0000Woo00=l07ooO0000Woo00Al
07ooOoml009oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03
O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`05O01oogooOoml0003
Ool027`0Oomoog`0Ooml07ooO01AOol007aoo`=l0008Ooml07ooO01oog`0Ooml009oo`04O01oogoo
O002Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomo
o`03Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00=l
07ooOol00W`000=oog`0Ool0DGoo001mOol4O00017ooO01oog`00Woo00=l07ooO0000Woo00Al07oo
Ooml00Eoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01o
ogoo009oo`03O01oogoo00=oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool017`0Ooml07oo0W`0
Dgoo001mOol4O0002GooO01oogooO01oog`0Ooml0002Ool017`0Oomoog`01Goo00=l07ooOol017oo
00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol00goo
00El07ooOomoog`000=oo`05O01oogooOoml0002Ool3O01DOol007ioo`Il0006Ooml07ooO01oog`0
0Woo00Al07ooOoml00Eoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo
00=oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`05O01oogooOoml0003Ool017`0
Ooml07oo0W`0E7oo001oOol3O00027ooO01oog`0Ooml07ooO002Ool017`0Oomoog`01Goo00=l07oo
Ool017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07oo
Ool00Woo00El07ooOomoog`000=oo`05O01oogooOoml0002Ool3O01EOol0081oo`Il0007Ooml07oo
Ooml07ooO0000Woo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00Woo00=l07ooOol017oo
00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo00El07ooOomoog`000=oo`09O01oogoo
Ooml07ooO01oog`005Ioo`00PGoo1W`000Ioog`0Ooml07ooO002Ool00g`0Oomoo`03Ool00g`0Oomo
o`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool00g`0Oomo
o`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00=l07ooOol00W`0Egoo0022Ool3O00027oo
O01l07`0Ooml07ooO002Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomo
o`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00Il
07ooOomoog`0Ool3O01GOol0089oo`Ul0005Ooml07ooOoml0005Ool00g`0Oomoo`03Ool00g`0Oomo
o`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool01G`0Oomo
ogooO0000goo00El07ooOoml07oo00=l05Qoo`00Pgoo2g`000=oog`0Ool017oo00=l07ooOol00goo
00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00Woo
00El07ooOomoog`000=oo`04O01oogooOol4O01IOol008Aoo`=l0007Ooml07`0O01oog`0Ool00W`0
1Goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol0
0goo00=l07ooOol00Woo00El07ooOomoog`0009oo`04O01oogooOol4O01JOol008Eoo`=l0003Ooml
07`0009l009oo`=l00=oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo
00=oo`03O01oogoo009oo`03O01oogoo009oo`05O01oogooOoml0003Ool00g`0Oomoo`04O01KOol0
08Eoo`]l009oo`9l0003Ooml07oo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=o
o`03O01oogoo009oo`03O01oogoo009oo`05O01oogooOoml0002Ool00g`0Oomoo`04O01LOol008Io
o`Ql0004Ooml07`0O002Ool3O003Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool0
0g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00=l07ooO00017`0GGoo0027Ool5
O00017ooO01l07`00Woo0g`00Woo0W`000=oog`0Ool017oo00=l07ooOol00Woo00=l07ooOol00goo
00=l07ooOol00Woo00=l07ooOol00Woo00Al07ooOomoo`El0003Ooml07`005moo`00Qgoo1g`000=o
og`0O0000goo0g`00Woo17`00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l
07ooOol00Woo00Al07ooOomoo`9l0004Ooml07ooOol2O01POol008Qoo`Ql0005Ooml07ooOoml0002
Ool2O00017ooO01oogoo1G`00Woo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00Woo17`0
0Woo00=l07ooO0000W`0HGoo0029Ool5O00017ooO01l07oo0g`017oo0W`017oo00=l07ooOol04g`0
0Woo00=l07ooO0000g`0Hgoo0029Ool7O00017ooO01l07oo17`000=oog`0Ool01G`017oo00=l07oo
Ool00Woo00=l07ooOol00Woo00El07ooOomoog`000=oo`Il06Aoo`00RWoo27`000=oog`0O0000goo
0g`00goo2g`017oo2G`000=oog`0O0000W`0IGoo002;Ool5O002Ool6O0000gooO01oo`02O0000goo
O01oo`03Ool00g`0Oomoo`02Ool5O004Ool00g`0Ooml0006O01VOol008]oo`Ml009oo`9l009oo`9l
00=oo`Ql009oo`03O01oogoo009oo`03O01oogoo00Al0003Ooml07`000=l06Moo`00S7oo1G`000=o
og`0O0000Woo0g`000=oog`0O0000W`017oo00=l07ooOol02g`00goo17`0JGoo002=Ool8O003Ool3
O002Ool6O003Ool01G`0OomoogooO00017oo1W`0Jgoo002=Ool3O0000gooO01oo`06O002Ool4O002
OolBO01]Ool008eoo`Al0004Ooml07`0Ool6O00017ooO01oogoo17`00Woo00El07ooOomoog`0009o
o`Al071oo`00SWoo1g`00Woo00Al07ooOomoo`9l00=oo`03O01oogoo00]l079oo`00SWoo0W`000Eo
og`0Ooml07oo00El0003Ooml07oo00ml07Aoo`00Sgoo0W`000=oog`0Ool037`00Woo00=l07ooO000
1G`0MWoo002?Ool5O002Ool2O0000gooO01l0003O002Ool7O01iOol008moo`Ql0003Ooml07`000Yl
07aoo`00Sgoo1g`000=oog`0O0001g`0P7oo002?Ool:O027Ool00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {324.75, 95.375}} -> {-0.399192, \
0.415803, 0.00348777, 0.00348777}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["Figure 4.  The field-line pattern given by Eq. (10) from three \
orthogonal perspectives (consisting of parts A-C in the ",
    FontFamily->"New York"],
  StyleBox["Mathematica",
    FontFamily->"New York",
    FontSlant->"Italic"],
  StyleBox[" notebook) of a LHCP photon-e&mvf corresponding to the first \
great circle magnetic field line and the second great circle electric field \
line shown with 6 degree increments of the angle \[Theta].  (Electric field \
lines blue; Magnetic field lines red).  ",
    FontFamily->"New York"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig4A = Show[BFieldLHCP, \ EFieldLHCP];\)\)], "Input",
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.49116 .5 m
.50884 .5 L
s
.47352 .5 m
.49116 .5 L
s
1 0 0 r
.5 .49116 m
.5 .50884 L
s
.5 .47352 m
.5 .49116 L
s
0 0 1 r
.50884 .5 m
.52648 .5 L
s
1 0 0 r
.5 .50884 m
.5 .52648 L
s
0 0 1 r
.49343 .48459 m
.51112 .48465 L
s
.47577 .48462 m
.49343 .48459 L
s
1 0 0 r
.48459 .49343 m
.48465 .51112 L
s
.48462 .47577 m
.48459 .49343 L
s
0 0 1 r
.51112 .48465 m
.52877 .4848 L
s
1 0 0 r
.48465 .51112 m
.4848 .52877 L
s
0 0 1 r
.45595 .5 m
.47352 .5 L
s
1 0 0 r
.5 .45595 m
.5 .47352 L
s
0 0 1 r
.52648 .5 m
.54405 .5 L
s
1 0 0 r
.5 .52648 m
.5 .54405 L
s
0 0 1 r
.45818 .48474 m
.47577 .48462 L
s
1 0 0 r
.48474 .45818 m
.48462 .47577 L
s
0 0 1 r
.49579 .46929 m
.51349 .46953 L
s
.47809 .46923 m
.49579 .46929 L
s
1 0 0 r
.46929 .49579 m
.46953 .51349 L
s
.46923 .47809 m
.46929 .49579 L
s
0 0 1 r
.52877 .4848 m
.54633 .48504 L
s
1 0 0 r
.4848 .52877 m
.48504 .54633 L
s
0 0 1 r
.51349 .46953 m
.53116 .46994 L
s
1 0 0 r
.46953 .51349 m
.46994 .53116 L
s
0 0 1 r
.46046 .46934 m
.47809 .46923 L
s
1 0 0 r
.46934 .46046 m
.46923 .47809 L
s
0 0 1 r
.53116 .46994 m
.54874 .47053 L
s
1 0 0 r
.46994 .53116 m
.47053 .54874 L
s
0 0 1 r
.4385 .5 m
.45595 .5 L
s
1 0 0 r
.5 .4385 m
.5 .45595 L
s
0 0 1 r
.54405 .5 m
.5615 .5 L
s
1 0 0 r
.5 .54405 m
.5 .5615 L
s
0 0 1 r
.44071 .48495 m
.45818 .48474 L
s
1 0 0 r
.48495 .44071 m
.48474 .45818 L
s
0 0 1 r
.49831 .45424 m
.51606 .45478 L
s
.48056 .45397 m
.49831 .45424 L
s
1 0 0 r
.45424 .49831 m
.45478 .51606 L
s
.45397 .48056 m
.45424 .49831 L
s
0 0 1 r
.51606 .45478 m
.53375 .45557 L
s
1 0 0 r
.45478 .51606 m
.45557 .53375 L
s
0 0 1 r
.54633 .48504 m
.56376 .48537 L
s
1 0 0 r
.48504 .54633 m
.48537 .56376 L
s
0 0 1 r
.46287 .45397 m
.48056 .45397 L
s
1 0 0 r
.45397 .46287 m
.45397 .48056 L
s
0 0 1 r
.44294 .46964 m
.46046 .46934 L
s
1 0 0 r
.46964 .44294 m
.46934 .46046 L
s
0 0 1 r
.53375 .45557 m
.55135 .45664 L
s
1 0 0 r
.45557 .53375 m
.45664 .55135 L
s
0 0 1 r
.54874 .47053 m
.56617 .4713 L
s
1 0 0 r
.47053 .54874 m
.4713 .56617 L
s
0 0 1 r
.44529 .45423 m
.46287 .45397 L
s
1 0 0 r
.45423 .44529 m
.45397 .46287 L
s
0 0 1 r
.50108 .43961 m
.51888 .44056 L
s
.48328 .43901 m
.50108 .43961 L
s
1 0 0 r
.43961 .50108 m
.44056 .51888 L
s
.43901 .48328 m
.43961 .50108 L
s
0 0 1 r
.42342 .48525 m
.44071 .48495 L
s
1 0 0 r
.48525 .42342 m
.48495 .44071 L
s
0 0 1 r
.42125 .5 m
.4385 .5 L
s
1 0 0 r
.5 .42125 m
.5 .4385 L
s
0 0 1 r
.5615 .5 m
.57875 .5 L
s
1 0 0 r
.5 .5615 m
.5 .57875 L
s
0 0 1 r
.51888 .44056 m
.53661 .44185 L
s
1 0 0 r
.44056 .51888 m
.44185 .53661 L
s
0 0 1 r
.46552 .43877 m
.48328 .43901 L
s
1 0 0 r
.43877 .46552 m
.43901 .48328 L
s
0 0 1 r
.42559 .47012 m
.44294 .46964 L
s
1 0 0 r
.47012 .42559 m
.46964 .44294 L
s
0 0 1 r
.56376 .48537 m
.581 .48578 L
s
1 0 0 r
.48537 .56376 m
.48578 .581 L
s
0 0 1 r
.55135 .45664 m
.56878 .45796 L
s
1 0 0 r
.45664 .55135 m
.45796 .56878 L
s
0 0 1 r
.53661 .44185 m
.55422 .4435 L
s
1 0 0 r
.44185 .53661 m
.4435 .55422 L
s
0 0 1 r
.44785 .43888 m
.46552 .43877 L
s
1 0 0 r
.43888 .44785 m
.43877 .46552 L
s
0 0 1 r
.42787 .45477 m
.44529 .45423 L
s
1 0 0 r
.45477 .42787 m
.45423 .44529 L
s
0 0 1 r
.56617 .4713 m
.58339 .47225 L
s
1 0 0 r
.4713 .56617 m
.47225 .58339 L
s
0 0 1 r
.50418 .42555 m
.52202 .42702 L
s
.48631 .42451 m
.50418 .42555 L
s
1 0 0 r
.42555 .50418 m
.42702 .52202 L
s
.42451 .48631 m
.42555 .50418 L
s
0 0 1 r
.52202 .42702 m
.53978 .42892 L
s
1 0 0 r
.42702 .52202 m
.42892 .53978 L
s
0 0 1 r
.46847 .42392 m
.48631 .42451 L
s
1 0 0 r
.42392 .46847 m
.42451 .48631 L
s
0 0 1 r
.40636 .48563 m
.42342 .48525 L
s
1 0 0 r
.48563 .40636 m
.48525 .42342 L
s
0 0 1 r
.55422 .4435 m
.57165 .44548 L
s
1 0 0 r
.4435 .55422 m
.44548 .57165 L
s
0 0 1 r
.40423 .5 m
.42125 .5 L
s
1 0 0 r
.5 .40423 m
.5 .42125 L
s
0 0 1 r
.57875 .5 m
.59577 .5 L
s
1 0 0 r
.5 .57875 m
.5 .59577 L
s
0 0 1 r
.40847 .47077 m
.42559 .47012 L
s
1 0 0 r
.47077 .40847 m
.47012 .42559 L
s
0 0 1 r
.43035 .43936 m
.44785 .43888 L
s
1 0 0 r
.43936 .43035 m
.43888 .44785 L
s
0 0 1 r
.56878 .45796 m
.586 .45955 L
s
1 0 0 r
.45796 .56878 m
.45955 .586 L
s
0 0 1 r
.53978 .42892 m
.55739 .43125 L
s
1 0 0 r
.42892 .53978 m
.43125 .55739 L
s
0 0 1 r
.581 .48578 m
.59798 .48629 L
s
1 0 0 r
.48578 .581 m
.48629 .59798 L
s
0 0 1 r
.45072 .42376 m
.46847 .42392 L
s
1 0 0 r
.42376 .45072 m
.42392 .46847 L
s
0 0 1 r
.41067 .45557 m
.42787 .45477 L
s
1 0 0 r
.45557 .41067 m
.45477 .42787 L
s
0 0 1 r
.58339 .47225 m
.60036 .47337 L
s
1 0 0 r
.47225 .58339 m
.47337 .60036 L
s
0 0 1 r
.50765 .41221 m
.52552 .41431 L
s
.48973 .41062 m
.50765 .41221 L
s
1 0 0 r
.41221 .50765 m
.41431 .52552 L
s
.41062 .48973 m
.41221 .50765 L
s
0 0 1 r
.52552 .41431 m
.54329 .41692 L
s
1 0 0 r
.41431 .52552 m
.41692 .54329 L
s
0 0 1 r
.55739 .43125 m
.57481 .434 L
s
1 0 0 r
.43125 .55739 m
.434 .57481 L
s
0 0 1 r
.47182 .40956 m
.48973 .41062 L
s
1 0 0 r
.40956 .47182 m
.41062 .48973 L
s
0 0 1 r
.57165 .44548 m
.58885 .44782 L
s
1 0 0 r
.44548 .57165 m
.44782 .58885 L
s
0 0 1 r
.43311 .42406 m
.45072 .42376 L
s
1 0 0 r
.42406 .43311 m
.42376 .45072 L
s
0 0 1 r
.41305 .4402 m
.43035 .43936 L
s
1 0 0 r
.4402 .41305 m
.43936 .43035 L
s
0 0 1 r
.54329 .41692 m
.56089 .42003 L
s
1 0 0 r
.41692 .54329 m
.42003 .56089 L
s
0 0 1 r
.45397 .40902 m
.47182 .40956 L
s
1 0 0 r
.40902 .45397 m
.40956 .47182 L
s
0 0 1 r
.38959 .48611 m
.40636 .48563 L
s
1 0 0 r
.48611 .38959 m
.48563 .40636 L
s
0 0 1 r
.586 .45955 m
.60294 .4614 L
s
1 0 0 r
.45955 .586 m
.4614 .60294 L
s
0 0 1 r
.38752 .5 m
.40423 .5 L
s
1 0 0 r
.5 .38752 m
.5 .40423 L
s
0 0 1 r
.59577 .5 m
.61248 .5 L
s
1 0 0 r
.5 .59577 m
.5 .61248 L
s
0 0 1 r
.39164 .47162 m
.40847 .47077 L
s
1 0 0 r
.47162 .39164 m
.47077 .40847 L
s
0 0 1 r
.59798 .48629 m
.61466 .48688 L
s
1 0 0 r
.48629 .59798 m
.48688 .61466 L
s
0 0 1 r
.57481 .434 m
.59197 .43718 L
s
1 0 0 r
.434 .57481 m
.43718 .59197 L
s
0 0 1 r
.39376 .45666 m
.41067 .45557 L
s
1 0 0 r
.45666 .39376 m
.45557 .41067 L
s
0 0 1 r
.56089 .42003 m
.57826 .42364 L
s
1 0 0 r
.42003 .56089 m
.42364 .57826 L
s
0 0 1 r
.51153 .39972 m
.52941 .40255 L
s
.49358 .39749 m
.51153 .39972 L
s
1 0 0 r
.39972 .51153 m
.40255 .52941 L
s
.39749 .49358 m
.39972 .51153 L
s
0 0 1 r
.4157 .42481 m
.43311 .42406 L
s
1 0 0 r
.42481 .4157 m
.42406 .43311 L
s
0 0 1 r
.52941 .40255 m
.54715 .40596 L
s
1 0 0 r
.40255 .52941 m
.40596 .54715 L
s
0 0 1 r
.43625 .40902 m
.45397 .40902 L
s
1 0 0 r
.40902 .43625 m
.40902 .45397 L
s
0 0 1 r
.4756 .39585 m
.49358 .39749 L
s
1 0 0 r
.39585 .4756 m
.39749 .49358 L
s
0 0 1 r
.58885 .44782 m
.60575 .45049 L
s
1 0 0 r
.44782 .58885 m
.45049 .60575 L
s
0 0 1 r
.60036 .47337 m
.617 .47467 L
s
1 0 0 r
.47337 .60036 m
.47467 .617 L
s
0 0 1 r
.54715 .40596 m
.5647 .40995 L
s
1 0 0 r
.40596 .54715 m
.40995 .5647 L
s
0 0 1 r
.39603 .44141 m
.41305 .4402 L
s
1 0 0 r
.44141 .39603 m
.4402 .41305 L
s
0 0 1 r
.45767 .39482 m
.4756 .39585 L
s
1 0 0 r
.39482 .45767 m
.39585 .4756 L
s
0 0 1 r
.57826 .42364 m
.59535 .42775 L
s
1 0 0 r
.42364 .57826 m
.42775 .59535 L
s
0 0 1 r
.60294 .4614 m
.61954 .4635 L
s
1 0 0 r
.4614 .60294 m
.4635 .61954 L
s
0 0 1 r
.5647 .40995 m
.58199 .4145 L
s
1 0 0 r
.40995 .5647 m
.4145 .58199 L
s
0 0 1 r
.41872 .40957 m
.43625 .40902 L
s
1 0 0 r
.40957 .41872 m
.40902 .43625 L
s
0 0 1 r
.37319 .48669 m
.38959 .48611 L
s
1 0 0 r
.48669 .37319 m
.48611 .38959 L
s
0 0 1 r
.59197 .43718 m
.60881 .44077 L
s
1 0 0 r
.43718 .59197 m
.44077 .60881 L
s
0 0 1 r
.37517 .47264 m
.39164 .47162 L
s
1 0 0 r
.47264 .37517 m
.47162 .39164 L
s
0 0 1 r
.37117 .5 m
.38752 .5 L
s
1 0 0 r
.5 .37117 m
.5 .38752 L
s
0 0 1 r
.61248 .5 m
.62883 .5 L
s
1 0 0 r
.5 .61248 m
.5 .62883 L
s
0 0 1 r
.51583 .38823 m
.53368 .39188 L
s
.49787 .38525 m
.51583 .38823 L
s
1 0 0 r
.38823 .51583 m
.39188 .53368 L
s
.38525 .49787 m
.38823 .51583 L
s
0 0 1 r
.39856 .42602 m
.4157 .42481 L
s
1 0 0 r
.42602 .39856 m
.42481 .4157 L
s
0 0 1 r
.53368 .39188 m
.55135 .39617 L
s
1 0 0 r
.39188 .53368 m
.39617 .55135 L
s
0 0 1 r
.43985 .39441 m
.45767 .39482 L
s
1 0 0 r
.39441 .43985 m
.39482 .45767 L
s
0 0 1 r
.37719 .45802 m
.39376 .45666 L
s
1 0 0 r
.45802 .37719 m
.45666 .39376 L
s
0 0 1 r
.47987 .38294 m
.49787 .38525 L
s
1 0 0 r
.38294 .47987 m
.38525 .49787 L
s
0 0 1 r
.61466 .48688 m
.63096 .48756 L
s
1 0 0 r
.48688 .61466 m
.48756 .63096 L
s
0 0 1 r
.55135 .39617 m
.5688 .40111 L
s
1 0 0 r
.39617 .55135 m
.40111 .5688 L
s
0 0 1 r
.60575 .45049 m
.6223 .45351 L
s
1 0 0 r
.45049 .60575 m
.45351 .6223 L
s
0 0 1 r
.58199 .4145 m
.59896 .41961 L
s
1 0 0 r
.4145 .58199 m
.41961 .59896 L
s
0 0 1 r
.46188 .38131 m
.47987 .38294 L
s
1 0 0 r
.38131 .46188 m
.38294 .47987 L
s
0 0 1 r
.37935 .44299 m
.39603 .44141 L
s
1 0 0 r
.44299 .37935 m
.44141 .39603 L
s
0 0 1 r
.59535 .42775 m
.61209 .43234 L
s
1 0 0 r
.42775 .59535 m
.43234 .61209 L
s
0 0 1 r
.617 .47467 m
.63325 .47615 L
s
1 0 0 r
.47467 .617 m
.47615 .63325 L
s
0 0 1 r
.5688 .40111 m
.58595 .40667 L
s
1 0 0 r
.40111 .5688 m
.40667 .58595 L
s
0 0 1 r
.42219 .39464 m
.43985 .39441 L
s
1 0 0 r
.39464 .42219 m
.39441 .43985 L
s
0 0 1 r
.40144 .41066 m
.41872 .40957 L
s
1 0 0 r
.41066 .40144 m
.40957 .41872 L
s
0 0 1 r
.53829 .38238 m
.55584 .38764 L
s
.52053 .37784 m
.53829 .38238 L
s
1 0 0 r
.38238 .53829 m
.38764 .55584 L
s
.37784 .52053 m
.38238 .53829 L
s
0 0 1 r
.50263 .37403 m
.52053 .37784 L
s
1 0 0 r
.37403 .50263 m
.37784 .52053 L
s
0 0 1 r
.60881 .44077 m
.62527 .44478 L
s
1 0 0 r
.44077 .60881 m
.44478 .62527 L
s
0 0 1 r
.44397 .38039 m
.46188 .38131 L
s
1 0 0 r
.38039 .44397 m
.38131 .46188 L
s
0 0 1 r
.61954 .4635 m
.63573 .46587 L
s
1 0 0 r
.4635 .61954 m
.46587 .63573 L
s
0 0 1 r
.55584 .38764 m
.57312 .39358 L
s
1 0 0 r
.38764 .55584 m
.39358 .57312 L
s
0 0 1 r
.38175 .4277 m
.39856 .42602 L
s
1 0 0 r
.4277 .38175 m
.42602 .39856 L
s
0 0 1 r
.48463 .37095 m
.50263 .37403 L
s
1 0 0 r
.37095 .48463 m
.37403 .50263 L
s
0 0 1 r
.58595 .40667 m
.60274 .41284 L
s
1 0 0 r
.40667 .58595 m
.41284 .60274 L
s
0 0 1 r
.59896 .41961 m
.61555 .42527 L
s
1 0 0 r
.41961 .59896 m
.42527 .61555 L
s
0 0 1 r
.35721 .48735 m
.37319 .48669 L
s
1 0 0 r
.48735 .35721 m
.48669 .37319 L
s
0 0 1 r
.35911 .47386 m
.37517 .47264 L
s
1 0 0 r
.47386 .35911 m
.47264 .37517 L
s
0 0 1 r
.35525 .5 m
.37117 .5 L
s
1 0 0 r
.5 .35525 m
.5 .37117 L
s
0 0 1 r
.62883 .5 m
.64475 .5 L
s
1 0 0 r
.5 .62883 m
.5 .64475 L
s
0 0 1 r
.57312 .39358 m
.59005 .4002 L
s
1 0 0 r
.39358 .57312 m
.4002 .59005 L
s
0 0 1 r
.36104 .45967 m
.37719 .45802 L
s
1 0 0 r
.45967 .36104 m
.45802 .37719 L
s
0 0 1 r
.46662 .36863 m
.48463 .37095 L
s
1 0 0 r
.36863 .46662 m
.37095 .48463 L
s
0 0 1 r
.6223 .45351 m
.63841 .45686 L
s
1 0 0 r
.45351 .6223 m
.45686 .63841 L
s
0 0 1 r
.61209 .43234 m
.62841 .43741 L
s
1 0 0 r
.43234 .61209 m
.43741 .62841 L
s
0 0 1 r
.40477 .3955 m
.42219 .39464 L
s
1 0 0 r
.3955 .40477 m
.39464 .42219 L
s
0 0 1 r
.63096 .48756 m
.64682 .48834 L
s
1 0 0 r
.48756 .63096 m
.48834 .64682 L
s
0 0 1 r
.4262 .38018 m
.44397 .38039 L
s
1 0 0 r
.38018 .4262 m
.38039 .44397 L
s
0 0 1 r
.38448 .41232 m
.40144 .41066 L
s
1 0 0 r
.41232 .38448 m
.41066 .40144 L
s
0 0 1 r
.5432 .37416 m
.56054 .38041 L
s
.52559 .36866 m
.5432 .37416 L
s
1 0 0 r
.37416 .5432 m
.38041 .56054 L
s
.36866 .52559 m
.37416 .5432 L
s
0 0 1 r
.36308 .44494 m
.37935 .44299 L
s
1 0 0 r
.44494 .36308 m
.44299 .37935 L
s
0 0 1 r
.5078 .36394 m
.52559 .36866 L
s
1 0 0 r
.36394 .5078 m
.36866 .52559 L
s
0 0 1 r
.56054 .38041 m
.57757 .38741 L
s
1 0 0 r
.38041 .56054 m
.38741 .57757 L
s
0 0 1 r
.59005 .4002 m
.60658 .40747 L
s
1 0 0 r
.4002 .59005 m
.40747 .60658 L
s
0 0 1 r
.60274 .41284 m
.6191 .41961 L
s
1 0 0 r
.41284 .60274 m
.41961 .6191 L
s
0 0 1 r
.63325 .47615 m
.64905 .4778 L
s
1 0 0 r
.47615 .63325 m
.4778 .64905 L
s
0 0 1 r
.44864 .36709 m
.46662 .36863 L
s
1 0 0 r
.36709 .44864 m
.36863 .46662 L
s
0 0 1 r
.48987 .36002 m
.5078 .36394 L
s
1 0 0 r
.36002 .48987 m
.36394 .5078 L
s
0 0 1 r
.57757 .38741 m
.59421 .39512 L
s
1 0 0 r
.38741 .57757 m
.39512 .59421 L
s
0 0 1 r
.62527 .44478 m
.64126 .4492 L
s
1 0 0 r
.44478 .62527 m
.4492 .64126 L
s
0 0 1 r
.61555 .42527 m
.63168 .43147 L
s
1 0 0 r
.42527 .61555 m
.43147 .63168 L
s
0 0 1 r
.36534 .42985 m
.38175 .4277 L
s
1 0 0 r
.42985 .36534 m
.4277 .38175 L
s
0 0 1 r
.63573 .46587 m
.65145 .4685 L
s
1 0 0 r
.46587 .63573 m
.4685 .65145 L
s
0 0 1 r
.47188 .35692 m
.48987 .36002 L
s
1 0 0 r
.35692 .47188 m
.36002 .48987 L
s
0 0 1 r
.40864 .38069 m
.4262 .38018 L
s
1 0 0 r
.38069 .40864 m
.38018 .4262 L
s
0 0 1 r
.59421 .39512 m
.61039 .40352 L
s
1 0 0 r
.39512 .59421 m
.40352 .61039 L
s
0 0 1 r
.60658 .40747 m
.62265 .41539 L
s
1 0 0 r
.40747 .60658 m
.41539 .62265 L
s
0 0 1 r
.5483 .36725 m
.56535 .37455 L
s
.53094 .36074 m
.5483 .36725 L
s
1 0 0 r
.36725 .5483 m
.37455 .56535 L
s
.36074 .53094 m
.36725 .5483 L
s
0 0 1 r
.38766 .39701 m
.40477 .3955 L
s
1 0 0 r
.39701 .38766 m
.3955 .40477 L
s
0 0 1 r
.56535 .37455 m
.58203 .38262 L
s
1 0 0 r
.37455 .56535 m
.38262 .58203 L
s
0 0 1 r
.43078 .36634 m
.44864 .36709 L
s
1 0 0 r
.36634 .43078 m
.36709 .44864 L
s
0 0 1 r
.51333 .35506 m
.53094 .36074 L
s
1 0 0 r
.35506 .51333 m
.36074 .53094 L
s
0 0 1 r
.62841 .43741 m
.64425 .44296 L
s
1 0 0 r
.43741 .62841 m
.44296 .64425 L
s
0 0 1 r
.58203 .38262 m
.59828 .39143 L
s
1 0 0 r
.38262 .58203 m
.39143 .59828 L
s
0 0 1 r
.34355 .47526 m
.35911 .47386 L
s
1 0 0 r
.47526 .34355 m
.47386 .35911 L
s
0 0 1 r
.34173 .48811 m
.35721 .48735 L
s
1 0 0 r
.48811 .34173 m
.48735 .35721 L
s
0 0 1 r
.6191 .41961 m
.63497 .42697 L
s
1 0 0 r
.41961 .6191 m
.42697 .63497 L
s
0 0 1 r
.34537 .4616 m
.36104 .45967 L
s
1 0 0 r
.4616 .34537 m
.45967 .36104 L
s
0 0 1 r
.33985 .5 m
.35525 .5 L
s
1 0 0 r
.5 .33985 m
.5 .35525 L
s
0 0 1 r
.64475 .5 m
.66015 .5 L
s
1 0 0 r
.5 .64475 m
.5 .66015 L
s
0 0 1 r
.63841 .45686 m
.65402 .46055 L
s
1 0 0 r
.45686 .63841 m
.46055 .65402 L
s
0 0 1 r
.36792 .41454 m
.38448 .41232 L
s
1 0 0 r
.41454 .36792 m
.41232 .38448 L
s
0 0 1 r
.49555 .35024 m
.51333 .35506 L
s
1 0 0 r
.35024 .49555 m
.35506 .51333 L
s
0 0 1 r
.4539 .35467 m
.47188 .35692 L
s
1 0 0 r
.35467 .4539 m
.35692 .47188 L
s
0 0 1 r
.59828 .39143 m
.61402 .40097 L
s
1 0 0 r
.39143 .59828 m
.40097 .61402 L
s
0 0 1 r
.61039 .40352 m
.62606 .4126 L
s
1 0 0 r
.40352 .61039 m
.4126 .62606 L
s
0 0 1 r
.64682 .48834 m
.66216 .4892 L
s
1 0 0 r
.48834 .64682 m
.4892 .66216 L
s
0 0 1 r
.34729 .44728 m
.36308 .44494 L
s
1 0 0 r
.44728 .34729 m
.44494 .36308 L
s
0 0 1 r
.57014 .37005 m
.58637 .3792 L
s
.55348 .36169 m
.57014 .37005 L
s
1 0 0 r
.37005 .57014 m
.3792 .58637 L
s
.36169 .55348 m
.37005 .57014 L
s
0 0 1 r
.53646 .35415 m
.55348 .36169 L
s
1 0 0 r
.35415 .53646 m
.36169 .55348 L
s
0 0 1 r
.63168 .43147 m
.64728 .43819 L
s
1 0 0 r
.43147 .63168 m
.43819 .64728 L
s
0 0 1 r
.58637 .3792 m
.60212 .38911 L
s
1 0 0 r
.3792 .58637 m
.38911 .60212 L
s
0 0 1 r
.62265 .41539 m
.63817 .42394 L
s
1 0 0 r
.41539 .62265 m
.42394 .63817 L
s
0 0 1 r
.47766 .34629 m
.49555 .35024 L
s
1 0 0 r
.34629 .47766 m
.35024 .49555 L
s
0 0 1 r
.64126 .4492 m
.65673 .45403 L
s
1 0 0 r
.4492 .64126 m
.45403 .65673 L
s
0 0 1 r
.39137 .38195 m
.40864 .38069 L
s
1 0 0 r
.38195 .39137 m
.38069 .40864 L
s
0 0 1 r
.51914 .34748 m
.53646 .35415 L
s
1 0 0 r
.34748 .51914 m
.35415 .53646 L
s
0 0 1 r
.41311 .3664 m
.43078 .36634 L
s
1 0 0 r
.3664 .41311 m
.36634 .43078 L
s
0 0 1 r
.64905 .4778 m
.66431 .47963 L
s
1 0 0 r
.4778 .64905 m
.47963 .66431 L
s
0 0 1 r
.60212 .38911 m
.61731 .39974 L
s
1 0 0 r
.38911 .60212 m
.39974 .61731 L
s
0 0 1 r
.61402 .40097 m
.6292 .41118 L
s
1 0 0 r
.40097 .61402 m
.41118 .6292 L
s
0 0 1 r
.34941 .43248 m
.36534 .42985 L
s
1 0 0 r
.43248 .34941 m
.42985 .36534 L
s
0 0 1 r
.37092 .39919 m
.38766 .39701 L
s
1 0 0 r
.39919 .37092 m
.39701 .38766 L
s
0 0 1 r
.43599 .35328 m
.4539 .35467 L
s
1 0 0 r
.35328 .43599 m
.35467 .4539 L
s
0 0 1 r
.59042 .3771 m
.60556 .38807 L
s
.57474 .36688 m
.59042 .3771 L
s
1 0 0 r
.3771 .59042 m
.38807 .60556 L
s
.36688 .57474 m
.3771 .59042 L
s
0 0 1 r
.55859 .35747 m
.57474 .36688 L
s
1 0 0 r
.35747 .55859 m
.36688 .57474 L
s
0 0 1 r
.62606 .4126 m
.64114 .42232 L
s
1 0 0 r
.4126 .62606 m
.42232 .64114 L
s
0 0 1 r
.63497 .42697 m
.65026 .43491 L
s
1 0 0 r
.42697 .63497 m
.43491 .65026 L
s
0 0 1 r
.50159 .34169 m
.51914 .34748 L
s
1 0 0 r
.34169 .50159 m
.34748 .51914 L
s
0 0 1 r
.60556 .38807 m
.6201 .39977 L
s
1 0 0 r
.38807 .60556 m
.39977 .6201 L
s
0 0 1 r
.54202 .3489 m
.55859 .35747 L
s
1 0 0 r
.3489 .54202 m
.35747 .55859 L
s
0 0 1 r
.61731 .39974 m
.6319 .41106 L
s
1 0 0 r
.39974 .61731 m
.41106 .6319 L
s
0 0 1 r
.65145 .4685 m
.66661 .47139 L
s
1 0 0 r
.4685 .65145 m
.47139 .66661 L
s
0 0 1 r
.64425 .44296 m
.65951 .44898 L
s
1 0 0 r
.44296 .64425 m
.44898 .65951 L
s
0 0 1 r
.45973 .34324 m
.47766 .34629 L
s
1 0 0 r
.34324 .45973 m
.34629 .47766 L
s
0 0 1 r
.59401 .37624 m
.60843 .38822 L
s
.579 .365 m
.59401 .37624 L
s
1 0 0 r
.37624 .59401 m
.38822 .60843 L
s
.365 .579 m
.37624 .59401 L
s
0 0 1 r
.60843 .38822 m
.62222 .40092 L
s
1 0 0 r
.38822 .60843 m
.40092 .62222 L
s
0 0 1 r
.56346 .35456 m
.579 .365 L
s
1 0 0 r
.35456 .56346 m
.365 .579 L
s
0 0 1 r
.6201 .39977 m
.63399 .41214 L
s
1 0 0 r
.39977 .6201 m
.41214 .63399 L
s
0 0 1 r
.6292 .41118 m
.64374 .42205 L
s
1 0 0 r
.41118 .6292 m
.42205 .64374 L
s
0 0 1 r
.5251 .34121 m
.54202 .3489 L
s
1 0 0 r
.34121 .5251 m
.3489 .54202 L
s
0 0 1 r
.35182 .41734 m
.36792 .41454 L
s
1 0 0 r
.41734 .35182 m
.41454 .36792 L
s
0 0 1 r
.62222 .40092 m
.6353 .41426 L
s
1 0 0 r
.40092 .62222 m
.41426 .6353 L
s
0 0 1 r
.63817 .42394 m
.65307 .43308 L
s
1 0 0 r
.42394 .63817 m
.43308 .65307 L
s
0 0 1 r
.48388 .33683 m
.50159 .34169 L
s
1 0 0 r
.33683 .48388 m
.34169 .50159 L
s
0 0 1 r
.32856 .47685 m
.34355 .47526 L
s
1 0 0 r
.47685 .32856 m
.47526 .34355 L
s
0 0 1 r
.54746 .34497 m
.56346 .35456 L
s
1 0 0 r
.34497 .54746 m
.35456 .56346 L
s
0 0 1 r
.32683 .48896 m
.34173 .48811 L
s
1 0 0 r
.48896 .32683 m
.48811 .34173 L
s
0 0 1 r
.65402 .46055 m
.66905 .46458 L
s
1 0 0 r
.46055 .65402 m
.46458 .66905 L
s
0 0 1 r
.6319 .41106 m
.6458 .42304 L
s
1 0 0 r
.41106 .6319 m
.42304 .6458 L
s
0 0 1 r
.33028 .46381 m
.34537 .4616 L
s
1 0 0 r
.46381 .33028 m
.4616 .34537 L
s
0 0 1 r
.39569 .36729 m
.41311 .3664 L
s
1 0 0 r
.36729 .39569 m
.3664 .41311 L
s
0 0 1 r
.64728 .43819 m
.66228 .44544 L
s
1 0 0 r
.43819 .64728 m
.44544 .66228 L
s
0 0 1 r
.41823 .35279 m
.43599 .35328 L
s
1 0 0 r
.35279 .41823 m
.35328 .43599 L
s
0 0 1 r
.32503 .5 m
.33985 .5 L
s
1 0 0 r
.5 .32503 m
.5 .33985 L
s
0 0 1 r
.66015 .5 m
.67497 .5 L
s
1 0 0 r
.5 .66015 m
.5 .67497 L
s
0 0 1 r
.6353 .41426 m
.64763 .42822 L
s
1 0 0 r
.41426 .6353 m
.42822 .64763 L
s
0 0 1 r
.63399 .41214 m
.64715 .42515 L
s
1 0 0 r
.41214 .63399 m
.42515 .64715 L
s
0 0 1 r
.37445 .38396 m
.39137 .38195 L
s
1 0 0 r
.38396 .37445 m
.38195 .39137 L
s
0 0 1 r
.50789 .33444 m
.5251 .34121 L
s
1 0 0 r
.33444 .50789 m
.34121 .5251 L
s
0 0 1 r
.64114 .42232 m
.65556 .43266 L
s
1 0 0 r
.42232 .64114 m
.43266 .65556 L
s
0 0 1 r
.33207 .45001 m
.34729 .44728 L
s
1 0 0 r
.45001 .33207 m
.44728 .34729 L
s
0 0 1 r
.44182 .34114 m
.45973 .34324 L
s
1 0 0 r
.34114 .44182 m
.34324 .45973 L
s
0 0 1 r
.53105 .33627 m
.54746 .34497 L
s
1 0 0 r
.33627 .53105 m
.34497 .54746 L
s
0 0 1 r
.66216 .4892 m
.67689 .49016 L
s
1 0 0 r
.4892 .66216 m
.49016 .67689 L
s
0 0 1 r
.65673 .45403 m
.67159 .45925 L
s
1 0 0 r
.45403 .65673 m
.45925 .67159 L
s
0 0 1 r
.64374 .42205 m
.65757 .43355 L
s
1 0 0 r
.42205 .64374 m
.43355 .65757 L
s
0 0 1 r
.65026 .43491 m
.66491 .44339 L
s
1 0 0 r
.43491 .65026 m
.44339 .66491 L
s
0 0 1 r
.35464 .40204 m
.37092 .39919 L
s
1 0 0 r
.40204 .35464 m
.39919 .37092 L
s
0 0 1 r
.46608 .33293 m
.48388 .33683 L
s
1 0 0 r
.33293 .46608 m
.33683 .48388 L
s
0 0 1 r
.64763 .42822 m
.65915 .44273 L
s
1 0 0 r
.42822 .64763 m
.44273 .65915 L
s
0 0 1 r
.6458 .42304 m
.65895 .43563 L
s
1 0 0 r
.42304 .6458 m
.43563 .65895 L
s
0 0 1 r
.33403 .43559 m
.34941 .43248 L
s
1 0 0 r
.43559 .33403 m
.43248 .34941 L
s
0 0 1 r
.64715 .42515 m
.65952 .43875 L
s
1 0 0 r
.42515 .64715 m
.43875 .65952 L
s
0 0 1 r
.66431 .47963 m
.67894 .48164 L
s
1 0 0 r
.47963 .66431 m
.48164 .67894 L
s
0 0 1 r
.49046 .32863 m
.50789 .33444 L
s
1 0 0 r
.32863 .49046 m
.33444 .50789 L
s
0 0 1 r
.5143 .3285 m
.53105 .33627 L
s
1 0 0 r
.3285 .5143 m
.33627 .53105 L
s
0 0 1 r
.65307 .43308 m
.66729 .4428 L
s
1 0 0 r
.43308 .65307 m
.4428 .66729 L
s
0 0 1 r
.65951 .44898 m
.67413 .45545 L
s
1 0 0 r
.44898 .65951 m
.45545 .67413 L
s
0 0 1 r
.40069 .3532 m
.41823 .35279 L
s
1 0 0 r
.3532 .40069 m
.35279 .41823 L
s
0 0 1 r
.37861 .36903 m
.39569 .36729 L
s
1 0 0 r
.36903 .37861 m
.36729 .39569 L
s
0 0 1 r
.66661 .47139 m
.68113 .47454 L
s
1 0 0 r
.47139 .66661 m
.47454 .68113 L
s
0 0 1 r
.65915 .44273 m
.66979 .45775 L
s
1 0 0 r
.44273 .65915 m
.45775 .66979 L
s
0 0 1 r
.42402 .33999 m
.44182 .34114 L
s
1 0 0 r
.33999 .42402 m
.34114 .44182 L
s
0 0 1 r
.65556 .43266 m
.66925 .44358 L
s
1 0 0 r
.43266 .65556 m
.44358 .66925 L
s
0 0 1 r
.33628 .42072 m
.35182 .41734 L
s
1 0 0 r
.42072 .33628 m
.41734 .35182 L
s
0 0 1 r
.44825 .33002 m
.46608 .33293 L
s
1 0 0 r
.33002 .44825 m
.33293 .46608 L
s
0 0 1 r
.65952 .43875 m
.67105 .45289 L
s
1 0 0 r
.43875 .65952 m
.45289 .67105 L
s
0 0 1 r
.35798 .38674 m
.37445 .38396 L
s
1 0 0 r
.38674 .35798 m
.38396 .37445 L
s
0 0 1 r
.65757 .43355 m
.67063 .44563 L
s
1 0 0 r
.43355 .65757 m
.44563 .67063 L
s
0 0 1 r
.66228 .44544 m
.67659 .45318 L
s
1 0 0 r
.44544 .66228 m
.45318 .67659 L
s
0 0 1 r
.65895 .43563 m
.67129 .44878 L
s
1 0 0 r
.43563 .65895 m
.44878 .67129 L
s
0 0 1 r
.47288 .32381 m
.49046 .32863 L
s
1 0 0 r
.32381 .47288 m
.32863 .49046 L
s
0 0 1 r
.49727 .32171 m
.5143 .3285 L
s
1 0 0 r
.32171 .49727 m
.3285 .5143 L
s
0 0 1 r
.66905 .46458 m
.68342 .46893 L
s
1 0 0 r
.46458 .66905 m
.46893 .68342 L
s
0 0 1 r
.31423 .47863 m
.32856 .47685 L
s
1 0 0 r
.47863 .31423 m
.47685 .32856 L
s
0 0 1 r
.3126 .4899 m
.32683 .48896 L
s
1 0 0 r
.4899 .3126 m
.48896 .32683 L
s
0 0 1 r
.31584 .46632 m
.33028 .46381 L
s
1 0 0 r
.46632 .31584 m
.46381 .33028 L
s
0 0 1 r
.66491 .44339 m
.67884 .45242 L
s
1 0 0 r
.44339 .66491 m
.45242 .67884 L
s
0 0 1 r
.66979 .45775 m
.6795 .47321 L
s
1 0 0 r
.45775 .66979 m
.47321 .6795 L
s
0 0 1 r
.31089 .5 m
.32503 .5 L
s
1 0 0 r
.5 .31089 m
.5 .32503 L
s
0 0 1 r
.67497 .5 m
.68911 .5 L
s
1 0 0 r
.5 .67497 m
.5 .68911 L
s
0 0 1 r
.3175 .45312 m
.33207 .45001 L
s
1 0 0 r
.45312 .3175 m
.45001 .33207 L
s
0 0 1 r
.33891 .40557 m
.35464 .40204 L
s
1 0 0 r
.40557 .33891 m
.40204 .35464 L
s
0 0 1 r
.67159 .45925 m
.68574 .46487 L
s
1 0 0 r
.45925 .67159 m
.46487 .68574 L
s
0 0 1 r
.66729 .4428 m
.68073 .45308 L
s
1 0 0 r
.4428 .66729 m
.45308 .68073 L
s
0 0 1 r
.4064 .33983 m
.42402 .33999 L
s
1 0 0 r
.33983 .4064 m
.33999 .42402 L
s
0 0 1 r
.67689 .49016 m
.69093 .49121 L
s
1 0 0 r
.49016 .67689 m
.49121 .69093 L
s
0 0 1 r
.38345 .35455 m
.40069 .3532 L
s
1 0 0 r
.35455 .38345 m
.3532 .40069 L
s
0 0 1 r
.67105 .45289 m
.68166 .46752 L
s
1 0 0 r
.45289 .67105 m
.46752 .68166 L
s
0 0 1 r
.43048 .32814 m
.44825 .33002 L
s
1 0 0 r
.32814 .43048 m
.33002 .44825 L
s
0 0 1 r
.31931 .43919 m
.33403 .43559 L
s
1 0 0 r
.43919 .31931 m
.43559 .33403 L
s
0 0 1 r
.45523 .32005 m
.47288 .32381 L
s
1 0 0 r
.32005 .45523 m
.32381 .47288 L
s
0 0 1 r
.48003 .31596 m
.49727 .32171 L
s
1 0 0 r
.31596 .48003 m
.32171 .49727 L
s
0 0 1 r
.66925 .44358 m
.68212 .45507 L
s
1 0 0 r
.44358 .66925 m
.45507 .68212 L
s
0 0 1 r
.36194 .37162 m
.37861 .36903 L
s
1 0 0 r
.37162 .36194 m
.36903 .37861 L
s
0 0 1 r
.67129 .44878 m
.68273 .46247 L
s
1 0 0 r
.44878 .67129 m
.46247 .68273 L
s
0 0 1 r
.67063 .44563 m
.68284 .45826 L
s
1 0 0 r
.44563 .67063 m
.45826 .68284 L
s
0 0 1 r
.67413 .45545 m
.68802 .46237 L
s
1 0 0 r
.45545 .67413 m
.46237 .68802 L
s
0 0 1 r
.67894 .48164 m
.69287 .48382 L
s
1 0 0 r
.48164 .67894 m
.48382 .69287 L
s
0 0 1 r
.6795 .47321 m
.68821 .48907 L
s
1 0 0 r
.47321 .6795 m
.48907 .68821 L
s
0 0 1 r
.34204 .39031 m
.35798 .38674 L
s
1 0 0 r
.39031 .34204 m
.38674 .35798 L
s
0 0 1 r
.32137 .42469 m
.33628 .42072 L
s
1 0 0 r
.42469 .32137 m
.42072 .33628 L
s
0 0 1 r
.67659 .45318 m
.69013 .46142 L
s
1 0 0 r
.45318 .67659 m
.46142 .69013 L
s
0 0 1 r
.68113 .47454 m
.69492 .47794 L
s
1 0 0 r
.47454 .68113 m
.47794 .69492 L
s
0 0 1 r
.68166 .46752 m
.69129 .4826 L
s
1 0 0 r
.46752 .68166 m
.4826 .69129 L
s
0 0 1 r
.67884 .45242 m
.69194 .46195 L
s
1 0 0 r
.45242 .67884 m
.46195 .69194 L
s
0 0 1 r
.46265 .31129 m
.48003 .31596 L
s
1 0 0 r
.31129 .46265 m
.31596 .48003 L
s
0 0 1 r
.41284 .32731 m
.43048 .32814 L
s
1 0 0 r
.32731 .41284 m
.32814 .43048 L
s
0 0 1 r
.43757 .31736 m
.45523 .32005 L
s
1 0 0 r
.31736 .43757 m
.32005 .45523 L
s
0 0 1 r
.38905 .34068 m
.4064 .33983 L
s
1 0 0 r
.34068 .38905 m
.33983 .4064 L
s
0 0 1 r
.68342 .46893 m
.69702 .47361 L
s
1 0 0 r
.46893 .68342 m
.47361 .69702 L
s
0 0 1 r
.36661 .35685 m
.38345 .35455 L
s
1 0 0 r
.35685 .36661 m
.35455 .38345 L
s
0 0 1 r
.68273 .46247 m
.69322 .47663 L
s
1 0 0 r
.46247 .68273 m
.47663 .69322 L
s
0 0 1 r
.68073 .45308 m
.69332 .46388 L
s
1 0 0 r
.45308 .68073 m
.46388 .69332 L
s
0 0 1 r
.3238 .40979 m
.33891 .40557 L
s
1 0 0 r
.40979 .3238 m
.40557 .33891 L
s
0 0 1 r
.30065 .4806 m
.31423 .47863 L
s
1 0 0 r
.4806 .30065 m
.47863 .31423 L
s
0 0 1 r
.30214 .46912 m
.31584 .46632 L
s
1 0 0 r
.46912 .30214 m
.46632 .31584 L
s
0 0 1 r
.68284 .45826 m
.69411 .4714 L
s
1 0 0 r
.45826 .68284 m
.4714 .69411 L
s
0 0 1 r
.68212 .45507 m
.69409 .46708 L
s
1 0 0 r
.45507 .68212 m
.46708 .69409 L
s
0 0 1 r
.29913 .49094 m
.3126 .4899 L
s
1 0 0 r
.49094 .29913 m
.4899 .3126 L
s
0 0 1 r
.30367 .45663 m
.3175 .45312 L
s
1 0 0 r
.45663 .30367 m
.45312 .3175 L
s
0 0 1 r
.34579 .3751 m
.36194 .37162 L
s
1 0 0 r
.3751 .34579 m
.37162 .36194 L
s
0 0 1 r
.68821 .48907 m
.69586 .50525 L
s
1 0 0 r
.48907 .68821 m
.50525 .69586 L
s
0 0 1 r
.68574 .46487 m
.69911 .47088 L
s
1 0 0 r
.46487 .68574 m
.47088 .69911 L
s
0 0 1 r
.29752 .5 m
.31089 .5 L
s
1 0 0 r
.5 .29752 m
.5 .31089 L
s
0 0 1 r
.68911 .5 m
.70248 .5 L
s
1 0 0 r
.5 .68911 m
.5 .70248 L
s
0 0 1 r
.30533 .44329 m
.31931 .43919 L
s
1 0 0 r
.44329 .30533 m
.43919 .31931 L
s
0 0 1 r
.69093 .49121 m
.70419 .49234 L
s
1 0 0 r
.49121 .69093 m
.49234 .70419 L
s
0 0 1 r
.68802 .46237 m
.70107 .46972 L
s
1 0 0 r
.46237 .68802 m
.46972 .70107 L
s
0 0 1 r
.69129 .4826 m
.69987 .49805 L
s
1 0 0 r
.4826 .69129 m
.49805 .69987 L
s
0 0 1 r
.32672 .39466 m
.34204 .39031 L
s
1 0 0 r
.39466 .32672 m
.39031 .34204 L
s
0 0 1 r
.44521 .30774 m
.46265 .31129 L
s
1 0 0 r
.30774 .44521 m
.31129 .46265 L
s
0 0 1 r
.41999 .31579 m
.43757 .31736 L
s
1 0 0 r
.31579 .41999 m
.31736 .43757 L
s
0 0 1 r
.39542 .32758 m
.41284 .32731 L
s
1 0 0 r
.32758 .39542 m
.32731 .41284 L
s
0 0 1 r
.69287 .48382 m
.706 .48618 L
s
1 0 0 r
.48382 .69287 m
.48618 .706 L
s
0 0 1 r
.30721 .42926 m
.32137 .42469 L
s
1 0 0 r
.42926 .30721 m
.42469 .32137 L
s
0 0 1 r
.69013 .46142 m
.7028 .47012 L
s
1 0 0 r
.46142 .69013 m
.47012 .7028 L
s
0 0 1 r
.37205 .34258 m
.38905 .34068 L
s
1 0 0 r
.34258 .37205 m
.34068 .38905 L
s
0 0 1 r
.69322 .47663 m
.70267 .49122 L
s
1 0 0 r
.47663 .69322 m
.49122 .70267 L
s
0 0 1 r
.35025 .36012 m
.36661 .35685 L
s
1 0 0 r
.36012 .35025 m
.35685 .36661 L
s
0 0 1 r
.69194 .46195 m
.70415 .47197 L
s
1 0 0 r
.46195 .69194 m
.47197 .70415 L
s
0 0 1 r
.69586 .50525 m
.7024 .5217 L
s
1 0 0 r
.50525 .69586 m
.5217 .7024 L
s
0 0 1 r
.69492 .47794 m
.70788 .48159 L
s
1 0 0 r
.47794 .69492 m
.48159 .70788 L
s
0 0 1 r
.69411 .4714 m
.70437 .485 L
s
1 0 0 r
.4714 .69411 m
.485 .70437 L
s
0 0 1 r
.69332 .46388 m
.70496 .47518 L
s
1 0 0 r
.46388 .69332 m
.47518 .70496 L
s
0 0 1 r
.69409 .46708 m
.70509 .47958 L
s
1 0 0 r
.46708 .69409 m
.47958 .70509 L
s
0 0 1 r
.30943 .41472 m
.3238 .40979 L
s
1 0 0 r
.41472 .30943 m
.40979 .3238 L
s
0 0 1 r
.33024 .37947 m
.34579 .3751 L
s
1 0 0 r
.37947 .33024 m
.3751 .34579 L
s
0 0 1 r
.69702 .47361 m
.70977 .47861 L
s
1 0 0 r
.47361 .69702 m
.47861 .70977 L
s
0 0 1 r
.69987 .49805 m
.70732 .51382 L
s
1 0 0 r
.49805 .69987 m
.51382 .70732 L
s
0 0 1 r
.42779 .30537 m
.44521 .30774 L
s
1 0 0 r
.30537 .42779 m
.30774 .44521 L
s
0 0 1 r
.2893 .47221 m
.30214 .46912 L
s
1 0 0 r
.47221 .2893 m
.46912 .30214 L
s
0 0 1 r
.28793 .48277 m
.30065 .4806 L
s
1 0 0 r
.48277 .28793 m
.4806 .30065 L
s
0 0 1 r
.40258 .31539 m
.41999 .31579 L
s
1 0 0 r
.31539 .40258 m
.31579 .41999 L
s
0 0 1 r
.29069 .46053 m
.30367 .45663 L
s
1 0 0 r
.46053 .29069 m
.45663 .30367 L
s
0 0 1 r
.28652 .49208 m
.29913 .49094 L
s
1 0 0 r
.49208 .28652 m
.49094 .29913 L
s
0 0 1 r
.69911 .47088 m
.71158 .47725 L
s
1 0 0 r
.47088 .69911 m
.47725 .71158 L
s
0 0 1 r
.37832 .32897 m
.39542 .32758 L
s
1 0 0 r
.32897 .37832 m
.32758 .39542 L
s
0 0 1 r
.28503 .5 m
.29752 .5 L
s
1 0 0 r
.5 .28503 m
.5 .29752 L
s
0 0 1 r
.70248 .5 m
.71497 .5 L
s
1 0 0 r
.5 .70248 m
.5 .71497 L
s
0 0 1 r
.29218 .44788 m
.30533 .44329 L
s
1 0 0 r
.44788 .29218 m
.44329 .30533 L
s
0 0 1 r
.31212 .39982 m
.32672 .39466 L
s
1 0 0 r
.39982 .31212 m
.39466 .32672 L
s
0 0 1 r
.70267 .49122 m
.711 .50618 L
s
1 0 0 r
.49122 .70267 m
.50618 .711 L
s
0 0 1 r
.3555 .34554 m
.37205 .34258 L
s
1 0 0 r
.34554 .3555 m
.34258 .37205 L
s
0 0 1 r
.70107 .46972 m
.71321 .47749 L
s
1 0 0 r
.46972 .70107 m
.47749 .71321 L
s
0 0 1 r
.7024 .5217 m
.70775 .53833 L
s
1 0 0 r
.5217 .7024 m
.53833 .70775 L
s
0 0 1 r
.70419 .49234 m
.71656 .49357 L
s
1 0 0 r
.49234 .70419 m
.49357 .71656 L
s
0 0 1 r
.70437 .485 m
.71353 .49901 L
s
1 0 0 r
.485 .70437 m
.49901 .71353 L
s
0 0 1 r
.33446 .36439 m
.35025 .36012 L
s
1 0 0 r
.36439 .33446 m
.36012 .35025 L
s
0 0 1 r
.7028 .47012 m
.71451 .47926 L
s
1 0 0 r
.47012 .7028 m
.47926 .71451 L
s
0 0 1 r
.29388 .43443 m
.30721 .42926 L
s
1 0 0 r
.43443 .29388 m
.42926 .30721 L
s
0 0 1 r
.70415 .47197 m
.71535 .48246 L
s
1 0 0 r
.47197 .70415 m
.48246 .71535 L
s
0 0 1 r
.70509 .47958 m
.71501 .49252 L
s
1 0 0 r
.47958 .70509 m
.49252 .71501 L
s
0 0 1 r
.70496 .47518 m
.71557 .48693 L
s
1 0 0 r
.47518 .70496 m
.48693 .71557 L
s
0 0 1 r
.706 .48618 m
.71821 .48871 L
s
1 0 0 r
.48618 .706 m
.48871 .71821 L
s
0 0 1 r
.41048 .30422 m
.42779 .30537 L
s
1 0 0 r
.30422 .41048 m
.30537 .42779 L
s
0 0 1 r
.70732 .51382 m
.71358 .52984 L
s
1 0 0 r
.51382 .70732 m
.52984 .71358 L
s
0 0 1 r
.31539 .38474 m
.33024 .37947 L
s
1 0 0 r
.38474 .31539 m
.37947 .33024 L
s
0 0 1 r
.70788 .48159 m
.7199 .48548 L
s
1 0 0 r
.48159 .70788 m
.48548 .7199 L
s
0 0 1 r
.38543 .31618 m
.40258 .31539 L
s
1 0 0 r
.31618 .38543 m
.31539 .40258 L
s
0 0 1 r
.29589 .42035 m
.30943 .41472 L
s
1 0 0 r
.42035 .29589 m
.41472 .30943 L
s
0 0 1 r
.36162 .33152 m
.37832 .32897 L
s
1 0 0 r
.33152 .36162 m
.32897 .37832 L
s
0 0 1 r
.70977 .47861 m
.72155 .48391 L
s
1 0 0 r
.47861 .70977 m
.48391 .72155 L
s
0 0 1 r
.711 .50618 m
.71814 .52145 L
s
1 0 0 r
.50618 .711 m
.52145 .71814 L
s
0 0 1 r
.70775 .53833 m
.71185 .55508 L
s
1 0 0 r
.53833 .70775 m
.55508 .71185 L
s
0 0 1 r
.3395 .34959 m
.3555 .34554 L
s
1 0 0 r
.34959 .3395 m
.34554 .3555 L
s
0 0 1 r
.27741 .47558 m
.2893 .47221 L
s
1 0 0 r
.47558 .27741 m
.47221 .2893 L
s
0 0 1 r
.27617 .48512 m
.28793 .48277 L
s
1 0 0 r
.48512 .27617 m
.48277 .28793 L
s
0 0 1 r
.71158 .47725 m
.72306 .48398 L
s
1 0 0 r
.47725 .71158 m
.48398 .72306 L
s
0 0 1 r
.29833 .40579 m
.31212 .39982 L
s
1 0 0 r
.40579 .29833 m
.39982 .31212 L
s
0 0 1 r
.27866 .46482 m
.29069 .46053 L
s
1 0 0 r
.46482 .27866 m
.46053 .29069 L
s
0 0 1 r
.71353 .49901 m
.72151 .51337 L
s
1 0 0 r
.49901 .71353 m
.51337 .72151 L
s
0 0 1 r
.27488 .4933 m
.28652 .49208 L
s
1 0 0 r
.4933 .27488 m
.49208 .28652 L
s
0 0 1 r
.31936 .36966 m
.33446 .36439 L
s
1 0 0 r
.36966 .31936 m
.36439 .33446 L
s
0 0 1 r
.27999 .45297 m
.29218 .44788 L
s
1 0 0 r
.45297 .27999 m
.44788 .29218 L
s
0 0 1 r
.71321 .47749 m
.72431 .48565 L
s
1 0 0 r
.47749 .71321 m
.48565 .72431 L
s
0 0 1 r
.27352 .5 m
.28503 .5 L
s
1 0 0 r
.5 .27352 m
.5 .28503 L
s
0 0 1 r
.71497 .5 m
.72648 .5 L
s
1 0 0 r
.5 .71497 m
.5 .72648 L
s
0 0 1 r
.71501 .49252 m
.72377 .50584 L
s
1 0 0 r
.49252 .71501 m
.50584 .72377 L
s
0 0 1 r
.39336 .30434 m
.41048 .30422 L
s
1 0 0 r
.30434 .39336 m
.30422 .41048 L
s
0 0 1 r
.71451 .47926 m
.72515 .48882 L
s
1 0 0 r
.47926 .71451 m
.48882 .72515 L
s
0 0 1 r
.71358 .52984 m
.71857 .54604 L
s
1 0 0 r
.52984 .71358 m
.54604 .71857 L
s
0 0 1 r
.71557 .48693 m
.72504 .4991 L
s
1 0 0 r
.48693 .71557 m
.4991 .72504 L
s
0 0 1 r
.71535 .48246 m
.72545 .49336 L
s
1 0 0 r
.48246 .71535 m
.49336 .72545 L
s
0 0 1 r
.28149 .4402 m
.29388 .43443 L
s
1 0 0 r
.4402 .28149 m
.43443 .29388 L
s
0 0 1 r
.36863 .31821 m
.38543 .31618 L
s
1 0 0 r
.31821 .36863 m
.31618 .38543 L
s
0 0 1 r
.71656 .49357 m
.72792 .49488 L
s
1 0 0 r
.49357 .71656 m
.49488 .72792 L
s
0 0 1 r
.30135 .39093 m
.31539 .38474 L
s
1 0 0 r
.39093 .30135 m
.38474 .31539 L
s
0 0 1 r
.34543 .33524 m
.36162 .33152 L
s
1 0 0 r
.33524 .34543 m
.33152 .36162 L
s
0 0 1 r
.71821 .48871 m
.72941 .4914 L
s
1 0 0 r
.48871 .71821 m
.4914 .72941 L
s
0 0 1 r
.71185 .55508 m
.71464 .57184 L
s
1 0 0 r
.55508 .71185 m
.57184 .71464 L
s
0 0 1 r
.28329 .42668 m
.29589 .42035 L
s
1 0 0 r
.42668 .28329 m
.42035 .29589 L
s
0 0 1 r
.71814 .52145 m
.72401 .53695 L
s
1 0 0 r
.52145 .71814 m
.53695 .72401 L
s
0 0 1 r
.32416 .35475 m
.3395 .34959 L
s
1 0 0 r
.35475 .32416 m
.34959 .3395 L
s
0 0 1 r
.7199 .48548 m
.73088 .48961 L
s
1 0 0 r
.48548 .7199 m
.48961 .73088 L
s
0 0 1 r
.72151 .51337 m
.72822 .52802 L
s
1 0 0 r
.51337 .72151 m
.52802 .72822 L
s
0 0 1 r
.72155 .48391 m
.73226 .48951 L
s
1 0 0 r
.48391 .72155 m
.48951 .73226 L
s
0 0 1 r
.28549 .41257 m
.29833 .40579 L
s
1 0 0 r
.41257 .28549 m
.40579 .29833 L
s
0 0 1 r
.30505 .37595 m
.31936 .36966 L
s
1 0 0 r
.37595 .30505 m
.36966 .31936 L
s
0 0 1 r
.37655 .30577 m
.39336 .30434 L
s
1 0 0 r
.30577 .37655 m
.30434 .39336 L
s
0 0 1 r
.71857 .54604 m
.72221 .56233 L
s
1 0 0 r
.54604 .71857 m
.56233 .72221 L
s
0 0 1 r
.72306 .48398 m
.73343 .49106 L
s
1 0 0 r
.48398 .72306 m
.49106 .73343 L
s
0 0 1 r
.72377 .50584 m
.73127 .5195 L
s
1 0 0 r
.50584 .72377 m
.5195 .73127 L
s
0 0 1 r
.2666 .47925 m
.27741 .47558 L
s
1 0 0 r
.47925 .2666 m
.47558 .27741 L
s
0 0 1 r
.2677 .4695 m
.27866 .46482 L
s
1 0 0 r
.4695 .2677 m
.46482 .27866 L
s
0 0 1 r
.3523 .32152 m
.36863 .31821 L
s
1 0 0 r
.32152 .3523 m
.31821 .36863 L
s
0 0 1 r
.26549 .48766 m
.27617 .48512 L
s
1 0 0 r
.48766 .26549 m
.48512 .27617 L
s
0 0 1 r
.72431 .48565 m
.73427 .49418 L
s
1 0 0 r
.48565 .72431 m
.49418 .73427 L
s
0 0 1 r
.26886 .45855 m
.27999 .45297 L
s
1 0 0 r
.45855 .26886 m
.45297 .27999 L
s
0 0 1 r
.72504 .4991 m
.73327 .51163 L
s
1 0 0 r
.4991 .72504 m
.51163 .73327 L
s
0 0 1 r
.26433 .49462 m
.27488 .4933 L
s
1 0 0 r
.49462 .26433 m
.4933 .27488 L
s
0 0 1 r
.72515 .48882 m
.73462 .49877 L
s
1 0 0 r
.48882 .72515 m
.49877 .73462 L
s
0 0 1 r
.72545 .49336 m
.73434 .50465 L
s
1 0 0 r
.49336 .72545 m
.50465 .73434 L
s
0 0 1 r
.32986 .34018 m
.34543 .33524 L
s
1 0 0 r
.34018 .32986 m
.33524 .34543 L
s
0 0 1 r
.71464 .57184 m
.71606 .58854 L
s
1 0 0 r
.57184 .71464 m
.58854 .71606 L
s
0 0 1 r
.26311 .5 m
.27352 .5 L
s
1 0 0 r
.5 .26311 m
.5 .27352 L
s
0 0 1 r
.72648 .5 m
.73689 .5 L
s
1 0 0 r
.5 .72648 m
.5 .73689 L
s
0 0 1 r
.27017 .44658 m
.28149 .4402 L
s
1 0 0 r
.44658 .27017 m
.4402 .28149 L
s
0 0 1 r
.28823 .39804 m
.30135 .39093 L
s
1 0 0 r
.39804 .28823 m
.39093 .30135 L
s
0 0 1 r
.72401 .53695 m
.72852 .55261 L
s
1 0 0 r
.53695 .72401 m
.55261 .72852 L
s
0 0 1 r
.72792 .49488 m
.73817 .49627 L
s
1 0 0 r
.49488 .72792 m
.49627 .73817 L
s
0 0 1 r
.30958 .36103 m
.32416 .35475 L
s
1 0 0 r
.36103 .30958 m
.35475 .32416 L
s
0 0 1 r
.27174 .43372 m
.28329 .42668 L
s
1 0 0 r
.43372 .27174 m
.42668 .28329 L
s
0 0 1 r
.72941 .4914 m
.73946 .49425 L
s
1 0 0 r
.4914 .72941 m
.49425 .73946 L
s
0 0 1 r
.72822 .52802 m
.73357 .54289 L
s
1 0 0 r
.52802 .72822 m
.54289 .73357 L
s
0 0 1 r
.36015 .30856 m
.37655 .30577 L
s
1 0 0 r
.30856 .36015 m
.30577 .37655 L
s
0 0 1 r
.72221 .56233 m
.72445 .57862 L
s
1 0 0 r
.56233 .72221 m
.57862 .72445 L
s
0 0 1 r
.29165 .38328 m
.30505 .37595 L
s
1 0 0 r
.38328 .29165 m
.37595 .30505 L
s
0 0 1 r
.73088 .48961 m
.74069 .49396 L
s
1 0 0 r
.48961 .73088 m
.49396 .74069 L
s
0 0 1 r
.27369 .42016 m
.28549 .41257 L
s
1 0 0 r
.42016 .27369 m
.41257 .28549 L
s
0 0 1 r
.33655 .32612 m
.3523 .32152 L
s
1 0 0 r
.32612 .33655 m
.32152 .3523 L
s
0 0 1 r
.73127 .5195 m
.73742 .53343 L
s
1 0 0 r
.5195 .73127 m
.53343 .73742 L
s
0 0 1 r
.73226 .48951 m
.74177 .49538 L
s
1 0 0 r
.48951 .73226 m
.49538 .74177 L
s
0 0 1 r
.31502 .34634 m
.32986 .34018 L
s
1 0 0 r
.34634 .31502 m
.34018 .32986 L
s
0 0 1 r
.71606 .58854 m
.71603 .60508 L
s
1 0 0 r
.58854 .71606 m
.60508 .71603 L
s
0 0 1 r
.73327 .51163 m
.74017 .52447 L
s
1 0 0 r
.51163 .73327 m
.52447 .74017 L
s
0 0 1 r
.73343 .49106 m
.74258 .49845 L
s
1 0 0 r
.49106 .73343 m
.49845 .74258 L
s
0 0 1 r
.25792 .47456 m
.2677 .4695 L
s
1 0 0 r
.47456 .25792 m
.4695 .2677 L
s
0 0 1 r
.25698 .48319 m
.2666 .47925 L
s
1 0 0 r
.48319 .25698 m
.47925 .2666 L
s
0 0 1 r
.73427 .49418 m
.74297 .50305 L
s
1 0 0 r
.49418 .73427 m
.50305 .74297 L
s
0 0 1 r
.73434 .50465 m
.74191 .51627 L
s
1 0 0 r
.50465 .73434 m
.51627 .74191 L
s
0 0 1 r
.72852 .55261 m
.73159 .56834 L
s
1 0 0 r
.55261 .72852 m
.56834 .73159 L
s
0 0 1 r
.73462 .49877 m
.7428 .50906 L
s
1 0 0 r
.49877 .73462 m
.50906 .7428 L
s
0 0 1 r
.25891 .46462 m
.26886 .45855 L
s
1 0 0 r
.46462 .25891 m
.45855 .26886 L
s
0 0 1 r
.25601 .49039 m
.26549 .48766 L
s
1 0 0 r
.49039 .25601 m
.48766 .26549 L
s
0 0 1 r
.27616 .40607 m
.28823 .39804 L
s
1 0 0 r
.40607 .27616 m
.39804 .28823 L
s
0 0 1 r
.255 .49602 m
.26433 .49462 L
s
1 0 0 r
.49602 .255 m
.49462 .26433 L
s
0 0 1 r
.29588 .36845 m
.30958 .36103 L
s
1 0 0 r
.36845 .29588 m
.36103 .30958 L
s
0 0 1 r
.26003 .45354 m
.27017 .44658 L
s
1 0 0 r
.45354 .26003 m
.44658 .27017 L
s
0 0 1 r
.25393 .5 m
.26311 .5 L
s
1 0 0 r
.5 .25393 m
.5 .26311 L
s
0 0 1 r
.73689 .5 m
.74607 .5 L
s
1 0 0 r
.5 .73689 m
.5 .74607 L
s
0 0 1 r
.34426 .31273 m
.36015 .30856 L
s
1 0 0 r
.31273 .34426 m
.30856 .36015 L
s
0 0 1 r
.73357 .54289 m
.73746 .5579 L
s
1 0 0 r
.54289 .73357 m
.5579 .73746 L
s
0 0 1 r
.26138 .44146 m
.27174 .43372 L
s
1 0 0 r
.44146 .26138 m
.43372 .27174 L
s
0 0 1 r
.72445 .57862 m
.7252 .59482 L
s
1 0 0 r
.57862 .72445 m
.59482 .7252 L
s
0 0 1 r
.73817 .49627 m
.74717 .49775 L
s
1 0 0 r
.49627 .73817 m
.49775 .74717 L
s
0 0 1 r
.32148 .33205 m
.33655 .32612 L
s
1 0 0 r
.33205 .32148 m
.32612 .33655 L
s
0 0 1 r
.27928 .39163 m
.29165 .38328 L
s
1 0 0 r
.39163 .27928 m
.38328 .29165 L
s
0 0 1 r
.73946 .49425 m
.74824 .49726 L
s
1 0 0 r
.49425 .73946 m
.49726 .74824 L
s
0 0 1 r
.73742 .53343 m
.74212 .54756 L
s
1 0 0 r
.53343 .73742 m
.54756 .74212 L
s
0 0 1 r
.26307 .42857 m
.27369 .42016 L
s
1 0 0 r
.42857 .26307 m
.42016 .27369 L
s
0 0 1 r
.71603 .60508 m
.71451 .62134 L
s
1 0 0 r
.60508 .71603 m
.62134 .71451 L
s
0 0 1 r
.30104 .35374 m
.31502 .34634 L
s
1 0 0 r
.35374 .30104 m
.34634 .31502 L
s
0 0 1 r
.74069 .49396 m
.74921 .49853 L
s
1 0 0 r
.49396 .74069 m
.49853 .74921 L
s
0 0 1 r
.74017 .52447 m
.74561 .53756 L
s
1 0 0 r
.52447 .74017 m
.53756 .74561 L
s
0 0 1 r
.73159 .56834 m
.73314 .58405 L
s
1 0 0 r
.56834 .73159 m
.58405 .73314 L
s
0 0 1 r
.74177 .49538 m
.74996 .50151 L
s
1 0 0 r
.49538 .74177 m
.50151 .74996 L
s
0 0 1 r
.74191 .51627 m
.74806 .52817 L
s
1 0 0 r
.51627 .74191 m
.52817 .74806 L
s
0 0 1 r
.74258 .49845 m
.75037 .50612 L
s
1 0 0 r
.49845 .74258 m
.50612 .75037 L
s
0 0 1 r
.26525 .41502 m
.27616 .40607 L
s
1 0 0 r
.41502 .26525 m
.40607 .27616 L
s
0 0 1 r
.28319 .37701 m
.29588 .36845 L
s
1 0 0 r
.37701 .28319 m
.36845 .29588 L
s
0 0 1 r
.7428 .50906 m
.74957 .51965 L
s
1 0 0 r
.50906 .7428 m
.51965 .74957 L
s
0 0 1 r
.74297 .50305 m
.75029 .51223 L
s
1 0 0 r
.50305 .74297 m
.51223 .75029 L
s
0 0 1 r
.24947 .48 m
.25792 .47456 L
s
1 0 0 r
.48 .24947 m
.47456 .25792 L
s
0 0 1 r
.32902 .31833 m
.34426 .31273 L
s
1 0 0 r
.31833 .32902 m
.31273 .34426 L
s
0 0 1 r
.24868 .48741 m
.25698 .48319 L
s
1 0 0 r
.48741 .24868 m
.48319 .25698 L
s
0 0 1 r
.25028 .47117 m
.25891 .46462 L
s
1 0 0 r
.47117 .25028 m
.46462 .25891 L
s
0 0 1 r
.24787 .49329 m
.25601 .49039 L
s
1 0 0 r
.49329 .24787 m
.49039 .25601 L
s
0 0 1 r
.7252 .59482 m
.7244 .61082 L
s
1 0 0 r
.59482 .7252 m
.61082 .7244 L
s
0 0 1 r
.73746 .5579 m
.73982 .57297 L
s
1 0 0 r
.5579 .73746 m
.57297 .73982 L
s
0 0 1 r
.2512 .46108 m
.26003 .45354 L
s
1 0 0 r
.46108 .2512 m
.45354 .26003 L
s
0 0 1 r
.24701 .49751 m
.255 .49602 L
s
1 0 0 r
.49751 .24701 m
.49602 .255 L
s
0 0 1 r
.30723 .33933 m
.32148 .33205 L
s
1 0 0 r
.33933 .30723 m
.33205 .32148 L
s
0 0 1 r
.25232 .44989 m
.26138 .44146 L
s
1 0 0 r
.44989 .25232 m
.44146 .26138 L
s
0 0 1 r
.26806 .40101 m
.27928 .39163 L
s
1 0 0 r
.40101 .26806 m
.39163 .27928 L
s
0 0 1 r
.24611 .5 m
.25393 .5 L
s
1 0 0 r
.5 .24611 m
.5 .25393 L
s
0 0 1 r
.74607 .5 m
.75389 .5 L
s
1 0 0 r
.5 .74607 m
.5 .75389 L
s
0 0 1 r
.71451 .62134 m
.71144 .63722 L
s
1 0 0 r
.62134 .71451 m
.63722 .71144 L
s
0 0 1 r
.74212 .54756 m
.74526 .56181 L
s
1 0 0 r
.54756 .74212 m
.56181 .74526 L
s
0 0 1 r
.28803 .3624 m
.30104 .35374 L
s
1 0 0 r
.3624 .28803 m
.35374 .30104 L
s
0 0 1 r
.74717 .49775 m
.75479 .4993 L
s
1 0 0 r
.49775 .74717 m
.4993 .75479 L
s
0 0 1 r
.25376 .43777 m
.26307 .42857 L
s
1 0 0 r
.43777 .25376 m
.42857 .26307 L
s
0 0 1 r
.73314 .58405 m
.73309 .59965 L
s
1 0 0 r
.58405 .73314 m
.59965 .73309 L
s
0 0 1 r
.74824 .49726 m
.75562 .5004 L
s
1 0 0 r
.49726 .74824 m
.5004 .75562 L
s
0 0 1 r
.74561 .53756 m
.74951 .55082 L
s
1 0 0 r
.53756 .74561 m
.55082 .74951 L
s
0 0 1 r
.74921 .49853 m
.7563 .50329 L
s
1 0 0 r
.49853 .74921 m
.50329 .7563 L
s
0 0 1 r
.27164 .38671 m
.28319 .37701 L
s
1 0 0 r
.38671 .27164 m
.37701 .28319 L
s
0 0 1 r
.31454 .32538 m
.32902 .31833 L
s
1 0 0 r
.32538 .31454 m
.31833 .32902 L
s
0 0 1 r
.74806 .52817 m
.75266 .54029 L
s
1 0 0 r
.52817 .74806 m
.54029 .75266 L
s
0 0 1 r
.25564 .42488 m
.26525 .41502 L
s
1 0 0 r
.42488 .25564 m
.41502 .26525 L
s
0 0 1 r
.74996 .50151 m
.7567 .50788 L
s
1 0 0 r
.50151 .74996 m
.50788 .7567 L
s
0 0 1 r
.7244 .61082 m
.72199 .62652 L
s
1 0 0 r
.61082 .7244 m
.62652 .72199 L
s
0 0 1 r
.74957 .51965 m
.75481 .53048 L
s
1 0 0 r
.51965 .74957 m
.53048 .75481 L
s
0 0 1 r
.75037 .50612 m
.75668 .51406 L
s
1 0 0 r
.50612 .75037 m
.51406 .75668 L
s
0 0 1 r
.75029 .51223 m
.7561 .52166 L
s
1 0 0 r
.51223 .75029 m
.52166 .7561 L
s
0 0 1 r
.73982 .57297 m
.74054 .58799 L
s
1 0 0 r
.57297 .73982 m
.58799 .74054 L
s
0 0 1 r
.29392 .34796 m
.30723 .33933 L
s
1 0 0 r
.34796 .29392 m
.33933 .30723 L
s
0 0 1 r
.24246 .48579 m
.24947 .48 L
s
1 0 0 r
.48579 .24246 m
.48 .24947 L
s
0 0 1 r
.2431 .47818 m
.25028 .47117 L
s
1 0 0 r
.47818 .2431 m
.47117 .25028 L
s
0 0 1 r
.24184 .49189 m
.24868 .48741 L
s
1 0 0 r
.49189 .24184 m
.48741 .24868 L
s
0 0 1 r
.24381 .46919 m
.2512 .46108 L
s
1 0 0 r
.46919 .24381 m
.46108 .2512 L
s
0 0 1 r
.71144 .63722 m
.70678 .65258 L
s
1 0 0 r
.63722 .71144 m
.65258 .70678 L
s
0 0 1 r
.25813 .41141 m
.26806 .40101 L
s
1 0 0 r
.41141 .25813 m
.40101 .26806 L
s
0 0 1 r
.24119 .49636 m
.24787 .49329 L
s
1 0 0 r
.49636 .24119 m
.49329 .24787 L
s
0 0 1 r
.2447 .45899 m
.25232 .44989 L
s
1 0 0 r
.45899 .2447 m
.44989 .25232 L
s
0 0 1 r
.27614 .3723 m
.28803 .3624 L
s
1 0 0 r
.3723 .27614 m
.3624 .28803 L
s
0 0 1 r
.74526 .56181 m
.74675 .57608 L
s
1 0 0 r
.56181 .74526 m
.57608 .74675 L
s
0 0 1 r
.2405 .49908 m
.24701 .49751 L
s
1 0 0 r
.49908 .2405 m
.49751 .24701 L
s
0 0 1 r
.73309 .59965 m
.73137 .61501 L
s
1 0 0 r
.59965 .73309 m
.61501 .73137 L
s
0 0 1 r
.23979 .5 m
.24611 .5 L
s
1 0 0 r
.5 .23979 m
.5 .24611 L
s
0 0 1 r
.75389 .5 m
.76021 .5 L
s
1 0 0 r
.5 .75389 m
.5 .76021 L
s
0 0 1 r
.24587 .44774 m
.25376 .43777 L
s
1 0 0 r
.44774 .24587 m
.43777 .25376 L
s
0 0 1 r
.74951 .55082 m
.75174 .56418 L
s
1 0 0 r
.55082 .74951 m
.56418 .75174 L
s
0 0 1 r
.30096 .33389 m
.31454 .32538 L
s
1 0 0 r
.33389 .30096 m
.32538 .31454 L
s
0 0 1 r
.75479 .4993 m
.76089 .50092 L
s
1 0 0 r
.4993 .75479 m
.50092 .76089 L
s
0 0 1 r
.26137 .39753 m
.27164 .38671 L
s
1 0 0 r
.39753 .26137 m
.38671 .27164 L
s
0 0 1 r
.72199 .62652 m
.7179 .64178 L
s
1 0 0 r
.62652 .72199 m
.64178 .7179 L
s
0 0 1 r
.75562 .5004 m
.76146 .50368 L
s
1 0 0 r
.5004 .75562 m
.50368 .76146 L
s
0 0 1 r
.24746 .43562 m
.25564 .42488 L
s
1 0 0 r
.43562 .24746 m
.42488 .25564 L
s
0 0 1 r
.75266 .54029 m
.75559 .55256 L
s
1 0 0 r
.54029 .75266 m
.55256 .75559 L
s
0 0 1 r
.28169 .35796 m
.29392 .34796 L
s
1 0 0 r
.35796 .28169 m
.34796 .29392 L
s
0 0 1 r
.74054 .58799 m
.73955 .60286 L
s
1 0 0 r
.58799 .74054 m
.60286 .73955 L
s
0 0 1 r
.7563 .50329 m
.76182 .50822 L
s
1 0 0 r
.50329 .7563 m
.50822 .76182 L
s
0 0 1 r
.75481 .53048 m
.7584 .54151 L
s
1 0 0 r
.53048 .75481 m
.54151 .7584 L
s
0 0 1 r
.7567 .50788 m
.76184 .51445 L
s
1 0 0 r
.50788 .7567 m
.51445 .76184 L
s
0 0 1 r
.70678 .65258 m
.70048 .66731 L
s
1 0 0 r
.65258 .70678 m
.66731 .70048 L
s
0 0 1 r
.7561 .52166 m
.76028 .5313 L
s
1 0 0 r
.52166 .7561 m
.5313 .76028 L
s
0 0 1 r
.75668 .51406 m
.76138 .5222 L
s
1 0 0 r
.51406 .75668 m
.5222 .76138 L
s
0 0 1 r
.24962 .4228 m
.25813 .41141 L
s
1 0 0 r
.4228 .24962 m
.41141 .25813 L
s
0 0 1 r
.2655 .38344 m
.27614 .3723 L
s
1 0 0 r
.38344 .2655 m
.3723 .27614 L
s
0 0 1 r
.2375 .48563 m
.2431 .47818 L
s
1 0 0 r
.48563 .2375 m
.47818 .2431 L
s
0 0 1 r
.23705 .49193 m
.24246 .48579 L
s
1 0 0 r
.49193 .23705 m
.48579 .24246 L
s
0 0 1 r
.23801 .47784 m
.24381 .46919 L
s
1 0 0 r
.47784 .23801 m
.46919 .24381 L
s
0 0 1 r
.74675 .57608 m
.74649 .59028 L
s
1 0 0 r
.57608 .74675 m
.59028 .74649 L
s
0 0 1 r
.2366 .49662 m
.24184 .49189 L
s
1 0 0 r
.49662 .2366 m
.49189 .24184 L
s
0 0 1 r
.73137 .61501 m
.72792 .63002 L
s
1 0 0 r
.61501 .73137 m
.63002 .72792 L
s
0 0 1 r
.23866 .46874 m
.2447 .45899 L
s
1 0 0 r
.46874 .23866 m
.45899 .2447 L
s
0 0 1 r
.23613 .49958 m
.24119 .49636 L
s
1 0 0 r
.49958 .23613 m
.49636 .24119 L
s
0 0 1 r
.28841 .34387 m
.30096 .33389 L
s
1 0 0 r
.34387 .28841 m
.33389 .30096 L
s
0 0 1 r
.23956 .45847 m
.24587 .44774 L
s
1 0 0 r
.45847 .23956 m
.44774 .24587 L
s
0 0 1 r
.23562 .50073 m
.2405 .49908 L
s
1 0 0 r
.50073 .23562 m
.49908 .2405 L
s
0 0 1 r
.25249 .40946 m
.26137 .39753 L
s
1 0 0 r
.40946 .25249 m
.39753 .26137 L
s
0 0 1 r
.75174 .56418 m
.75221 .57754 L
s
1 0 0 r
.56418 .75174 m
.57754 .75221 L
s
0 0 1 r
.7179 .64178 m
.71209 .65647 L
s
1 0 0 r
.64178 .7179 m
.65647 .71209 L
s
0 0 1 r
.23511 .5 m
.23979 .5 L
s
1 0 0 r
.5 .23511 m
.5 .23979 L
s
0 0 1 r
.76021 .5 m
.76489 .5 L
s
1 0 0 r
.5 .76021 m
.5 .76489 L
s
0 0 1 r
.27068 .36931 m
.28169 .35796 L
s
1 0 0 r
.36931 .27068 m
.35796 .28169 L
s
0 0 1 r
.24085 .44721 m
.24746 .43562 L
s
1 0 0 r
.44721 .24085 m
.43562 .24746 L
s
0 0 1 r
.73955 .60286 m
.73677 .61747 L
s
1 0 0 r
.60286 .73955 m
.61747 .73677 L
s
0 0 1 r
.76089 .50092 m
.76533 .50261 L
s
1 0 0 r
.50092 .76089 m
.50261 .76533 L
s
0 0 1 r
.75559 .55256 m
.75676 .56489 L
s
1 0 0 r
.55256 .75559 m
.56489 .75676 L
s
0 0 1 r
.70048 .66731 m
.69251 .68126 L
s
1 0 0 r
.66731 .70048 m
.68126 .69251 L
s
0 0 1 r
.76146 .50368 m
.76562 .50707 L
s
1 0 0 r
.50368 .76146 m
.50707 .76562 L
s
0 0 1 r
.7584 .54151 m
.76022 .55264 L
s
1 0 0 r
.54151 .7584 m
.55264 .76022 L
s
0 0 1 r
.25625 .3958 m
.2655 .38344 L
s
1 0 0 r
.3958 .25625 m
.38344 .2655 L
s
0 0 1 r
.76182 .50822 m
.76564 .51331 L
s
1 0 0 r
.50822 .76182 m
.51331 .76564 L
s
0 0 1 r
.24266 .43515 m
.24962 .4228 L
s
1 0 0 r
.43515 .24266 m
.4228 .24962 L
s
0 0 1 r
.76028 .5313 m
.7627 .54109 L
s
1 0 0 r
.5313 .76028 m
.54109 .7627 L
s
0 0 1 r
.76184 .51445 m
.76526 .52118 L
s
1 0 0 r
.51445 .76184 m
.52118 .76526 L
s
0 0 1 r
.76138 .5222 m
.76433 .53052 L
s
1 0 0 r
.5222 .76138 m
.53052 .76433 L
s
0 0 1 r
.72792 .63002 m
.72268 .64456 L
s
1 0 0 r
.63002 .72792 m
.64456 .72268 L
s
0 0 1 r
.74649 .59028 m
.74441 .60431 L
s
1 0 0 r
.59028 .74649 m
.60431 .74441 L
s
0 0 1 r
.23362 .49349 m
.2375 .48563 L
s
1 0 0 r
.49349 .23362 m
.48563 .2375 L
s
0 0 1 r
.23391 .487 m
.23801 .47784 L
s
1 0 0 r
.487 .23391 m
.47784 .23801 L
s
0 0 1 r
.27705 .35532 m
.28841 .34387 L
s
1 0 0 r
.35532 .27705 m
.34387 .28841 L
s
0 0 1 r
.23337 .49839 m
.23705 .49193 L
s
1 0 0 r
.49839 .23337 m
.49193 .23705 L
s
0 0 1 r
.23433 .47909 m
.23866 .46874 L
s
1 0 0 r
.47909 .23433 m
.46874 .23866 L
s
0 0 1 r
.23311 .50158 m
.2366 .49662 L
s
1 0 0 r
.50158 .23311 m
.49662 .2366 L
s
0 0 1 r
.24517 .42246 m
.25249 .40946 L
s
1 0 0 r
.42246 .24517 m
.40946 .25249 L
s
0 0 1 r
.71209 .65647 m
.70453 .67047 L
s
1 0 0 r
.65647 .71209 m
.67047 .70453 L
s
0 0 1 r
.23496 .4699 m
.23956 .45847 L
s
1 0 0 r
.4699 .23496 m
.45847 .23956 L
s
0 0 1 r
.75221 .57754 m
.75082 .59079 L
s
1 0 0 r
.57754 .75221 m
.59079 .75082 L
s
0 0 1 r
.23281 .50295 m
.23613 .49958 L
s
1 0 0 r
.50295 .23281 m
.49958 .23613 L
s
0 0 1 r
.26103 .38198 m
.27068 .36931 L
s
1 0 0 r
.38198 .26103 m
.36931 .27068 L
s
0 0 1 r
.73677 .61747 m
.73213 .63168 L
s
1 0 0 r
.61747 .73677 m
.63168 .73213 L
s
0 0 1 r
.23251 .50244 m
.23562 .50073 L
s
1 0 0 r
.50244 .23251 m
.50073 .23562 L
s
0 0 1 r
.69251 .68126 m
.68286 .69429 L
s
1 0 0 r
.68126 .69251 m
.69429 .68286 L
s
0 0 1 r
.23593 .45962 m
.24085 .44721 L
s
1 0 0 r
.45962 .23593 m
.44721 .24085 L
s
0 0 1 r
.75676 .56489 m
.75605 .5772 L
s
1 0 0 r
.56489 .75676 m
.5772 .75605 L
s
0 0 1 r
.23222 .5 m
.23511 .5 L
s
1 0 0 r
.5 .23222 m
.5 .23511 L
s
0 0 1 r
.76489 .5 m
.76778 .5 L
s
1 0 0 r
.5 .76489 m
.5 .76778 L
s
0 0 1 r
.24852 .40933 m
.25625 .3958 L
s
1 0 0 r
.40933 .24852 m
.3958 .25625 L
s
0 0 1 r
.76533 .50261 m
.76796 .50435 L
s
1 0 0 r
.50261 .76533 m
.50435 .76796 L
s
0 0 1 r
.2374 .44842 m
.24266 .43515 L
s
1 0 0 r
.44842 .2374 m
.43515 .24266 L
s
0 0 1 r
.72268 .64456 m
.71559 .65848 L
s
1 0 0 r
.64456 .72268 m
.65848 .71559 L
s
0 0 1 r
.76022 .55264 m
.76015 .56382 L
s
1 0 0 r
.55264 .76022 m
.56382 .76015 L
s
0 0 1 r
.76562 .50707 m
.76795 .51056 L
s
1 0 0 r
.50707 .76562 m
.51056 .76795 L
s
0 0 1 r
.74441 .60431 m
.74041 .61804 L
s
1 0 0 r
.60431 .74441 m
.61804 .74041 L
s
0 0 1 r
.267 .3682 m
.27705 .35532 L
s
1 0 0 r
.3682 .267 m
.35532 .27705 L
s
0 0 1 r
.7627 .54109 m
.76323 .55096 L
s
1 0 0 r
.54109 .7627 m
.55096 .76323 L
s
0 0 1 r
.76564 .51331 m
.76761 .51851 L
s
1 0 0 r
.51331 .76564 m
.51851 .76761 L
s
0 0 1 r
.76433 .53052 m
.7654 .53894 L
s
1 0 0 r
.53052 .76433 m
.53894 .7654 L
s
0 0 1 r
.76526 .52118 m
.76681 .52804 L
s
1 0 0 r
.52118 .76526 m
.52804 .76681 L
s
0 0 1 r
.70453 .67047 m
.69519 .68363 L
s
1 0 0 r
.67047 .70453 m
.68363 .69519 L
s
0 0 1 r
.23952 .43648 m
.24517 .42246 L
s
1 0 0 r
.43648 .23952 m
.42246 .24517 L
s
0 0 1 r
.23168 .49663 m
.23391 .487 L
s
1 0 0 r
.49663 .23168 m
.487 .23391 L
s
0 0 1 r
.23161 .50172 m
.23362 .49349 L
s
1 0 0 r
.50172 .23161 m
.49349 .23362 L
s
0 0 1 r
.23184 .49 m
.23433 .47909 L
s
1 0 0 r
.49 .23184 m
.47909 .23433 L
s
0 0 1 r
.25288 .39595 m
.26103 .38198 L
s
1 0 0 r
.39595 .25288 m
.38198 .26103 L
s
0 0 1 r
.23156 .50513 m
.23337 .49839 L
s
1 0 0 r
.50513 .23156 m
.49839 .23337 L
s
0 0 1 r
.75082 .59079 m
.74747 .60384 L
s
1 0 0 r
.59079 .75082 m
.60384 .74747 L
s
0 0 1 r
.23219 .48199 m
.23496 .4699 L
s
1 0 0 r
.48199 .23219 m
.4699 .23496 L
s
0 0 1 r
.68286 .69429 m
.67153 .70626 L
s
1 0 0 r
.69429 .68286 m
.70626 .67153 L
s
0 0 1 r
.73213 .63168 m
.72558 .64538 L
s
1 0 0 r
.63168 .73213 m
.64538 .72558 L
s
0 0 1 r
.23149 .50674 m
.23311 .50158 L
s
1 0 0 r
.50674 .23149 m
.50158 .23311 L
s
0 0 1 r
.23285 .47278 m
.23593 .45962 L
s
1 0 0 r
.47278 .23285 m
.45962 .23593 L
s
0 0 1 r
.2314 .50645 m
.23281 .50295 L
s
1 0 0 r
.50645 .2314 m
.50295 .23281 L
s
0 0 1 r
.24245 .424 m
.24852 .40933 L
s
1 0 0 r
.424 .24245 m
.40933 .24852 L
s
0 0 1 r
.75605 .5772 m
.75335 .58938 L
s
1 0 0 r
.5772 .75605 m
.58938 .75335 L
s
0 0 1 r
.2313 .50421 m
.23251 .50244 L
s
1 0 0 r
.50421 .2313 m
.50244 .23251 L
s
0 0 1 r
.71559 .65848 m
.70663 .67164 L
s
1 0 0 r
.65848 .71559 m
.67164 .70663 L
s
0 0 1 r
.23396 .46254 m
.2374 .44842 L
s
1 0 0 r
.46254 .23396 m
.44842 .2374 L
s
0 0 1 r
.25843 .3825 m
.267 .3682 L
s
1 0 0 r
.3825 .25843 m
.3682 .267 L
s
0 0 1 r
.23126 .5 m
.23222 .5 L
s
1 0 0 r
.5 .23126 m
.5 .23222 L
s
0 0 1 r
.76778 .5 m
.76874 .5 L
s
1 0 0 r
.5 .76778 m
.5 .76874 L
s
0 0 1 r
.74041 .61804 m
.73443 .63134 L
s
1 0 0 r
.61804 .74041 m
.63134 .73443 L
s
0 0 1 r
.76015 .56382 m
.75808 .57494 L
s
1 0 0 r
.56382 .76015 m
.57494 .75808 L
s
0 0 1 r
.69519 .68363 m
.68405 .69579 L
s
1 0 0 r
.68363 .69519 m
.69579 .68405 L
s
0 0 1 r
.76796 .50435 m
.76865 .50614 L
s
1 0 0 r
.50435 .76796 m
.50614 .76865 L
s
0 0 1 r
.76323 .55096 m
.76175 .56084 L
s
1 0 0 r
.55096 .76323 m
.56084 .76175 L
s
0 0 1 r
.23568 .45146 m
.23952 .43648 L
s
1 0 0 r
.45146 .23568 m
.43648 .23952 L
s
0 0 1 r
.24637 .41116 m
.25288 .39595 L
s
1 0 0 r
.41116 .24637 m
.39595 .25288 L
s
0 0 1 r
.76795 .51056 m
.76832 .51412 L
s
1 0 0 r
.51056 .76795 m
.51412 .76832 L
s
0 0 1 r
.7654 .53894 m
.76447 .54742 L
s
1 0 0 r
.53894 .7654 m
.54742 .76447 L
s
0 0 1 r
.76761 .51851 m
.7676 .52379 L
s
1 0 0 r
.51851 .76761 m
.52379 .7676 L
s
0 0 1 r
.67153 .70626 m
.65853 .71701 L
s
1 0 0 r
.70626 .67153 m
.71701 .65853 L
s
0 0 1 r
.76681 .52804 m
.76637 .53498 L
s
1 0 0 r
.52804 .76681 m
.53498 .76637 L
s
0 0 1 r
.23142 .50667 m
.23168 .49663 L
s
1 0 0 r
.50667 .23142 m
.49663 .23168 L
s
0 0 1 r
.23133 .50141 m
.23184 .49 L
s
1 0 0 r
.50141 .23133 m
.49 .23184 L
s
0 0 1 r
.72558 .64538 m
.71707 .65841 L
s
1 0 0 r
.64538 .72558 m
.65841 .71707 L
s
0 0 1 r
.74747 .60384 m
.7421 .61656 L
s
1 0 0 r
.60384 .74747 m
.61656 .7421 L
s
0 0 1 r
.23158 .51028 m
.23161 .50172 L
s
1 0 0 r
.51028 .23158 m
.50172 .23161 L
s
0 0 1 r
.23139 .49467 m
.23219 .48199 L
s
1 0 0 r
.49467 .23139 m
.48199 .23219 L
s
0 0 1 r
.23175 .51212 m
.23156 .50513 L
s
1 0 0 r
.51212 .23175 m
.50513 .23156 L
s
0 0 1 r
.23818 .43973 m
.24245 .424 L
s
1 0 0 r
.43973 .23818 m
.424 .24245 L
s
0 0 1 r
.23172 .48662 m
.23285 .47278 L
s
1 0 0 r
.48662 .23172 m
.47278 .23285 L
s
0 0 1 r
.2319 .51207 m
.23149 .50674 L
s
1 0 0 r
.51207 .2319 m
.50674 .23149 L
s
0 0 1 r
.70663 .67164 m
.69577 .6839 L
s
1 0 0 r
.67164 .70663 m
.6839 .69577 L
s
0 0 1 r
.25146 .39814 m
.25843 .3825 L
s
1 0 0 r
.39814 .25146 m
.3825 .25843 L
s
0 0 1 r
.75335 .58938 m
.74858 .60132 L
s
1 0 0 r
.58938 .75335 m
.60132 .74858 L
s
0 0 1 r
.23247 .47744 m
.23396 .46254 L
s
1 0 0 r
.47744 .23247 m
.46254 .23396 L
s
0 0 1 r
.23202 .51005 m
.2314 .50645 L
s
1 0 0 r
.51005 .23202 m
.50645 .2314 L
s
0 0 1 r
.73443 .63134 m
.72642 .64407 L
s
1 0 0 r
.63134 .73443 m
.64407 .72642 L
s
0 0 1 r
.68405 .69579 m
.67114 .70681 L
s
1 0 0 r
.69579 .68405 m
.70681 .67114 L
s
0 0 1 r
.23215 .50602 m
.2313 .50421 L
s
1 0 0 r
.50602 .23215 m
.50421 .2313 L
s
0 0 1 r
.24164 .42753 m
.24637 .41116 L
s
1 0 0 r
.42753 .24164 m
.41116 .24637 L
s
0 0 1 r
.75808 .57494 m
.75391 .5859 L
s
1 0 0 r
.57494 .75808 m
.5859 .75391 L
s
0 0 1 r
.23378 .46731 m
.23568 .45146 L
s
1 0 0 r
.46731 .23378 m
.45146 .23568 L
s
0 0 1 r
.65853 .71701 m
.64389 .72639 L
s
1 0 0 r
.71701 .65853 m
.72639 .64389 L
s
0 0 1 r
.23237 .5 m
.23126 .5 L
s
1 0 0 r
.5 .23237 m
.5 .23126 L
s
0 0 1 r
.76874 .5 m
.76763 .5 L
s
1 0 0 r
.5 .76874 m
.5 .76763 L
s
0 0 1 r
.76175 .56084 m
.75815 .57064 L
s
1 0 0 r
.56084 .76175 m
.57064 .75815 L
s
0 0 1 r
.71707 .65841 m
.70657 .67063 L
s
1 0 0 r
.65841 .71707 m
.67063 .70657 L
s
0 0 1 r
.76865 .50614 m
.76725 .50795 L
s
1 0 0 r
.50614 .76865 m
.50795 .76725 L
s
0 0 1 r
.7421 .61656 m
.73462 .62882 L
s
1 0 0 r
.61656 .7421 m
.62882 .73462 L
s
0 0 1 r
.76832 .51412 m
.76658 .51772 L
s
1 0 0 r
.51412 .76832 m
.51772 .76658 L
s
0 0 1 r
.76447 .54742 m
.76141 .55588 L
s
1 0 0 r
.54742 .76447 m
.55588 .76141 L
s
0 0 1 r
.23291 .51326 m
.23133 .50141 L
s
1 0 0 r
.51326 .23291 m
.50141 .23133 L
s
0 0 1 r
.23583 .45643 m
.23818 .43973 L
s
1 0 0 r
.45643 .23583 m
.43973 .23818 L
s
0 0 1 r
.23267 .50787 m
.23139 .49467 L
s
1 0 0 r
.50787 .23267 m
.49467 .23139 L
s
0 0 1 r
.23328 .51706 m
.23142 .50667 L
s
1 0 0 r
.51706 .23328 m
.50667 .23142 L
s
0 0 1 r
.7676 .52379 m
.76548 .52912 L
s
1 0 0 r
.52379 .7676 m
.52912 .76548 L
s
0 0 1 r
.76637 .53498 m
.76381 .54193 L
s
1 0 0 r
.53498 .76637 m
.54193 .76381 L
s
0 0 1 r
.23368 .51912 m
.23158 .51028 L
s
1 0 0 r
.51912 .23368 m
.51028 .23158 L
s
0 0 1 r
.23267 .50107 m
.23172 .48662 L
s
1 0 0 r
.50107 .23267 m
.48662 .23172 L
s
0 0 1 r
.24623 .41506 m
.25146 .39814 L
s
1 0 0 r
.41506 .24623 m
.39814 .25146 L
s
0 0 1 r
.69577 .6839 m
.68304 .6951 L
s
1 0 0 r
.6839 .69577 m
.6951 .68304 L
s
0 0 1 r
.23408 .51931 m
.23175 .51212 L
s
1 0 0 r
.51931 .23408 m
.51212 .23175 L
s
0 0 1 r
.23304 .49303 m
.23247 .47744 L
s
1 0 0 r
.49303 .23304 m
.47744 .23247 L
s
0 0 1 r
.67114 .70681 m
.65648 .71654 L
s
1 0 0 r
.70681 .67114 m
.71654 .65648 L
s
0 0 1 r
.74858 .60132 m
.74167 .6129 L
s
1 0 0 r
.60132 .74858 m
.6129 .74167 L
s
0 0 1 r
.23445 .51753 m
.2319 .51207 L
s
1 0 0 r
.51753 .23445 m
.51207 .2319 L
s
0 0 1 r
.72642 .64407 m
.71634 .6561 L
s
1 0 0 r
.64407 .72642 m
.6561 .71634 L
s
0 0 1 r
.2388 .44498 m
.24164 .42753 L
s
1 0 0 r
.44498 .2388 m
.42753 .24164 L
s
0 0 1 r
.64389 .72639 m
.62768 .73427 L
s
1 0 0 r
.72639 .64389 m
.73427 .62768 L
s
0 0 1 r
.23393 .48394 m
.23378 .46731 L
s
1 0 0 r
.48394 .23393 m
.46731 .23378 L
s
0 0 1 r
.23481 .51372 m
.23202 .51005 L
s
1 0 0 r
.51372 .23481 m
.51005 .23202 L
s
0 0 1 r
.75391 .5859 m
.74756 .59661 L
s
1 0 0 r
.5859 .75391 m
.59661 .74756 L
s
0 0 1 r
.70657 .67063 m
.69409 .68189 L
s
1 0 0 r
.67063 .70657 m
.68189 .69409 L
s
0 0 1 r
.23519 .50787 m
.23215 .50602 L
s
1 0 0 r
.50787 .23519 m
.50602 .23215 L
s
0 0 1 r
.23551 .474 m
.23583 .45643 L
s
1 0 0 r
.474 .23551 m
.45643 .23583 L
s
0 0 1 r
.73462 .62882 m
.72501 .64048 L
s
1 0 0 r
.62882 .73462 m
.64048 .72501 L
s
0 0 1 r
.75815 .57064 m
.75235 .58027 L
s
1 0 0 r
.57064 .75815 m
.58027 .75235 L
s
0 0 1 r
.23567 .5 m
.23237 .5 L
s
1 0 0 r
.5 .23567 m
.5 .23237 L
s
0 0 1 r
.76763 .5 m
.76433 .5 L
s
1 0 0 r
.5 .76763 m
.5 .76433 L
s
0 0 1 r
.24287 .43316 m
.24623 .41506 L
s
1 0 0 r
.43316 .24287 m
.41506 .24623 L
s
0 0 1 r
.68304 .6951 m
.66844 .70509 L
s
1 0 0 r
.6951 .68304 m
.70509 .66844 L
s
0 0 1 r
.23615 .5215 m
.23267 .50787 L
s
1 0 0 r
.5215 .23615 m
.50787 .23267 L
s
0 0 1 r
.2367 .52546 m
.23291 .51326 L
s
1 0 0 r
.52546 .2367 m
.51326 .23291 L
s
0 0 1 r
.76725 .50795 m
.76364 .50979 L
s
1 0 0 r
.50795 .76725 m
.50979 .76364 L
s
0 0 1 r
.2358 .51602 m
.23267 .50107 L
s
1 0 0 r
.51602 .2358 m
.50107 .23267 L
s
0 0 1 r
.76141 .55588 m
.75613 .56423 L
s
1 0 0 r
.55588 .76141 m
.56423 .75613 L
s
0 0 1 r
.23735 .52773 m
.23328 .51706 L
s
1 0 0 r
.52773 .23735 m
.51706 .23328 L
s
0 0 1 r
.76658 .51772 m
.76262 .52134 L
s
1 0 0 r
.51772 .76658 m
.52134 .76262 L
s
0 0 1 r
.65648 .71654 m
.64013 .72482 L
s
1 0 0 r
.71654 .65648 m
.72482 .64013 L
s
0 0 1 r
.76381 .54193 m
.75901 .54885 L
s
1 0 0 r
.54193 .76381 m
.54885 .75901 L
s
0 0 1 r
.76548 .52912 m
.76112 .53445 L
s
1 0 0 r
.52912 .76548 m
.53445 .76112 L
s
0 0 1 r
.23577 .5092 m
.23304 .49303 L
s
1 0 0 r
.5092 .23577 m
.49303 .23304 L
s
0 0 1 r
.23802 .52817 m
.23368 .51912 L
s
1 0 0 r
.52817 .23802 m
.51912 .23368 L
s
0 0 1 r
.23797 .46339 m
.2388 .44498 L
s
1 0 0 r
.46339 .23797 m
.44498 .2388 L
s
0 0 1 r
.62768 .73427 m
.60997 .74049 L
s
1 0 0 r
.73427 .62768 m
.74049 .60997 L
s
0 0 1 r
.71634 .6561 m
.70419 .66728 L
s
1 0 0 r
.6561 .71634 m
.66728 .70419 L
s
0 0 1 r
.74167 .6129 m
.73255 .624 L
s
1 0 0 r
.6129 .74167 m
.624 .73255 L
s
0 0 1 r
.23866 .52665 m
.23408 .51931 L
s
1 0 0 r
.52665 .23866 m
.51931 .23408 L
s
0 0 1 r
.23622 .50123 m
.23393 .48394 L
s
1 0 0 r
.50123 .23622 m
.48394 .23393 L
s
0 0 1 r
.23927 .52309 m
.23445 .51753 L
s
1 0 0 r
.52309 .23927 m
.51753 .23445 L
s
0 0 1 r
.69409 .68189 m
.67965 .69204 L
s
1 0 0 r
.68189 .69409 m
.69204 .67965 L
s
0 0 1 r
.23732 .4923 m
.23551 .474 L
s
1 0 0 r
.4923 .23732 m
.474 .23551 L
s
0 0 1 r
.74756 .59661 m
.73895 .60693 L
s
1 0 0 r
.59661 .74756 m
.60693 .73895 L
s
0 0 1 r
.2415 .4523 m
.24287 .43316 L
s
1 0 0 r
.4523 .2415 m
.43316 .24287 L
s
0 0 1 r
.23987 .51745 m
.23481 .51372 L
s
1 0 0 r
.51745 .23987 m
.51372 .23481 L
s
0 0 1 r
.66844 .70509 m
.65205 .71371 L
s
1 0 0 r
.70509 .66844 m
.71371 .65205 L
s
0 0 1 r
.72501 .64048 m
.71324 .6514 L
s
1 0 0 r
.64048 .72501 m
.6514 .71324 L
s
0 0 1 r
.24052 .50973 m
.23519 .50787 L
s
1 0 0 r
.50973 .24052 m
.50787 .23519 L
s
0 0 1 r
.64013 .72482 m
.62217 .73151 L
s
1 0 0 r
.72482 .64013 m
.73151 .62217 L
s
0 0 1 r
.75235 .58027 m
.74425 .58962 L
s
1 0 0 r
.58027 .75235 m
.58962 .74425 L
s
0 0 1 r
.2419 .53543 m
.23615 .5215 L
s
1 0 0 r
.53543 .2419 m
.5215 .23615 L
s
0 0 1 r
.24118 .53134 m
.2358 .51602 L
s
1 0 0 r
.53134 .24118 m
.51602 .2358 L
s
0 0 1 r
.23925 .48262 m
.23797 .46339 L
s
1 0 0 r
.48262 .23925 m
.46339 .23797 L
s
0 0 1 r
.24278 .5379 m
.2367 .52546 L
s
1 0 0 r
.5379 .24278 m
.52546 .2367 L
s
0 0 1 r
.60997 .74049 m
.59087 .74493 L
s
1 0 0 r
.74049 .60997 m
.74493 .59087 L
s
0 0 1 r
.24075 .52581 m
.23577 .5092 L
s
1 0 0 r
.52581 .24075 m
.5092 .23577 L
s
0 0 1 r
.24129 .5 m
.23567 .5 L
s
1 0 0 r
.5 .24129 m
.5 .23567 L
s
0 0 1 r
.76433 .5 m
.75871 .5 L
s
1 0 0 r
.5 .76433 m
.5 .75871 L
s
0 0 1 r
.24373 .53859 m
.23735 .52773 L
s
1 0 0 r
.53859 .24373 m
.52773 .23735 L
s
0 0 1 r
.75613 .56423 m
.74853 .5724 L
s
1 0 0 r
.56423 .75613 m
.5724 .74853 L
s
0 0 1 r
.70419 .66728 m
.68997 .67745 L
s
1 0 0 r
.66728 .70419 m
.67745 .68997 L
s
0 0 1 r
.76364 .50979 m
.7577 .51162 L
s
1 0 0 r
.50979 .76364 m
.51162 .7577 L
s
0 0 1 r
.24074 .51903 m
.23622 .50123 L
s
1 0 0 r
.51903 .24074 m
.50123 .23622 L
s
0 0 1 r
.75901 .54885 m
.75188 .55564 L
s
1 0 0 r
.54885 .75901 m
.55564 .75188 L
s
0 0 1 r
.73255 .624 m
.7212 .63447 L
s
1 0 0 r
.624 .73255 m
.63447 .7212 L
s
0 0 1 r
.24468 .53735 m
.23802 .52817 L
s
1 0 0 r
.53735 .24468 m
.52817 .23802 L
s
0 0 1 r
.76262 .52134 m
.75632 .52494 L
s
1 0 0 r
.52134 .76262 m
.52494 .75632 L
s
0 0 1 r
.76112 .53445 m
.75443 .53971 L
s
1 0 0 r
.53445 .76112 m
.53971 .75443 L
s
0 0 1 r
.67965 .69204 m
.6633 .70092 L
s
1 0 0 r
.69204 .67965 m
.70092 .6633 L
s
0 0 1 r
.24221 .47236 m
.2415 .4523 L
s
1 0 0 r
.47236 .24221 m
.4523 .2415 L
s
0 0 1 r
.24134 .5112 m
.23732 .4923 L
s
1 0 0 r
.5112 .24134 m
.4923 .23732 L
s
0 0 1 r
.24559 .53407 m
.23866 .52665 L
s
1 0 0 r
.53407 .24559 m
.52665 .23866 L
s
0 0 1 r
.65205 .71371 m
.63394 .72083 L
s
1 0 0 r
.71371 .65205 m
.72083 .63394 L
s
0 0 1 r
.73895 .60693 m
.72805 .61676 L
s
1 0 0 r
.60693 .73895 m
.61676 .72805 L
s
0 0 1 r
.62217 .73151 m
.60272 .73648 L
s
1 0 0 r
.73151 .62217 m
.73648 .60272 L
s
0 0 1 r
.24646 .5287 m
.23927 .52309 L
s
1 0 0 r
.5287 .24646 m
.52309 .23927 L
s
0 0 1 r
.71324 .6514 m
.69932 .66143 L
s
1 0 0 r
.6514 .71324 m
.66143 .69932 L
s
0 0 1 r
.24271 .50251 m
.23925 .48262 L
s
1 0 0 r
.50251 .24271 m
.48262 .23925 L
s
0 0 1 r
.59087 .74493 m
.57052 .74747 L
s
1 0 0 r
.74493 .59087 m
.74747 .57052 L
s
0 0 1 r
.24733 .52119 m
.23987 .51745 L
s
1 0 0 r
.52119 .24733 m
.51745 .23987 L
s
0 0 1 r
.24889 .54691 m
.24118 .53134 L
s
1 0 0 r
.54691 .24889 m
.53134 .24118 L
s
0 0 1 r
.24802 .54273 m
.24075 .52581 L
s
1 0 0 r
.54273 .24802 m
.52581 .24075 L
s
0 0 1 r
.25 .54956 m
.2419 .53543 L
s
1 0 0 r
.54956 .25 m
.53543 .2419 L
s
0 0 1 r
.74425 .58962 m
.73382 .59857 L
s
1 0 0 r
.58962 .74425 m
.59857 .73382 L
s
0 0 1 r
.25123 .55048 m
.24278 .5379 L
s
1 0 0 r
.55048 .25123 m
.5379 .24278 L
s
0 0 1 r
.68997 .67745 m
.67375 .68646 L
s
1 0 0 r
.67745 .68997 m
.68646 .67375 L
s
0 0 1 r
.24754 .5372 m
.24074 .51903 L
s
1 0 0 r
.5372 .24754 m
.51903 .24074 L
s
0 0 1 r
.24825 .51159 m
.24052 .50973 L
s
1 0 0 r
.51159 .24825 m
.50973 .24052 L
s
0 0 1 r
.24507 .49316 m
.24221 .47236 L
s
1 0 0 r
.49316 .24507 m
.47236 .24221 L
s
0 0 1 r
.25249 .54953 m
.24373 .53859 L
s
1 0 0 r
.54953 .25249 m
.53859 .24373 L
s
0 0 1 r
.6633 .70092 m
.64512 .70838 L
s
1 0 0 r
.70092 .6633 m
.70838 .64512 L
s
0 0 1 r
.24761 .53052 m
.24134 .5112 L
s
1 0 0 r
.53052 .24761 m
.5112 .24134 L
s
0 0 1 r
.7212 .63447 m
.70762 .64418 L
s
1 0 0 r
.63447 .7212 m
.64418 .70762 L
s
0 0 1 r
.74853 .5724 m
.73855 .58028 L
s
1 0 0 r
.5724 .74853 m
.58028 .73855 L
s
0 0 1 r
.24932 .5 m
.24129 .5 L
s
1 0 0 r
.5 .24932 m
.5 .24129 L
s
0 0 1 r
.75871 .5 m
.75068 .5 L
s
1 0 0 r
.5 .75871 m
.5 .75068 L
s
0 0 1 r
.63394 .72083 m
.61422 .7263 L
s
1 0 0 r
.72083 .63394 m
.7263 .61422 L
s
0 0 1 r
.25374 .54657 m
.24468 .53735 L
s
1 0 0 r
.54657 .25374 m
.53735 .24468 L
s
0 0 1 r
.7577 .51162 m
.74934 .51343 L
s
1 0 0 r
.51162 .7577 m
.51343 .74934 L
s
0 0 1 r
.75188 .55564 m
.74235 .56225 L
s
1 0 0 r
.55564 .75188 m
.56225 .74235 L
s
0 0 1 r
.60272 .73648 m
.58191 .73961 L
s
1 0 0 r
.73648 .60272 m
.73961 .58191 L
s
0 0 1 r
.75632 .52494 m
.7476 .52848 L
s
1 0 0 r
.52494 .75632 m
.52848 .7476 L
s
0 0 1 r
.75443 .53971 m
.74532 .54486 L
s
1 0 0 r
.53971 .75443 m
.54486 .74532 L
s
0 0 1 r
.57052 .74747 m
.54909 .74801 L
s
1 0 0 r
.74747 .57052 m
.74801 .54909 L
s
0 0 1 r
.24841 .52289 m
.24271 .50251 L
s
1 0 0 r
.52289 .24841 m
.50251 .24271 L
s
0 0 1 r
.25493 .54151 m
.24559 .53407 L
s
1 0 0 r
.54151 .25493 m
.53407 .24559 L
s
0 0 1 r
.69932 .66143 m
.68328 .67043 L
s
1 0 0 r
.66143 .69932 m
.67043 .68328 L
s
0 0 1 r
.72805 .61676 m
.71485 .62595 L
s
1 0 0 r
.61676 .72805 m
.62595 .71485 L
s
0 0 1 r
.25763 .55979 m
.24802 .54273 L
s
1 0 0 r
.55979 .25763 m
.54273 .24802 L
s
0 0 1 r
.25895 .56258 m
.24889 .54691 L
s
1 0 0 r
.56258 .25895 m
.54691 .24889 L
s
0 0 1 r
.25665 .55556 m
.24754 .5372 L
s
1 0 0 r
.55556 .25665 m
.5372 .24754 L
s
0 0 1 r
.25608 .53429 m
.24646 .5287 L
s
1 0 0 r
.53429 .25608 m
.5287 .24646 L
s
0 0 1 r
.25014 .51451 m
.24507 .49316 L
s
1 0 0 r
.51451 .25014 m
.49316 .24507 L
s
0 0 1 r
.26046 .56374 m
.25 .54956 L
s
1 0 0 r
.56374 .26046 m
.54956 .25 L
s
0 0 1 r
.67375 .68646 m
.65558 .69417 L
s
1 0 0 r
.68646 .67375 m
.69417 .65558 L
s
0 0 1 r
.25617 .55008 m
.24761 .53052 L
s
1 0 0 r
.55008 .25617 m
.53052 .24761 L
s
0 0 1 r
.64512 .70838 m
.62522 .71429 L
s
1 0 0 r
.70838 .64512 m
.71429 .62522 L
s
0 0 1 r
.26207 .56308 m
.25123 .55048 L
s
1 0 0 r
.56308 .26207 m
.55048 .25123 L
s
0 0 1 r
.73382 .59857 m
.72102 .60703 L
s
1 0 0 r
.59857 .73382 m
.60703 .72102 L
s
0 0 1 r
.25723 .52491 m
.24733 .52119 L
s
1 0 0 r
.52491 .25723 m
.52119 .24733 L
s
0 0 1 r
.61422 .7263 m
.59304 .73 L
s
1 0 0 r
.7263 .61422 m
.73 .59304 L
s
0 0 1 r
.58191 .73961 m
.55991 .7408 L
s
1 0 0 r
.73961 .58191 m
.7408 .55991 L
s
0 0 1 r
.54909 .74801 m
.52675 .74647 L
s
1 0 0 r
.74801 .54909 m
.74647 .52675 L
s
0 0 1 r
.70762 .64418 m
.69184 .65299 L
s
1 0 0 r
.64418 .70762 m
.65299 .69184 L
s
0 0 1 r
.25636 .54356 m
.24841 .52289 L
s
1 0 0 r
.54356 .25636 m
.52289 .24841 L
s
0 0 1 r
.26368 .56046 m
.25249 .54953 L
s
1 0 0 r
.56046 .26368 m
.54953 .25249 L
s
0 0 1 r
.25845 .51344 m
.24825 .51159 L
s
1 0 0 r
.51344 .25845 m
.51159 .24825 L
s
0 0 1 r
.73855 .58028 m
.72617 .58778 L
s
1 0 0 r
.58028 .73855 m
.58778 .72617 L
s
0 0 1 r
.25983 .5 m
.24932 .5 L
s
1 0 0 r
.5 .25983 m
.5 .24932 L
s
0 0 1 r
.75068 .5 m
.74017 .5 L
s
1 0 0 r
.5 .75068 m
.5 .74017 L
s
0 0 1 r
.26524 .55575 m
.25374 .54657 L
s
1 0 0 r
.55575 .26524 m
.54657 .25374 L
s
0 0 1 r
.25743 .5362 m
.25014 .51451 L
s
1 0 0 r
.5362 .25743 m
.51451 .25014 L
s
0 0 1 r
.68328 .67043 m
.66521 .67825 L
s
1 0 0 r
.67043 .68328 m
.67825 .66521 L
s
0 0 1 r
.74235 .56225 m
.73038 .56858 L
s
1 0 0 r
.56225 .74235 m
.56858 .73038 L
s
0 0 1 r
.74934 .51343 m
.7385 .51521 L
s
1 0 0 r
.51343 .74934 m
.51521 .7385 L
s
0 0 1 r
.26957 .57681 m
.25763 .55979 L
s
1 0 0 r
.57681 .26957 m
.55979 .25763 L
s
0 0 1 r
.26806 .57391 m
.25665 .55556 L
s
1 0 0 r
.57391 .26806 m
.55556 .25665 L
s
0 0 1 r
.74532 .54486 m
.73375 .54983 L
s
1 0 0 r
.54486 .74532 m
.54983 .73375 L
s
0 0 1 r
.7476 .52848 m
.73641 .53192 L
s
1 0 0 r
.52848 .7476 m
.53192 .73641 L
s
0 0 1 r
.71485 .62595 m
.69937 .63437 L
s
1 0 0 r
.62595 .71485 m
.63437 .69937 L
s
0 0 1 r
.27136 .57818 m
.25895 .56258 L
s
1 0 0 r
.57818 .27136 m
.56258 .25895 L
s
0 0 1 r
.267 .56967 m
.25617 .55008 L
s
1 0 0 r
.56967 .267 m
.55008 .25617 L
s
0 0 1 r
.65558 .69417 m
.63559 .70043 L
s
1 0 0 r
.69417 .65558 m
.70043 .63559 L
s
0 0 1 r
.26674 .54888 m
.25493 .54151 L
s
1 0 0 r
.54888 .26674 m
.54151 .25493 L
s
0 0 1 r
.62522 .71429 m
.60376 .71852 L
s
1 0 0 r
.71429 .62522 m
.71852 .60376 L
s
0 0 1 r
.55991 .7408 m
.53693 .73996 L
s
1 0 0 r
.7408 .55991 m
.73996 .53693 L
s
0 0 1 r
.59304 .73 m
.57058 .73183 L
s
1 0 0 r
.73 .59304 m
.73183 .57058 L
s
0 0 1 r
.52675 .74647 m
.50372 .7428 L
s
1 0 0 r
.74647 .52675 m
.7428 .50372 L
s
0 0 1 r
.27331 .57781 m
.26046 .56374 L
s
1 0 0 r
.57781 .27331 m
.56374 .26046 L
s
0 0 1 r
.26656 .5643 m
.25636 .54356 L
s
1 0 0 r
.5643 .26656 m
.54356 .25636 L
s
0 0 1 r
.26819 .5398 m
.25608 .53429 L
s
1 0 0 r
.5398 .26819 m
.53429 .25608 L
s
0 0 1 r
.27531 .57555 m
.26207 .56308 L
s
1 0 0 r
.57555 .27531 m
.56308 .26207 L
s
0 0 1 r
.72102 .60703 m
.70588 .61485 L
s
1 0 0 r
.60703 .72102 m
.61485 .70588 L
s
0 0 1 r
.69184 .65299 m
.67393 .66076 L
s
1 0 0 r
.65299 .69184 m
.66076 .67393 L
s
0 0 1 r
.26694 .558 m
.25743 .5362 L
s
1 0 0 r
.558 .26694 m
.5362 .25743 L
s
0 0 1 r
.26963 .52856 m
.25723 .52491 L
s
1 0 0 r
.52856 .26963 m
.52491 .25723 L
s
0 0 1 r
.27729 .57124 m
.26368 .56046 L
s
1 0 0 r
.57124 .27729 m
.56046 .26368 L
s
0 0 1 r
.28173 .59205 m
.26806 .57391 L
s
1 0 0 r
.59205 .28173 m
.57391 .26806 L
s
0 0 1 r
.28006 .58907 m
.267 .56967 L
s
1 0 0 r
.58907 .28006 m
.56967 .267 L
s
0 0 1 r
.66521 .67825 m
.64521 .68475 L
s
1 0 0 r
.67825 .66521 m
.68475 .64521 L
s
0 0 1 r
.28379 .5936 m
.26957 .57681 L
s
1 0 0 r
.5936 .28379 m
.57681 .26957 L
s
0 0 1 r
.50372 .7428 m
.48024 .73698 L
s
1 0 0 r
.7428 .50372 m
.73698 .48024 L
s
0 0 1 r
.53693 .73996 m
.51319 .73705 L
s
1 0 0 r
.73996 .53693 m
.73705 .51319 L
s
0 0 1 r
.72617 .58778 m
.71138 .59478 L
s
1 0 0 r
.58778 .72617 m
.59478 .71138 L
s
0 0 1 r
.57058 .73183 m
.54705 .7317 L
s
1 0 0 r
.73183 .57058 m
.7317 .54705 L
s
0 0 1 r
.27896 .58488 m
.26656 .5643 L
s
1 0 0 r
.58488 .27896 m
.5643 .26656 L
s
0 0 1 r
.63559 .70043 m
.61394 .70512 L
s
1 0 0 r
.70043 .63559 m
.70512 .61394 L
s
0 0 1 r
.27115 .51524 m
.25845 .51344 L
s
1 0 0 r
.51524 .27115 m
.51344 .25845 L
s
0 0 1 r
.60376 .71852 m
.58092 .72097 L
s
1 0 0 r
.71852 .60376 m
.72097 .58092 L
s
0 0 1 r
.28609 .59352 m
.27136 .57818 L
s
1 0 0 r
.59352 .28609 m
.57818 .27136 L
s
0 0 1 r
.27919 .56477 m
.26524 .55575 L
s
1 0 0 r
.56477 .27919 m
.55575 .26524 L
s
0 0 1 r
.69937 .63437 m
.68168 .64189 L
s
1 0 0 r
.63437 .69937 m
.64189 .68168 L
s
0 0 1 r
.73038 .56858 m
.71596 .57455 L
s
1 0 0 r
.56858 .73038 m
.57455 .71596 L
s
0 0 1 r
.27285 .5 m
.25983 .5 L
s
1 0 0 r
.5 .27285 m
.5 .25983 L
s
0 0 1 r
.74017 .5 m
.72715 .5 L
s
1 0 0 r
.5 .74017 m
.5 .72715 L
s
0 0 1 r
.27862 .57967 m
.26694 .558 L
s
1 0 0 r
.57967 .27862 m
.558 .26694 L
s
0 0 1 r
.2885 .59162 m
.27331 .57781 L
s
1 0 0 r
.59162 .2885 m
.57781 .27331 L
s
0 0 1 r
.73375 .54983 m
.71969 .55456 L
s
1 0 0 r
.54983 .73375 m
.55456 .71969 L
s
0 0 1 r
.7385 .51521 m
.72515 .51692 L
s
1 0 0 r
.51521 .7385 m
.51692 .72515 L
s
0 0 1 r
.73641 .53192 m
.72271 .53522 L
s
1 0 0 r
.53192 .73641 m
.53522 .72271 L
s
0 0 1 r
.28102 .55609 m
.26674 .54888 L
s
1 0 0 r
.55609 .28102 m
.54888 .26674 L
s
0 0 1 r
.48024 .73698 m
.45657 .72902 L
s
1 0 0 r
.73698 .48024 m
.72902 .45657 L
s
0 0 1 r
.51319 .73705 m
.48894 .73204 L
s
1 0 0 r
.73705 .51319 m
.73204 .48894 L
s
0 0 1 r
.29527 .60807 m
.28006 .58907 L
s
1 0 0 r
.60807 .29527 m
.58907 .28006 L
s
0 0 1 r
.29092 .58774 m
.27531 .57555 L
s
1 0 0 r
.58774 .29092 m
.57555 .27531 L
s
0 0 1 r
.29757 .60977 m
.28173 .59205 L
s
1 0 0 r
.60977 .29757 m
.59205 .28173 L
s
0 0 1 r
.67393 .66076 m
.65399 .66734 L
s
1 0 0 r
.66076 .67393 m
.66734 .65399 L
s
0 0 1 r
.29348 .60506 m
.27896 .58488 L
s
1 0 0 r
.60506 .29348 m
.58488 .27896 L
s
0 0 1 r
.54705 .7317 m
.52267 .72957 L
s
1 0 0 r
.7317 .54705 m
.72957 .52267 L
s
0 0 1 r
.70588 .61485 m
.68844 .62192 L
s
1 0 0 r
.61485 .70588 m
.62192 .68844 L
s
0 0 1 r
.30021 .60996 m
.28379 .5936 L
s
1 0 0 r
.60996 .30021 m
.5936 .28379 L
s
0 0 1 r
.58092 .72097 m
.55692 .72154 L
s
1 0 0 r
.72097 .58092 m
.72154 .55692 L
s
0 0 1 r
.29238 .60095 m
.27862 .57967 L
s
1 0 0 r
.60095 .29238 m
.57967 .27862 L
s
0 0 1 r
.28278 .54517 m
.26819 .5398 L
s
1 0 0 r
.54517 .28278 m
.5398 .26819 L
s
0 0 1 r
.64521 .68475 m
.62344 .6898 L
s
1 0 0 r
.68475 .64521 m
.6898 .62344 L
s
0 0 1 r
.61394 .70512 m
.5908 .70813 L
s
1 0 0 r
.70512 .61394 m
.70813 .5908 L
s
0 0 1 r
.29329 .58174 m
.27729 .57124 L
s
1 0 0 r
.58174 .29329 m
.57124 .27729 L
s
0 0 1 r
.30305 .60843 m
.28609 .59352 L
s
1 0 0 r
.60843 .30305 m
.59352 .28609 L
s
0 0 1 r
.45657 .72902 m
.43297 .71897 L
s
1 0 0 r
.72902 .45657 m
.71897 .43297 L
s
0 0 1 r
.48894 .73204 m
.46445 .72493 L
s
1 0 0 r
.73204 .48894 m
.72493 .46445 L
s
0 0 1 r
.28453 .53209 m
.26963 .52856 L
s
1 0 0 r
.53209 .28453 m
.52856 .26963 L
s
0 0 1 r
.30999 .6246 m
.29348 .60506 L
s
1 0 0 r
.6246 .30999 m
.60506 .29348 L
s
0 0 1 r
.71138 .59478 m
.69424 .60119 L
s
1 0 0 r
.59478 .71138 m
.60119 .69424 L
s
0 0 1 r
.31251 .62642 m
.29527 .60807 L
s
1 0 0 r
.62642 .31251 m
.60807 .29527 L
s
0 0 1 r
.30811 .6216 m
.29238 .60095 L
s
1 0 0 r
.6216 .30811 m
.60095 .29238 L
s
0 0 1 r
.52267 .72957 m
.49773 .72539 L
s
1 0 0 r
.72957 .52267 m
.72539 .49773 L
s
0 0 1 r
.68168 .64189 m
.66186 .64839 L
s
1 0 0 r
.64189 .68168 m
.64839 .66186 L
s
0 0 1 r
.30594 .605 m
.2885 .59162 L
s
1 0 0 r
.605 .30594 m
.59162 .2885 L
s
0 0 1 r
.31548 .62685 m
.29757 .60977 L
s
1 0 0 r
.62685 .31548 m
.60977 .29757 L
s
0 0 1 r
.29556 .57352 m
.27919 .56477 L
s
1 0 0 r
.57352 .29556 m
.56477 .27919 L
s
0 0 1 r
.28636 .51697 m
.27115 .51524 L
s
1 0 0 r
.51697 .28636 m
.51524 .27115 L
s
0 0 1 r
.43297 .71897 m
.40971 .70691 L
s
1 0 0 r
.71897 .43297 m
.70691 .40971 L
s
0 0 1 r
.55692 .72154 m
.532 .72018 L
s
1 0 0 r
.72154 .55692 m
.72018 .532 L
s
0 0 1 r
.71596 .57455 m
.69913 .58007 L
s
1 0 0 r
.57455 .71596 m
.58007 .69913 L
s
0 0 1 r
.31873 .62568 m
.30021 .60996 L
s
1 0 0 r
.62568 .31873 m
.60996 .30021 L
s
0 0 1 r
.46445 .72493 m
.44 .71578 L
s
1 0 0 r
.72493 .46445 m
.71578 .44 L
s
0 0 1 r
.65399 .66734 m
.63218 .67262 L
s
1 0 0 r
.66734 .65399 m
.67262 .63218 L
s
0 0 1 r
.32834 .64326 m
.30999 .6246 L
s
1 0 0 r
.64326 .32834 m
.6246 .30999 L
s
0 0 1 r
.32564 .64136 m
.30811 .6216 L
s
1 0 0 r
.64136 .32564 m
.6216 .30811 L
s
0 0 1 r
.28837 .5 m
.27285 .5 L
s
1 0 0 r
.5 .28837 m
.5 .27285 L
s
0 0 1 r
.72715 .5 m
.71163 .5 L
s
1 0 0 r
.5 .72715 m
.5 .71163 L
s
0 0 1 r
.5908 .70813 m
.56641 .70937 L
s
1 0 0 r
.70813 .5908 m
.70937 .56641 L
s
0 0 1 r
.30882 .5995 m
.29092 .58774 L
s
1 0 0 r
.5995 .30882 m
.58774 .29092 L
s
0 0 1 r
.62344 .6898 m
.6001 .69329 L
s
1 0 0 r
.6898 .62344 m
.69329 .6001 L
s
0 0 1 r
.71969 .55456 m
.70319 .55897 L
s
1 0 0 r
.55456 .71969 m
.55897 .70319 L
s
0 0 1 r
.33161 .6439 m
.31251 .62642 L
s
1 0 0 r
.6439 .33161 m
.62642 .31251 L
s
0 0 1 r
.29772 .56304 m
.28102 .55609 L
s
1 0 0 r
.56304 .29772 m
.55609 .28102 L
s
0 0 1 r
.72515 .51692 m
.70931 .51854 L
s
1 0 0 r
.51692 .72515 m
.51854 .70931 L
s
0 0 1 r
.40971 .70691 m
.38709 .69295 L
s
1 0 0 r
.70691 .40971 m
.69295 .38709 L
s
0 0 1 r
.72271 .53522 m
.70654 .53833 L
s
1 0 0 r
.53522 .72271 m
.53833 .70654 L
s
0 0 1 r
.49773 .72539 m
.47249 .71919 L
s
1 0 0 r
.72539 .49773 m
.71919 .47249 L
s
0 0 1 r
.32212 .62271 m
.30305 .60843 L
s
1 0 0 r
.62271 .32212 m
.60843 .30305 L
s
0 0 1 r
.3448 .65998 m
.32564 .64136 L
s
1 0 0 r
.65998 .3448 m
.64136 .32564 L
s
0 0 1 r
.68844 .62192 m
.66881 .62813 L
s
1 0 0 r
.62192 .68844 m
.62813 .66881 L
s
0 0 1 r
.44 .71578 m
.41587 .70467 L
s
1 0 0 r
.71578 .44 m
.70467 .41587 L
s
0 0 1 r
.33527 .64308 m
.31548 .62685 L
s
1 0 0 r
.64308 .33527 m
.62685 .31548 L
s
0 0 1 r
.34834 .66081 m
.32834 .64326 L
s
1 0 0 r
.66081 .34834 m
.64326 .32834 L
s
0 0 1 r
.38709 .69295 m
.36536 .67725 L
s
1 0 0 r
.69295 .38709 m
.67725 .36536 L
s
0 0 1 r
.36536 .67725 m
.3448 .65998 L
s
1 0 0 r
.67725 .36536 m
.65998 .3448 L
s
0 0 1 r
.532 .72018 m
.50644 .71687 L
s
1 0 0 r
.72018 .532 m
.71687 .50644 L
s
0 0 1 r
.3116 .59182 m
.29329 .58174 L
s
1 0 0 r
.59182 .3116 m
.58174 .29329 L
s
0 0 1 r
.29981 .55033 m
.28278 .54517 L
s
1 0 0 r
.55033 .29981 m
.54517 .28278 L
s
0 0 1 r
.35239 .66029 m
.33161 .6439 L
s
1 0 0 r
.66029 .35239 m
.6439 .33161 L
s
0 0 1 r
.41587 .70467 m
.39237 .6917 L
s
1 0 0 r
.70467 .41587 m
.6917 .39237 L
s
0 0 1 r
.36977 .67702 m
.34834 .66081 L
s
1 0 0 r
.67702 .36977 m
.66081 .34834 L
s
0 0 1 r
.47249 .71919 m
.44726 .71099 L
s
1 0 0 r
.71919 .47249 m
.71099 .44726 L
s
0 0 1 r
.32553 .61776 m
.30594 .605 L
s
1 0 0 r
.61776 .32553 m
.605 .30594 L
s
0 0 1 r
.33916 .64056 m
.31873 .62568 L
s
1 0 0 r
.64056 .33916 m
.62568 .31873 L
s
0 0 1 r
.39237 .6917 m
.36977 .67702 L
s
1 0 0 r
.6917 .39237 m
.67702 .36977 L
s
0 0 1 r
.56641 .70937 m
.54102 .70877 L
s
1 0 0 r
.70937 .56641 m
.70877 .54102 L
s
0 0 1 r
.66186 .64839 m
.64009 .65373 L
s
1 0 0 r
.64839 .66186 m
.65373 .64009 L
s
0 0 1 r
.69424 .60119 m
.67483 .60689 L
s
1 0 0 r
.60119 .69424 m
.60689 .67483 L
s
0 0 1 r
.35677 .65823 m
.33527 .64308 L
s
1 0 0 r
.65823 .35677 m
.64308 .33527 L
s
0 0 1 r
.37461 .67537 m
.35239 .66029 L
s
1 0 0 r
.67537 .37461 m
.66029 .35239 L
s
0 0 1 r
.30188 .53546 m
.28453 .53209 L
s
1 0 0 r
.53546 .30188 m
.53209 .28453 L
s
0 0 1 r
.6001 .69329 m
.5754 .69513 L
s
1 0 0 r
.69329 .6001 m
.69513 .5754 L
s
0 0 1 r
.44726 .71099 m
.42233 .70088 L
s
1 0 0 r
.71099 .44726 m
.70088 .42233 L
s
0 0 1 r
.63218 .67262 m
.6087 .67648 L
s
1 0 0 r
.67262 .63218 m
.67648 .6087 L
s
0 0 1 r
.31425 .58188 m
.29556 .57352 L
s
1 0 0 r
.58188 .31425 m
.57352 .29556 L
s
0 0 1 r
.50644 .71687 m
.48053 .71159 L
s
1 0 0 r
.71687 .50644 m
.71159 .48053 L
s
0 0 1 r
.34314 .63617 m
.32212 .62271 L
s
1 0 0 r
.63617 .34314 m
.62271 .32212 L
s
0 0 1 r
.39802 .68896 m
.37461 .67537 L
s
1 0 0 r
.68896 .39802 m
.67537 .37461 L
s
0 0 1 r
.32888 .61067 m
.30882 .5995 L
s
1 0 0 r
.61067 .32888 m
.5995 .30882 L
s
0 0 1 r
.42233 .70088 m
.39802 .68896 L
s
1 0 0 r
.70088 .42233 m
.68896 .39802 L
s
0 0 1 r
.69913 .58007 m
.67997 .58504 L
s
1 0 0 r
.58007 .69913 m
.58504 .67997 L
s
0 0 1 r
.30403 .51861 m
.28636 .51697 L
s
1 0 0 r
.51861 .30403 m
.51697 .28636 L
s
0 0 1 r
.36131 .6544 m
.33916 .64056 L
s
1 0 0 r
.6544 .36131 m
.64056 .33916 L
s
0 0 1 r
.37972 .6721 m
.35677 .65823 L
s
1 0 0 r
.6721 .37972 m
.65823 .35677 L
s
0 0 1 r
.54102 .70877 m
.51492 .70631 L
s
1 0 0 r
.70877 .54102 m
.70631 .51492 L
s
0 0 1 r
.48053 .71159 m
.45459 .70439 L
s
1 0 0 r
.71159 .48053 m
.70439 .45459 L
s
0 0 1 r
.66881 .62813 m
.64712 .63336 L
s
1 0 0 r
.62813 .66881 m
.63336 .64712 L
s
0 0 1 r
.31678 .56966 m
.29772 .56304 L
s
1 0 0 r
.56966 .31678 m
.56304 .29772 L
s
0 0 1 r
.30635 .5 m
.28837 .5 L
s
.71163 .5 m
.69365 .5 L
s
1 0 0 r
.5 .30635 m
.5 .28837 L
s
.5 .71163 m
.5 .69365 L
s
0 0 1 r
.70319 .55897 m
.68431 .563 L
s
1 0 0 r
.55897 .70319 m
.563 .68431 L
s
0 0 1 r
.34709 .62973 m
.32553 .61776 L
s
1 0 0 r
.62973 .34709 m
.61776 .32553 L
s
0 0 1 r
.70931 .51854 m
.69102 .52006 L
s
1 0 0 r
.51854 .70931 m
.52006 .69102 L
s
0 0 1 r
.70654 .53833 m
.68796 .54119 L
s
1 0 0 r
.53833 .70654 m
.54119 .68796 L
s
0 0 1 r
.40388 .68453 m
.37972 .6721 L
s
1 0 0 r
.68453 .40388 m
.6721 .37972 L
s
0 0 1 r
.33209 .60135 m
.3116 .59182 L
s
1 0 0 r
.60135 .33209 m
.59182 .3116 L
s
0 0 1 r
.45459 .70439 m
.42893 .69533 L
s
1 0 0 r
.70439 .45459 m
.69533 .42893 L
s
0 0 1 r
.5754 .69513 m
.54962 .69525 L
s
1 0 0 r
.69513 .5754 m
.69525 .54962 L
s
0 0 1 r
.42893 .69533 m
.40388 .68453 L
s
1 0 0 r
.69533 .42893 m
.68453 .40388 L
s
0 0 1 r
.64009 .65373 m
.61654 .65782 L
s
1 0 0 r
.65373 .64009 m
.65782 .61654 L
s
0 0 1 r
.3659 .64862 m
.34314 .63617 L
s
1 0 0 r
.64862 .3659 m
.63617 .34314 L
s
0 0 1 r
.38495 .667 m
.36131 .6544 L
s
1 0 0 r
.667 .38495 m
.6544 .36131 L
s
0 0 1 r
.6087 .67648 m
.58377 .67883 L
s
1 0 0 r
.67648 .6087 m
.67883 .58377 L
s
0 0 1 r
.51492 .70631 m
.48842 .70197 L
s
1 0 0 r
.70631 .51492 m
.70197 .48842 L
s
0 0 1 r
.31921 .5552 m
.29981 .55033 L
s
1 0 0 r
.5552 .31921 m
.55033 .29981 L
s
0 0 1 r
.67483 .60689 m
.65329 .61179 L
s
1 0 0 r
.60689 .67483 m
.61179 .65329 L
s
0 0 1 r
.35093 .6211 m
.32888 .61067 L
s
1 0 0 r
.6211 .35093 m
.61067 .32888 L
s
0 0 1 r
.33515 .58973 m
.31425 .58188 L
s
1 0 0 r
.58973 .33515 m
.58188 .31425 L
s
0 0 1 r
.40978 .6782 m
.38495 .667 L
s
1 0 0 r
.6782 .40978 m
.667 .38495 L
s
0 0 1 r
.48842 .70197 m
.46185 .6958 L
s
1 0 0 r
.70197 .48842 m
.6958 .46185 L
s
0 0 1 r
.54962 .69525 m
.52306 .69362 L
s
1 0 0 r
.69525 .54962 m
.69362 .52306 L
s
0 0 1 r
.3216 .53862 m
.30188 .53546 L
s
1 0 0 r
.53862 .3216 m
.53546 .30188 L
s
0 0 1 r
.3704 .64073 m
.34709 .62973 L
s
1 0 0 r
.64073 .3704 m
.62973 .34709 L
s
0 0 1 r
.39015 .65989 m
.3659 .64862 L
s
1 0 0 r
.65989 .39015 m
.64862 .3659 L
s
0 0 1 r
.43552 .68784 m
.40978 .6782 L
s
1 0 0 r
.68784 .43552 m
.6782 .40978 L
s
0 0 1 r
.46185 .6958 m
.43552 .68784 L
s
1 0 0 r
.6958 .46185 m
.68784 .43552 L
s
0 0 1 r
.67997 .58504 m
.65862 .58939 L
s
1 0 0 r
.58504 .67997 m
.58939 .65862 L
s
0 0 1 r
.64712 .63336 m
.62358 .6375 L
s
1 0 0 r
.63336 .64712 m
.6375 .62358 L
s
0 0 1 r
.58377 .67883 m
.55768 .6796 L
s
1 0 0 r
.67883 .58377 m
.6796 .55768 L
s
0 0 1 r
.32405 .52013 m
.30403 .51861 L
s
1 0 0 r
.52013 .32405 m
.51861 .30403 L
s
0 0 1 r
.61654 .65782 m
.59146 .66055 L
s
1 0 0 r
.65782 .61654 m
.66055 .59146 L
s
0 0 1 r
.35459 .61018 m
.33209 .60135 L
s
1 0 0 r
.61018 .35459 m
.60135 .33209 L
s
0 0 1 r
.33804 .57582 m
.31678 .56966 L
s
1 0 0 r
.57582 .33804 m
.56966 .31678 L
s
0 0 1 r
.52306 .69362 m
.49604 .69022 L
s
1 0 0 r
.69362 .52306 m
.69022 .49604 L
s
0 0 1 r
.68431 .563 m
.66318 .56657 L
s
1 0 0 r
.563 .68431 m
.56657 .66318 L
s
0 0 1 r
.41561 .66981 m
.39015 .65989 L
s
1 0 0 r
.66981 .41561 m
.65989 .39015 L
s
0 0 1 r
.69365 .5 m
.67333 .5 L
s
1 0 0 r
.5 .69365 m
.5 .67333 L
s
0 0 1 r
.32667 .5 m
.30635 .5 L
s
1 0 0 r
.5 .32667 m
.5 .30635 L
s
0 0 1 r
.68796 .54119 m
.66708 .54377 L
s
1 0 0 r
.54119 .68796 m
.54377 .66708 L
s
0 0 1 r
.69102 .52006 m
.67042 .52143 L
s
1 0 0 r
.52006 .69102 m
.52143 .67042 L
s
0 0 1 r
.37475 .63061 m
.35093 .6211 L
s
1 0 0 r
.63061 .37475 m
.6211 .35093 L
s
0 0 1 r
.39522 .65061 m
.3704 .64073 L
s
1 0 0 r
.65061 .39522 m
.64073 .3704 L
s
0 0 1 r
.49604 .69022 m
.46889 .68508 L
s
1 0 0 r
.69022 .49604 m
.68508 .46889 L
s
0 0 1 r
.65329 .61179 m
.62981 .61579 L
s
1 0 0 r
.61179 .65329 m
.61579 .62981 L
s
0 0 1 r
.44197 .67825 m
.41561 .66981 L
s
1 0 0 r
.67825 .44197 m
.66981 .41561 L
s
0 0 1 r
.34082 .5597 m
.31921 .5552 L
s
1 0 0 r
.5597 .34082 m
.5552 .31921 L
s
0 0 1 r
.55768 .6796 m
.53074 .67875 L
s
1 0 0 r
.6796 .55768 m
.67875 .53074 L
s
0 0 1 r
.35806 .59695 m
.33515 .58973 L
s
1 0 0 r
.59695 .35806 m
.58973 .33515 L
s
0 0 1 r
.46889 .68508 m
.44197 .67825 L
s
1 0 0 r
.68508 .46889 m
.67825 .44197 L
s
0 0 1 r
.62358 .6375 m
.59842 .64046 L
s
1 0 0 r
.6375 .62358 m
.64046 .59842 L
s
0 0 1 r
.59146 .66055 m
.56514 .66187 L
s
1 0 0 r
.66055 .59146 m
.66187 .56514 L
s
0 0 1 r
.42125 .65922 m
.39522 .65061 L
s
1 0 0 r
.65922 .42125 m
.65061 .39522 L
s
0 0 1 r
.34354 .54152 m
.3216 .53862 L
s
1 0 0 r
.54152 .34354 m
.53862 .3216 L
s
0 0 1 r
.37888 .61818 m
.35459 .61018 L
s
1 0 0 r
.61818 .37888 m
.61018 .35459 L
s
0 0 1 r
.65862 .58939 m
.63526 .59303 L
s
1 0 0 r
.58939 .65862 m
.59303 .63526 L
s
0 0 1 r
.53074 .67875 m
.50326 .67625 L
s
1 0 0 r
.67875 .53074 m
.67625 .50326 L
s
0 0 1 r
.40008 .63907 m
.37475 .63061 L
s
1 0 0 r
.63907 .40008 m
.63061 .37475 L
s
0 0 1 r
.36134 .58144 m
.33804 .57582 L
s
1 0 0 r
.58144 .36134 m
.57582 .33804 L
s
0 0 1 r
.44816 .66643 m
.42125 .65922 L
s
1 0 0 r
.66643 .44816 m
.65922 .42125 L
s
0 0 1 r
.34629 .52151 m
.32405 .52013 L
s
1 0 0 r
.52151 .34629 m
.52013 .32405 L
s
0 0 1 r
.50326 .67625 m
.47562 .67213 L
s
1 0 0 r
.67625 .50326 m
.67213 .47562 L
s
0 0 1 r
.66318 .56657 m
.63999 .56962 L
s
1 0 0 r
.56657 .66318 m
.56962 .63999 L
s
0 0 1 r
.56514 .66187 m
.53788 .66171 L
s
1 0 0 r
.66187 .56514 m
.66171 .53788 L
s
0 0 1 r
.47562 .67213 m
.44816 .66643 L
s
1 0 0 r
.67213 .47562 m
.66643 .44816 L
s
0 0 1 r
.62981 .61579 m
.60464 .6188 L
s
1 0 0 r
.61579 .62981 m
.6188 .60464 L
s
0 0 1 r
.67333 .5 m
.65081 .5 L
s
1 0 0 r
.5 .67333 m
.5 .65081 L
s
0 0 1 r
.34919 .5 m
.32667 .5 L
s
1 0 0 r
.5 .34919 m
.5 .32667 L
s
0 0 1 r
.66708 .54377 m
.64408 .54601 L
s
1 0 0 r
.54377 .66708 m
.54601 .64408 L
s
0 0 1 r
.38276 .60342 m
.35806 .59695 L
s
1 0 0 r
.60342 .38276 m
.59695 .35806 L
s
0 0 1 r
.67042 .52143 m
.64765 .52265 L
s
1 0 0 r
.52143 .67042 m
.52265 .64765 L
s
0 0 1 r
.59842 .64046 m
.57193 .64218 L
s
1 0 0 r
.64046 .59842 m
.64218 .57193 L
s
0 0 1 r
.42662 .64635 m
.40008 .63907 L
s
1 0 0 r
.64635 .42662 m
.63907 .40008 L
s
0 0 1 r
.36446 .56376 m
.34082 .5597 L
s
1 0 0 r
.56376 .36446 m
.5597 .34082 L
s
0 0 1 r
.40467 .62521 m
.37888 .61818 L
s
1 0 0 r
.62521 .40467 m
.61818 .37888 L
s
0 0 1 r
.53788 .66171 m
.51003 .66005 L
s
1 0 0 r
.66171 .53788 m
.66005 .51003 L
s
0 0 1 r
.63526 .59303 m
.61013 .59588 L
s
1 0 0 r
.59303 .63526 m
.59588 .61013 L
s
0 0 1 r
.45403 .65232 m
.42662 .64635 L
s
1 0 0 r
.65232 .45403 m
.64635 .42662 L
s
0 0 1 r
.36749 .5441 m
.34354 .54152 L
s
1 0 0 r
.5441 .36749 m
.54152 .34354 L
s
0 0 1 r
.38642 .58642 m
.36134 .58144 L
s
1 0 0 r
.58642 .38642 m
.58144 .36134 L
s
0 0 1 r
.51003 .66005 m
.48196 .65691 L
s
1 0 0 r
.66005 .51003 m
.65691 .48196 L
s
0 0 1 r
.57193 .64218 m
.54444 .6426 L
s
1 0 0 r
.64218 .57193 m
.6426 .54444 L
s
0 0 1 r
.48196 .65691 m
.45403 .65232 L
s
1 0 0 r
.65691 .48196 m
.65232 .45403 L
s
0 0 1 r
.60464 .6188 m
.57805 .62075 L
s
1 0 0 r
.6188 .60464 m
.62075 .57805 L
s
0 0 1 r
.43166 .63116 m
.40467 .62521 L
s
1 0 0 r
.63116 .43166 m
.62521 .40467 L
s
0 0 1 r
.63999 .56962 m
.61495 .57209 L
s
1 0 0 r
.56962 .63999 m
.57209 .61495 L
s
0 0 1 r
.40897 .60904 m
.38276 .60342 L
s
1 0 0 r
.60904 .40897 m
.60342 .38276 L
s
0 0 1 r
.37053 .52273 m
.34629 .52151 L
s
1 0 0 r
.52273 .37053 m
.52151 .34629 L
s
0 0 1 r
.64408 .54601 m
.61919 .54787 L
s
1 0 0 r
.54601 .64408 m
.54787 .61919 L
s
0 0 1 r
.65081 .5 m
.62632 .5 L
s
1 0 0 r
.5 .65081 m
.5 .62632 L
s
0 0 1 r
.37368 .5 m
.34919 .5 L
s
1 0 0 r
.5 .37368 m
.5 .34919 L
s
0 0 1 r
.38988 .56731 m
.36446 .56376 L
s
1 0 0 r
.56731 .38988 m
.56376 .36446 L
s
0 0 1 r
.64765 .52265 m
.62294 .52368 L
s
1 0 0 r
.52265 .64765 m
.52368 .62294 L
s
0 0 1 r
.54444 .6426 m
.51628 .6417 L
s
1 0 0 r
.6426 .54444 m
.6417 .51628 L
s
0 0 1 r
.45951 .63594 m
.43166 .63116 L
s
1 0 0 r
.63594 .45951 m
.63116 .43166 L
s
0 0 1 r
.61013 .59588 m
.58352 .59788 L
s
1 0 0 r
.59588 .61013 m
.59788 .58352 L
s
0 0 1 r
.57805 .62075 m
.55039 .62161 L
s
1 0 0 r
.62075 .57805 m
.62161 .55039 L
s
0 0 1 r
.41299 .59068 m
.38642 .58642 L
s
1 0 0 r
.59068 .41299 m
.58642 .38642 L
s
0 0 1 r
.51628 .6417 m
.48785 .63947 L
s
1 0 0 r
.6417 .51628 m
.63947 .48785 L
s
0 0 1 r
.43637 .61371 m
.40897 .60904 L
s
1 0 0 r
.61371 .43637 m
.60904 .40897 L
s
0 0 1 r
.48785 .63947 m
.45951 .63594 L
s
1 0 0 r
.63947 .48785 m
.63594 .45951 L
s
0 0 1 r
.39321 .54632 m
.36749 .5441 L
s
1 0 0 r
.54632 .39321 m
.5441 .36749 L
s
0 0 1 r
.61495 .57209 m
.58837 .57393 L
s
1 0 0 r
.57209 .61495 m
.57393 .58837 L
s
0 0 1 r
.55039 .62161 m
.522 .62133 L
s
1 0 0 r
.62161 .55039 m
.62133 .522 L
s
0 0 1 r
.3965 .52376 m
.37053 .52273 L
s
1 0 0 r
.52376 .3965 m
.52273 .37053 L
s
0 0 1 r
.46459 .61735 m
.43637 .61371 L
s
1 0 0 r
.61735 .46459 m
.61371 .43637 L
s
0 0 1 r
.41677 .57029 m
.38988 .56731 L
s
1 0 0 r
.57029 .41677 m
.56731 .38988 L
s
0 0 1 r
.58352 .59788 m
.55575 .59899 L
s
1 0 0 r
.59788 .58352 m
.59899 .55575 L
s
0 0 1 r
.61919 .54787 m
.59268 .54932 L
s
1 0 0 r
.54787 .61919 m
.54932 .59268 L
s
0 0 1 r
.62632 .5 m
.60013 .5 L
s
1 0 0 r
.5 .62632 m
.5 .60013 L
s
0 0 1 r
.39987 .5 m
.37368 .5 L
s
1 0 0 r
.5 .39987 m
.5 .37368 L
s
0 0 1 r
.44074 .59413 m
.41299 .59068 L
s
1 0 0 r
.59413 .44074 m
.59068 .41299 L
s
0 0 1 r
.62294 .52368 m
.59657 .52451 L
s
1 0 0 r
.52368 .62294 m
.52451 .59657 L
s
0 0 1 r
.522 .62133 m
.49327 .6199 L
s
1 0 0 r
.62133 .522 m
.6199 .49327 L
s
0 0 1 r
.49327 .6199 m
.46459 .61735 L
s
1 0 0 r
.6199 .49327 m
.61735 .46459 L
s
0 0 1 r
.42038 .54814 m
.39321 .54632 L
s
1 0 0 r
.54814 .42038 m
.54632 .39321 L
s
0 0 1 r
.58837 .57393 m
.56056 .57509 L
s
1 0 0 r
.57393 .58837 m
.57509 .56056 L
s
0 0 1 r
.55575 .59899 m
.52719 .59917 L
s
1 0 0 r
.59899 .55575 m
.59917 .52719 L
s
0 0 1 r
.46928 .59673 m
.44074 .59413 L
s
1 0 0 r
.59673 .46928 m
.59413 .44074 L
s
0 0 1 r
.44481 .57264 m
.41677 .57029 L
s
1 0 0 r
.57264 .44481 m
.57029 .41677 L
s
0 0 1 r
.4239 .52457 m
.3965 .52376 L
s
1 0 0 r
.52457 .4239 m
.52376 .3965 L
s
0 0 1 r
.59268 .54932 m
.5649 .55031 L
s
1 0 0 r
.54932 .59268 m
.55031 .5649 L
s
0 0 1 r
.52719 .59917 m
.49823 .59841 L
s
1 0 0 r
.59917 .52719 m
.59841 .49823 L
s
0 0 1 r
.49823 .59841 m
.46928 .59673 L
s
1 0 0 r
.59841 .49823 m
.59673 .46928 L
s
0 0 1 r
.60013 .5 m
.57255 .5 L
s
1 0 0 r
.5 .60013 m
.5 .57255 L
s
0 0 1 r
.42745 .5 m
.39987 .5 L
s
1 0 0 r
.5 .42745 m
.5 .39987 L
s
0 0 1 r
.59657 .52451 m
.56886 .52512 L
s
1 0 0 r
.52451 .59657 m
.52512 .56886 L
s
0 0 1 r
.56056 .57509 m
.5319 .57555 L
s
1 0 0 r
.57509 .56056 m
.57555 .5319 L
s
0 0 1 r
.44866 .54952 m
.42038 .54814 L
s
1 0 0 r
.54952 .44866 m
.54814 .42038 L
s
0 0 1 r
.47361 .57431 m
.44481 .57264 L
s
1 0 0 r
.57431 .47361 m
.57264 .44481 L
s
0 0 1 r
.5649 .55031 m
.5362 .55084 L
s
1 0 0 r
.55031 .5649 m
.55084 .5362 L
s
0 0 1 r
.5319 .57555 m
.50278 .57529 L
s
1 0 0 r
.57555 .5319 m
.57529 .50278 L
s
0 0 1 r
.45237 .52517 m
.4239 .52457 L
s
1 0 0 r
.52517 .45237 m
.52457 .4239 L
s
0 0 1 r
.50278 .57529 m
.47361 .57431 L
s
1 0 0 r
.57529 .50278 m
.57431 .47361 L
s
0 0 1 r
.56886 .52512 m
.54018 .5255 L
s
1 0 0 r
.52512 .56886 m
.5255 .54018 L
s
0 0 1 r
.45605 .5 m
.42745 .5 L
s
.57255 .5 m
.54395 .5 L
s
1 0 0 r
.5 .45605 m
.5 .42745 L
s
.5 .57255 m
.5 .54395 L
s
0 0 1 r
.47766 .55044 m
.44866 .54952 L
s
1 0 0 r
.55044 .47766 m
.54952 .44866 L
s
0 0 1 r
.5362 .55084 m
.50698 .55089 L
s
1 0 0 r
.55084 .5362 m
.55089 .50698 L
s
0 0 1 r
.50698 .55089 m
.47766 .55044 L
s
1 0 0 r
.55089 .50698 m
.55044 .47766 L
s
0 0 1 r
.48151 .52552 m
.45237 .52517 L
s
1 0 0 r
.52552 .48151 m
.52517 .45237 L
s
0 0 1 r
.54018 .5255 m
.51092 .52563 L
s
1 0 0 r
.5255 .54018 m
.52563 .51092 L
s
0 0 1 r
.54395 .5 m
.51472 .5 L
s
1 0 0 r
.5 .54395 m
.5 .51472 L
s
0 0 1 r
.48528 .5 m
.45605 .5 L
s
1 0 0 r
.5 .48528 m
.5 .45605 L
s
0 0 1 r
.51092 .52563 m
.48151 .52552 L
s
1 0 0 r
.52563 .51092 m
.52552 .48151 L
s
0 0 1 r
.51472 .5 m
.48528 .5 L
s
1 0 0 r
.5 .51472 m
.5 .48528 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0026Ool?O02;Ool0081ooaMl
08Uoo`00O7oo57`000=oog`0O0001W`0Qgoo001iOolRO025Ool007Eoo`Ml009oo`=l009oo`03O01o
og`0009oo`03O01oog`000El009oo`Yl08Aoo`00Lgoo1g`00goo0g`00Woo00]l07ooOoml07ooO01o
og`0Ooml07oo015l089oo`00LGoo1W`000Aoog`0Oomoo`=l00=oo`06O01oogooO01oog`00Woo0W`0
00=oog`0Ool00W`00Woo00=l07ooOol02W`0PGoo001_Ool4O0001WooO01oogooO01oo`9l0003Ooml
07oo009oo`04O01oogooO002Ool027`0Ooml07ooO01oog`0Ool2O003Ool01G`0Oomoog`0Ool02G`0
Ogoo001]Ool2O0001GooO01oogooO0000Woo00=l07ooO0000goo00Al07ooOoml009oo`04O01oogoo
O002Ool017`0Ooml07oo0W`000=oog`0Ool00Woo00Al07ooOoml009oo`03O01oog`000Il07ioo`00
Jgoo0W`00Woo00El07ooOoml07oo009l009oo`04O01oogooO002Ool017`0Oomoog`00Woo00al07oo
Ooml07ooO01oog`0Ooml07ooO003Ool017`0Oomoog`00goo00=l07ooO0001g`0O7oo001YOol3O002
Ool01W`0Ooml07`0Ooml00=oo`04O01oogooO002Ool01G`0OomoogooO0000Woo00=l07ooO0000Woo
00Ml07ooO01oog`0Ooml0003Ool01G`0OomoogooO0000Woo00El07ooOoml07oo00Il07]oo`00J7oo
0W`00goo0g`00Woo00El07ooOomoog`0009oo`04O01oogooO003Ool017`0Oomoog`00Woo00Yl07oo
Ooml07ooO01oog`0Ooml00=oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo1W`0NWoo001VOol3
O002Ool3O003Ool01G`0OomoogooO0000Woo00Al07ooOoml00=oo`07O01oogooOoml07ooO0000Woo
00Ql07ooOoml07ooO01oog`00goo00El07ooOomoog`000=oo`07O01oogooO01oog`0Ool01W`0N7oo
001UOol00g`0Ooml0002Ool017`0Oomoog`00goo00Al07ooOoml009oo`05O01oogooOoml0003Ool0
17`0Oomoog`00Woo00Al07ooOoml009oo`05O01oog`0Ooml0003Ool01G`0OomoogooO0000goo00Al
07ooOoml009oo`04O01oog`0Ool4O01gOol006Aoo`03O01oog`0009oo`04O01oogooO003Ool017`0
Oomoog`00goo00Al07ooOoml00=oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo00El07ooO01o
og`000Aoo`05O01oogooOoml0003Ool017`0Oomoog`00Woo00Al07ooO01oo`Al07Ioo`00Hgoo00=l
07ooO0000goo00Al07ooOoml009oo`05O01oogooOoml0002Ool01G`0OomoogooO0000Woo00El07oo
Oomoog`0009oo`04O01oogooO002Ool01W`0Oomoog`0Ooml00Aoo`05O01oogooOoml0003Ool017`0
Oomoog`00Woo00Il07ooO01oog`0Ool3O01eOol0069oo`03O01oog`000=oo`04O01oogooO003Ool0
17`0Oomoog`00Woo00El07ooOomoog`000=oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo00Il
07ooOoml07ooO004Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`06O01oog`0Ooml07oo
17`0Lgoo001QOol017`0Oomoog`00Woo00Al07ooOoml00=oo`04O01oogooO003Ool01G`0Oomoogoo
O0000Woo00El07ooOomoog`000=oo`04O01oogooO002Ool01W`0Oomoog`0Ooml00Aoo`05O01oogoo
Ooml0003Ool01G`0OomoogooO0000Woo00=l07ooO0000Woo00=l07ooO0000g`0LWoo001POol017`0
Oomoog`00Woo00Al07ooOoml00=oo`05O01oogooOoml0002Ool01G`0OomoogooO0000goo00El07oo
Oomoog`000=oo`06O01oogooO01oog`00Woo00Al07ooOoml00Aoo`03O01oogoo009oo`05O01oogoo
Ooml0003Ool01W`0Oomoog`0Ooml009oo`03O01oog`000=l075oo`00H7oo00=l07ooO0000goo00=l
07ooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool017`0Oomoog`00goo00Al07oo
Ooml009oo`04O01oogooO002Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo
00Al07ooOoml009oo`03O01oogoo009l0004Ooml07`0O01`Ool005moo`04O01oogooO002Ool017`0
Oomoog`00goo00El07ooOomoog`0009oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00Al
07ooOoml009oo`04O01oogooO002Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO000
0goo00Ml07ooOomoog`0Ooml0002Ool017`0Ooml07oo0g`0Kgoo001NOol017`0Oomoog`00Woo00Al
07ooOoml009oo`0301ml000O00X07`06O0007`0O01ml000O0Woo00El07ooOomoog`0009oo`04O01o
ogooO002Ool017`0Oomoog`017oo00=l07ooOol00Woo00El07ooOomoog`000Aoo`04O01oogooO002
Ool01g`0Oomoog`0Ooml07oo00Al06eoo`00GWoo00Al07ooOoml009oo`03O0007`0O00<07`03Ooml
07oo009oo`04O01oogooO004Ool01W`0OomoogooO01oo`D07`04Ooml07ooO003Ool017`0Oomoog`0
0Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`000=oo`03O01o
og`000=oo`05O01oog`0O01oo`03O01/Ool005eoo`08O01oogooO01oo`0OO0007`9oo`04O01oogoo
O003Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`04O01oogooOol301l01G`001moogoo
O0000Woo00Al07ooOoml00Aoo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo009oo`04O01o
ogooO002Ool01g`0Oomoog`0Ooml07oo00El06]oo`00GGoo00Ml07ooOoml000OOoml0002Ool01W`0
OomoogooO01oo`807`03O0007`0O00T07`05O01oogooOoml0003Ool01G`0Oomoog`0Ool00P0O00Al
000OOoml009oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo009oo`05O01oogooOoml0003
Ool00g`0Ooml0003Ool017`0Ooml07oo1G`0JWoo001LOol017`0Ool07g`00Woo00Il07ooOomoog`0
Ool201l017`001moog`00goo00El07ooOomoog`000=oo`03O01oo`0O00807`05O0007`0O01ml0002
01l01W`0OomoogooO01oo`807`9oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`05
O01oogooOoml0003Ool017`0Oomoog`00Woo00=l07ooOol00W`000=oog`0O0000W`0JGoo001LOol0
17`001moog`00Woo00=l000O01l00`0O00=oog`0Ool00Woo00El07ooOomoog`000=oo`05O01oogoo
Ooml0004Ool01G`0OomoogooO0000Woo0`0O00El07ooOomoog`000807`03O01oogoo00=oo`03O01o
ogoo009oo`03O01oogoo009oo`03O01oogoo009oo`07O01oogooOoml07ooO0000goo00Il07ooO01o
og`0Ool4O01XOol005Yoo`0901ml07ooOoml07oo01ml000O009oo`05O01oogooOoml0002Ool00g`0
Oomoo`02Ool00g`0Oomoo`0501l01G`0OomoogooO0000goo00El07ooOomoog`0009oo`05O0007`0O
Ooml0002Ool00g`001l07`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0
OomoogooO0000Woo00Al07ooOoml009oo`03O01oog`000El06Moo`00F7oo0P0O00Qoog`0Oomoog`0
01moog`00goo00El07ooOoml07oo00X07`05Ooml07ooOoml000401l01W`001l07`0OO0007`9oo`04
O01oogooO002Ool401l00g`0Oomoo`0301l00g`0Oomoo`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02
Ool01G`0OomoogooO0000Woo00Yl07ooOomoog`0Ooml07ooO01oo`El06Ioo`00EWoo0P0O0Woo00Al
07oo01ml00=oo`05O01oogooO01oo`0201l01G`001moogooO00017oo00Al07ooOoml00=oo`03O01o
ogoo009oo`06O01oogooOoml07oo1@0O00El07ooOomoog`0009oo`04O0007`0O01l2Ool00g`001mo
o`02Ool00g`0Oomoo`03Ool01G`0OomoogooO00017oo00Al07ooOoml009oo`07O01oogooO01oog`0
Ool01G`0IGoo001EOol00`0OOomoo`02Ool201l00gooO01oo`02Ool01G`001l07g`001l00Woo00El
07ooOomoog`000=oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00=l
07ooOol0100O00Al07ooOoml00=oo`807`04O01oo`0O01l2Ool00g`0Oomoo`02Ool00g`0Oomoo`02
Ool01G`0OomoogooO0000Woo00Ml07ooOomoog`0Ooml0002Ool2O0000gooO01l0002O01TOol005=o
o`807`=oo`807`=oo`04O0007`0OO003Ool01G`0OomoogooO0000Woo00=l07oo01l00P0O00El000O
01l07g`000`07`=oo`05O01oogooOoml0003Ool017`001moog`01Goo00Al000OOomoo`807`03O01o
ogoo009oo`03O01oogoo009oo`05O01oogooOoml0003Ool017`0Oomoog`00Woo00Il07ooO01oog`0
Ool4O01SOol0059oo`0401moogooOol201l017ooO01oogoo0P0O0Woo00El07ooOomoog`0009oo`06
O01oo`0O01ml000O0goo00El07ooOomoog`0009oo`03O01oogoo009oo`05O01oogooOoml000301l0
1G`001moogooO0000goo00Al07oo01ml00807`=oo`04O01oo`0O01l2Ool00g`001moo`02Ool00g`0
Oomoo`02Ool00g`0Oomoo`02Ool017`0Oomoog`00goo00=l07ooO0000Woo00=l07ooO0000W`000=o
og`0O000HWoo001AOol00`0OOomoo`0201l3Ool017`001l07g`00goo00El07ooOomoog`000807`05
O0007gooOoml0003Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00El07ooOomoog`000=oo`03
O01oo`0O00D07`04O01oogooO002Ool301l017`0Oomoogoo0P0O00=l07oo01l00Woo00=l07ooOol0
0Woo00=l07ooOol00Woo00El07ooOomoog`0009oo`04O01oogooO002Ool2O00017ooO01l07oo0W`0
HGoo001@Ool0100OOomoo`0O17oo0P0O0Woo00Al07ooOomoo`<07`05O01oogooOoml0003Ool01G`0
OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool01G`0OomoogooO0000Woo
00Il000O01l07g`001l4Ool00g`001l07`03Ool00g`001moo`0201l00g`0Oomoo`02Ool00g`0Oomo
o`02Ool01G`0OomoogooO0000goo00=l07ooO0000Woo00Al07ooO01oo`9l0003Ooml07`0061oo`00
Cgoo00@07goo01l07`=oo`807`05O01oogooOoml000301l3Ool01G`0OomoogooO0000Woo00=l07oo
01l0600O0Woo00El07ooOomoog`000=oo`03O01oo`0O00<07`03O01oogoo00<07`07O01oo`0O01mo
o`0OO00017oo00=l07ooOol00Woo00El07ooOomoog`0009oo`04O01oogooO002Ool01G`0Ooml07`0
Ool00g`0H7oo001>Ool00`0OOol07`04Ool01@0OOomoog`0Ool00P0O00Al07ooOoml00=oo`05O01o
ogooOoml000201l01G`001moogooO00017oo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool0
0g`0Ool07`0401l00gooO01oo`02Ool00g`0Oomoo`03Ool00g`001moo`03Ool0100OO01oogoo0P0O
00=l000O01l00Woo00=l07ooOol00Woo00El07ooOomoog`000=oo`03O01oog`0009oo`06O01oog`0
Ooml07oo0g`0Ggoo001=Ool00`0OOol07`03Ool201l3Ool017`001moog`00goo00=l07ooOol0100O
00El07ooOomoog`000=oo`03O01oogoo009oo`04O01oogooO004Ool01G`0OomoogooO0000goo00El
07ooOomoog`0009oo`D07`03O01oogoo00Aoo`04O0007`0O01l2Ool00g`001l07`02Ool00g`0Oomo
o`0201l00g`0Oomoo`02Ool00g`0Oomoo`02Ool017`0Oomoog`00Woo00Ml07ooOoml07ooO01oo`02
O0000gooO01l001NOol004eoo`807`=oo`0401moogooOol201l017`0Oomoog`00goo0`0O00El07oo
Oomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO00017oo00El07ooOomoog`000=oo`05
O01oogooOoml0003Ool01G`0OomoogooO000100O0Woo00Al07ooOomoo`807`03O01oogoo00807`03
O0007`0O009oo`03O01oogoo00=oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo00=l07ooOol0
0W`000=oog`0Ool00W`0GGoo001<Ool201l2Ool201l2Ool201l2Ool01G`0Oomoog`0Ool00P0O00Al
07ooOoml00=oo`05O01oogooOoml000301l01G`001l07`0OO0005@0O0goo00El07ooOomoog`000Ao
o`807`03O0007goo00=oo`03O0007`0O009oo`04O0007goo01l2Ool00g`0Oomoo`02Ool01G`0Oomo
ogooO0000Woo00El07ooOomoog`0009oo`06O01oog`0Ooml07oo0W`000=oog`0Ool0Fgoo001;Ool2
01l2Ool01@0OOomoogoo01l00goo00=l07ooOol00`0O00=oog`0Ool00Woo00Al07ooOomoo`<07`03
O01oogoo009oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00El07oo
Oomoog`000H07`03Ooml07oo00Eoo`04O01oo`0O01l2Ool00g`0Oomoo`0201l00g`0Ool07`0301l0
0g`001l07`02Ool01G`0OomoogooO0000goo00Al07ooOoml009oo`05O01oogooO01oo`02O0000goo
O01l001LOol004]oo`0401moogoo01l3Ool00`0OOomoo`02Ool301l01GooO01oogooO0000Woo1@0O
00Al07ooOoml00Aoo`05O01oogooOoml0003Ool01G`0OomoogooO00017oo00El07ooOomoog`000=o
o`05O01oogooOoml0002Ool00`0OO0007`0201l3Ool017`0Oomoogoo0P0O00=l07ooOol00Woo00Al
000O01moo`807`06O0007goo01moog`017oo00Al07ooOoml009oo`0<O01oogooOoml07ooO01oog`0
Ooml07oo0W`0Fgoo001:Ool201l00goo01moo`02Ool0100OOomoogoo0P0O00Al07ooOoml00=oo`05
O0007`0OOoml0002Ool01G`0OomoogooO00017oo00El07ooOomoog`000=oo`05O01oogooOoml0004
Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`04O01oogooOol301l00g`001moo`03Ool0
0g`001l07`03Ool01W`0Ool07`0OOoml00807`04Ool07gooO003Ool017`0Oomoog`00goo00Al07oo
Ooml009oo`04O01oog`0Ool3O01KOol004Yoo`0501moogoo01moo`0201l2Ool201l2Ool01G`0Oomo
og`0Ool00P0O00Al07ooOoml00=oo`05O01oogooOoml0004Ool017`001l07g`0100O00=l000O01l0
4`0O0goo00=l07ooOol017oo00=l07oo01l00`0O00=l07ooOol00`0O00Al07ooOomoo`807`06O000
7`0OOol07g`00goo00El07ooOomoog`0009oo`07O01oogooOoml07ooO0000Woo0W`000=oog`0O000
FWoo0019Ool201l017oo01l07`0O0goo00<07gooOol00Woo00=l07ooOol00P0O0Woo00Al07ooOoml
00=oo`03O0007`0O00D07`05O01oogooOoml0004Ool01G`0OomoogooO00017oo00El07ooOomoog`0
00=oo`05O01oogooOoml000301l00g`001moo`04Ool00g`0Oomoo`03Ool00g`001moo`03Ool00g`0
01moo`03Ool00g`0Ool07`0201l01G`0OomoogooO0000goo00El07ooOomoog`0009oo`0:O01oogoo
O01oog`0Ooml07ooO01JOol004Uoo`0401moo`0O01l4Ool00`0OOomoo`03Ool017`001l07g`00goo
00Al07ooOoml009oo`807`=oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO000
0goo00=l07ooOol00Woo00El07ooOomoog`000=oo`06O01oogooOoml07oo1@0O00=l07ooOol00goo
00=l07oo01l00`0O00=l07oo01l00P0O00Qoog`001l07goo01ml000O0goo00El07ooOomoog`0009o
o`07O01oogooOoml07ooO0000Woo0W`000=oog`0O000FGoo0018Ool301l00goo01moo`02Ool00`0O
Oomoo`03Ool01@0OO01oogooO0000goo00=l07oo01l00`0O00=oog`0Ool00Woo00El07ooOomoog`0
00=oo`03O01oogoo009oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo
00El07ooOomoog`000Ioo`03O0007`0O00<07`03O01oogoo00=oo`07O0007`0O01moo`0OO0000Woo
00<07gooO0000P0O0Woo00El07ooOomoog`000=oo`04O01oogooO002Ool01W`0Ooml07ooO01oo`9l
05Qoo`00B7oo0P0O00=oo`0OOol00Woo00<07gooOol00Woo0P0O00Ioog`0Oomoog`0Ool201l017`0
01moog`00goo00El07ooOomoog`000=oo`@07`05O0007`0O01ml000401l00g`001l07`0601l00g`0
01l07`0501l01G`0OomoogooO0001Woo00=l07ooOol00goo00Al000O01l07`9oo`04O01oogooOol2
01l00g`001l07`0201l01W`0Ool07`0OOoml00Aoo`04O01oogooO003Ool00g`0Ooml0002Ool2O002
Ool00g`0Oomoo`1FOol004Qoo`0501moogoo01moo`0201l3Ool201l3Ool01G`0Ool07g`001l00Woo
00Al07ooOoml00=oo`03O01oogoo00D07`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0Oomo
ogooO00017oo00El07ooOomoog`000=oo`@07`03O0007`0O00<07`03Ooml07oo00Aoo`04O01oogoo
Ool201l00g`0Oomoo`03Ool017`001l07goo0P0O00El000OOol07g`000Aoo`04O01oogooO003Ool0
2G`0Oomoog`0Ooml07ooO01oo`02O01GOol004Moo`807`04Ool07goo01l3Ool201l5Ool017`001mo
og`00goo00Al07ooOoml009oo`@07`03Ooml07oo009oo`05O01oogooOoml0003Ool00g`0Oomoo`02
Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00El07ooOomoog`000=oo`03O01oogoo00=oo`03
01ml000O00807`9oo`03O01oogoo00=oo`04O0007`0O01l3Ool01W`0Ool07`0OOoml00807`03Ool0
7g`000=oo`05O01oogooOoml0002Ool017`0Oomoog`00Woo00Al07ooO01oo`9l05Ioo`00Agoo00D0
7goo01moo`0O00=oo`0301moogoo00=oo`807`04O01oogooO002Ool00g`0Ool07`0401l00gooO01o
o`02Ool01G`0OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool00g`0Oomo
o`02Ool01G`0OomoogooO0000goo00=l07ooOol017oo00Al07ooOomoo`807`04O0007`0O01l3Ool0
0g`0Oomoo`0301l01g`0Oomoogoo01ml07oo00807`03Ooml000O009oo`05O01oogooOoml0003Ool0
2G`0Oomoog`0Ooml07ooO01oo`02O01FOol004Ioo`<07`9oo`0401moogoo01l4Ool201l2Ool027`0
Oomoog`0Ool07g`001l2Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`@07`05O0007`0O
01ml000401l00g`001l07`0601l00g`001l07`0501l00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0
Oomoo`0301l00g`001moo`03Ool00g`001moo`02Ool00g`001moo`0201l00g`001l07`02Ool01G`0
OomoogooO0000Woo00Al07ooOoml009oo`04O01oog`0Ool2O01EOol004Ioo`807`9oo`0401moogoo
01l3Ool201l4Ool01g`0Oomoog`001moog`000=oo`06O01oogooOoml07oo0P0O00=l000O01l01@0O
00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0004Ool01G`0OomoogooO0000goo
00=l000O01l0100O00=l000O01l017oo00=l07ooOol00goo00=l07oo01l00P0O00=oog`0Ool00`0O
00Ml07oo01l07goo01ml000201l00gooO01oo`02Ool01g`0OomoogooO01oog`0009oo`07O01oog`0
Ooml07ooO000E7oo0016Ool201l01Goo01moogoo01l00Woo0P0O1Woo0`0O00Al07ooOoml00=oo`06
O01oo`0O01ml000O0Woo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool0
1G`0OomoogooO00017oo00El07ooOomoog`000=oo`03O01oogoo00Aoo`03O01oogoo00@07`03O01o
ogoo00=oo`03O01oogoo009oo`0301ml07oo00=oo`04O0007gooOol201l01G`001l07`0OO00017oo
00Al07ooOoml009oo`03O01oog`0009oo`04O01oog`0O01DOol004Eoo`807`03Ool07goo00807`9o
o`0301moogoo00=oo`<07`04O01oogooO002Ool01W`0Ool07`0OO0007`9oo`05O01oogooOoml0003
Ool01G`0OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml0003Ool00g`0Oomoo`02
Ool01G`0OomoogooO0001Woo00=l07ooOol017oo00=l000O01l00`0O00=l07ooOol00goo00Al000O
01l07`9oo`06O0007`0O01moog`00`0O00=l07ooOol00Woo00Al07ooOoml009oo`0:O01oogooO01o
og`0Ooml07ooO01COol004Eoo`<07`04Ool07gooOol201l4Ool201l3Ool01G`0Oomoog`0Ool00P0O
00Al07ooOoml00=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo100O00=l000O01l00P0O
00El000O01l07g`000P07`05O0007`0OOoml0006Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0
01l07`0201l00gooO01oo`02Ool201l01g`0Oomoogoo01ml07oo00<07`05O01oogooOoml0003Ool0
1W`0Oomoog`0Ooml009oo`04O01oog`0O01COol004Eoo`807`05Ool07gooOol07`05Ool00`0OOomo
o`03Ool00g`0Oomoo`0201l2Ool017`0Oomoog`00goo00Il07ooOomoog`0Ool201l00g`001l07`05
01l01G`0OomoogooO00017oo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogoo01ml0006
01l00g`001moo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool0100OO0007`0O0goo00Al000O01l0
7`9oo`06O0007goo01ml000O0Woo00El07ooOomoog`0009oo`0:O01oogooO01oog`0Ooml07ooO01B
Ool004Eoo`807`04Ool07goo01l4Ool201l6Ool301l01GooO01oogooO0000Woo00Il07ooOomoog`0
Ool201l01G`001moogooO0000goo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml
0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0001Woo00=l07oo01l0100O00=l000O01l00P0O00=o
og`0Ool01Goo00Il07oo01l07gooO003Ool201l01G`0Ool07`0OO0000P0O0Woo00Al07ooOoml00=o
o`03O01oog`0009oo`04O01oog`0O01BOol004Aoo`807`04Ool07goo01l3Ool201l5Ool301l01G`0
OomoogooO0000Woo00Al07ooOoml00<07`05O0007gooOoml0003Ool01G`0OomoogooO0000goo00El
07ooOomoog`000Aoo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0001Woo00=l
07ooOol017oo00=l07ooOol00Woo0P0O00=l000O01l00goo00Al07ooOomoo`807`03O0007goo009o
o`05O0007`0OOoml000301l01GooO01oogooO0000goo00=l07ooO0000Woo00El07ooO01oog`0055o
o`00A7oo0P0O00=oo`0O01l00goo00<07gooOol00goo0P0O17oo00Al07ooOoml009oo`<07`05O01o
ogooOoml0003Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`03O01oogoo009oo`05O000
7`0O01ml000301l00g`001l07`0201l01G`001moogooO0001Woo00=l07ooOol017oo00=l07ooOol0
17oo00=l07ooOol00`0O00=l000OOol00goo00=l07oo01l00P0O00=l07ooOol00P0O00El000O01l0
7g`000=oo`04O01oogooO002Ool01G`0Oomoog`0Ool00W`0DGoo0014Ool401l3Ool00`0OOomoo`02
Ool201l6Ool00g`0Ool07`0301l017`0Oomoog`00goo00El07ooOomoog`000=oo`05O01oo`0O01ml
000;01l00g`0Oomoo`02Ool01G`0OomoogooO00017oo00El07oo01l07g`000H07`03O0007`0O00@0
7`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oo`0O00<07`03O01oogoo009oo`03O0007goo009o
o`06O0007`0O01ml000O0Woo00Al07ooOoml009oo`08O01oogooO01oog`0Ooml051oo`00@goo1@0O
0Woo00@07gooOomoo`807`Ioo`807`04O0007gooO002Ool017`0Oomoog`00goo00El000O01l07g`0
00<07`05O0007gooOoml0003Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00El07ooOomoog`0
00Aoo`05O01oogooOoml0006Ool00g`0Oomoo`04Ool00g`001l07`0401l00g`001l07`03Ool00g`0
Oomoo`03Ool00g`001l07`0201l00g`0Ool07`0201l00g`0Oomoo`0201l017`001moog`00goo00Al
07ooOoml009oo`9l0003Ooml07oo04moo`00@goo100O0Woo00D07gooOomoo`0O00Eoo`<07`9oo`04
O01oogooO002Ool017`0Oomoog`00`0O00El07ooOomoog`000=oo`05O01oogooOoml0003Ool01G`0
OomoogooO0000goo00=l07ooOol00Woo00El07ooOomoog`000Aoo`05O01oogooOoml0006Ool00g`0
Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`0301l00g`0Oomoo`03Ool00g`0Oomoo`03Ool01G`0
01l07gooO000100O00Al000O01ml00=oo`04O01oogooO002Ool01G`0Ooml07ooO000Cgoo0013Ool3
01l2Ool00`0OOomoo`0201l4Ool201l5Ool017`0Oomoog`00Woo100O00Al07ooOoml00=oo`05O01o
ogooOoml0003Ool01G`0OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml0004Ool0
1G`0OomoogooO0001Woo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l000O01l0
0`0O00=l07ooOol00goo00=l07ooOol00P0O00El07ooOol07g`000<07`04O01oogooO003Ool01g`0
Ooml07ooO01oog`004moo`00@goo0`0O00Eoo`0OOomoo`0O00Aoo`807`Qoo`03O0007`0O00807`05
O01oogooOoml0002Ool01G`0OomoogooO0000goo00El07ooOomoog`0009oo`0301ml000O00/07`05
O0007`0O01ml000801l00g`001l07`0401l00g`001l07`0301l00gooO01oo`05Ool00g`0Oomoo`03
Ool00g`0Oomoo`03Ool00`0OO0007`0201l00gooO01oo`03Ool01G`001l07gooO0000`0O00Al07oo
Ooml00=oo`08O01oogooO01oog`0Ooml04ioo`00@goo100O0Woo00@07gooOomoo`807`Moo`<07`03
O01oog`000=oo`04O01oogooO002Ool01G`001l07`0OO0000`0O00=l000O01l0100O00=oog`0Ool0
0Woo00El07ooOomoog`000Aoo`05O01oogooOoml0004Ool01G`0OomoogooO0001Woo00=l07ooOol0
0goo00<07g`001l01@0O00=l000O01l0100O00=l07ooOol00goo00Il07ooOomoo`0OO00201l2Ool0
1G`0Oomoo`0OO0000`0O00El000O01moog`0009oo`08O01oogooO01oog`0Ooml04ioo`00@goo0`0O
0Woo00<07gooOol00P0O1Goo100O0goo00=l07ooO0000goo00=l07oo01l00`0O00El07ooOomoog`0
00=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00El07ooOomoog`0
00Aoo`05O01oogooOoml0006Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool017`0
01l07`0O0Woo00=l07ooOol00Woo00=l07ooOol00P0O00Il000O01moog`0Ool201l01G`001l07`0O
O0000goo00=l07ooO0000Woo0W`0CWoo0012Ool601l2Ool0100OOomoogoo100O1goo0`0O00Ml000O
01ml000OOoml0003Ool017`0Oomoog`00goo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool0
0g`0Oomoo`02Ool01G`0OomoogooO00017oo00El07ooOomoog`000Ioo`03O01oogoo00Aoo`03O01o
ogoo00Aoo`03O01oogoo00Aoo`04O01oogooOol201l00g`001l07`0201l00g`001moo`02Ool00g`0
Oomoo`0201l01G`001l07`0OO0000P0O00Ml000OOomoog`0Ooml0002Ool00g`0Ooml001=Ool0049o
o`@07`9oo`807`9oo`807`Moo`@07`04O01oogooO002Ool017`0Oomoog`00goo00Al07ooOoml00=o
o`05O01oogooOoml0003Ool01G`0Oomoo`0OO000300O00=l000O01l01P0O00=l000O01l0100O00=l
000O01l00P0O0Woo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo
00=l07oo01l00P0O00=l000OOol00Woo00El07oo01l07g`000807`05O0007`0OOoml0002Ool01G`0
Ooml07ooO000CGoo0012Ool401l00goo01moo`02Ool00`0OOomoo`04Ool301l5Ool00g`0Ooml0002
Ool027`0OomoogooO01oo`0OO00201l01G`001l07`0OO0000`0O00=l000O01l0100O00=oog`0Ool0
0Woo00=l07ooOol00Woo00El07ooOomoog`000Aoo`05O01oogooOoml0006Ool00g`0Oomoo`02Ool2
01l00g`001l07`0401l00g`001l07`0401l017`001l07`0O0Woo00=l07ooOol00Woo00=l07ooOol0
0goo00El000O01l07g`0009oo`0301ml000O00807`04O0007`0OO002Ool00g`0Oomoo`02O01=Ool0
049oo`D07`9oo`807`=oo`@07`Qoo`03O01oog`000<07`07O0007`0OO0007gooO0000Woo00El07oo
Oomoog`000=oo`05O01oogooOoml0003Ool01G`0OomoogooO00017oo00El07ooOomoog`000Aoo`05
O01oogooOoml0006Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool017`0Oomoogoo
0P0O00=l000O01l00`0O00=l07ooOol00Woo00El07ooOomoog`000<07`05O01oo`0OOoml000301l0
0g`0Ooml0002Ool00g`0Ooml001<Ool0049oo`@07`03Ool07`0O009oo`<07`Moo`P07`04O01oogoo
O002Ool017`0Oomoog`00goo00Al07ooOoml00=oo`05O01oogooOoml0003Ool01G`0OomoogooO000
17oo00El07ooOomoog`000Aoo`05O01oogooOoml0006Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool0
0g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`001l07`0201l01G`001l07`0OO000
0goo00H07g`001l07g`0Ool201l027`001l07g`0Ooml07ooO01<Ool0049oo`D07`9oo`807`Ioo`@0
7`Eoo`04O01oogooO002Ool017`0Oomoog`00goo00Al07ooOoml009oo`05O01oogooOoml0003Ool0
1G`0OomoogooO0000goo00=l07ooOol00Woo00El07ooOomoog`000Aoo`05O01oogooOoml0006Ool0
0g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool0
0g`0Oomoo`02Ool01G`0OomoogooO000100O00Al000O01ml00<07`08O0007`0OO01oog`0Ooml04ao
o`00@Woo1`0O0Woo1P0O2Woo00Il07ooOoml07ooO002Ool01G`0Ool07`0OO0000P0O00Al000O01ml
00@07`04O0007`0OO00<01l01G`001l07`0OO000100O00El000O01l07g`000H07`03O0007`0O00@0
7`03O0007`0O00@07`03O0007`0O00@07`03O0007`0O00<07`03O0007`0O00<07`03O01oogoo009o
o`03O01oogoo009oo`09O01oogooOoml000OOol07g`000807`04O0007`0OO00201l00g`0Ooml001;
Ool0049oo`<07`04Ool07gooOol201l9Ool701l017`001l07g`01@0O00Al07ooOoml009oo`05O01o
ogooOoml0003Ool017`0Oomoog`00goo00El07ooOomoog`000Aoo`05O01oogooOoml0004Ool01G`0
OomoogooO0001Woo00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol00goo
00=l07ooOol00goo00=l000O01l00P0O00=l000O01l00P0O00El000O01l07g`000807`05Ooml000O
Ooml000201l01W`001l07g`0Ooml04]oo`00@Woo1`0O0Woo2@0O27oo00=l07ooO0000Woo00Al07oo
Ooml009oo`04O01oogooO003Ool01G`0OomoogooO0000Woo00El07ooOomoog`000Aoo`05O01oogoo
Ooml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0001Woo00=l07ooOol017oo00=l07ooOol01Goo
00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00Woo
00Il07ooOomoo`0OO00201l017`001l07g`00P0O00Ioog`001ml000OO01;Ool0049oo`T07a5oo`03
O01oog`000=oo`03O01oog`0009oo`05O01oogooOoml0002Ool01G`0OomoogooO0000Woo00=l07oo
Ool00Woo00El07ooOomoog`000=oo`05O01oogooOoml0004Ool01G`0OomoogooO0001Woo00=l07oo
Ool01Goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07oo
Ool00Woo00=l07ooOol00Woo00=l07ooOol00Woo00Al07oo01ml00807`09Ooml07oo01ml000OO000
7g`000807dUoo`00@WooC@0O00=l000O01l0100O00=l000O01l01@0O00=l000O01l0100O00=l000O
01l02@0O00=l000O01l00`0O00=l000O01l00`0O00=l000O01l00P0O00=l000O01l0100O00El000O
01l07g`000@07`04O0007`0OO00701m3Ool0049oo`807`03Ool07`0O01Ioo`03O01oog`0009oo`03
O01oog`000=oo`04O01oogooO002Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`05O01o
ogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0001Woo00=l07ooOol01Goo00=l07ooOol0
17oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol0
0Woo00ml07ooOomoog`001moo`0OO0007gooO0007gooO0000P0O00El07ooO0007goo00D07d=oo`00
@Woo100O00=oo`0OOol057oo00=l07ooO0000Woo00Al07ooOoml009oo`04O01oogooO002Ool01G`0
OomoogooO0000goo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0
OomoogooO0001Woo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00goo
00=l07ooOol017oo00=l07ooOol00Woo00=l07ooOol00Woo00Il07ooOomoog`001l2Ool01g`0Ool0
7g`0Ool07g`000807`03O0007g`000807`03Ool07`0O00807d=oo`00@Woo1`0O5Goo0W`00goo00=l
07ooO0000Woo00Al07ooOoml00=oo`04O01oogooO003Ool01G`0OomoogooO0000goo00El07ooOomo
og`000=oo`03O01oogoo009oo`05O01oogooOoml0006Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool0
0g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool0
1W`0OomoogooO0007`9oo`04O01oo`0OO00201l027`0Ool07g`0Ooml000OOol501m3Ool0049oo`80
7`05Ool07`0O01moo`0701l>Ool00g`0Ooml0002Ool00g`0Ooml0002Ool01G`0OomoogooO0000Woo
00Al07ooOoml00=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00El
07ooOomoog`000Ioo`03O01oogoo00Eoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Ao
o`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo009oo`08O0007gooO000
7gooO01oo`807`05O0007g`001ml000701m3Ool0049oo`H07`Qoo`X07`Aoo`03O01oog`0009oo`03
O01oog`000=oo`04O01oogooO002Ool017`0Oomoog`00goo00El07ooOomoog`000=oo`05O01oogoo
Ooml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0001Woo00=l07ooOol01Goo00=l07ooOol017oo
00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00Woo
00=l07ooOol00Woo00=l000O01l00`0O00]l000O01l07g`0Ooml000OOoml07oo00<07`03Ool07goo
049oo`00@goo1P0O4Goo3@0O0Woo00Al07ooOoml009oo`05O01oogooOoml0002Ool01G`0Oomoogoo
O0000goo00El07ooOomoog`000=oo`03O01oogoo009oo`05O01oogooOoml0006Ool00g`0Oomoo`05
Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool017`0Oomoogoo0P0O00=l000O01l0
0P0O00=l000O01l00P0O00=l000O01l00P0O00El000O01ml000O009oo`0;O01oo`0OO01oog`0Ool0
7g`001moo`0401m3Ool004=oo`P07aAoo`03O01oog`0009oo`03O01oog`002l07`03O0007`0O00D0
7`03O0007`0O00@07`03O0007`0O00h07`9oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo
009oo`0=O01oo`0OO01oo`0OOoml07oo01ml07ooO0000P0O00=l000O01l0100O@goo0013Ool601l2
Ool401lAOol01G`0Ooml07ooO0000Woo00=l07ooO0000Woo00El07ooOomoog`0009oo`04O01oogoo
O003Ool01G`0OomoogooO0000goo00El07ooOomoog`000Aoo`05O01oogooOoml0006Ool00g`0Oomo
o`05Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomo
o`02Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool027`0Oomoog`0Ool07gooO002Ool01W`001moog`0
01ml00807`04Ool07`0O01m3Ool004Aoo`H07`Eoo`D07`aoo`03O01oog`0009oo`03O01oog`0009o
o`04O01oogooO002Ool017`0Oomoog`00Woo00=l07ooOol00Woo00Al07ooOoml00=oo`05O01oogoo
Ooml0004Ool01G`0OomoogooO0001Woo00=l07ooOol01Goo00=l07ooOol017oo00=l07ooOol00goo
00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooOol00Woo
00]l07ooOol07g`001moog`001moog`000807`06O01oog`0Ool07goo0P0OA7oo0014Ool701l9Ool5
01l8Ool01g`0Ooml07ooO01oog`0009oo`04O01oogooO002Ool017`0Oomoog`00goo00El07ooOomo
og`0009oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0001Woo00=l07ooOol0
1Goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol0
0Woo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`000D07`06O01oo`0OO0007g`00P0O
00=oo`0O01l0A7oo0015Ool501l017oo01l07`0O2goo1P0O0Woo00El07ooO01oog`0009oo`06O01o
ogooO01oog`00Woo00Al07ooOoml00=oo`05O01oogooOoml0002Ool01G`0OomoogooO0000goo00=l
07ooOol00Woo00El07ooOomoog`000Ioo`03O01oogoo00Eoo`03O01oogoo00Aoo`03O01oogoo00=o
o`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo009o
o`05O0007`0O01ml000201l017`001moog`00P0O00=l000OO0001@0OA7oo0016Ool501l3Ool201l?
Ool701l00g`0Ooml0002Ool00g`0Ooml0002Ool01G`0OomoogooO0000Woo00El07ooOomoog`0009o
o`05O01oogooOoml0004Ool01G`0OomoogooO0000goo00=l07ooOol017oo00=l07ooOol01Goo00=l
07ooOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00=l
07ooOol00Woo00=l000O01l00P0O00]l07ooOomoog`0Ool07g`001moog`000807`03O0007g`000D0
7dAoo`00AWoo1P0O17oo100O3Woo00Al07ooO01oo`h07`04O01oogooO003Ool017`0Oomoog`017oo
00El07ooOomoog`000=oo`05O01oogooOoml0006Ool00g`0Oomoo`05Ool00g`0Oomoo`04Ool00g`0
Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`0301l00g`001l07`0701l00g`0Oomoo`02Ool01G`0
OomoogooO0000Woo00X07g`001ml000OOoml000OO01oo`@07dAoo`00Agoo1P0O1goo100O2goo00Ml
07ooO01oog`0Ooml0002Ool00g`0Ooml0002Ool00g`0Oomoo`0I01l2Ool00g`0Oomoo`04Ool00g`0
Oomoo`05Ool00g`001l07`0401l00g`001l07`0301l00g`001l07`0401l00g`001l07`03Ool00g`0
Oomoo`02Ool00g`0Oomoo`03Ool01G`0OomoogooO0000goo00Ml000OOol07g`001ml000201l017`0
Ooml07oo100OA7oo0018Ool401l00goo01l07`09Ool201l9Ool01g`0Ooml07ooO01oog`0009oo`06
O01oogooO01oog`00Woo00El07ooOomoog`0009oo`05O01oogooOoml0003Ool01G`0OomoogooO000
0goo00=l07oo01l03`0O00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol0
0goo00=l07ooOol00Woo00=l07ooOol00goo00El07ooOomoog`000=oo`05O0007goo01ml000201l0
1Goo01ml07ooO0000P0O00=oo`0O01l0A7oo0018Ool501l2Ool301l8Ool401l6Ool01g`0Ooml07oo
O01oog`0009oo`05O01oog`0Ooml0002Ool01G`0OomoogooO0000Woo00El07ooOomoog`000=oo`05
O01oogooOoml0003Ool01G`0OomoogooO0001Woo00=l07ooOol017oo00=l07ooOol01Goo00=l07oo
Ool00goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo00El07oo
Oomoog`000=oo`0<O0007`0O01ml07ooO01oo`0OO01oog`00P0O00=oo`0OOol0A7oo0019Ool501l4
Ool201l:Ool701l01WooO01oog`0Ooml009oo`03O01oog`0009oo`04O01oogooO002Ool017`0Oomo
og`00goo00El07ooOomoog`000=oo`05O01oogooOoml0003Ool00g`0Oomoo`04Ool00g`0Oomoo`04
Ool00g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02
Ool00g`0Oomoo`03Ool01G`0OomoogooO0000`0O00al000OOomoog`0Ooml07oo01ml000OO00401m5
Ool004Yoo`<07`03Ool07`0O00Aoo`<07`ioo`L07`04Ooml07ooO002Ool017`0Oomoog`00Woo00Al
07ooOoml00=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00=l07ooOol017oo00=l07oo
Ool017oo00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo00=l07oo
Ool00Woo00=l07ooOol00Woo1@0O00Il07ooOomoog`001l2Ool02W`0Ool07g`001ml000OO0007goo
0P0OAGoo001;Ool401l00goo01moo`05Ool201l=Ool2O00017ooO01oog`01`0O00=l07ooO0000Woo
00El07ooOomoog`0009oo`05O01oogooOoml0003Ool01G`0OomoogooO0000goo00=l07ooOol017oo
00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00goo
00=l07ooOol00P0O00=l000O01l00P0O00=oog`0Ool00Woo00al07ooOomoog`0Ool07gooO01oo`0O
O00301l00g`001l07`0201m5Ool004]oo`<07`03Ool07goo00807`Ioo`<07`Yoo`04O01oog`0Ool2
O002Ool00g`0Ooml0002Ool801l01GooO01oogooO0000goo00El07ooOomoog`000=oo`05O01oogoo
Ooml0006Ool00g`0Oomoo`04Ool00g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0
Ool07`0301l00g`001l07`02Ool00g`0Oomoo`03Ool01G`0OomoogooO0000goo00Al07oo01ml00<0
7`08O01oog`001ml000OOol07dIoo`00C7oo0`0O00Aoo`0O01moo`<07`Ioo`@07`Moo`06O01oog`0
O01oog`00Woo0W`00Woo00=l07ooO0000goo00=l07oo01l0400O0goo00=l07ooOol017oo00=l07oo
Ool017oo00=l07ooOol017oo00=l000O01l0100O00=l000O01l0100O00=l000OOol00goo00=l07oo
Ool00Woo00=l07ooOol00Woo00=l07ooOol00Woo00El07ooOomoog`000807`08O0007goo01ml07oo
O01oo`@07dIoo`00CGoo0`0O0Woo0P0O0Woo0`0O1goo100O0goo00=l07ooOol00g`00Woo0W`00Woo
00Al07ooOoml009oo`04O01oogooO002Ool01G`0OomoogooO0000goo00El07ooOomoog`001P07`03
O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`03
O01oogoo009oo`0@O01oogoo01ml07oo01ml000OOol07g`0Ooml000OO00301m6Ool004ioo`<07`=o
o`0301moogoo009oo`807`Uoo`D07`09Ooml07`0Ooml07ooO01oog`0009oo`03O01oog`0009oo`04
O01oogooO002Ool01G`0OomoogooO0000goo00El07ooOomoog`000=oo`03O01oogoo00Aoo`03O01o
ogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01o
ogoo009oo`03O01oogoo009oo`04O01oogooOol401l01WooO01oo`0OO0007`9oo`04O0007g`0O004
01m6Ool004ioo`D07`9oo`807`Aoo`807`aoo`@07`03O01oogoo009l009oo`03O01oog`0009oo`05
O01oogooOoml0002Ool017`0Oomoog`00goo00El07ooOomoog`000=oo`03O01oogoo00Aoo`03O01o
ogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01o
ogoo009oo`03O01oogoo009oo`06O0007`0O01moog`00goo00Ul07oo01ml000OOoml000OOol00W`0
0`0OAgoo001?Ool301l00goo01moo`02Ool201l4Ool201l:Ool017`0Ooml07`01@0O00El07ooO01o
og`000=oo`04O01oogooO002Ool017`0Oomoog`00goo00El07ooOomoog`000=oo`03O01oogoo00Ao
o`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo009o
o`03O01oogoo00=oo`03O01oo`0O00807`03O01oogoo009oo`08O01oogooOoml07oo01ml00807`03
O0007goo009l00<07dMoo`00D7oo0`0O00=oo`0OOol00goo00<07gooOol00goo0`0O27oo00=l07oo
O0000W`00Woo00=l000O01l01P0O00Al07ooOoml009oo`04O01oogooO003Ool01G`0OomoogooO000
0goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol0
0goo00=l07ooOol00goo00=l07ooOol01@0O0goo00El07ooOomoog`000Aoo`04O01oo`0OO00201l0
17`001moog`0100OAgoo001AOol301l00goo01l07`03Ool201l6Ool301l6Ool01W`0Ooml07ooO01o
o`9l009oo`03O01oog`0009oo`P07`03Ooml07oo009oo`05O01oogooOoml0003Ool00g`0Oomoo`04
Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Ool07`03
01l00g`001l07`03Ool00g`0Oomoo`02Ool01G`0OomoogooO00017oo0`0O00Ql07oo01ml000OO000
7g`00P0OB7oo001BOol401l00goo01moo`03Ool201l7Ool301l4Ool3O0001gooO01l07ooO01oog`0
009oo`03O01oog`0009oo`05O01oogooOoml000=01l00g`001l07`0401l00g`001l07`0B01l00g`0
01l07`0301l00g`001moo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo
0P0O00]l07oo01ml07oo01ml000OO0007g`000807dQoo`00DWoo0`0O00Aoo`0OOol07`Eoo`807`Qo
o`@07`05Ooml07`0O01oo`03O002Ool00g`0Ooml0002Ool017`0Oomoog`00Woo00Al07ooOoml009o
o`05O01oogooOoml0003Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomo
o`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0Oomo
ogooO0000P0O0Woo00Ql07oo01ml07oo01ml000O0W`00P0OBGoo001COol301l00goo01moo`0201l5
Ool201l:Ool501l2O00017ooO01oog`00Woo00=l07ooO0000Woo00Al07ooOoml009oo`04O01oogoo
O003Ool01G`0OomoogooO0001Woo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l
07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo00El000O01l07g`000=o
o`09O01oogoo01ml000OO01oo`0O009l00807dUoo`00E7oo0`0O00Aoo`0O01moo`807`Eoo`807`]o
o`9l00H07`03O01oog`0009oo`03O01oog`0009oo`04O01oogooO002Ool01G`0OomoogooO0000goo
00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo
00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00`0O00El07ooOomoog`000=oo`03O01oogoo
00<07`04O0007g`0Ool201m:Ool005Eoo`@07`04Ool07gooOol201l5Ool301l9Ool4O0000gooO01o
o`0401l017ooO01oog`00Woo00Al07ooOoml00=oo`04O01oogooO003Ool00g`0Oomoo`04Ool00g`0
Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0
Ool07`0301l00g`001l07`03Ool017`0Oomoog`017oo00al07oo01l07g`001ml000OO0007g`001m:
Ool005Ioo`807`03Ool07goo00807`9oo`807`Ioo`@07`Ioo`03O01oog`0009l009oo`03O01oog`0
00H07`05Ooml07ooOoml0002Ool017`0Oomoog`00goo00=l07ooOol017oo00=l07ooOol017oo00=l
07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l000O01l00P0O00=l000OOol00goo00=l
07ooOol00goo00Al07ooOoml00=oo`0<01ml000OOoml07oo01ml000OO0007g`0Bgoo001GOol501l0
0goo01moo`02Ool201l8Ool301l4Ool02g`0Ooml07ooO01oog`0Ooml07ooO0000Woo00=l07oo01l0
3`0O1Goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo1P0O00=l07ooOol00goo00=l
07ooOol00goo00=l07ooOol00goo00El07ooOoml07oo00807`06Ooml07ooOoml07oo0P0O00Al07oo
01l07d]oo`00Egoo100O00=oo`0OOol00P0O0goo0`0O27oo100O00Eoog`0O01l07oo009l0007Ooml
07ooOoml07ooO0000Woo00Al07ooOoml009oo`04O01oogooO003Ool00g`0Ool07`0401l00g`001l0
7`0A01l00gooO01oo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomo
o`0301l3Ool017`0Oomoog`00`0O00=l000OO000C7oo001HOol401l017oo01l07goo0P0O17oo100O
27oo100O0W`000Qoog`0Ooml07ooO01oog`00Woo00Al07ooOoml009oo`04O01oogooO003Ool00g`0
Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0
Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`001l07gooO0000goo00Ul07ooOomoog`0
Ooml000OO0000P0OC7oo001IOol501l017oo01moogoo0`0O1Goo0`0O1goo0W`0100O00Ioog`0Ooml
07ooO002Ool017`0Oomoog`00Woo00Al07ooOoml00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03
O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`03
O01oo`0O00<07`05O01oogooOoml0003Ool017`0Ool07`0O0W`00`0O00=l07ooOol0Bgoo001JOol3
01l00goo01moo`0201l3Ool201l6Ool201l6Ool4O0000goo01l07`0301l01g`0OomoogooO01oog`0
009oo`04O01oogooO003Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomo
o`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`001l07`0201l00g`001moo`03Ool01G`0Oomo
ogooO0000goo00Il000OOoml07ooO00401m=Ool005]oo`H07`03Ool07goo00=oo`807`Ioo`807`Eo
o`Il009oo`03O0007`0O00L07`04O01oogooO003Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0
Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool601l00g`0Oomoo`03Ool00g`0Oomoo`03Ool0
17`0Oomoog`00Woo0P0O00El07ooOoml07oo00807`03O0007goo04eoo`00G7oo100O00=oo`0OOol0
0P0O17oo0`0O1Goo0`0O0goo17`000Ioog`0Ooml07ooO002Ool00g`0Ooml0002Ool801l6Ool00g`0
Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool701l00gooO01oo`03Ool00g`0Oomoo`03Ool0
0g`0Oomoo`02Ool01G`0OomoogooO0000P0O0Woo00Al07ooOoml00<07`03O0007goo04eoo`00GGoo
100O00Aoo`0O01moo`807`Eoo`807`Ioo`@07`El009oo`9l009oo`03O01oog`000=oo`04O01oogoo
O002Ool00g`001l07`0F01l2Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0
Oomoo`02Ool01G`0Ool07`0OO0000goo00Il07ooOol07gooO00201l00g`0Oomoo`1=Ool005ioo`D0
7`04Ool07gooOol201l5Ool201l8Ool401l00gooO01oo`02O002Ool017`0Oomoog`00Woo00Al07oo
Ooml009oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01o
ogoo009oo`03O01oogoo00=oo`03O01oogoo00=oo`07O01oogooOol07g`001l00Woo00El07ooOomo
og`000807`06O01oog`001ml000OCgoo001OOol301l00goo01moo`0201l2Ool00`0OOomoo`04Ool3
01l7Ool2O00401l01gooO01oogooO01oog`0009oo`04O01oogooO002Ool00g`0Oomoo`04Ool00g`0
Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0
Oomoo`02Ool00g`001l07`0201l00g`0Oomoo`02Ool027`0Oomoo`0OO01oo`0OO00201l00g`001mo
o`1?Ool0061oo`H07`04Ool07gooOol201l7Ool201l6Ool4O0000goo01l07`0401l017`0Oomoog`0
0Woo00Al07ooOoml00Ioo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo
00=oo`03O01oogoo009oo`H07`03O01oogoo009oo`06O01oogooOoml07oo0P0O00Ql07ooOoml000O
O0007g`0DGoo001QOol201l01Goo01moo`0OOol00P0O0Woo0P0O1goo0P0O1Goo0g`000Moog`0Ooml
07ooO01oo`0801l00gooO01oo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool0
17`0Oomoogoo1`0O00=l07ooOol00goo00=l07ooOol00Woo00Il07ooOomoog`001l2Ool00g`0Ool0
7`02O00201mBOol0069oo`807`03Ool07goo00807`03Ool07`0O009oo`<07`Ioo`<07`=oo`Al0004
Ooml07ooO002Ool00g`0Ooml0002Ool00g`0Ool07`0=01l00g`001l07`0:01l017`001l07`0O0Woo
00=l07ooOol00Woo00=l07ooOol00goo00Il07ooOomoog`0Ool201l00g`0Oomoo`02Ool01W`001ml
07ooO0007e=oo`00Hgoo1@0O00Aoo`0OOomoo`807`=oo`807`Moo`@07`=l0009Ooml07ooOoml07oo
O01oog`0009oo`04O01oogooO005Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool0
0g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool01W`0Oomoo`0OO0007`9oo`07O01oogoo
Ooml000OOol00W`000<07gooOol0DWoo001TOol01P0OOol07goo01moo`807`9oo`807`=oo`<07`Qo
o`H07`06Ooml07ooO01oog`00Woo00Al07ooOoml00Eoo`03O01oogoo00Aoo`03O01oogoo00=oo`03
O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`06O0007`0O01moog`0
0goo00Ml07ooOol07g`0Ooml000201l00g`0Oomoo`1BOol006Eoo`<07`05Ool07`0OOol07`03Ool2
01l4Ool301l6Ool3O0000gooO0007`0501l2Ool017`0Oomoog`01Goo00=l07ooOol017oo00=l07oo
Ool00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00`0O0goo00Il
07ooOomoog`0Ool201l017`0Oomoog`00P0OEGoo001WOol301l00goo01moo`0201l3Ool201l5Ool4
01l3Ool6O00017ooO01oogoo100O00=oog`0Ool017oo00=l07ooOol017oo00=l07ooOol00Woo00=l
07ooOol017oo00=l07ooOol00goo00Al07ooOomoo`D07`9oo`05O01oogooOoml0002Ool00`0OO000
7`02Ool01G`0Ooml000OO000EWoo001XOol0100OOol07goo0P0O00=oo`0O01l00goo0`0O1Woo0`0O
00=oog`0O00017`000Moog`0Ooml07ooO01oo`0>01l5Ool00g`0Oomoo`0>01l00gooO01oo`03Ool0
0g`0Oomoo`02Ool301l01gooO01oogooO01oo`0O009l05Moo`00JGoo100O00Aoo`0O01moo`807`Ao
o`807`Moo`@07`03O01oog`0009l0004Ooml07ooO002Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool0
0g`001l07`0301l00g`001l07`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool0
0g`0Oomoo`0201l3Ool02G`0OomoogooO0007g`001ml001GOol006]oo`<07`9oo`807`03Ool07`0O
00Aoo`807`Moo`9l00@07`=l0005Ooml07ooOoml0005Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool0
0g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool017`0Oomoogoo1@0O00=oog`0Ool00Woo
00Ql07oo01ml07ooO0007g`0F7oo001]Ool301l2Ool00`0OOomoo`0201l4Ool301l5Ool5O00401l2
O0000gooO01oo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`03
Ool00g`0Oomoo`0201l01W`001l07`0OOoml00=oo`05O01oogooOoml000201l01GooO01l000OO000
FGoo001_Ool201l2Ool201l2Ool301l4Ool401l2Ool3O0001GooO01l07`0Ool00`0O00=l000O01l0
0goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol01`0O0Woo00=l07oo
Ool00Woo00El07ooOomoog`0009oo`807`9oo`04O0007g`0O01JOol0071oo`<07`9oo`807`=oo`<0
7`Eoo`@07`9l0003Ooml07`0009l009oo`=l01@07`03O0007`0O00=oo`03O01oogoo009oo`03O01o
ogoo009oo`05O01oogooOoml000301l00g`0Oomoo`0201l00g`001moo`1JOol0079oo`<07`9oo`80
7`Aoo`807`Ioo`03O0007`0O00807`Il009oo`9l0003Ooml07oo00=oo`03O01oogoo00=oo`03O01o
ogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oo`0O00807`9oo`05
O01oo`0O01ml000201mLOol007=oo`@07`9oo`807`Aoo`807`Eoo`Al00H07`9l009oo`=l00=oo`03
O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`04O01oogooOol401l0
1GooO01oogooO0000P0O0W`00P0OGGoo001eOol0100OOol07`0O0Woo0P0O17oo0`0O0goo1G`000Ao
og`0O01l00@07`03O0007`0O009l0003Ooml07oo00Aoo`03O01oogoo009oo`03O01oogoo00=oo`03
O01oo`0O00H07`03Ooml07oo009oo`9l00807`04O01oog`0O01OOol007Ioo`807`03Ool07`0O009o
o`807`Eoo`@07`Il0003Ooml07`000=oo`=l01<07`03O0007`0O009oo`03O01oogoo009oo`05O01o
ogoo01ml000201l00g`0Ool07`0201mPOol007Qoo`807`03Ool07`0O009oo`<07`Ioo`D07`=l0005
Ooml07ooOoml0002Ool2O00017ooO01oogoo1G`00Woo00=l07ooOol00goo00=l07ooOol00Woo00=l
07ooOol00P0O00Al000O01ml009oo`05O0007`0OO0007`1QOol007Yoo`807`04Ool07`0O01l2Ool4
01l3Ool4O00801l4Ool2O004Ool00g`0Oomoo`0=O00301l3O002Ool00g`001l07`03O01SOol007ao
o`807`9oo`807`Aoo`<07`Ml0005Ooml07`0Ooml000401l00g`001l07`04O003Ool;01l01W`0Oomo
ogooO01oo`807`Al00807fAoo`00OWoo0P0O0Woo0P0O1Goo100O1G`000=oog`0O0000goo0g`000=o
o`0O01l01@0O1W`017oo1W`000@07g`0O01oo`9l000301ml07oo06Aoo`00P7oo0P0O0Woo0`0O17oo
0W`00P0O00=l000O01l01W`000=oog`0Ool00W`000=oog`0Ool00goo00=l07ooOol00Woo1G`000Io
o`0O01l07g`0Ool2O00401l00g`0Oomoo`1TOol0089oo`<07`9oo`@07`Ml00h07`El009oo`L07`03
Ooml07`000<07`=l000301ml07oo06Ioo`00QGoo0`0O0goo1@0O00Al07ooO01l009oo`=l0003Ooml
07`0009l009oo`L07`Ml00<07`9oo`04O0007`0OO01YOol008Qoo`<07`9oo`=l00L07`04Ooml07`0
O002Ool6O003Ool017`0Oomoogoo100O00=oog`0O00017`0Jgoo002;Ool401l017`0Ooml07oo17`0
2P0O00=l000O01l01P0O0g`000<07g`001l00g`0KGoo002=Ool2O00501l00gooO01l0004O00017oo
O01oogoo17`00Woo00El07oo01l07g`000<07`=l071oo`00SWoo1W`0400O00=l000O01l01g`0LWoo
002>Ool2O0001GooO01oog`0Ool01G`000=oog`0Ool03g`0M7oo002?Ool2O0000gooO01oo`0<O002
Ool00g`0Ooml0005O01fOol008moo`El009oo`9l0003Ooml07`000=l009oo`Ml07Uoo`00Sgoo27`0
00=oog`0O0002W`0O7oo002?Ool7O0000gooO01l0007O020Ool008moo`Yl08Moo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {652.688, 423.313}} -> {-0.399192, \
1.84552, 0.00348777, 0.00348777}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig4B = 
        Show[RotateShape[Fig4A, \[Pi]/2, 0, 0], 
          ViewPoint \[Rule] {0, 2, 0}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.5 .48233 m
.5 .5 L
s
.5 .5 m
.5 .51767 L
s
.49926 .50223 m
.49796 .51984 L
s
.50057 .48461 m
.49926 .50223 L
s
.49707 .50425 m
.49448 .52172 L
s
.49967 .48677 m
.49707 .50425 L
s
.49347 .50587 m
.48963 .5231 L
s
.49733 .48862 m
.49347 .50587 L
s
.50122 .47141 m
.49733 .48862 L
s
.49362 .48998 m
.48853 .50691 L
s
.49875 .47308 m
.49362 .48998 L
s
.50228 .46933 m
.49967 .48677 L
s
.48853 .50691 m
.48351 .52382 L
s
.48862 .49066 m
.48238 .5072 L
s
.49494 .47416 m
.48862 .49066 L
s
.50188 .46703 m
.50057 .48461 L
s
.5 .46472 m
.5 .48233 L
s
.5 .51767 m
.5 .53528 L
s
.48238 .5072 m
.47622 .52373 L
s
.48246 .49052 m
.47512 .50661 L
s
.4899 .47448 m
.48246 .49052 L
s
.49796 .51984 m
.49666 .5374 L
s
.49448 .52172 m
.49192 .53912 L
s
.48963 .5231 m
.48585 .54027 L
s
.47512 .50661 m
.46791 .5227 L
s
.50131 .45775 m
.49494 .47416 L
s
.47526 .48944 m
.46691 .50504 L
s
.48376 .47391 m
.47526 .48944 L
s
.50391 .45628 m
.49875 .47308 L
s
.49743 .45854 m
.4899 .47448 L
s
.50512 .45429 m
.50122 .47141 L
s
.48351 .52382 m
.47855 .54068 L
s
.49236 .4585 m
.48376 .47391 L
s
.50489 .45198 m
.50228 .46933 L
s
.50318 .44955 m
.50188 .46703 L
s
.46691 .50504 m
.45872 .52065 L
s
.47622 .52373 m
.47017 .54021 L
s
.46718 .48733 m
.4579 .50241 L
s
.47665 .47235 m
.46718 .48733 L
s
.5 .44721 m
.5 .46472 L
s
.5 .53528 m
.5 .55279 L
s
.48626 .4575 m
.47665 .47235 L
s
.49666 .5374 m
.49538 .55485 L
s
.46791 .5227 m
.46084 .53876 L
s
.49192 .53912 m
.48939 .55641 L
s
.50501 .44275 m
.49743 .45854 L
s
.4579 .50241 m
.44883 .51753 L
s
.50106 .44324 m
.49236 .4585 L
s
.50772 .44148 m
.50131 .45775 L
s
.48585 .54027 m
.48211 .55732 L
s
.46873 .46972 m
.45838 .48414 L
s
.47926 .45546 m
.46873 .46972 L
s
.50908 .43961 m
.50391 .45628 L
s
.45838 .48414 m
.44826 .49868 L
s
.496 .44283 m
.48626 .4575 L
s
.47855 .54068 m
.47369 .55742 L
s
.50902 .4373 m
.50512 .45429 L
s
.45872 .52065 m
.45072 .53625 L
s
.50749 .43477 m
.50489 .45198 L
s
.48996 .44141 m
.47926 .45546 L
s
.47017 .54021 m
.46424 .55658 L
s
.50448 .43222 m
.50318 .44955 L
s
.44826 .49868 m
.43839 .5133 L
s
.46015 .46599 m
.44901 .47985 L
s
.47153 .45233 m
.46015 .46599 L
s
.5 .42985 m
.5 .44721 L
s
.5 .55279 m
.5 .57015 L
s
.44883 .51753 m
.43999 .53265 L
s
.44901 .47985 m
.43814 .49386 L
s
.49538 .55485 m
.49411 .57213 L
s
.46084 .53876 m
.45394 .55472 L
s
.48311 .4389 m
.47153 .45233 L
s
.50982 .42819 m
.50106 .44324 L
s
.50583 .42838 m
.496 .44283 L
s
.48939 .55641 m
.48689 .57354 L
s
.51263 .42715 m
.50501 .44275 L
s
.51413 .4254 m
.50772 .44148 L
s
.50079 .4276 m
.48996 .44141 L
s
.48211 .55732 m
.47845 .57421 L
s
.51425 .42313 m
.50908 .43961 L
s
.45072 .53625 m
.44294 .55177 L
s
.43814 .49386 m
.42756 .50798 L
s
.45109 .46115 m
.43924 .47446 L
s
.46322 .44808 m
.45109 .46115 L
s
.43839 .5133 m
.4288 .52794 L
s
.47369 .55742 m
.46892 .574 L
s
.5129 .42051 m
.50902 .4373 L
s
.49485 .42576 m
.48311 .4389 L
s
.47559 .43528 m
.46322 .44808 L
s
.51007 .41776 m
.50749 .43477 L
s
.43924 .47446 m
.4277 .48796 L
s
.46424 .55658 m
.45846 .5728 L
s
.50576 .41509 m
.50448 .43222 L
s
.43999 .53265 m
.43142 .54772 L
s
.48816 .4228 m
.47559 .43528 L
s
.5 .41271 m
.5 .42985 L
s
.5 .57015 m
.5 .58729 L
s
.45394 .55472 m
.44723 .57054 L
s
.51573 .4142 m
.50583 .42838 L
s
.49411 .57213 m
.49286 .5892 L
s
.51172 .41408 m
.50079 .4276 L
s
.51863 .4134 m
.50982 .42819 L
s
.42756 .50798 m
.41733 .52217 L
s
.45449 .44273 m
.4417 .45524 L
s
.46757 .43054 m
.45449 .44273 L
s
.4277 .48796 m
.41652 .50162 L
s
.4417 .45524 m
.42922 .46803 L
s
.52027 .4118 m
.51263 .42715 L
s
.50672 .41293 m
.49485 .42576 L
s
.48689 .57354 m
.48444 .59044 L
s
.52055 .40956 m
.51413 .4254 L
s
.4288 .52794 m
.41954 .54258 L
s
.48088 .41872 m
.46757 .43054 L
s
.44294 .55177 m
.4354 .56717 L
s
.47845 .57421 m
.47487 .59087 L
s
.42922 .46803 m
.41711 .48106 L
s
.5009 .41068 m
.48816 .4228 L
s
.5194 .40689 m
.51425 .42313 L
s
.46892 .574 m
.46428 .59035 L
s
.51676 .40396 m
.5129 .42051 L
s
.51263 .40101 m
.51007 .41776 L
s
.4944 .40729 m
.48088 .41872 L
s
.41652 .50162 m
.40572 .51539 L
s
.43142 .54772 m
.42314 .5627 L
s
.45846 .5728 m
.45285 .5888 L
s
.4455 .43632 m
.43211 .44831 L
s
.4592 .42471 m
.4455 .43632 L
s
.41711 .48106 m
.40539 .49429 L
s
.50703 .39823 m
.50576 .41509 L
s
.43211 .44831 m
.4191 .46062 L
s
.41733 .52217 m
.40746 .53639 L
s
.47318 .41351 m
.4592 .42471 L
s
.52271 .40091 m
.51172 .41408 L
s
.52567 .40035 m
.51573 .4142 L
s
.5 .39583 m
.5 .41271 L
s
.5 .58729 m
.5 .60417 L
s
.51869 .40048 m
.50672 .41293 L
s
.44723 .57054 m
.44074 .58616 L
s
.52744 .39891 m
.51863 .4134 L
s
.51376 .39896 m
.5009 .41068 L
s
.49286 .5892 m
.49164 .60599 L
s
.4191 .46062 m
.40649 .47323 L
s
.52789 .39674 m
.52027 .4118 L
s
.4874 .40276 m
.47318 .41351 L
s
.41954 .54258 m
.41063 .55715 L
s
.48444 .59044 m
.48205 .60706 L
s
.52694 .39402 m
.52055 .40956 L
s
.50808 .39631 m
.4944 .40729 L
s
.4354 .56717 m
.42813 .5824 L
s
.47487 .59087 m
.47138 .60725 L
s
.40539 .49429 m
.39412 .50769 L
s
.52451 .39095 m
.5194 .40689 L
s
.43637 .42894 m
.42248 .44045 L
s
.45063 .41786 m
.43637 .42894 L
s
.40572 .51539 m
.39535 .52923 L
s
.4652 .40724 m
.45063 .41786 L
s
.46428 .59035 m
.45978 .60644 L
s
.40649 .47323 m
.39433 .48611 L
s
.52059 .38772 m
.51676 .40396 L
s
.42248 .44045 m
.409 .45235 L
s
.5018 .3925 m
.4874 .40276 L
s
.48004 .39713 m
.4652 .40724 L
s
.42314 .5627 m
.4152 .57753 L
s
.40746 .53639 m
.39802 .55059 L
s
.51516 .38457 m
.51263 .40101 L
s
.45285 .5888 m
.44743 .60454 L
s
.53072 .38844 m
.51869 .40048 L
s
.53373 .38813 m
.52271 .40091 L
s
.52671 .38769 m
.51376 .39896 L
s
.50828 .38169 m
.50703 .39823 L
s
.409 .45235 m
.39597 .46461 L
s
.53562 .38687 m
.52567 .40035 L
s
.52187 .38581 m
.50808 .39631 L
s
.5 .37929 m
.5 .39583 L
s
.5 .60417 m
.5 .62071 L
s
.44074 .58616 m
.4345 .60153 L
s
.53624 .38479 m
.52744 .39891 L
s
.4951 .38756 m
.48004 .39713 L
s
.41063 .55715 m
.40211 .57161 L
s
.39412 .50769 m
.38335 .52122 L
s
.49164 .60599 m
.49044 .62244 L
s
.39433 .48611 m
.38268 .4992 L
s
.53548 .38205 m
.52789 .39674 L
s
.51636 .38277 m
.5018 .3925 L
s
.48205 .60706 m
.47972 .62334 L
s
.39535 .52923 m
.38547 .5431 L
s
.42813 .5824 m
.42117 .5974 L
s
.53328 .37884 m
.52694 .39402 L
s
.39597 .46461 m
.38345 .47718 L
s
.47138 .60725 m
.46799 .62329 L
s
.52958 .37537 m
.52451 .39095 L
s
.51034 .37856 m
.4951 .38756 L
s
.45978 .60644 m
.45543 .62218 L
s
.39802 .55059 m
.38903 .56472 L
s
.52436 .37185 m
.52059 .38772 L
s
.4152 .57753 m
.40762 .59217 L
s
.5397 .37691 m
.52671 .38769 L
s
.54276 .37687 m
.53072 .38844 L
s
.53573 .37584 m
.52187 .38581 L
s
.51765 .3685 m
.51516 .38457 L
s
.54475 .3758 m
.53373 .38813 L
s
.44743 .60454 m
.44222 .61996 L
s
.38268 .4992 m
.37157 .51247 L
s
.53101 .3736 m
.51636 .38277 L
s
.38335 .52122 m
.37311 .53482 L
s
.5095 .36554 m
.50828 .38169 L
s
.54553 .37382 m
.53562 .38687 L
s
.38345 .47718 m
.37149 .49004 L
s
1 0 0 r
.4334 .59856 m
.44894 .60819 L
s
.41825 .58835 m
.4334 .59856 L
s
.44894 .60819 m
.46482 .61718 L
s
.40355 .57757 m
.41825 .58835 L
s
0 0 1 r
.5 .36315 m
.5 .37929 L
s
.5 .62071 m
.5 .63685 L
s
.54498 .37108 m
.53624 .38479 L
s
.4345 .60153 m
.42852 .6166 L
s
.40211 .57161 m
.39402 .58591 L
s
.5257 .37019 m
.51034 .37856 L
s
1 0 0 r
.46482 .61718 m
.48098 .62552 L
s
0 0 1 r
.38547 .5431 m
.3761 .55695 L
s
.49044 .62244 m
.48927 .63848 L
s
.54301 .36777 m
.53548 .38205 L
s
1 0 0 r
.38934 .56628 m
.40355 .57757 L
s
0 0 1 r
.47972 .62334 m
.47746 .63921 L
s
.42117 .5974 m
.41454 .61211 L
s
.53955 .36408 m
.53328 .37884 L
s
1 0 0 r
.48098 .62552 m
.49737 .63315 L
s
0 0 1 r
.46799 .62329 m
.46474 .63891 L
s
.53457 .36022 m
.52958 .37537 L
s
.38903 .56472 m
.38054 .57872 L
s
.37149 .49004 m
.36014 .50313 L
s
1 0 0 r
.37569 .55449 m
.38934 .56628 L
s
0 0 1 r
.37157 .51247 m
.36107 .52587 L
s
.54962 .36645 m
.53573 .37584 L
s
.5527 .36668 m
.5397 .37691 L
s
.45543 .62218 m
.45127 .63752 L
s
.54571 .36506 m
.53101 .3736 L
s
.55478 .36582 m
.54276 .37687 L
s
.52806 .35642 m
.52436 .37185 L
s
.40762 .59217 m
.40045 .60655 L
s
1 0 0 r
.44091 .61711 m
.45722 .62565 L
s
.42498 .60787 m
.44091 .61711 L
s
.40947 .59797 m
.42498 .60787 L
s
0 0 1 r
.37311 .53482 m
.36346 .54845 L
s
.55572 .36396 m
.54475 .3758 L
s
.54113 .36248 m
.5257 .37019 L
s
.52008 .35289 m
.51765 .3685 L
s
1 0 0 r
.45722 .62565 m
.47383 .63346 L
s
0 0 1 r
.44222 .61996 m
.43724 .63497 L
s
1 0 0 r
.49737 .63315 m
.51393 .64006 L
s
.39445 .58744 m
.40947 .59797 L
s
0 0 1 r
.55538 .36126 m
.54553 .37382 L
s
.51069 .34985 m
.5095 .36554 L
s
1 0 0 r
.36265 .54225 m
.37569 .55449 L
s
.47383 .63346 m
.4907 .64051 L
s
0 0 1 r
.3761 .55695 m
.3673 .57072 L
s
.39402 .58591 m
.38641 .59999 L
s
.55365 .35786 m
.54498 .37108 L
s
.42852 .6166 m
.42286 .63128 L
s
.5 .34748 m
.5 .36315 L
s
.5 .63685 m
.5 .65252 L
s
1 0 0 r
.37997 .57631 m
.39445 .58744 L
s
0 0 1 r
.48927 .63848 m
.48815 .65404 L
s
.55045 .35398 m
.54301 .36777 L
s
.36014 .50313 m
.34945 .51643 L
s
1 0 0 r
.51393 .64006 m
.5306 .64619 L
s
.4907 .64051 m
.50777 .64676 L
s
0 0 1 r
.41454 .61211 m
.40829 .62647 L
s
.47746 .63921 m
.4753 .65459 L
s
.36107 .52587 m
.35122 .53936 L
s
.54572 .3498 m
.53955 .36408 L
s
1 0 0 r
.3661 .56463 m
.37997 .57631 L
s
0 0 1 r
.5604 .35718 m
.54571 .36506 L
s
.56348 .35769 m
.54962 .36645 L
s
.38054 .57872 m
.37259 .59255 L
s
1 0 0 r
.43307 .62664 m
.44975 .63481 L
s
.41679 .6177 m
.43307 .62664 L
s
0 0 1 r
.46474 .63891 m
.46162 .65405 L
s
.56564 .35705 m
.5527 .36668 L
s
.55657 .35548 m
.54113 .36248 L
s
1 0 0 r
.35029 .5296 m
.36265 .54225 L
s
.44975 .63481 m
.46678 .64218 L
s
0 0 1 r
.53946 .34557 m
.53457 .36022 L
s
1 0 0 r
.40097 .60803 m
.41679 .6177 L
s
0 0 1 r
.36346 .54845 m
.35444 .56206 L
s
.56673 .35534 m
.55478 .36582 L
s
.40045 .60655 m
.39372 .62061 L
s
.45127 .63752 m
.4473 .65238 L
s
1 0 0 r
.46678 .64218 m
.48408 .64872 L
s
0 0 1 r
.53168 .34149 m
.52806 .35642 L
s
1 0 0 r
.38569 .59765 m
.40097 .60803 L
s
.50777 .64676 m
.52496 .65219 L
s
0 0 1 r
.5666 .35269 m
.55572 .36396 L
s
.52244 .3378 m
.52008 .35289 L
s
1 0 0 r
.35289 .55241 m
.3661 .56463 L
s
0 0 1 r
.43724 .63497 m
.43254 .64953 L
s
1 0 0 r
.5306 .64619 m
.54732 .65152 L
s
0 0 1 r
.56512 .34925 m
.55538 .36126 L
s
1 0 0 r
.48408 .64872 m
.50159 .65439 L
s
.37099 .58659 m
.38569 .59765 L
s
0 0 1 r
.3673 .57072 m
.35912 .58437 L
s
.51184 .33469 m
.51069 .34985 L
s
.38641 .59999 m
.37932 .61379 L
s
.34945 .51643 m
.33949 .52987 L
s
.5622 .3452 m
.55365 .35786 L
s
.42286 .63128 m
.41752 .64552 L
s
.5 .33236 m
.5 .34748 L
s
.5 .65252 m
.5 .66764 L
s
1 0 0 r
.33865 .51658 m
.35029 .5296 L
s
0 0 1 r
.35122 .53936 m
.34208 .55289 L
s
1 0 0 r
.52496 .65219 m
.54222 .65674 L
s
.50159 .65439 m
.51925 .65916 L
s
0 0 1 r
.55776 .34074 m
.55045 .35398 L
s
.48815 .65404 m
.48707 .66905 L
s
.57503 .35002 m
.5604 .35718 L
s
.57197 .34924 m
.55657 .35548 L
s
1 0 0 r
.35695 .57491 m
.37099 .58659 L
s
.44252 .64451 m
.4599 .65152 L
s
.4255 .63663 m
.44252 .64451 L
s
.40892 .62789 m
.4255 .63663 L
s
0 0 1 r
.57726 .34962 m
.56348 .35769 L
s
1 0 0 r
.34042 .53972 m
.35289 .55241 L
s
0 0 1 r
.40829 .62647 m
.40245 .64041 L
s
.4753 .65459 m
.47322 .66941 L
s
1 0 0 r
.4599 .65152 m
.47759 .65763 L
s
0 0 1 r
.55177 .3361 m
.54572 .3498 L
s
1 0 0 r
.39284 .61834 m
.40892 .62789 L
s
0 0 1 r
.57849 .34808 m
.56564 .35705 L
s
.37259 .59255 m
.36524 .60614 L
s
.35444 .56206 m
.34613 .57559 L
s
1 0 0 r
.54732 .65152 m
.56403 .656 L
s
0 0 1 r
.46162 .65405 m
.45865 .66864 L
s
1 0 0 r
.47759 .65763 m
.4955 .66279 L
s
0 0 1 r
.57856 .34551 m
.56673 .35534 L
s
.54424 .33149 m
.53946 .34557 L
s
1 0 0 r
.37733 .60801 m
.39284 .61834 L
s
.51925 .65916 m
.53698 .663 L
s
0 0 1 r
.39372 .62061 m
.38748 .63428 L
s
.4473 .65238 m
.44355 .66668 L
s
1 0 0 r
.34363 .56262 m
.35695 .57491 L
s
0 0 1 r
.5352 .32716 m
.53168 .34149 L
s
.57734 .34205 m
.5666 .35269 L
s
1 0 0 r
.32782 .50322 m
.33865 .51658 L
s
.54222 .65674 m
.55947 .66039 L
s
.4955 .66279 m
.51358 .66698 L
s
0 0 1 r
.33949 .52987 m
.33031 .54341 L
s
1 0 0 r
.36246 .59693 m
.37733 .60801 L
s
0 0 1 r
.52474 .32332 m
.52244 .3378 L
s
.43254 .64953 m
.42812 .66354 L
s
.35912 .58437 m
.35162 .59782 L
s
.57471 .33787 m
.56512 .34925 L
s
1 0 0 r
.32874 .52658 m
.34042 .53972 L
s
0 0 1 r
.51295 .32016 m
.51184 .33469 L
s
.37932 .61379 m
.3728 .62724 L
s
.34208 .55289 m
.33372 .56641 L
s
.57059 .33316 m
.5622 .3452 L
s
.58726 .3438 m
.57197 .34924 L
s
1 0 0 r
.53698 .663 m
.55473 .66587 L
s
0 0 1 r
.41752 .64552 m
.41256 .65924 L
s
1 0 0 r
.43557 .65457 m
.45328 .66132 L
s
.41825 .64687 m
.43557 .65457 L
s
.51358 .66698 m
.53175 .67018 L
s
0 0 1 r
.5 .31787 m
.5 .33236 L
s
.5 .66764 m
.5 .68213 L
s
.58954 .34364 m
.57503 .35002 L
s
1 0 0 r
.45328 .66132 m
.47131 .66708 L
s
.4014 .63824 m
.41825 .64687 L
s
.3483 .58514 m
.36246 .59693 L
s
.33111 .54978 m
.34363 .56262 L
s
.56403 .656 m
.58065 .65958 L
s
0 0 1 r
.59089 .34229 m
.57726 .34962 L
s
.56491 .32814 m
.55776 .34074 L
s
1 0 0 r
.47131 .66708 m
.4896 .67182 L
s
0 0 1 r
.48707 .66905 m
.48604 .68342 L
s
1 0 0 r
.3851 .62872 m
.4014 .63824 L
s
0 0 1 r
.40245 .64041 m
.39705 .65386 L
s
.59117 .33983 m
.57849 .34808 L
s
1 0 0 r
.55947 .66039 m
.57665 .6631 L
s
0 0 1 r
.34613 .57559 m
.33857 .58899 L
s
.47322 .66941 m
.47126 .68359 L
s
.36524 .60614 m
.35855 .61943 L
s
.55767 .32303 m
.55177 .3361 L
s
1 0 0 r
.4896 .67182 m
.50806 .67552 L
s
.31785 .48958 m
.32782 .50322 L
s
.3694 .61834 m
.3851 .62872 L
s
.53175 .67018 m
.54993 .67235 L
s
.31793 .51304 m
.32874 .52658 L
s
0 0 1 r
.59021 .33639 m
.57856 .34551 L
s
.45865 .66864 m
.45587 .68257 L
s
1 0 0 r
.33492 .57267 m
.3483 .58514 L
s
0 0 1 r
.54888 .31808 m
.54424 .33149 L
s
1 0 0 r
.55473 .66587 m
.5724 .66776 L
s
0 0 1 r
.33031 .54341 m
.32199 .557 L
s
.38748 .63428 m
.38178 .64749 L
s
1 0 0 r
.50806 .67552 m
.52662 .67815 L
s
0 0 1 r
.5879 .33211 m
.57734 .34205 L
s
.44355 .66668 m
.44006 .68035 L
s
1 0 0 r
.31945 .53642 m
.33111 .54978 L
s
.3544 .60712 m
.3694 .61834 L
s
0 0 1 r
.5386 .3135 m
.5352 .32716 L
s
.35162 .59782 m
.34486 .61102 L
s
.52694 .30952 m
.52474 .32332 L
s
.58411 .32719 m
.57471 .33787 L
s
.42812 .66354 m
.42404 .67693 L
s
1 0 0 r
.58065 .65958 m
.59711 .66223 L
s
0 0 1 r
.60237 .33921 m
.58726 .3438 L
s
.33372 .56641 m
.3262 .57985 L
s
1 0 0 r
.44696 .67138 m
.46532 .67689 L
s
.42895 .66481 m
.44696 .67138 L
s
.54993 .67235 m
.56804 .67347 L
s
.41136 .65719 m
.42895 .66481 L
s
0 0 1 r
.3728 .62724 m
.3669 .64027 L
s
1 0 0 r
.52662 .67815 m
.54519 .67969 L
s
0 0 1 r
.60385 .33807 m
.58954 .34364 L
s
1 0 0 r
.57665 .6631 m
.59368 .66482 L
s
.46532 .67689 m
.48394 .68131 L
s
0 0 1 r
.51402 .30634 m
.51295 .32016 L
s
1 0 0 r
.32239 .55957 m
.33492 .57267 L
s
.39428 .64857 m
.41136 .65719 L
s
.34016 .59512 m
.3544 .60712 L
s
0 0 1 r
.57878 .32183 m
.57059 .33316 L
s
.41256 .65924 m
.40801 .67236 L
s
1 0 0 r
.48394 .68131 m
.50276 .6846 L
s
0 0 1 r
.60432 .33576 m
.59089 .34229 L
s
.5 .3041 m
.5 .31787 L
s
.5 .68213 m
.5 .6959 L
s
1 0 0 r
.37778 .63897 m
.39428 .64857 L
s
.30882 .47571 m
.31785 .48958 L
s
.30806 .49914 m
.31793 .51304 L
s
.5724 .66776 m
.58992 .66861 L
s
0 0 1 r
.57187 .31625 m
.56491 .32814 L
s
.48604 .68342 m
.48507 .69705 L
s
1 0 0 r
.30872 .52258 m
.31945 .53642 L
s
0 0 1 r
.60363 .33237 m
.59117 .33983 L
s
.33857 .58899 m
.33184 .6022 L
s
1 0 0 r
.50276 .6846 m
.52167 .68675 L
s
.36194 .62842 m
.37778 .63897 L
s
0 0 1 r
.39705 .65386 m
.39215 .66673 L
s
.35855 .61943 m
.35256 .63234 L
s
1 0 0 r
.54519 .67969 m
.5637 .68011 L
s
0 0 1 r
.47126 .68359 m
.46943 .69702 L
s
1 0 0 r
.32676 .58237 m
.34016 .59512 L
s
0 0 1 r
.56337 .3107 m
.55767 .32303 L
s
1 0 0 r
.56804 .67347 m
.58601 .6735 L
s
0 0 1 r
.60164 .32804 m
.59021 .33639 L
s
.32199 .557 m
.31459 .57058 L
s
1 0 0 r
.31079 .54589 m
.32239 .55957 L
s
0 0 1 r
.45587 .68257 m
.45328 .69577 L
s
1 0 0 r
.52167 .68675 m
.54061 .68773 L
s
0 0 1 r
.55335 .30541 m
.54888 .31808 L
s
1 0 0 r
.34684 .61697 m
.36194 .62842 L
s
0 0 1 r
.38178 .64749 m
.37666 .66016 L
s
1 0 0 r
.59711 .66223 m
.61334 .66391 L
s
0 0 1 r
.59821 .32295 m
.5879 .33211 L
s
1 0 0 r
.59368 .66482 m
.61047 .66554 L
s
0 0 1 r
.44006 .68035 m
.43683 .69328 L
s
.54186 .30061 m
.5386 .3135 L
s
.61722 .33554 m
.60237 .33921 L
s
.34486 .61102 m
.33889 .6239 L
s
1 0 0 r
.44098 .68152 m
.45964 .68688 L
s
.42269 .67501 m
.44098 .68152 L
s
.5637 .68011 m
.58206 .67938 L
s
.58992 .66861 m
.60722 .6684 L
s
.45964 .68688 m
.47858 .69106 L
s
0 0 1 r
.3262 .57985 m
.31959 .59315 L
s
1 0 0 r
.40485 .66738 m
.42269 .67501 L
s
.31428 .56891 m
.32676 .58237 L
s
.29921 .48495 m
.30806 .49914 L
s
.54061 .68773 m
.55948 .68753 L
s
0 0 1 r
.59325 .31729 m
.58411 .32719 L
s
1 0 0 r
.47858 .69106 m
.49773 .69404 L
s
0 0 1 r
.61789 .3334 m
.60385 .33807 L
s
.52904 .29652 m
.52694 .30952 L
s
1 0 0 r
.38756 .65866 m
.40485 .66738 L
s
0 0 1 r
.42404 .67693 m
.42031 .6896 L
s
1 0 0 r
.29901 .50833 m
.30872 .52258 L
s
.30081 .46166 m
.30882 .47571 L
s
.33256 .60466 m
.34684 .61697 L
s
0 0 1 r
.3669 .64027 m
.36167 .65279 L
s
1 0 0 r
.58601 .6735 m
.60374 .67241 L
s
.49773 .69404 m
.51698 .6958 L
s
0 0 1 r
.51502 .29332 m
.51402 .30634 L
s
1 0 0 r
.37089 .64887 m
.38756 .65866 L
s
0 0 1 r
.61747 .3301 m
.60432 .33576 L
s
1 0 0 r
.30021 .53166 m
.31079 .54589 L
s
0 0 1 r
.58672 .31128 m
.57878 .32183 L
s
.40801 .67236 m
.4039 .68478 L
s
.5 .29116 m
.5 .3041 L
s
.5 .6959 m
.5 .70884 L
s
1 0 0 r
.51698 .6958 m
.53626 .69632 L
s
.55948 .68753 m
.5782 .68612 L
s
0 0 1 r
.33184 .6022 m
.32599 .61513 L
s
1 0 0 r
.35493 .63807 m
.37089 .64887 L
s
0 0 1 r
.6158 .32577 m
.60363 .33237 L
s
1 0 0 r
.58206 .67938 m
.60018 .67749 L
s
0 0 1 r
.57858 .30517 m
.57187 .31625 L
s
1 0 0 r
.31918 .59152 m
.33256 .60466 L
s
0 0 1 r
.48507 .69705 m
.48416 .70985 L
s
1 0 0 r
.3028 .5548 m
.31428 .56891 L
s
0 0 1 r
.35256 .63234 m
.34734 .6448 L
s
.31459 .57058 m
.30819 .58408 L
s
.39215 .66673 m
.3878 .67893 L
s
1 0 0 r
.61047 .66554 m
.62694 .66519 L
s
.61334 .66391 m
.62924 .66457 L
s
0 0 1 r
.46943 .69702 m
.46773 .70962 L
s
.56886 .29919 m
.56337 .3107 L
s
1 0 0 r
.60722 .6684 m
.62418 .66709 L
s
.53626 .69632 m
.55547 .69557 L
s
0 0 1 r
.61276 .32055 m
.60164 .32804 L
s
1 0 0 r
.33976 .62628 m
.35493 .63807 L
s
.29039 .49372 m
.29901 .50833 L
s
.60374 .67241 m
.62114 .67019 L
s
0 0 1 r
.45328 .69577 m
.4509 .70813 L
s
1 0 0 r
.29145 .47052 m
.29921 .48495 L
s
0 0 1 r
.55761 .29359 m
.55335 .30541 L
s
1 0 0 r
.5782 .68612 m
.59666 .68349 L
s
0 0 1 r
.63174 .33283 m
.61722 .33554 L
s
1 0 0 r
.45429 .69683 m
.47354 .70088 L
s
.43534 .69153 m
.45429 .69683 L
s
0 0 1 r
.37666 .66016 m
.37217 .6722 L
s
1 0 0 r
.41679 .68499 m
.43534 .69153 L
s
.29071 .51695 m
.30021 .53166 L
s
0 0 1 r
.60821 .31464 m
.59821 .32295 L
s
1 0 0 r
.47354 .70088 m
.49301 .70364 L
s
.30678 .57761 m
.31918 .59152 L
s
.39873 .67724 m
.41679 .68499 L
s
.29388 .4475 m
.30081 .46166 L
s
0 0 1 r
.31959 .59315 m
.31396 .60624 L
s
.33889 .6239 m
.33379 .63638 L
s
1 0 0 r
.55547 .69557 m
.57451 .69356 L
s
0 0 1 r
.43683 .69328 m
.43392 .70539 L
s
.54495 .2886 m
.54186 .30061 L
s
1 0 0 r
.49301 .70364 m
.51259 .7051 L
s
.60018 .67749 m
.61796 .67441 L
s
.32548 .61355 m
.33976 .62628 L
s
0 0 1 r
.63158 .32967 m
.61789 .3334 L
s
1 0 0 r
.38124 .66831 m
.39873 .67724 L
s
.2924 .54008 m
.3028 .5548 L
s
0 0 1 r
.6021 .30825 m
.59325 .31729 L
s
1 0 0 r
.51259 .7051 m
.5322 .70524 L
s
0 0 1 r
.53102 .28441 m
.52904 .29652 L
s
.42031 .6896 m
.41698 .70145 L
s
1 0 0 r
.36443 .65825 m
.38124 .66831 L
s
0 0 1 r
.36167 .65279 m
.35718 .66473 L
s
.63026 .32538 m
.61747 .3301 L
s
.51597 .28121 m
.51502 .29332 L
s
1 0 0 r
.59666 .68349 m
.61478 .67962 L
s
.57451 .69356 m
.59329 .69027 L
s
0 0 1 r
.59436 .30162 m
.58672 .31128 L
s
1 0 0 r
.5322 .70524 m
.55172 .70405 L
s
.62418 .66709 m
.64074 .66466 L
s
.31216 .59993 m
.32548 .61355 L
s
.29546 .56297 m
.30678 .57761 L
s
0 0 1 r
.4039 .68478 m
.40029 .69641 L
s
1 0 0 r
.62694 .66519 m
.643 .66376 L
s
.34837 .64708 m
.36443 .65825 L
s
0 0 1 r
.32599 .61513 m
.3211 .62772 L
s
.5 .27914 m
.5 .29116 L
s
.5 .70884 m
.5 .72086 L
s
1 0 0 r
.62114 .67019 m
.63812 .66681 L
s
0 0 1 r
.62761 .3201 m
.6158 .32577 L
s
1 0 0 r
.62924 .66457 m
.64472 .66416 L
s
0 0 1 r
.30819 .58408 m
.30285 .59743 L
s
1 0 0 r
.28294 .4788 m
.29039 .49372 L
s
.28237 .50181 m
.29071 .51695 L
s
0 0 1 r
.58501 .29499 m
.57858 .30517 L
s
.34734 .6448 m
.34296 .65672 L
s
.48416 .70985 m
.48333 .7217 L
s
1 0 0 r
.55172 .70405 m
.57108 .70152 L
s
.61796 .67441 m
.6353 .67013 L
s
.28486 .45591 m
.29145 .47052 L
s
0 0 1 r
.3878 .67893 m
.38403 .69038 L
s
1 0 0 r
.33317 .63486 m
.34837 .64708 L
s
.28315 .52482 m
.2924 .54008 L
s
.59329 .69027 m
.61171 .68568 L
s
0 0 1 r
.62351 .314 m
.61276 .32055 L
s
.46773 .70962 m
.46618 .72127 L
s
.57408 .28861 m
.56886 .29919 L
s
1 0 0 r
.44927 .70655 m
.46883 .71056 L
s
.43004 .7012 m
.44927 .70655 L
s
.28812 .43329 m
.29388 .4475 L
s
.29989 .58548 m
.31216 .59993 L
s
0 0 1 r
.64583 .33114 m
.63174 .33283 L
s
1 0 0 r
.46883 .71056 m
.4886 .7132 L
s
.41124 .69452 m
.43004 .7012 L
s
.61478 .67962 m
.63244 .67451 L
s
.4886 .7132 m
.50851 .71446 L
s
.57108 .70152 m
.59016 .69765 L
s
.39296 .68656 m
.41124 .69452 L
s
0 0 1 r
.4509 .70813 m
.44877 .71955 L
s
1 0 0 r
.28528 .54767 m
.29546 .56297 L
s
0 0 1 r
.31396 .60624 m
.30938 .61904 L
s
.56165 .28272 m
.55761 .29359 L
s
.37217 .6722 m
.36838 .68351 L
s
1 0 0 r
.31891 .62163 m
.33317 .63486 L
s
.50851 .71446 m
.52844 .71432 L
s
0 0 1 r
.61785 .30728 m
.60821 .31464 L
s
.33379 .63638 m
.32961 .64837 L
s
1 0 0 r
.37531 .67733 m
.39296 .68656 L
s
0 0 1 r
.64485 .32695 m
.63158 .32967 L
s
.43392 .70539 m
.43134 .71657 L
s
.54786 .27756 m
.54495 .2886 L
s
1 0 0 r
.52844 .71432 m
.54828 .71277 L
s
.63812 .66681 m
.65457 .66225 L
s
.64074 .66466 m
.65677 .66108 L
s
.61171 .68568 m
.62966 .67981 L
s
.35837 .66689 m
.37531 .67733 L
s
0 0 1 r
.61057 .30018 m
.6021 .30825 L
s
1 0 0 r
.59016 .69765 m
.60885 .69242 L
s
.6353 .67013 m
.65211 .66464 L
s
.643 .66376 m
.65854 .6612 L
s
.28876 .57024 m
.29989 .58548 L
s
.27529 .48631 m
.28237 .50181 L
s
0 0 1 r
.53286 .2733 m
.53102 .28441 L
s
.64261 .32166 m
.63026 .32538 L
s
.41698 .70145 m
.41408 .71239 L
s
.35718 .66473 m
.35349 .67599 L
s
1 0 0 r
.27675 .46364 m
.28294 .4788 L
s
.30568 .60744 m
.31891 .62163 L
s
.54828 .71277 m
.56794 .7098 L
s
.27516 .50907 m
.28315 .52482 L
s
.64472 .66416 m
.65969 .66265 L
s
.34224 .65528 m
.35837 .66689 L
s
.63244 .67451 m
.64956 .66815 L
s
0 0 1 r
.51684 .27013 m
.51597 .28121 L
s
1 0 0 r
.27952 .44119 m
.28486 .45591 L
s
0 0 1 r
.60165 .29294 m
.59436 .30162 L
s
.3211 .62772 m
.31725 .63988 L
s
.30285 .59743 m
.29866 .61055 L
s
1 0 0 r
.27635 .53177 m
.28528 .54767 L
s
0 0 1 r
.40029 .69641 m
.39721 .70714 L
s
1 0 0 r
.56794 .7098 m
.58731 .70543 L
s
0 0 1 r
.63897 .31544 m
.62761 .3201 L
s
.5 .26817 m
.5 .27914 L
s
.5 .72086 m
.5 .73183 L
s
1 0 0 r
.60885 .69242 m
.62706 .68586 L
s
.32703 .64253 m
.34224 .65528 L
s
.62966 .67981 m
.64704 .67264 L
s
0 0 1 r
.34296 .65672 m
.33947 .66801 L
s
.5911 .28581 m
.58501 .29499 L
s
1 0 0 r
.29357 .59236 m
.30568 .60744 L
s
.28361 .41911 m
.28812 .43329 L
s
0 0 1 r
.48333 .7217 m
.48258 .73251 L
s
1 0 0 r
.27885 .55428 m
.28876 .57024 L
s
.46442 .7199 m
.48451 .72251 L
s
.44456 .71583 m
.46442 .7199 L
s
.42506 .71033 m
.44456 .71583 L
s
0 0 1 r
.38403 .69038 m
.38091 .70096 L
s
1 0 0 r
.48451 .72251 m
.50474 .72366 L
s
0 0 1 r
.6594 .33054 m
.64583 .33114 L
s
1 0 0 r
.58731 .70543 m
.60627 .69965 L
s
0 0 1 r
.63381 .30846 m
.62351 .314 L
s
1 0 0 r
.40601 .70342 m
.42506 .71033 L
s
.50474 .72366 m
.52499 .72333 L
s
0 0 1 r
.46618 .72127 m
.4648 .73187 L
s
.57899 .27906 m
.57408 .28861 L
s
1 0 0 r
.38753 .69514 m
.40601 .70342 L
s
.65457 .66225 m
.67039 .65648 L
s
.31282 .62872 m
.32703 .64253 L
s
.65211 .66464 m
.66828 .65792 L
s
.52499 .72333 m
.54516 .72151 L
s
0 0 1 r
.30938 .61904 m
.30593 .63148 L
s
1 0 0 r
.65677 .66108 m
.67217 .65632 L
s
.2685 .49291 m
.27516 .50907 L
s
.64956 .66815 m
.66601 .66053 L
s
.26955 .47053 m
.27529 .48631 L
s
.62706 .68586 m
.64467 .67796 L
s
.36972 .68553 m
.38753 .69514 L
s
0 0 1 r
.44877 .71955 m
.44691 .72991 L
s
.65758 .32531 m
.64485 .32695 L
s
.36838 .68351 m
.36534 .694 L
s
.56542 .27292 m
.56165 .28272 L
s
.62704 .30095 m
.61785 .30728 L
s
1 0 0 r
.26873 .51534 m
.27635 .53177 L
s
0 0 1 r
.32961 .64837 m
.32645 .65979 L
s
1 0 0 r
.54516 .72151 m
.56512 .7182 L
s
.65854 .6612 m
.67345 .65748 L
s
.28268 .57645 m
.29357 .59236 L
s
.60627 .69965 m
.62471 .69248 L
s
.27189 .44832 m
.27675 .46364 L
s
.35267 .67463 m
.36972 .68553 L
s
.64704 .67264 m
.66373 .66419 L
s
.29972 .6139 m
.31282 .62872 L
s
0 0 1 r
.43134 .71657 m
.42912 .72669 L
s
.55055 .26761 m
.54786 .27756 L
s
1 0 0 r
.27026 .53768 m
.27885 .55428 L
s
.56512 .7182 m
.58477 .71342 L
s
.65969 .66265 m
.67403 .65999 L
s
.27552 .42644 m
.27952 .44119 L
s
0 0 1 r
.65443 .31903 m
.64261 .32166 L
s
.61861 .29316 m
.61057 .30018 L
s
1 0 0 r
.3365 .66248 m
.35267 .67463 L
s
0 0 1 r
.35349 .67599 m
.35065 .68647 L
s
.53455 .26332 m
.53286 .2733 L
s
.41408 .71239 m
.41166 .7223 L
s
1 0 0 r
.64467 .67796 m
.66156 .66875 L
s
.62471 .69248 m
.64254 .68393 L
s
.58477 .71342 m
.604 .70717 L
s
0 0 1 r
.29866 .61055 m
.29571 .62337 L
s
.31725 .63988 m
.3145 .65153 L
s
1 0 0 r
.27308 .55978 m
.28268 .57645 L
s
.28781 .59814 m
.29972 .6139 L
s
0 0 1 r
.51762 .2602 m
.51684 .27013 L
s
1 0 0 r
.32131 .64915 m
.3365 .66248 L
s
0 0 1 r
.60851 .28534 m
.60165 .29294 L
s
1 0 0 r
.66828 .65792 m
.68368 .64997 L
s
.66601 .66053 m
.68168 .65166 L
s
.28043 .40503 m
.28361 .41911 L
s
0 0 1 r
.6498 .31187 m
.63897 .31544 L
s
.39721 .70714 m
.39472 .71688 L
s
1 0 0 r
.67039 .65648 m
.68545 .64951 L
s
.26325 .47642 m
.2685 .49291 L
s
.26253 .49846 m
.26873 .51534 L
s
.604 .70717 m
.62268 .69947 L
s
0 0 1 r
.5 .25836 m
.5 .26817 L
s
.5 .73183 m
.5 .74164 L
s
1 0 0 r
.66373 .66419 m
.67962 .65447 L
s
.46028 .72867 m
.48069 .73136 L
s
.44012 .72445 m
.46028 .72867 L
s
.48069 .73136 m
.50125 .73249 L
s
.42035 .71871 m
.44012 .72445 L
s
.26522 .45453 m
.26955 .47053 L
s
0 0 1 r
.33947 .66801 m
.33696 .67857 L
s
1 0 0 r
.50125 .73249 m
.52184 .73206 L
s
.67217 .65632 m
.68684 .65036 L
s
0 0 1 r
.67233 .33107 m
.6594 .33054 L
s
1 0 0 r
.64254 .68393 m
.65962 .67403 L
s
0 0 1 r
.5968 .27776 m
.5911 .28581 L
s
1 0 0 r
.30719 .6347 m
.32131 .64915 L
s
.40107 .71149 m
.42035 .71871 L
s
.26307 .52051 m
.27026 .53768 L
s
.52184 .73206 m
.54233 .73006 L
s
0 0 1 r
.48258 .73251 m
.48192 .74214 L
s
1 0 0 r
.38239 .70282 m
.40107 .71149 L
s
0 0 1 r
.38091 .70096 m
.37848 .71057 L
s
1 0 0 r
.66156 .66875 m
.67764 .65824 L
s
0 0 1 r
.64358 .30403 m
.63381 .30846 L
s
1 0 0 r
.27718 .5815 m
.28781 .59814 L
s
.26846 .43292 m
.27189 .44832 L
s
.54233 .73006 m
.56262 .72651 L
s
.62268 .69947 m
.64071 .69035 L
s
.67345 .65748 m
.68763 .65256 L
s
0 0 1 r
.30593 .63148 m
.30369 .64345 L
s
1 0 0 r
.36443 .69274 m
.38239 .70282 L
s
0 0 1 r
.4648 .73187 m
.46362 .74128 L
s
.58355 .27066 m
.57899 .27906 L
s
1 0 0 r
.26487 .54243 m
.27308 .55978 L
s
.56262 .72651 m
.58257 .7214 L
s
.29424 .61919 m
.30719 .6347 L
s
0 0 1 r
.66968 .32481 m
.65758 .32531 L
s
1 0 0 r
.3473 .6813 m
.36443 .69274 L
s
0 0 1 r
.32645 .65979 m
.32436 .67052 L
s
.44691 .72991 m
.44534 .73909 L
s
.6357 .29576 m
.62704 .30095 L
s
1 0 0 r
.65962 .67403 m
.67584 .6628 L
s
0 0 1 r
.36534 .694 m
.36311 .70356 L
s
1 0 0 r
.27295 .41175 m
.27552 .42644 L
s
.58257 .7214 m
.60207 .71476 L
s
0 0 1 r
.56889 .2643 m
.56542 .27292 L
s
1 0 0 r
.67403 .65999 m
.68764 .65614 L
s
.68168 .65166 m
.69645 .64156 L
s
.64071 .69035 m
.65796 .67983 L
s
.67962 .65447 m
.6946 .6435 L
s
.33111 .66856 m
.3473 .6813 L
s
.68368 .64997 m
.6982 .6408 L
s
.26793 .56408 m
.27718 .5815 L
s
.25781 .4812 m
.26253 .49846 L
s
0 0 1 r
.42912 .72669 m
.42732 .73565 L
s
1 0 0 r
.60207 .71476 m
.62099 .70662 L
s
.28256 .6027 m
.29424 .61919 L
s
.25736 .50285 m
.26307 .52051 L
s
0 0 1 r
.553 .25888 m
.55055 .26761 L
s
1 0 0 r
.67764 .65824 m
.69277 .64646 L
s
0 0 1 r
.66561 .31755 m
.65443 .31903 L
s
1 0 0 r
.25949 .45968 m
.26325 .47642 L
s
.68545 .64951 m
.69965 .64131 L
s
0 0 1 r
.62614 .2873 m
.61861 .29316 L
s
1 0 0 r
.31597 .65459 m
.33111 .66856 L
s
0 0 1 r
.29571 .62337 m
.29406 .63578 L
s
.35065 .68647 m
.34874 .69607 L
s
1 0 0 r
.25814 .52448 m
.26487 .54243 L
s
.2624 .43841 m
.26522 .45453 L
s
0 0 1 r
.53607 .25458 m
.53455 .26332 L
s
.41166 .7223 m
.40976 .73106 L
s
1 0 0 r
.27867 .39116 m
.28043 .40503 L
s
.65796 .67983 m
.67433 .66797 L
s
.62099 .70662 m
.63923 .69701 L
s
0 0 1 r
.3145 .65153 m
.31294 .66255 L
s
1 0 0 r
.67584 .6628 m
.6911 .6503 L
s
.68684 .65036 m
.70064 .64318 L
s
.30197 .63945 m
.31597 .65459 L
s
0 0 1 r
.51832 .25154 m
.51762 .2602 L
s
1 0 0 r
.27224 .58532 m
.28256 .6027 L
s
0 0 1 r
.65999 .30947 m
.6498 .31187 L
s
.6149 .27894 m
.60851 .28534 L
s
1 0 0 r
.4771 .73953 m
.49801 .74073 L
s
.45636 .73668 m
.4771 .73953 L
s
.4359 .73222 m
.45636 .73668 L
s
.49801 .74073 m
.51894 .74029 L
s
.26014 .54596 m
.26793 .56408 L
s
.41585 .72617 m
.4359 .73222 L
s
.51894 .74029 m
.53978 .73821 L
s
.26653 .41753 m
.26846 .43292 L
s
0 0 1 r
.39472 .71688 m
.39287 .72548 L
s
1 0 0 r
.63923 .69701 m
.65665 .68596 L
s
.39634 .71855 m
.41585 .72617 L
s
0 0 1 r
.68453 .3328 m
.67233 .33107 L
s
1 0 0 r
.53978 .73821 m
.5604 .73449 L
s
0 0 1 r
.5 .24984 m
.5 .25836 L
s
.5 .74164 m
.5 .75016 L
s
1 0 0 r
.6946 .6435 m
.70854 .6313 L
s
0 0 1 r
.33696 .67857 m
.33548 .6883 L
s
1 0 0 r
.68763 .65256 m
.70095 .64644 L
s
.37748 .70941 m
.39634 .71855 L
s
.67433 .66797 m
.68968 .65481 L
s
.69277 .64646 m
.70684 .63346 L
s
.5604 .73449 m
.58066 .72915 L
s
.69645 .64156 m
.71021 .63024 L
s
.28921 .62323 m
.30197 .63945 L
s
0 0 1 r
.60205 .27093 m
.5968 .27776 L
s
1 0 0 r
.3594 .6988 m
.37748 .70941 L
s
.25321 .48481 m
.25736 .50285 L
s
0 0 1 r
.48192 .74214 m
.48136 .75046 L
s
1 0 0 r
.25467 .46368 m
.25781 .4812 L
s
.58066 .72915 m
.60045 .72221 L
s
0 0 1 r
.65273 .3008 m
.64358 .30403 L
s
1 0 0 r
.25295 .50604 m
.25814 .52448 L
s
0 0 1 r
.37848 .71057 m
.37681 .71909 L
s
1 0 0 r
.6982 .6408 m
.71171 .63041 L
s
.6911 .6503 m
.70526 .63656 L
s
0 0 1 r
.30369 .64345 m
.30274 .65486 L
s
1 0 0 r
.65665 .68596 m
.67314 .67354 L
s
.26337 .56714 m
.27224 .58532 L
s
.34221 .68678 m
.3594 .6988 L
s
.27187 .39721 m
.27295 .41175 L
s
.60045 .72221 m
.61964 .71371 L
s
.25732 .44278 m
.25949 .45968 L
s
0 0 1 r
.68104 .32553 m
.66968 .32481 L
s
.46362 .74128 m
.46264 .74938 L
s
.58771 .26353 m
.58355 .27066 L
s
1 0 0 r
.68764 .65614 m
.70039 .65107 L
s
.2778 .60601 m
.28921 .62323 L
s
.25389 .52723 m
.26014 .54596 L
s
.32603 .67341 m
.34221 .68678 L
s
.69965 .64131 m
.71286 .6319 L
s
0 0 1 r
.32436 .67052 m
.32342 .68048 L
s
1 0 0 r
.68968 .65481 m
.70392 .64041 L
s
.61964 .71371 m
.63809 .70369 L
s
.67314 .67354 m
.68859 .6598 L
s
0 0 1 r
.64376 .29179 m
.6357 .29576 L
s
.44534 .73909 m
.44409 .74696 L
s
.36311 .70356 m
.36176 .71207 L
s
1 0 0 r
.26116 .42226 m
.2624 .43841 L
s
0 0 1 r
.57202 .25699 m
.56889 .2643 L
s
1 0 0 r
.31096 .65876 m
.32603 .67341 L
s
.25603 .54825 m
.26337 .56714 L
s
.63809 .70369 m
.65569 .69219 L
s
.70684 .63346 m
.71974 .61929 L
s
.26782 .58788 m
.2778 .60601 L
s
0 0 1 r
.67606 .3173 m
.66561 .31755 L
s
1 0 0 r
.70854 .6313 m
.72132 .61793 L
s
.70064 .64318 m
.71345 .63478 L
s
.70526 .63656 m
.71823 .62165 L
s
0 0 1 r
.42732 .73565 m
.42595 .7433 L
s
1 0 0 r
.27841 .37758 m
.27867 .39116 L
s
0 0 1 r
.29406 .63578 m
.2938 .64768 L
s
1 0 0 r
.29711 .64292 m
.31096 .65876 L
s
0 0 1 r
.55517 .25149 m
.553 .25888 L
s
1 0 0 r
.2494 .4872 m
.25295 .50604 L
s
.68859 .6598 m
.70288 .64481 L
s
.2507 .46648 m
.25321 .48481 L
s
0 0 1 r
.63308 .28271 m
.62614 .2873 L
s
1 0 0 r
.71021 .63024 m
.72283 .61773 L
s
.65569 .69219 m
.67233 .67929 L
s
.70392 .64041 m
.71692 .62483 L
s
.26619 .40225 m
.26653 .41753 L
s
.24926 .50801 m
.25389 .52723 L
s
0 0 1 r
.34874 .69607 m
.34782 .70466 L
s
.31294 .66255 m
.31264 .67284 L
s
1 0 0 r
.25317 .44598 m
.25467 .46368 L
s
0 0 1 r
.53739 .24722 m
.53607 .25458 L
s
.40976 .73106 m
.40842 .73854 L
s
1 0 0 r
.28459 .62598 m
.29711 .64292 L
s
.47367 .74682 m
.49493 .74819 L
s
.45259 .74375 m
.47367 .74682 L
s
.49493 .74819 m
.51623 .74782 L
s
.25936 .56895 m
.26782 .58788 L
s
.43183 .73897 m
.45259 .74375 L
s
.51623 .74782 m
.53744 .74574 L
s
.41151 .73253 m
.43183 .73897 L
s
.53744 .74574 m
.55841 .74193 L
s
.70095 .64644 m
.71328 .63907 L
s
.71171 .63041 m
.7241 .61882 L
s
.67233 .67929 m
.68787 .66505 L
s
.2503 .52877 m
.25603 .54825 L
s
0 0 1 r
.66945 .30833 m
.65999 .30947 L
s
1 0 0 r
.39178 .72446 m
.41151 .73253 L
s
.55841 .74193 m
.57902 .73644 L
s
0 0 1 r
.69587 .33578 m
.68453 .3328 L
s
.62073 .27384 m
.6149 .27894 L
s
.51892 .24428 m
.51832 .25154 L
s
1 0 0 r
.37275 .7148 m
.39178 .72446 L
s
.70288 .64481 m
.7159 .62864 L
s
.57902 .73644 m
.59912 .72929 L
s
.2568 .42583 m
.25732 .44278 L
s
.27348 .60804 m
.28459 .62598 L
s
0 0 1 r
.39287 .72548 m
.3917 .73284 L
s
1 0 0 r
.35457 .70361 m
.37275 .7148 L
s
.59912 .72929 m
.61858 .72051 L
s
.71823 .62165 m
.72987 .60563 L
s
.71974 .61929 m
.73133 .60399 L
s
0 0 1 r
.33548 .6883 m
.33512 .69707 L
s
1 0 0 r
.68787 .66505 m
.70221 .64955 L
s
0 0 1 r
.5 .24276 m
.5 .24984 L
s
.5 .75016 m
.5 .75724 L
s
1 0 0 r
.27238 .38292 m
.27187 .39721 L
s
.33734 .69097 m
.35457 .70361 L
s
.71692 .62483 m
.72857 .60816 L
s
.2525 .54933 m
.25936 .56895 L
s
.61858 .72051 m
.63728 .71016 L
s
.71286 .6319 m
.72494 .62127 L
s
0 0 1 r
.60679 .26545 m
.60205 .27093 L
s
1 0 0 r
.72132 .61793 m
.73282 .60342 L
s
0 0 1 r
.30274 .65486 m
.30316 .66561 L
s
1 0 0 r
.3212 .67695 m
.33734 .69097 L
s
.24632 .48841 m
.24926 .50801 L
s
.24754 .46808 m
.2494 .4872 L
s
.70039 .65107 m
.71216 .64475 L
s
.26388 .5892 m
.27348 .60804 L
s
0 0 1 r
.66115 .29886 m
.65273 .3008 L
s
1 0 0 r
.63728 .71016 m
.65509 .6983 L
s
0 0 1 r
.48136 .75046 m
.4809 .75734 L
s
1 0 0 r
.26159 .40619 m
.26116 .42226 L
s
.7159 .62864 m
.72754 .61139 L
s
0 0 1 r
.37681 .71909 m
.37595 .72639 L
s
1 0 0 r
.24625 .5088 m
.2503 .52877 L
s
0 0 1 r
.69155 .32751 m
.68104 .32553 L
s
1 0 0 r
.70221 .64955 m
.71524 .63287 L
s
.2499 .44798 m
.2507 .46648 L
s
.30624 .66162 m
.3212 .67695 L
s
.65509 .6983 m
.67187 .68499 L
s
.72283 .61773 m
.73418 .60407 L
s
0 0 1 r
.46264 .74938 m
.46189 .75603 L
s
.59141 .2578 m
.58771 .26353 L
s
1 0 0 r
.29259 .64509 m
.30624 .66162 L
s
.24731 .52914 m
.2525 .54933 L
s
.25586 .56957 m
.26388 .5892 L
s
.71345 .63478 m
.72514 .62515 L
s
0 0 1 r
.32342 .68048 m
.32372 .68954 L
s
1 0 0 r
.67187 .68499 m
.68752 .67033 L
s
.2534 .42822 m
.25317 .44598 L
s
.72857 .60816 m
.73878 .59048 L
s
.71524 .63287 m
.72686 .61511 L
s
.72987 .60563 m
.74009 .58858 L
s
0 0 1 r
.65111 .28916 m
.64376 .29179 L
s
1 0 0 r
.28033 .62746 m
.29259 .64509 L
s
0 0 1 r
.36176 .71207 m
.36134 .71941 L
s
1 0 0 r
.27973 .3644 m
.27841 .37758 L
s
0 0 1 r
.44409 .74696 m
.44319 .75339 L
s
1 0 0 r
.68752 .67033 m
.70193 .65439 L
s
.72754 .61139 m
.73771 .59316 L
s
.26751 .38719 m
.26619 .40225 L
s
0 0 1 r
.57475 .25111 m
.57202 .25699 L
s
.2938 .64768 m
.29502 .65898 L
s
1 0 0 r
.73133 .60399 m
.74152 .58764 L
s
.7241 .61882 m
.73523 .60606 L
s
0 0 1 r
.68565 .31835 m
.67606 .3173 L
s
1 0 0 r
.24951 .54929 m
.25586 .56957 L
s
.24394 .48849 m
.24625 .5088 L
s
.24514 .46854 m
.24632 .48841 L
s
.26957 .60884 m
.28033 .62746 L
s
.70193 .65439 m
.71497 .63728 L
s
.25801 .40895 m
.2568 .42583 L
s
0 0 1 r
.42595 .7433 m
.42505 .74953 L
s
1 0 0 r
.24386 .50851 m
.24731 .52914 L
s
.72686 .61511 m
.73696 .59639 L
s
.24746 .4488 m
.24754 .46808 L
s
0 0 1 r
.55704 .24559 m
.55517 .25149 L
s
1 0 0 r
.71328 .63907 m
.7245 .63046 L
s
.73282 .60342 m
.74293 .58784 L
s
.49195 .75466 m
.51363 .75444 L
s
.47032 .75307 m
.49195 .75466 L
s
0 0 1 r
.63935 .2795 m
.63308 .28271 L
s
1 0 0 r
.44889 .74969 m
.47032 .75307 L
s
.51363 .75444 m
.53523 .75243 L
s
.26038 .58934 m
.26957 .60884 L
s
.42782 .74454 m
.44889 .74969 L
s
.53523 .75243 m
.55659 .74863 L
s
0 0 1 r
.31264 .67284 m
.31368 .6823 L
s
1 0 0 r
.40724 .73766 m
.42782 .74454 L
s
.55659 .74863 m
.57756 .74306 L
s
0 0 1 r
.34782 .70466 m
.34797 .71213 L
s
1 0 0 r
.71497 .63728 m
.72656 .6191 L
s
.3873 .72908 m
.40724 .73766 L
s
.57756 .74306 m
.59801 .73577 L
s
.24489 .52848 m
.24951 .54929 L
s
.36814 .71887 m
.3873 .72908 L
s
.73771 .59316 m
.7463 .57404 L
s
.59801 .73577 m
.61778 .72679 L
s
.73878 .59048 m
.74743 .57189 L
s
.25088 .42942 m
.2499 .44798 L
s
0 0 1 r
.40842 .73854 m
.40768 .74461 L
s
1 0 0 r
.34988 .70709 m
.36814 .71887 L
s
0 0 1 r
.5385 .24137 m
.53739 .24722 L
s
1 0 0 r
.72494 .62127 m
.73576 .60946 L
s
.61778 .72679 m
.63675 .7162 L
s
0 0 1 r
.70622 .34006 m
.69587 .33578 L
s
1 0 0 r
.25285 .56911 m
.26038 .58934 L
s
.33265 .69382 m
.34988 .70709 L
s
.63675 .7162 m
.65479 .70405 L
s
.73696 .59639 m
.74547 .57682 L
s
0 0 1 r
.67807 .30853 m
.66945 .30833 L
s
1 0 0 r
.74009 .58858 m
.74877 .5706 L
s
.72656 .6191 m
.7366 .59996 L
s
.27455 .36899 m
.27238 .38292 L
s
.31658 .67915 m
.33265 .69382 L
s
.65479 .70405 m
.67176 .69042 L
s
.26374 .39031 m
.26159 .40619 L
s
.73418 .60407 m
.74414 .58932 L
s
.24219 .48757 m
.24386 .50851 L
s
.24343 .46795 m
.24394 .48849 L
s
0 0 1 r
.62593 .27018 m
.62073 .27384 L
s
1 0 0 r
.30178 .66317 m
.31658 .67915 L
s
0 0 1 r
.5194 .23857 m
.51892 .24428 L
s
1 0 0 r
.67176 .69042 m
.68754 .67541 L
s
.24704 .54826 m
.25285 .56911 L
s
.24205 .50728 m
.24489 .52848 L
s
.28836 .64599 m
.30178 .66317 L
s
.68754 .67541 m
.70202 .65911 L
s
.24577 .44854 m
.24514 .46854 L
s
0 0 1 r
.3917 .73284 m
.39126 .73882 L
s
1 0 0 r
.71216 .64475 m
.7228 .63716 L
s
.2554 .41052 m
.2534 .42822 L
s
.7366 .59996 m
.74502 .58001 L
s
.74152 .58764 m
.75018 .57033 L
s
0 0 1 r
.33512 .69707 m
.33594 .70477 L
s
1 0 0 r
.27642 .62773 m
.28836 .64599 L
s
.70202 .65911 m
.7151 .64164 L
s
.7463 .57404 m
.75323 .55416 L
s
.74547 .57682 m
.7523 .55651 L
s
0 0 1 r
.30316 .66561 m
.30503 .67557 L
s
.5 .23724 m
.5 .24276 L
s
.5 .75724 m
.5 .76276 L
s
1 0 0 r
.26605 .6085 m
.27642 .62773 L
s
.243 .52694 m
.24704 .54826 L
s
.7151 .64164 m
.72667 .6231 L
s
.72514 .62515 m
.73558 .61431 L
s
.74743 .57189 m
.75443 .55251 L
s
.24919 .42949 m
.24746 .4488 L
s
0 0 1 r
.61096 .26146 m
.60679 .26545 L
s
.66875 .29831 m
.66115 .29886 L
s
1 0 0 r
.74502 .58001 m
.75172 .55936 L
s
0 0 1 r
.70107 .33083 m
.69155 .32751 L
s
1 0 0 r
.25731 .58845 m
.26605 .6085 L
s
.72667 .6231 m
.73666 .60364 L
s
.73523 .60606 m
.74496 .59217 L
s
0 0 1 r
.4809 .75734 m
.48057 .76263 L
s
1 0 0 r
.24103 .48583 m
.24205 .50728 L
s
.24236 .46646 m
.24219 .48757 L
s
0 0 1 r
.37595 .72639 m
.37596 .73235 L
s
1 0 0 r
.2503 .5677 m
.25731 .58845 L
s
.74293 .58784 m
.75151 .57126 L
s
.73666 .60364 m
.74497 .58338 L
s
.24078 .50529 m
.243 .52694 L
s
.27056 .37246 m
.26751 .38719 L
s
.7523 .55651 m
.75737 .53561 L
s
.26101 .39225 m
.25801 .40895 L
s
.24477 .44733 m
.24343 .46795 L
s
.74877 .5706 m
.75581 .55177 L
s
.75172 .55936 m
.75666 .53815 L
s
.2827 .35174 m
.27973 .3644 L
s
.24505 .54641 m
.2503 .5677 L
s
.74497 .58338 m
.75156 .56245 L
s
0 0 1 r
.32372 .68954 m
.32531 .69759 L
s
.46189 .75603 m
.46138 .76109 L
s
.5946 .2536 m
.59141 .2578 L
s
1 0 0 r
.25369 .41093 m
.25088 .42942 L
s
.75323 .55416 m
.75841 .53364 L
s
.24162 .52472 m
.24505 .54641 L
s
.75156 .56245 m
.75635 .54102 L
s
.24042 .48347 m
.24078 .50529 L
s
.24187 .46428 m
.24103 .48583 L
s
.24824 .42856 m
.24577 .44854 L
s
0 0 1 r
.65767 .28796 m
.65111 .28916 L
s
.29502 .65898 m
.29778 .66954 L
s
1 0 0 r
.75666 .53815 m
.75978 .51654 L
s
0 0 1 r
.36134 .71941 m
.36192 .72545 L
s
1 0 0 r
.24004 .50278 m
.24162 .52472 L
s
.75635 .54102 m
.75932 .51922 L
s
.7245 .63046 m
.73445 .6206 L
s
0 0 1 r
.44319 .75339 m
.44267 .75823 L
s
.69427 .32078 m
.68565 .31835 L
s
1 0 0 r
.75443 .55251 m
.7597 .53244 L
s
.2444 .44534 m
.24236 .46646 L
s
.75737 .53561 m
.76063 .51426 L
s
0 0 1 r
.57706 .24682 m
.57475 .25111 L
s
1 0 0 r
.75018 .57033 m
.7572 .55214 L
s
.73576 .60946 m
.74519 .59648 L
s
.74414 .58932 m
.75257 .57352 L
s
.24033 .48075 m
.24004 .50278 L
s
.75932 .51922 m
.76042 .49721 L
s
.24193 .46164 m
.24042 .48347 L
s
.76021 .5 m
.75927 .47793 L
s
.75927 .52207 m
.76021 .5 L
s
.75647 .54398 m
.75927 .52207 L
s
.75927 .47793 m
.75647 .45602 L
s
.75181 .56557 m
.75647 .54398 L
s
.75647 .45602 m
.75181 .43443 L
s
.74534 .58669 m
.75181 .56557 L
s
.75181 .43443 m
.74534 .41331 L
s
.73711 .60718 m
.74534 .58669 L
s
.74534 .41331 m
.73711 .39282 L
s
.72717 .6269 m
.73711 .60718 L
s
.73711 .39282 m
.72717 .3731 L
s
.71559 .64571 m
.72717 .6269 L
s
.72717 .3731 m
.71559 .35429 L
s
.70245 .66347 m
.71559 .64571 L
s
.71559 .35429 m
.70245 .33653 L
s
.68786 .68005 m
.70245 .66347 L
s
.70245 .33653 m
.68786 .31995 L
s
.67191 .69533 m
.68786 .68005 L
s
.68786 .31995 m
.67191 .30467 L
s
.65473 .70921 m
.67191 .69533 L
s
.67191 .30467 m
.65473 .29079 L
s
.63643 .72157 m
.65473 .70921 L
s
.65473 .29079 m
.63643 .27843 L
s
.61715 .73235 m
.63643 .72157 L
s
.63643 .27843 m
.61715 .26765 L
s
.59702 .74144 m
.61715 .73235 L
s
.61715 .26765 m
.59702 .25856 L
s
.57619 .7488 m
.59702 .74144 L
s
.59702 .25856 m
.57619 .2512 L
s
.55482 .75437 m
.57619 .7488 L
s
.57619 .2512 m
.55482 .24563 L
s
.53305 .7581 m
.55482 .75437 L
s
.55482 .24563 m
.53305 .2419 L
s
.51104 .75997 m
.53305 .7581 L
s
.53305 .2419 m
.51104 .24003 L
s
.48896 .75997 m
.51104 .75997 L
s
.51104 .24003 m
.48896 .24003 L
s
.46695 .7581 m
.48896 .75997 L
s
.48896 .24003 m
.46695 .2419 L
s
.44518 .75437 m
.46695 .7581 L
s
.46695 .2419 m
.44518 .24563 L
s
.42381 .7488 m
.44518 .75437 L
s
.44518 .24563 m
.42381 .2512 L
s
.40298 .74144 m
.42381 .7488 L
s
.42381 .2512 m
.40298 .25856 L
s
.38285 .73235 m
.40298 .74144 L
s
.40298 .25856 m
.38285 .26765 L
s
.36357 .72157 m
.38285 .73235 L
s
.38285 .26765 m
.36357 .27843 L
s
.34527 .70921 m
.36357 .72157 L
s
.36357 .27843 m
.34527 .29079 L
s
.32809 .69533 m
.34527 .70921 L
s
.34527 .29079 m
.32809 .30467 L
s
.31214 .68005 m
.32809 .69533 L
s
.32809 .30467 m
.31214 .31995 L
s
.29755 .66347 m
.31214 .68005 L
s
.31214 .31995 m
.29755 .33653 L
s
.28441 .64571 m
.29755 .66347 L
s
.29755 .33653 m
.28441 .35429 L
s
.27283 .6269 m
.28441 .64571 L
s
.28441 .35429 m
.27283 .3731 L
s
.26289 .60718 m
.27283 .6269 L
s
.27283 .3731 m
.26289 .39282 L
s
.25466 .58669 m
.26289 .60718 L
s
.26289 .39282 m
.25466 .41331 L
s
.24819 .56557 m
.25466 .58669 L
s
.25466 .41331 m
.24819 .43443 L
s
.24353 .54398 m
.24819 .56557 L
s
.24819 .43443 m
.24353 .45602 L
s
.24073 .52207 m
.24353 .54398 L
s
.24353 .45602 m
.24073 .47793 L
s
.23979 .5 m
.24073 .52207 L
s
.24073 .47793 m
.23979 .5 L
s
.75978 .51654 m
.76105 .49467 L
s
.24249 .4588 m
.24033 .48075 L
s
.76042 .49721 m
.75965 .47516 L
s
.25925 .39301 m
.2554 .41052 L
s
.26769 .37475 m
.26374 .39031 L
s
.25278 .41029 m
.24919 .42949 L
s
0 0 1 r
.42505 .74953 m
.42467 .75419 L
s
1 0 0 r
.2446 .44279 m
.24187 .46428 L
s
.75841 .53364 m
.76179 .51262 L
s
.24798 .42677 m
.24477 .44733 L
s
0 0 1 r
.31368 .6823 m
.31614 .6908 L
s
.55857 .24131 m
.55704 .24559 L
s
1 0 0 r
.27846 .35554 m
.27455 .36899 L
s
.24652 .43707 m
.24249 .4588 L
s
.75965 .47516 m
.75699 .45322 L
s
0 0 1 r
.64486 .27778 m
.63935 .2795 L
s
1 0 0 r
.24532 .43995 m
.24193 .46164 L
s
0 0 1 r
.71546 .34568 m
.70622 .34006 L
s
.34797 .71213 m
.34924 .71835 L
s
1 0 0 r
.75581 .55177 m
.76111 .53223 L
s
.76063 .51426 m
.76203 .49261 L
s
.76105 .49467 m
.76042 .47271 L
s
.25241 .41573 m
.24652 .43707 L
s
.75699 .45322 m
.75247 .43155 L
s
.24832 .42434 m
.2444 .44534 L
s
.75151 .57126 m
.75845 .55376 L
s
0 0 1 r
.40768 .74461 m
.4076 .74913 L
s
.53937 .23719 m
.5385 .24137 L
s
.68573 .31016 m
.67807 .30853 L
s
1 0 0 r
.2601 .39494 m
.25241 .41573 L
s
.75247 .43155 m
.7461 .41031 L
s
.7228 .63716 m
.73219 .62828 L
s
.25058 .41856 m
.24532 .43995 L
s
.25261 .40873 m
.24824 .42856 L
s
.7597 .53244 m
.76315 .51183 L
s
.74496 .59217 m
.75317 .57721 L
s
.24921 .42152 m
.2446 .44279 L
s
.73558 .61431 m
.74462 .60226 L
s
.76042 .47271 m
.7579 .4508 L
s
.26956 .37485 m
.2601 .39494 L
s
.25837 .39266 m
.25369 .41093 L
s
.7461 .41031 m
.73792 .38965 L
s
0 0 1 r
.63042 .26805 m
.62593 .27018 L
s
1 0 0 r
.76179 .51262 m
.76329 .49125 L
s
.76203 .49261 m
.76153 .4708 L
s
0 0 1 r
.51976 .23456 m
.5194 .23857 L
s
1 0 0 r
.26586 .37586 m
.26101 .39225 L
s
.28073 .35562 m
.26956 .37485 L
s
.73792 .38965 m
.72799 .36975 L
s
0 0 1 r
.30503 .67557 m
.30842 .68462 L
s
1 0 0 r
.25769 .39763 m
.25058 .41856 L
s
0 0 1 r
.33594 .70477 m
.33801 .71128 L
s
.39126 .73882 m
.39162 .74328 L
s
1 0 0 r
.7572 .55214 m
.76248 .53318 L
s
.25309 .40644 m
.24798 .42677 L
s
.27541 .35819 m
.27056 .37246 L
s
.29352 .33738 m
.28073 .35562 L
s
.7579 .4508 m
.75348 .42912 L
s
.72799 .36975 m
.71638 .35074 L
s
0 0 1 r
.5 .23343 m
.5 .23724 L
s
.5 .76276 m
.5 .76657 L
s
.70948 .33554 m
.70107 .33083 L
s
1 0 0 r
.25569 .40062 m
.24921 .42152 L
s
.25414 .40365 m
.24832 .42434 L
s
.30785 .32028 m
.29352 .33738 L
s
.71638 .35074 m
.70315 .33277 L
s
0 0 1 r
.67542 .29923 m
.66875 .29831 L
s
1 0 0 r
.25828 .39134 m
.25278 .41029 L
s
.26662 .37732 m
.25769 .39763 L
s
.75257 .57352 m
.75936 .55677 L
s
.28739 .33972 m
.2827 .35174 L
s
0 0 1 r
.61448 .25906 m
.61096 .26146 L
s
1 0 0 r
.76111 .53223 m
.76458 .51209 L
s
.32362 .30446 m
.30785 .32028 L
s
.70315 .33277 m
.68841 .31598 L
s
.76153 .4708 m
.75911 .44901 L
s
.75348 .42912 m
.74718 .40784 L
s
.34071 .29002 m
.32362 .30446 L
s
0 0 1 r
.48057 .76263 m
.48037 .7662 L
s
1 0 0 r
.68841 .31598 m
.67226 .30049 L
s
0 0 1 r
.37596 .73235 m
.3769 .73684 L
s
1 0 0 r
.76315 .51183 m
.76472 .49082 L
s
.76329 .49125 m
.76288 .46968 L
s
.26498 .37583 m
.25925 .39301 L
s
.74519 .59648 m
.7531 .58239 L
s
.35901 .2771 m
.34071 .29002 L
s
.67226 .30049 m
.65481 .28644 L
s
.73445 .6206 m
.74301 .6095 L
s
.27731 .3578 m
.26662 .37732 L
s
.25888 .38921 m
.25261 .40873 L
s
0 0 1 r
.32531 .69759 m
.32828 .7045 L
s
1 0 0 r
.26403 .38026 m
.25569 .40062 L
s
.37836 .26579 m
.35901 .2771 L
s
.65481 .28644 m
.6362 .27392 L
s
.74718 .40784 m
.73903 .3871 L
s
0 0 1 r
.29778 .66954 m
.30216 .67925 L
s
1 0 0 r
.39864 .25617 m
.37836 .26579 L
s
.27349 .35964 m
.26769 .37475 L
s
0 0 1 r
.46138 .76109 m
.46114 .76442 L
s
1 0 0 r
.6362 .27392 m
.61657 .26305 L
s
0 0 1 r
.59723 .25105 m
.5946 .2536 L
s
1 0 0 r
.75845 .55376 m
.76364 .53545 L
s
.2601 .38648 m
.25309 .40644 L
s
.41969 .24833 m
.39864 .25617 L
s
.26184 .38341 m
.25414 .40365 L
s
.61657 .26305 m
.59605 .25389 L
s
.75911 .44901 m
.75476 .4274 L
s
.44136 .24232 m
.41969 .24833 L
s
.59605 .25389 m
.57481 .24654 L
s
.2897 .33921 m
.27731 .3578 L
s
0 0 1 r
.66332 .2883 m
.65767 .28796 L
s
1 0 0 r
.46347 .23821 m
.44136 .24232 L
s
.57481 .24654 m
.553 .24103 L
s
0 0 1 r
.70179 .32466 m
.69427 .32078 L
s
1 0 0 r
.48586 .23601 m
.46347 .23821 L
s
.553 .24103 m
.5308 .23743 L
s
.73903 .3871 m
.72907 .36708 L
s
.50836 .23575 m
.48586 .23601 L
s
.5308 .23743 m
.50836 .23575 L
s
0 0 1 r
.36192 .72545 m
.36356 .73006 L
s
1 0 0 r
.26496 .37476 m
.25837 .39266 L
s
.28415 .34271 m
.27846 .35554 L
s
0 0 1 r
.44267 .75823 m
.44256 .76134 L
s
1 0 0 r
.76248 .53318 m
.76592 .51358 L
s
.27419 .36061 m
.26403 .38026 L
s
.76288 .46968 m
.76052 .44807 L
s
0 0 1 r
.57889 .24424 m
.57706 .24682 L
s
1 0 0 r
.75317 .57721 m
.75973 .56124 L
s
.30371 .32171 m
.2897 .33921 L
s
.72907 .36708 m
.71738 .34794 L
s
.76458 .51209 m
.76616 .4915 L
s
.76472 .49082 m
.76435 .46955 L
s
.75476 .4274 m
.74849 .40613 L
s
0 0 1 r
.31614 .6908 m
.32007 .69822 L
s
1 0 0 r
.2726 .35993 m
.26586 .37586 L
s
.26569 .3728 m
.25828 .39134 L
s
0 0 1 r
.72344 .35268 m
.71546 .34568 L
s
.42467 .75419 m
.42484 .75713 L
s
1 0 0 r
.74462 .60226 m
.75212 .58906 L
s
.2714 .36379 m
.26184 .38341 L
s
.31924 .30543 m
.30371 .32171 L
s
0 0 1 r
.55972 .23878 m
.55857 .24131 L
s
1 0 0 r
.73219 .62828 m
.74017 .61811 L
s
0 0 1 r
.64952 .27765 m
.64486 .27778 L
s
1 0 0 r
.71738 .34794 m
.70401 .32982 L
s
0 0 1 r
.34924 .71835 m
.35171 .72319 L
s
1 0 0 r
.26707 .37015 m
.25888 .38921 L
s
.28611 .34181 m
.27419 .36061 L
s
.269 .36706 m
.2601 .38648 L
s
.75936 .55677 m
.76439 .53915 L
s
.33617 .29053 m
.31924 .30543 L
s
0 0 1 r
.69232 .31329 m
.68573 .31016 L
s
1 0 0 r
.28211 .34451 m
.27541 .35819 L
s
.74849 .40613 m
.74032 .38538 L
s
.76052 .44807 m
.75619 .42659 L
s
.70401 .32982 m
.68907 .31289 L
s
0 0 1 r
.4076 .74913 m
.40821 .75198 L
s
.53999 .23481 m
.53937 .23719 L
s
1 0 0 r
.27263 .35913 m
.26498 .37583 L
s
.3544 .27711 m
.33617 .29053 L
s
.68907 .31289 m
.67267 .29727 L
s
.76364 .53545 m
.76698 .51643 L
s
.29972 .32404 m
.28611 .34181 L
s
0 0 1 r
.30842 .68462 m
.3134 .69265 L
s
1 0 0 r
.76435 .46955 m
.76199 .44819 L
s
0 0 1 r
.63412 .2676 m
.63042 .26805 L
s
1 0 0 r
.28278 .34495 m
.2714 .36379 L
s
.7531 .58239 m
.75934 .56723 L
s
0 0 1 r
.51999 .23238 m
.51976 .23456 L
s
1 0 0 r
.37378 .2653 m
.3544 .27711 L
s
0 0 1 r
.33801 .71128 m
.3414 .71647 L
s
1 0 0 r
.74032 .38538 m
.73029 .36532 L
s
.29386 .32847 m
.28739 .33972 L
s
.76592 .51358 m
.76744 .49346 L
s
.76616 .4915 m
.76577 .47059 L
s
.67267 .29727 m
.65492 .2831 L
s
0 0 1 r
.71665 .34169 m
.70948 .33554 L
s
1 0 0 r
.27347 .35737 m
.26496 .37476 L
s
0 0 1 r
.39162 .74328 m
.39281 .74609 L
s
1 0 0 r
.28118 .34512 m
.27349 .35964 L
s
.39417 .2552 m
.37378 .2653 L
s
.75619 .42659 m
.7499 .40541 L
s
.27976 .34835 m
.269 .36706 L
s
.65492 .2831 m
.63595 .2705 L
s
.74301 .6095 m
.75003 .59718 L
s
0 0 1 r
.5 .23149 m
.5 .23343 L
s
.5 .76657 m
.5 .76851 L
s
1 0 0 r
.31493 .30745 m
.29972 .32404 L
s
0 0 1 r
.68104 .30172 m
.67542 .29923 L
s
1 0 0 r
.27501 .35483 m
.26569 .3728 L
s
.27715 .35174 m
.26707 .37015 L
s
.41541 .24689 m
.39417 .2552 L
s
.63595 .2705 m
.61592 .25958 L
s
0 0 1 r
.61728 .2584 m
.61448 .25906 L
s
1 0 0 r
.73029 .36532 m
.71846 .3461 L
s
.75973 .56124 m
.76452 .54435 L
s
.43733 .24045 m
.41541 .24689 L
s
.29591 .32707 m
.28278 .34495 L
s
.61592 .25958 m
.59498 .25043 L
s
0 0 1 r
.48037 .7662 m
.48031 .7679 L
s
.3769 .73684 m
.37882 .73972 L
s
.30216 .67925 m
.30823 .68798 L
s
1 0 0 r
.45977 .23594 m
.43733 .24045 L
s
.59498 .25043 m
.57328 .24312 L
s
0 0 1 r
.32828 .7045 m
.33268 .71014 L
s
1 0 0 r
.76199 .44819 m
.75763 .4269 L
s
.33164 .29217 m
.31493 .30745 L
s
.28125 .3446 m
.2726 .35993 L
s
.29168 .33062 m
.28415 .34271 L
s
.48254 .2334 m
.45977 .23594 L
s
.57328 .24312 m
.55101 .23773 L
s
.50546 .23285 m
.48254 .2334 L
s
.55101 .23773 m
.52834 .2343 L
s
.7499 .40541 m
.74166 .38471 L
s
.52834 .2343 m
.50546 .23285 L
s
.71846 .3461 m
.70491 .32791 L
s
0 0 1 r
.59923 .2503 m
.59723 .25105 L
s
.46114 .76442 m
.46119 .76588 L
s
1 0 0 r
.76439 .53915 m
.76755 .52076 L
s
0 0 1 r
.70808 .33003 m
.70179 .32466 L
s
.66798 .29027 m
.66332 .2883 L
s
1 0 0 r
.76577 .47059 m
.76336 .44954 L
s
.75212 .58906 m
.75796 .57473 L
s
.29235 .33052 m
.27976 .34835 L
s
.34974 .27836 m
.33164 .29217 L
s
.2822 .34306 m
.27263 .35913 L
s
0 0 1 r
.36356 .73006 m
.36633 .73312 L
s
1 0 0 r
.76698 .51643 m
.76837 .49684 L
s
.31073 .31029 m
.29591 .32707 L
s
.76744 .49346 m
.76696 .47298 L
s
0 0 1 r
.44256 .76134 m
.44288 .7626 L
s
1 0 0 r
.70491 .32791 m
.68972 .31089 L
s
0 0 1 r
.73003 .36109 m
.72344 .35268 L
s
1 0 0 r
.74017 .61811 m
.74661 .60667 L
s
0 0 1 r
.58019 .2435 m
.57889 .24424 L
s
1 0 0 r
.28909 .33412 m
.27715 .35174 L
s
.2907 .33156 m
.28211 .34451 L
s
.2839 .34065 m
.27347 .35737 L
s
0 0 1 r
.32007 .69822 m
.32556 .70442 L
s
1 0 0 r
.74166 .38471 m
.7315 .36466 L
s
.28624 .33759 m
.27501 .35483 L
s
.36908 .26613 m
.34974 .27836 L
s
.75763 .4269 m
.75126 .40587 L
s
.68972 .31089 m
.67301 .2952 L
s
0 0 1 r
.42484 .75713 m
.4256 .75823 L
s
1 0 0 r
.75934 .56723 m
.76379 .55109 L
s
0 0 1 r
.65323 .27924 m
.64952 .27765 L
s
.56046 .23816 m
.55972 .23878 L
s
.35171 .72319 m
.35542 .72653 L
s
1 0 0 r
.32713 .29478 m
.31073 .31029 L
s
.38952 .2556 m
.36908 .26613 L
s
.30668 .31372 m
.29235 .33052 L
s
0 0 1 r
.6977 .31798 m
.69232 .31329 L
s
1 0 0 r
.29079 .33134 m
.28118 .34512 L
s
.67301 .2952 m
.6549 .28097 L
s
.76336 .44954 m
.75891 .42851 L
s
.7315 .36466 m
.71949 .34544 L
s
.30216 .31813 m
.29386 .32847 L
s
0 0 1 r
.40821 .75198 m
.40955 .75299 L
s
.54032 .23437 m
.53999 .23481 L
s
.3134 .69265 m
.32002 .69952 L
s
1 0 0 r
.76452 .54435 m
.76741 .52664 L
s
.41089 .24687 m
.38952 .2556 L
s
.75003 .59718 m
.75537 .58368 L
s
.6549 .28097 m
.63553 .26834 L
s
.75126 .40587 m
.74289 .38528 L
s
.34501 .28069 m
.32713 .29478 L
s
0 0 1 r
.72243 .34931 m
.71665 .34169 L
s
1 0 0 r
.30285 .31747 m
.28909 .33412 L
s
.29183 .33003 m
.28125 .3446 L
s
0 0 1 r
.63694 .26892 m
.63412 .2676 L
s
1 0 0 r
.76696 .47298 m
.76444 .45228 L
s
0 0 1 r
.3414 .71647 m
.34617 .7202 L
s
1 0 0 r
.43304 .24003 m
.41089 .24687 L
s
.76755 .52076 m
.76873 .50174 L
s
0 0 1 r
.52007 .23217 m
.51999 .23238 L
s
1 0 0 r
.76837 .49684 m
.76774 .47683 L
s
.63553 .26834 m
.61506 .25742 L
s
0 0 1 r
.39281 .74609 m
.39489 .74712 L
s
1 0 0 r
.71949 .34544 m
.70569 .32722 L
s
.2937 .32778 m
.2822 .34306 L
s
.45577 .23514 m
.43304 .24003 L
s
.29933 .32125 m
.28624 .33759 L
s
.32268 .29813 m
.30668 .31372 L
s
.61506 .25742 m
.59364 .24831 L
s
.30109 .31941 m
.29168 .33062 L
s
0 0 1 r
.68549 .30586 m
.68104 .30172 L
s
1 0 0 r
.29624 .32477 m
.2839 .34065 L
s
0 0 1 r
.5 .23155 m
.5 .23149 L
s
.5 .76851 m
.5 .76845 L
s
1 0 0 r
.47889 .23226 m
.45577 .23514 L
s
0 0 1 r
.30823 .68798 m
.31601 .6956 L
s
1 0 0 r
.59364 .24831 m
.57146 .2411 L
s
.36423 .26814 m
.34501 .28069 L
s
0 0 1 r
.6193 .25958 m
.61728 .2584 L
s
1 0 0 r
.75796 .57473 m
.76199 .55935 L
s
.50222 .23141 m
.47889 .23226 L
s
.57146 .2411 m
.5487 .23585 L
s
.75891 .42851 m
.75239 .40768 L
s
.52556 .23261 m
.50222 .23141 L
s
.5487 .23585 m
.52556 .23261 L
s
0 0 1 r
.37882 .73972 m
.38176 .74086 L
s
.33268 .71014 m
.33857 .71438 L
s
1 0 0 r
.74289 .38528 m
.73254 .3653 L
s
0 0 1 r
.48031 .7679 m
.4804 .76758 L
s
1 0 0 r
.70569 .32722 m
.69019 .31017 L
s
.30119 .3195 m
.2907 .33156 L
s
.31835 .30196 m
.30285 .31747 L
s
0 0 1 r
.71301 .33695 m
.70808 .33003 L
s
1 0 0 r
.38465 .25728 m
.36423 .26814 L
s
.34025 .2839 m
.32268 .29813 L
s
.74661 .60667 m
.75137 .59397 L
s
0 0 1 r
.60054 .25146 m
.59923 .2503 L
s
.46119 .76588 m
.46154 .76532 L
s
1 0 0 r
.76379 .55109 m
.76634 .53406 L
s
.76444 .45228 m
.75981 .43156 L
s
0 0 1 r
.67152 .29397 m
.66798 .29027 L
s
.73508 .37092 m
.73003 .36109 L
s
1 0 0 r
.69019 .31017 m
.67312 .29445 L
s
0 0 1 r
.36633 .73312 m
.37025 .73448 L
s
1 0 0 r
.30232 .31845 m
.29079 .33134 L
s
.76741 .52664 m
.76831 .50821 L
s
0 0 1 r
.32556 .70442 m
.33264 .70929 L
s
1 0 0 r
.31424 .30598 m
.29933 .32125 L
s
0 0 1 r
.44288 .7626 m
.44366 .76184 L
s
1 0 0 r
.76774 .47683 m
.76501 .45654 L
s
.73254 .3653 m
.72027 .34611 L
s
.4061 .24821 m
.38465 .25728 L
s
0 0 1 r
.58093 .24475 m
.58019 .2435 L
s
1 0 0 r
.76873 .50174 m
.76786 .48223 L
s
.75239 .40768 m
.74381 .38724 L
s
.30433 .31638 m
.29183 .33003 L
s
.67312 .29445 m
.6546 .28021 L
s
.31044 .3099 m
.29624 .32477 L
s
.35926 .27117 m
.34025 .2839 L
s
.30709 .31346 m
.2937 .32778 L
s
.31231 .30883 m
.30216 .31813 L
s
0 0 1 r
.4256 .75823 m
.42698 .75735 L
s
1 0 0 r
.42841 .24102 m
.4061 .24821 L
s
.75537 .58368 m
.7589 .56906 L
s
0 0 1 r
.6559 .28263 m
.65323 .27924 L
s
1 0 0 r
.33551 .28774 m
.31835 .30196 L
s
0 0 1 r
.35542 .72653 m
.36044 .72823 L
s
.56076 .23958 m
.56046 .23816 L
s
.70175 .32432 m
.6977 .31798 L
s
1 0 0 r
.6546 .28021 m
.63477 .26758 L
s
0 0 1 r
.32002 .69952 m
.32833 .7051 L
s
1 0 0 r
.72027 .34611 m
.70616 .32792 L
s
.45138 .2358 m
.42841 .24102 L
s
.75981 .43156 m
.75308 .41097 L
s
0 0 1 r
.40955 .75299 m
.41167 .75206 L
s
.54035 .23601 m
.54032 .23437 L
s
1 0 0 r
.63477 .26758 m
.61381 .2567 L
s
0 0 1 r
.72669 .35843 m
.72243 .34931 L
s
1 0 0 r
.31239 .30924 m
.30109 .31941 L
s
.37956 .26008 m
.35926 .27117 L
s
.47483 .23261 m
.45138 .2358 L
s
.76199 .55935 m
.7641 .54301 L
s
.74381 .38724 m
.73321 .36737 L
s
0 0 1 r
.34617 .7202 m
.35235 .72236 L
s
1 0 0 r
.33087 .29194 m
.31424 .30598 L
s
0 0 1 r
.63881 .27213 m
.63694 .26892 L
s
1 0 0 r
.61381 .2567 m
.5919 .24767 L
s
0 0 1 r
.51999 .23408 m
.52007 .23217 L
s
1 0 0 r
.49855 .23148 m
.47483 .23261 L
s
.76501 .45654 m
.76014 .43615 L
s
.5919 .24767 m
.56921 .24057 L
s
.70616 .32792 m
.6903 .31087 L
s
0 0 1 r
.39489 .74712 m
.3979 .74624 L
s
1 0 0 r
.35419 .27497 m
.33551 .28774 L
s
0 0 1 r
.31601 .6956 m
.32557 .70197 L
s
1 0 0 r
.31359 .30847 m
.30119 .3195 L
s
.52233 .23244 m
.49855 .23148 L
s
0 0 1 r
.68867 .31172 m
.68549 .30586 L
s
1 0 0 r
.76634 .53406 m
.76685 .51625 L
s
.56921 .24057 m
.54595 .23548 L
s
.54595 .23548 m
.52233 .23244 L
s
.32643 .29621 m
.31044 .3099 L
s
0 0 1 r
.5 .23374 m
.5 .23155 L
s
.5 .76845 m
.5 .76626 L
s
1 0 0 r
.401 .25076 m
.37956 .26008 L
s
.76786 .48223 m
.76486 .46237 L
s
.76831 .50821 m
.76711 .48922 L
s
.31575 .3066 m
.30232 .31845 L
s
0 0 1 r
.62046 .26273 m
.6193 .25958 L
s
.33857 .71438 m
.346 .71711 L
s
1 0 0 r
.75137 .59397 m
.75431 .58007 L
s
.32233 .30025 m
.30709 .31346 L
s
.31872 .3038 m
.30433 .31638 L
s
0 0 1 r
.38176 .74086 m
.38578 .74013 L
s
1 0 0 r
.6903 .31087 m
.67281 .29516 L
s
0 0 1 r
.4804 .76758 m
.48065 .76512 L
s
1 0 0 r
.73321 .36737 m
.72063 .34827 L
s
.75308 .41097 m
.74423 .39072 L
s
0 0 1 r
.71645 .34546 m
.71301 .33695 L
s
.73846 .38216 m
.73508 .37092 L
s
1 0 0 r
.4234 .24332 m
.401 .25076 L
s
.37428 .2638 m
.35419 .27497 L
s
.34912 .27929 m
.33087 .29194 L
s
0 0 1 r
.6011 .25467 m
.60054 .25146 L
s
.46154 .76532 m
.46222 .76262 L
s
.67385 .29948 m
.67152 .29397 L
s
1 0 0 r
.67281 .29516 m
.65383 .28094 L
s
0 0 1 r
.37025 .73448 m
.37539 .73402 L
s
.33264 .70929 m
.34135 .71268 L
s
1 0 0 r
.7589 .56906 m
.76048 .55338 L
s
.32432 .30072 m
.31231 .30883 L
s
.44656 .23784 m
.4234 .24332 L
s
.76014 .43615 m
.75312 .41584 L
s
0 0 1 r
.44366 .76184 m
.44493 .75896 L
s
.58105 .2481 m
.58093 .24475 L
s
1 0 0 r
.72063 .34827 m
.70615 .33013 L
s
.34413 .28384 m
.32643 .29621 L
s
.65383 .28094 m
.63351 .26835 L
s
.7641 .54301 m
.76416 .5258 L
s
.39561 .25436 m
.37428 .2638 L
s
.74423 .39072 m
.73331 .371 L
s
.32558 .30025 m
.31239 .30924 L
s
.47028 .2344 m
.44656 .23784 L
s
0 0 1 r
.70435 .33233 m
.70175 .32432 L
s
1 0 0 r
.76486 .46237 m
.75967 .44234 L
s
0 0 1 r
.36044 .72823 m
.36679 .72816 L
s
.42698 .75735 m
.429 .75435 L
s
.65744 .28791 m
.6559 .28263 L
s
.32833 .7051 m
.33834 .70926 L
s
.56059 .24315 m
.56076 .23958 L
s
1 0 0 r
.63351 .26835 m
.61203 .25752 L
s
.36887 .26819 m
.34912 .27929 L
s
.76685 .51625 m
.76525 .49779 L
s
.33935 .28833 m
.32233 .30025 L
s
.76711 .48922 m
.76375 .46981 L
s
.32788 .29862 m
.31359 .30847 L
s
0 0 1 r
.7293 .36906 m
.72669 .35843 L
s
1 0 0 r
.49434 .23304 m
.47028 .2344 L
s
.33494 .29245 m
.31872 .3038 L
s
.70615 .33013 m
.68986 .31312 L
s
.33106 .29596 m
.31575 .3066 L
s
.61203 .25752 m
.58959 .24857 L
s
0 0 1 r
.41167 .75206 m
.4146 .74905 L
s
.54005 .23986 m
.54035 .23601 L
s
1 0 0 r
.51853 .23379 m
.49434 .23304 L
s
.58959 .24857 m
.56638 .24159 L
s
0 0 1 r
.35235 .72236 m
.36 .72281 L
s
1 0 0 r
.418 .24678 m
.39561 .25436 L
s
0 0 1 r
.32557 .70197 m
.3369 .70697 L
s
1 0 0 r
.54262 .23664 m
.51853 .23379 L
s
0 0 1 r
.63963 .27732 m
.63881 .27213 L
s
1 0 0 r
.56638 .24159 m
.54262 .23664 L
s
.75312 .41584 m
.74393 .39581 L
s
0 0 1 r
.51976 .23823 m
.51999 .23408 L
s
1 0 0 r
.75431 .58007 m
.7553 .56503 L
s
.73331 .371 m
.72035 .352 L
s
0 0 1 r
.3979 .74624 m
.40187 .74332 L
s
.69045 .31935 m
.68867 .31172 L
s
1 0 0 r
.36342 .27297 m
.34413 .28384 L
s
.68986 .31312 m
.6719 .29744 L
s
.38997 .25878 m
.36887 .26819 L
s
0 0 1 r
.5 .23819 m
.5 .23374 L
s
.5 .76626 m
.5 .76181 L
s
.346 .71711 m
.35498 .71818 L
s
1 0 0 r
.44126 .24114 m
.418 .24678 L
s
0 0 1 r
.62068 .26795 m
.62046 .26273 L
s
1 0 0 r
.75967 .44234 m
.75228 .42233 L
s
0 0 1 r
.74003 .39479 m
.73846 .38216 L
s
.71827 .35558 m
.71645 .34546 L
s
.38578 .74013 m
.3909 .73742 L
s
1 0 0 r
.76048 .55338 m
.76001 .53675 L
s
0 0 1 r
.48065 .76512 m
.48107 .76038 L
s
1 0 0 r
.35805 .27784 m
.33935 .28833 L
s
.6719 .29744 m
.65242 .28325 L
s
.33818 .29395 m
.32432 .30072 L
s
.76375 .46981 m
.75817 .45015 L
s
.46517 .23753 m
.44126 .24114 L
s
.72035 .352 m
.70543 .33393 L
s
.76416 .5258 m
.76208 .50786 L
s
0 0 1 r
.67486 .30686 m
.67385 .29948 L
s
.60087 .26001 m
.6011 .25467 L
s
.34135 .71268 m
.35171 .71448 L
s
.46222 .76262 m
.46323 .75765 L
s
1 0 0 r
.76525 .49779 m
.76146 .47882 L
s
.74393 .39581 m
.73261 .37625 L
s
.34061 .29258 m
.32558 .30025 L
s
.35291 .28251 m
.33494 .29245 L
s
.41224 .25118 m
.38997 .25878 L
s
0 0 1 r
.37539 .73402 m
.38177 .73164 L
s
1 0 0 r
.65242 .28325 m
.63157 .27069 L
s
.38416 .26374 m
.36342 .27297 L
s
.344 .29011 m
.32788 .29862 L
s
.34816 .28668 m
.33106 .29596 L
s
.48952 .23601 m
.46517 .23753 L
s
0 0 1 r
.44493 .75896 m
.44671 .75382 L
s
.5805 .25366 m
.58105 .2481 L
s
.33834 .70926 m
.35008 .71187 L
s
1 0 0 r
.63157 .27069 m
.60955 .25992 L
s
0 0 1 r
.70539 .34204 m
.70435 .33233 L
s
.36679 .72816 m
.37451 .72623 L
s
1 0 0 r
.51408 .2366 m
.48952 .23601 L
s
.70543 .33393 m
.68867 .31698 L
s
0 0 1 r
.65775 .29517 m
.65744 .28791 L
s
.429 .75435 m
.4317 .74914 L
s
.73014 .38118 m
.7293 .36906 L
s
1 0 0 r
.75228 .42233 m
.74269 .40252 L
s
0 0 1 r
.55991 .24899 m
.56059 .24315 L
s
1 0 0 r
.60955 .25992 m
.58656 .25104 L
s
.43549 .2455 m
.41224 .25118 L
s
.53859 .23933 m
.51408 .2366 L
s
.37829 .26895 m
.35805 .27784 L
s
.58656 .25104 m
.56284 .24415 L
s
.56284 .24415 m
.53859 .23933 L
s
0 0 1 r
.3369 .70697 m
.35 .71045 L
s
1 0 0 r
.73261 .37625 m
.71921 .35737 L
s
.7553 .56503 m
.75424 .54893 L
s
0 0 1 r
.4146 .74905 m
.41836 .74386 L
s
.53941 .24602 m
.54005 .23986 L
s
.36 .72281 m
.36912 .72144 L
s
1 0 0 r
.40618 .25628 m
.38416 .26374 L
s
.75817 .45015 m
.75035 .43043 L
s
.68867 .31698 m
.6702 .30133 L
s
0 0 1 r
.63934 .28458 m
.63963 .27732 L
s
1 0 0 r
.76001 .53675 m
.75739 .51929 L
s
.3725 .2741 m
.35291 .28251 L
s
.4595 .24184 m
.43549 .2455 L
s
0 0 1 r
.51934 .24472 m
.51976 .23823 L
s
.69074 .32879 m
.69045 .31935 L
s
.40187 .74332 m
.40682 .73826 L
s
1 0 0 r
.76146 .47882 m
.75542 .45952 L
s
.76208 .50786 m
.75778 .48931 L
s
0 0 1 r
.73968 .40876 m
.74003 .39479 L
s
1 0 0 r
.35385 .28864 m
.33818 .29395 L
s
0 0 1 r
.35498 .71818 m
.36554 .71749 L
s
1 0 0 r
.36697 .2789 m
.34816 .28668 L
s
0 0 1 r
.5 .245 m
.5 .23819 L
s
.5 .76181 m
.5 .755 L
s
.71836 .36729 m
.71827 .35558 L
s
1 0 0 r
.6702 .30133 m
.65017 .28716 L
s
.35744 .28638 m
.34061 .29258 L
s
0 0 1 r
.61992 .27532 m
.62068 .26795 L
s
1 0 0 r
.74269 .40252 m
.73091 .38313 L
s
.71921 .35737 m
.70382 .33937 L
s
.36188 .28307 m
.344 .29011 L
s
.48406 .24025 m
.4595 .24184 L
s
0 0 1 r
.3909 .73742 m
.39715 .73262 L
s
1 0 0 r
.42929 .2507 m
.40618 .25628 L
s
.39992 .26178 m
.37829 .26895 L
s
0 0 1 r
.48107 .76038 m
.48167 .75328 L
s
.35171 .71448 m
.36371 .71457 L
s
.67445 .31615 m
.67486 .30686 L
s
1 0 0 r
.65017 .28716 m
.62877 .27464 L
s
0 0 1 r
.59979 .26759 m
.60087 .26001 L
s
.46323 .75765 m
.4646 .75032 L
s
1 0 0 r
.5089 .24078 m
.48406 .24025 L
s
0 0 1 r
.38177 .73164 m
.38941 .72722 L
s
1 0 0 r
.75035 .43043 m
.74028 .41084 L
s
.62877 .27464 m
.60621 .26389 L
s
0 0 1 r
.35008 .71187 m
.36352 .71281 L
s
1 0 0 r
.70382 .33937 m
.68654 .32246 L
s
.39359 .26738 m
.3725 .2741 L
s
.53379 .24344 m
.5089 .24078 L
s
0 0 1 r
.44671 .75382 m
.44901 .74635 L
s
.57926 .26152 m
.5805 .25366 L
s
1 0 0 r
.45329 .24711 m
.42929 .2507 L
s
0 0 1 r
.70476 .35347 m
.70539 .34204 L
s
.72908 .39476 m
.73014 .38118 L
s
1 0 0 r
.75424 .54893 m
.75101 .53189 L
s
.60621 .26389 m
.58269 .25505 L
s
.73091 .38313 m
.71702 .36436 L
s
.55847 .24821 m
.53379 .24344 L
s
0 0 1 r
.37451 .72623 m
.38361 .72232 L
s
1 0 0 r
.75542 .45952 m
.7471 .44007 L
s
.58269 .25505 m
.55847 .24821 L
s
0 0 1 r
.65675 .30445 m
.65775 .29517 L
s
.35 .71045 m
.36483 .7123 L
s
1 0 0 r
.42275 .25646 m
.39992 .26178 L
s
0 0 1 r
.4317 .74914 m
.43509 .74161 L
s
1 0 0 r
.75739 .51929 m
.75253 .50113 L
s
0 0 1 r
.5587 .25718 m
.55991 .24899 L
s
1 0 0 r
.38736 .27277 m
.36697 .2789 L
s
.75778 .48931 m
.75122 .47034 L
s
.68654 .32246 m
.66752 .30683 L
s
0 0 1 r
.36912 .72144 m
.37971 .71815 L
s
1 0 0 r
.47793 .24558 m
.45329 .24711 L
s
.38142 .27766 m
.36188 .28307 L
s
0 0 1 r
.41836 .74386 m
.42297 .73639 L
s
.53842 .25458 m
.53941 .24602 L
s
1 0 0 r
.37126 .28493 m
.35385 .28864 L
s
.37598 .28178 m
.35744 .28638 L
s
0 0 1 r
.63787 .29395 m
.63934 .28458 L
s
.73731 .42401 m
.73968 .40876 L
s
.68943 .34006 m
.69074 .32879 L
s
1 0 0 r
.74028 .41084 m
.728 .39159 L
s
0 0 1 r
.51875 .25364 m
.51934 .24472 L
s
1 0 0 r
.71702 .36436 m
.7011 .34642 L
s
0 0 1 r
.40682 .73826 m
.41276 .73097 L
s
1 0 0 r
.41599 .26246 m
.39359 .26738 L
s
0 0 1 r
.36554 .71749 m
.37765 .71494 L
s
1 0 0 r
.66752 .30683 m
.64694 .29266 L
s
0 0 1 r
.71661 .38058 m
.71836 .36729 L
s
1 0 0 r
.44659 .25308 m
.42275 .25646 L
s
.50297 .24614 m
.47793 .24558 L
s
0 0 1 r
.5 .25426 m
.5 .245 L
s
.5 .755 m
.5 .74574 L
s
.61811 .2849 m
.61992 .27532 L
s
.39715 .73262 m
.40453 .72565 L
s
1 0 0 r
.7471 .44007 m
.73652 .42067 L
s
0 0 1 r
.36371 .71457 m
.37733 .71285 L
s
1 0 0 r
.64694 .29266 m
.62499 .28012 L
s
0 0 1 r
.48167 .75328 m
.48244 .74373 L
s
1 0 0 r
.52815 .24883 m
.50297 .24614 L
s
.40916 .26841 m
.38736 .27277 L
s
0 0 1 r
.67255 .32739 m
.67445 .31615 L
s
1 0 0 r
.7011 .34642 m
.68328 .32952 L
s
.75101 .53189 m
.74557 .51405 L
s
.75122 .47034 m
.74237 .45112 L
s
0 0 1 r
.59781 .27746 m
.59979 .26759 L
s
1 0 0 r
.62499 .28012 m
.60189 .26936 L
s
0 0 1 r
.4646 .75032 m
.46632 .74056 L
s
.36352 .71281 m
.37862 .71198 L
s
1 0 0 r
.55321 .25363 m
.52815 .24883 L
s
0 0 1 r
.38941 .72722 m
.3983 .72068 L
s
1 0 0 r
.47119 .25174 m
.44659 .25308 L
s
.75253 .50113 m
.74541 .48243 L
s
.728 .39159 m
.71358 .3729 L
s
.60189 .26936 m
.57788 .26049 L
s
0 0 1 r
.72604 .40973 m
.72908 .39476 L
s
1 0 0 r
.57788 .26049 m
.55321 .25363 L
s
.40246 .27398 m
.38142 .27766 L
s
.4395 .25946 m
.41599 .26246 L
s
0 0 1 r
.70235 .3666 m
.70476 .35347 L
s
.36483 .7123 m
.38134 .71241 L
s
.44901 .74635 m
.45184 .73646 L
s
.5773 .27175 m
.57926 .26152 L
s
1 0 0 r
.39609 .27891 m
.37598 .28178 L
s
0 0 1 r
.38361 .72232 m
.39406 .71635 L
s
1 0 0 r
.3903 .28293 m
.37126 .28493 L
s
0 0 1 r
.65437 .31578 m
.65675 .30445 L
s
1 0 0 r
.68328 .32952 m
.6637 .31387 L
s
0 0 1 r
.43509 .74161 m
.43917 .73171 L
s
1 0 0 r
.4963 .25247 m
.47119 .25174 L
s
0 0 1 r
.55693 .2678 m
.5587 .25718 L
s
1 0 0 r
.73652 .42067 m
.7237 .40152 L
s
0 0 1 r
.73282 .44044 m
.73731 .42401 L
s
.37971 .71815 m
.39175 .71287 L
s
1 0 0 r
.43219 .26592 m
.40916 .26841 L
s
0 0 1 r
.42297 .73639 m
.42843 .72659 L
s
1 0 0 r
.71358 .3729 m
.69711 .35498 L
s
0 0 1 r
.53705 .2656 m
.53842 .25458 L
s
1 0 0 r
.46391 .25845 m
.4395 .25946 L
s
0 0 1 r
.68644 .35315 m
.68943 .34006 L
s
.63514 .30548 m
.63787 .29395 L
s
1 0 0 r
.6637 .31387 m
.64257 .29965 L
s
.52167 .25531 m
.4963 .25247 L
s
0 0 1 r
.71294 .39539 m
.71661 .38058 L
s
.37765 .71494 m
.39128 .71045 L
s
1 0 0 r
.74237 .45112 m
.73123 .43185 L
s
0 0 1 r
.51797 .26505 m
.51875 .25364 L
s
.41276 .73097 m
.4197 .7214 L
s
1 0 0 r
.42483 .27215 m
.40246 .27398 L
s
.74541 .48243 m
.73598 .46338 L
s
.74557 .51405 m
.73785 .49555 L
s
.64257 .29965 m
.62008 .28704 L
s
0 0 1 r
.5 .26602 m
.5 .25426 L
s
.5 .74574 m
.5 .73398 L
s
.37733 .71285 m
.39251 .70922 L
s
1 0 0 r
.54701 .26023 m
.52167 .25531 L
s
0 0 1 r
.61521 .29673 m
.61811 .2849 L
s
.40453 .72565 m
.41304 .71644 L
s
1 0 0 r
.69711 .35498 m
.67873 .33805 L
s
.62008 .28704 m
.59649 .27619 L
s
.7237 .40152 m
.70872 .38286 L
s
0 0 1 r
.48244 .74373 m
.4834 .73169 L
s
1 0 0 r
.57204 .26722 m
.54701 .26023 L
s
.41763 .27785 m
.39609 .27891 L
s
0 0 1 r
.37862 .71198 m
.39529 .70929 L
s
1 0 0 r
.48896 .25949 m
.46391 .25845 L
s
0 0 1 r
.66909 .34056 m
.67255 .32739 L
s
1 0 0 r
.59649 .27619 m
.57204 .26722 L
s
.45623 .2654 m
.43219 .26592 L
s
0 0 1 r
.72094 .426 m
.72604 .40973 L
s
.38134 .71241 m
.39942 .71069 L
s
1 0 0 r
.41083 .28275 m
.3903 .28293 L
s
0 0 1 r
.5949 .28966 m
.59781 .27746 L
s
.3983 .72068 m
.40843 .71198 L
s
.46632 .74056 m
.46841 .72831 L
s
.6981 .38137 m
.70235 .3666 L
s
.45184 .73646 m
.4552 .72411 L
s
1 0 0 r
.67873 .33805 m
.65861 .32232 L
s
.73123 .43185 m
.71786 .41276 L
s
0 0 1 r
.57458 .28437 m
.5773 .27175 L
s
.39406 .71635 m
.40584 .70827 L
s
1 0 0 r
.51437 .2626 m
.48896 .25949 L
s
0 0 1 r
.65055 .32915 m
.65437 .31578 L
s
.72617 .45791 m
.73282 .44044 L
s
1 0 0 r
.44832 .27225 m
.42483 .27215 L
s
0 0 1 r
.43917 .73171 m
.44394 .71938 L
s
1 0 0 r
.70872 .38286 m
.6917 .3649 L
s
0 0 1 r
.5546 .28087 m
.55693 .2678 L
s
.39175 .71287 m
.40519 .70553 L
s
1 0 0 r
.73598 .46338 m
.72429 .44418 L
s
.48104 .26689 m
.45623 .2654 L
s
.65861 .32232 m
.63695 .30798 L
s
.73785 .49555 m
.72786 .47659 L
s
.53987 .26779 m
.51437 .2626 L
s
0 0 1 r
.42843 .72659 m
.43473 .71442 L
s
.68171 .368 m
.68644 .35315 L
s
.5353 .27911 m
.53705 .2656 L
s
.70727 .41163 m
.71294 .39539 L
s
1 0 0 r
.4404 .27871 m
.41763 .27785 L
s
0 0 1 r
.39128 .71045 m
.40635 .70395 L
s
.63113 .31916 m
.63514 .30548 L
s
1 0 0 r
.63695 .30798 m
.61399 .29521 L
s
0 0 1 r
.517 .27897 m
.51797 .26505 L
s
1 0 0 r
.56516 .275 m
.53987 .26779 L
s
0 0 1 r
.4197 .7214 m
.42762 .70952 L
s
.39251 .70922 m
.40916 .70365 L
s
1 0 0 r
.43269 .28446 m
.41083 .28275 L
s
.71786 .41276 m
.70233 .39405 L
s
.6917 .3649 m
.67278 .34787 L
s
.61399 .29521 m
.58996 .28418 L
s
.58996 .28418 m
.56516 .275 L
s
0 0 1 r
.39529 .70929 m
.41343 .70468 L
s
.5 .2803 m
.5 .26602 L
s
.5 .73398 m
.5 .7197 L
s
1 0 0 r
.50634 .27042 m
.48104 .26689 L
s
0 0 1 r
.61118 .3108 m
.61521 .29673 L
s
1 0 0 r
.47271 .27434 m
.44832 .27225 L
s
0 0 1 r
.39942 .71069 m
.41894 .70707 L
s
.41304 .71644 m
.42263 .70498 L
s
.71373 .44346 m
.72094 .426 L
s
.664 .35563 m
.66909 .34056 L
s
.4834 .73169 m
.48454 .71713 L
s
1 0 0 r
.72429 .44418 m
.71037 .42505 L
s
0 0 1 r
.40843 .71198 m
.41974 .70108 L
s
.69196 .3977 m
.6981 .38137 L
s
.59105 .30418 m
.5949 .28966 L
s
.46841 .72831 m
.47085 .71358 L
s
1 0 0 r
.67278 .34787 m
.65215 .33198 L
s
0 0 1 r
.71732 .47629 m
.72617 .45791 L
s
1 0 0 r
.53185 .27599 m
.50634 .27042 L
s
.46417 .28152 m
.4404 .27871 L
s
.72786 .47659 m
.71562 .45737 L
s
0 0 1 r
.40584 .70827 m
.41888 .69805 L
s
.4552 .72411 m
.45909 .70932 L
s
1 0 0 r
.70233 .39405 m
.68478 .37597 L
s
0 0 1 r
.5711 .29938 m
.57458 .28437 L
s
.64526 .34453 m
.65055 .32915 L
s
1 0 0 r
.49772 .27844 m
.47271 .27434 L
s
.65215 .33198 m
.63003 .31743 L
s
0 0 1 r
.44394 .71938 m
.44939 .70465 L
s
.40519 .70553 m
.41994 .69612 L
s
1 0 0 r
.55727 .28357 m
.53185 .27599 L
s
0 0 1 r
.55169 .29637 m
.5546 .28087 L
s
1 0 0 r
.45565 .28811 m
.43269 .28446 L
s
0 0 1 r
.69958 .42919 m
.70727 .41163 L
s
.6752 .38455 m
.68171 .368 L
s
.40635 .70395 m
.42275 .69542 L
s
1 0 0 r
.63003 .31743 m
.60666 .30441 L
s
0 0 1 r
.43473 .71442 m
.44184 .69989 L
s
1 0 0 r
.58231 .29307 m
.55727 .28357 L
s
0 0 1 r
.53317 .29508 m
.5353 .27911 L
s
.62581 .33495 m
.63113 .31916 L
s
1 0 0 r
.71037 .42505 m
.69433 .40621 L
s
0 0 1 r
.40916 .70365 m
.42715 .69608 L
s
1 0 0 r
.60666 .30441 m
.58231 .29307 L
s
.68478 .37597 m
.66537 .35874 L
s
0 0 1 r
.41894 .70707 m
.43974 .70151 L
s
.41343 .70468 m
.43289 .69811 L
s
.51585 .29538 m
.517 .27897 L
s
.42762 .70952 m
.43646 .69534 L
s
1 0 0 r
.52307 .28454 m
.49772 .27844 L
s
.48869 .28631 m
.46417 .28152 L
s
0 0 1 r
.70441 .46194 m
.71373 .44346 L
s
1 0 0 r
.71562 .45737 m
.7012 .4381 L
s
0 0 1 r
.5 .29706 m
.5 .2803 L
s
.5 .7197 m
.5 .70294 L
s
.60601 .32707 m
.61118 .3108 L
s
.42263 .70498 m
.43326 .69128 L
s
.7063 .49538 m
.71732 .47629 L
s
.65727 .3725 m
.664 .35563 L
s
.48454 .71713 m
.48587 .70011 L
s
.6839 .41548 m
.69196 .3977 L
s
1 0 0 r
.66537 .35874 m
.64429 .34259 L
s
.54846 .29261 m
.52307 .28454 L
s
0 0 1 r
.41974 .70108 m
.43217 .688 L
s
1 0 0 r
.47949 .29373 m
.45565 .28811 L
s
0 0 1 r
.58624 .32098 m
.59105 .30418 L
s
1 0 0 r
.69433 .40621 m
.6763 .38791 L
s
0 0 1 r
.47085 .71358 m
.47364 .6964 L
s
.41888 .69805 m
.43309 .68571 L
s
1 0 0 r
.51369 .29309 m
.48869 .28631 L
s
.64429 .34259 m
.62179 .32772 L
s
0 0 1 r
.45909 .70932 m
.46348 .69212 L
s
1 0 0 r
.57358 .30258 m
.54846 .29261 L
s
0 0 1 r
.56685 .31672 m
.5711 .29938 L
s
.63848 .36183 m
.64526 .34453 L
s
.41994 .69612 m
.43588 .68463 L
s
.68987 .4479 m
.69958 .42919 L
s
1 0 0 r
.62179 .32772 m
.59813 .31433 L
s
0 0 1 r
.44939 .70465 m
.45549 .68756 L
s
1 0 0 r
.59813 .31433 m
.57358 .30258 L
s
.7012 .4381 m
.6847 .41904 L
s
0 0 1 r
.43974 .70151 m
.4616 .69399 L
s
.42275 .69542 m
.44037 .68487 L
s
.54822 .31425 m
.55169 .29637 L
s
.66691 .40267 m
.6752 .38455 L
s
.42715 .69608 m
.44632 .68652 L
s
.43289 .69811 m
.45349 .68958 L
s
1 0 0 r
.6763 .38791 m
.65647 .37038 L
s
0 0 1 r
.44184 .69989 m
.44972 .68305 L
s
.69298 .48127 m
.70441 .46194 L
s
.53067 .31346 m
.53317 .29508 L
s
.61917 .35277 m
.62581 .33495 L
s
1 0 0 r
.53886 .30179 m
.51369 .29309 L
s
.50392 .30129 m
.47949 .29373 L
s
0 0 1 r
.69315 .51497 m
.7063 .49538 L
s
.43646 .69534 m
.44618 .6789 L
s
.51451 .31419 m
.51585 .29538 L
s
1 0 0 r
.65647 .37038 m
.63505 .35385 L
s
0 0 1 r
.5 .31623 m
.5 .29706 L
s
.5 .70294 m
.5 .68377 L
s
.59971 .34545 m
.60601 .32707 L
s
.43326 .69128 m
.44484 .67539 L
s
.6489 .39107 m
.65727 .3725 L
s
.67393 .43455 m
.6839 .41548 L
s
1 0 0 r
.56389 .31235 m
.53886 .30179 L
s
.6847 .41904 m
.66629 .4004 L
s
0 0 1 r
.48587 .70011 m
.48736 .6807 L
s
.43217 .688 m
.4456 .67279 L
s
1 0 0 r
.63505 .35385 m
.6123 .33854 L
s
.52867 .31076 m
.50392 .30129 L
s
0 0 1 r
.58048 .33995 m
.58624 .32098 L
s
1 0 0 r
.58848 .32465 m
.56389 .31235 L
s
0 0 1 r
.47364 .6964 m
.47677 .67687 L
s
.4616 .69399 m
.48429 .68455 L
s
.43309 .68571 m
.44834 .6713 L
s
.67817 .46759 m
.68987 .4479 L
s
1 0 0 r
.6123 .33854 m
.58848 .32465 L
s
0 0 1 r
.63022 .38094 m
.63848 .36183 L
s
.46348 .69212 m
.46835 .6726 L
s
.43588 .68463 m
.45289 .67111 L
s
.45349 .68958 m
.47501 .67911 L
s
.56186 .33629 m
.56685 .31672 L
s
.44037 .68487 m
.45902 .67233 L
s
.44632 .68652 m
.46648 .67501 L
s
.67953 .50123 m
.69298 .48127 L
s
1 0 0 r
.66629 .4004 m
.64615 .38245 L
s
0 0 1 r
.67796 .53484 m
.69315 .51497 L
s
.65684 .4222 m
.66691 .40267 L
s
.45549 .68756 m
.46219 .66821 L
s
.5442 .33439 m
.54822 .31425 L
s
1 0 0 r
.55342 .32204 m
.52867 .31076 L
s
0 0 1 r
.44972 .68305 m
.45831 .66401 L
s
.61123 .37248 m
.61917 .35277 L
s
.52781 .33413 m
.53067 .31346 L
s
1 0 0 r
.64615 .38245 m
.62452 .36542 L
s
0 0 1 r
.44618 .6789 m
.45669 .66032 L
s
.513 .3353 m
.51451 .31419 L
s
.66211 .45471 m
.67393 .43455 L
s
1 0 0 r
.57786 .33502 m
.55342 .32204 L
s
0 0 1 r
.48429 .68455 m
.50755 .67325 L
s
.63893 .41116 m
.6489 .39107 L
s
.5923 .3658 m
.59971 .34545 L
s
.44484 .67539 m
.45727 .65742 L
s
.5 .33767 m
.5 .31623 L
s
.5 .68377 m
.5 .66233 L
s
1 0 0 r
.62452 .36542 m
.60166 .34954 L
s
.60166 .34954 m
.57786 .33502 L
s
0 0 1 r
.66088 .55474 m
.67796 .53484 L
s
.4456 .67279 m
.45993 .65555 L
s
.48736 .6807 m
.48902 .65904 L
s
.66456 .48804 m
.67817 .46759 L
s
.47501 .67911 m
.4972 .66679 L
s
.66415 .52158 m
.67953 .50123 L
s
.57382 .36097 m
.58048 .33995 L
s
.44834 .6713 m
.46449 .65491 L
s
.47677 .67687 m
.4802 .65513 L
s
.46648 .67501 m
.48741 .66163 L
s
.45289 .67111 m
.47077 .65567 L
s
.45902 .67233 m
.4785 .6579 L
s
.62053 .40167 m
.63022 .38094 L
s
.46835 .6726 m
.47366 .65092 L
s
.64507 .44295 m
.65684 .4222 L
s
.55615 .35795 m
.56186 .33629 L
s
.50755 .67325 m
.53108 .66018 L
s
.46219 .66821 m
.46943 .64675 L
s
.53965 .35665 m
.5442 .33439 L
s
.64208 .5744 m
.66088 .55474 L
s
.45831 .66401 m
.46753 .64292 L
s
.60204 .3939 m
.61123 .37248 L
s
.64851 .47575 m
.66211 .45471 L
s
.52462 .35691 m
.52781 .33413 L
s
.4972 .66679 m
.51979 .6527 L
s
.45669 .66032 m
.46789 .63975 L
s
.647 .54207 m
.66415 .52158 L
s
.51132 .35851 m
.513 .3353 L
s
.64916 .50899 m
.66456 .48804 L
s
.62741 .43258 m
.63893 .41116 L
s
.53108 .66018 m
.55459 .64549 L
s
.45727 .65742 m
.47043 .63751 L
s
.58383 .38794 m
.5923 .3658 L
s
.5 .3612 m
.5 .33767 L
s
.5 .66233 m
.5 .6388 L
s
.48741 .66163 m
.50885 .64649 L
s
.45993 .65555 m
.47498 .63643 L
s
.62178 .59356 m
.64208 .5744 L
s
.48902 .65904 m
.49082 .63532 L
s
.4785 .6579 m
.49858 .6417 L
s
.46449 .65491 m
.48135 .63669 L
s
.47077 .65567 m
.48931 .63843 L
s
.56629 .38382 m
.57382 .36097 L
s
.4802 .65513 m
.48391 .63137 L
s
.63169 .46468 m
.64507 .44295 L
s
.60948 .42382 m
.62053 .40167 L
s
.55459 .64549 m
.57774 .62935 L
s
.51979 .6527 m
.54249 .63702 L
s
.60024 .61196 m
.62178 .59356 L
s
.47366 .65092 m
.47934 .62728 L
s
.62826 .56243 m
.647 .54207 L
s
.54977 .38148 m
.55615 .35795 L
s
.57774 .62935 m
.60024 .61196 L
s
.63328 .49741 m
.64851 .47575 L
s
.46943 .64675 m
.47714 .62338 L
s
.63212 .53019 m
.64916 .50899 L
s
.53462 .3808 m
.53965 .35665 L
s
.59168 .41682 m
.60204 .3939 L
s
.50885 .64649 m
.53052 .62976 L
s
.46753 .64292 m
.47727 .61998 L
s
.52111 .38158 m
.52462 .35691 L
s
.61446 .45508 m
.62741 .43258 L
s
.54249 .63702 m
.56499 .61992 L
s
.46789 .63975 m
.47965 .61739 L
s
.60817 .58237 m
.62826 .56243 L
s
.5095 .3836 m
.51132 .35851 L
s
.49858 .6417 m
.51901 .62391 L
s
.47043 .63751 m
.48415 .61586 L
s
.57439 .41164 m
.58383 .38794 L
s
.48931 .63843 m
.5083 .61958 L
s
.5 .38658 m
.5 .3612 L
s
.5 .6388 m
.5 .61342 L
s
.47498 .63643 m
.49058 .61562 L
s
.48135 .63669 m
.49872 .61683 L
s
.56499 .61992 m
.58698 .60162 L
s
.61684 .48713 m
.63169 .46468 L
s
.58698 .60162 m
.60817 .58237 L
s
.49082 .63532 m
.49275 .6098 L
s
.61366 .55134 m
.63212 .53019 L
s
.55797 .40827 m
.56629 .38382 L
s
.59718 .44713 m
.60948 .42382 L
s
.61657 .51941 m
.63328 .49741 L
s
.53052 .62976 m
.55213 .61164 L
s
.48391 .63137 m
.48785 .60586 L
s
.47934 .62728 m
.48534 .60194 L
s
.54279 .40663 m
.54977 .38148 L
s
.47714 .62338 m
.48522 .59837 L
s
.51901 .62391 m
.5395 .60472 L
s
.59399 .57216 m
.61366 .55134 L
s
.52915 .40656 m
.53462 .3808 L
s
.58026 .44096 m
.59168 .41682 L
s
.55213 .61164 m
.57338 .59235 L
s
.60021 .47837 m
.61446 .45508 L
s
.47727 .61998 m
.48741 .59546 L
s
.51733 .40787 m
.52111 .38158 L
s
.5083 .61958 m
.52747 .59934 L
s
.47965 .61739 m
.49182 .5935 L
s
.57338 .59235 m
.59399 .57216 L
s
.59859 .54144 m
.61657 .51941 L
s
.60068 .51 m
.61684 .48713 L
s
.48415 .61586 m
.49827 .59274 L
s
.49872 .61683 m
.51637 .59555 L
s
.50756 .41028 m
.5095 .3836 L
s
.49058 .61562 m
.50653 .59338 L
s
.56406 .4366 m
.57439 .41164 L
s
.5 .41351 m
.5 .38658 L
s
.5 .61342 m
.5 .58649 L
s
.5395 .60472 m
.55979 .5844 L
s
.58377 .47131 m
.59718 .44713 L
s
.49275 .6098 m
.49478 .58277 L
s
.54896 .43401 m
.55797 .40827 L
s
.57958 .56321 m
.59859 .54144 L
s
.48785 .60586 m
.49197 .57889 L
s
.55979 .5844 m
.57958 .56321 L
s
.52747 .59934 m
.54656 .57796 L
s
.48534 .60194 m
.49158 .5752 L
s
.53528 .43308 m
.54279 .40663 L
s
.58483 .50216 m
.60021 .47837 L
s
.58342 .53297 m
.60068 .51 L
s
.5679 .46602 m
.58026 .44096 L
s
.48522 .59837 m
.49357 .57201 L
s
.52333 .43363 m
.52915 .40656 L
s
.51637 .59555 m
.53405 .57313 L
s
.48741 .59546 m
.49784 .56964 L
s
.49182 .5935 m
.50425 .56837 L
s
.51334 .43543 m
.51733 .40787 L
s
.50653 .59338 m
.52262 .56997 L
s
.49827 .59274 m
.51259 .56842 L
s
.54656 .57796 m
.5653 .55573 L
s
.55298 .46252 m
.56406 .4366 L
s
.50551 .43821 m
.50756 .41028 L
s
.5653 .55573 m
.58342 .53297 L
s
.5694 .49603 m
.58377 .47131 L
s
.5 .44165 m
.5 .41351 L
s
.5 .58649 m
.5 .55835 L
s
.56853 .52611 m
.58483 .50216 L
s
.49478 .58277 m
.49689 .55458 L
s
.53936 .46072 m
.54896 .43401 L
s
.53405 .57313 m
.55152 .54988 L
s
.49197 .57889 m
.49622 .55082 L
s
.55477 .49166 m
.5679 .46602 L
s
.49158 .5752 m
.49798 .5474 L
s
.52735 .4605 m
.53528 .43308 L
s
.52262 .56997 m
.53861 .54571 L
s
.55152 .54988 m
.56853 .52611 L
s
.49357 .57201 m
.50208 .54466 L
s
.51721 .46165 m
.52333 .43363 L
s
.49784 .56964 m
.5084 .54288 L
s
.51259 .56842 m
.52692 .54323 L
s
.55428 .52095 m
.5694 .49603 L
s
.50425 .56837 m
.51675 .54233 L
s
.50917 .46392 m
.51334 .43543 L
s
.5413 .48903 m
.55298 .46252 L
s
.50339 .46701 m
.50551 .43821 L
s
.53861 .54571 m
.55428 .52095 L
s
.5 .47061 m
.5 .44165 L
s
.5 .55835 m
.5 .52939 L
s
.52931 .48803 m
.53936 .46072 L
s
.54104 .51752 m
.55477 .49166 L
s
.49689 .55458 m
.49905 .52562 L
s
.49622 .55082 m
.50055 .52203 L
s
.52692 .54323 m
.54104 .51752 L
s
.51909 .4885 m
.52735 .4605 L
s
.49798 .5474 m
.50444 .51895 L
s
.51675 .54233 m
.52916 .51576 L
s
.50208 .54466 m
.51062 .51669 L
s
.5084 .54288 m
.51893 .51555 L
s
.52916 .51576 m
.5413 .48903 L
s
.51088 .49022 m
.51721 .46165 L
s
.50488 .49292 m
.50917 .46392 L
s
.50123 .49629 m
.50339 .46701 L
s
.51893 .51555 m
.52931 .48803 L
s
.5 .5 m
.5 .47061 L
s
.5 .52939 m
.5 .5 L
s
.49905 .52562 m
.50123 .49629 L
s
.51062 .51669 m
.51909 .4885 L
s
.50055 .52203 m
.50488 .49292 L
s
.50444 .51895 m
.51088 .49022 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0025OolEO026Ool0081ooaml
085oo`00Ngoo57`000<07g`0O0000g`000<07g`0O0000W`000<07g`0O0001W`0OGoo001gOolCO004
OolBO0000`0OO01l0003O0000`0OOomoo`1gOol007EooaYl000301ml07`0009l00807`Aoo`0301ml
07`0009l000301ml07`000Ml07Moo`00LWoo3G`047oo00<07gooOol00Woo1g`017oo00=l000OO000
2G`000<07gooOol0LWoo001`Ool;O002OolBO0000`0OO01l0002Ool00`0OOomoo`02Ool201l5O000
0`0OOoml0003O0000`0OO01l0006O01aOol006ioo`ml019oo`0301moogoo009l000301ml07`0009l
00807`=oo`0301moo`0O00=l000301moog`000Yl06moo`00K7oo37`00goo5G`017oo00<07gooOol0
0Woo1G`000<07goo01l00Woo00H07g`0O01l07oo01l3O0000`0OO01l0004O01]Ool006Yooa5l01Ao
o`0301ml07`000El009oo`807`=oo`Al0005Ool07gooOol07`02O003Ool3O000100OO01l000O0W`0
Jgoo001XOol<O005OolEO0000goo01moo`03Ool00`0OOomoo`05O002Ool201l2Ool4O0000goo01mo
o`02O00017oo01moo`0O0g`000<07g`0O0000W`0JGoo001WOol8O004Ool6O00EOol5O0000goo01mo
o`02Ool0100OOol07goo17`00Woo00@07gooOol07`9l00=oo`=l00=oo`El000301ml07oo06Moo`00
IGoo1g`00Woo7G`017oo00@07gooOomoo`Al0003Ool07`0O00=oo`0301moo`0O00Al0004Ool07goo
01l2O00017oo01moogoo0W`000=oo`0O01l01g`0IWoo001TOol6O0000gooO01l0004O004Ool=O009
Ool5O004Ool00`0OOomoo`03O003Ool00`0OOol07`02Ool01@0OOoml07`001l00goo00=l000OOol0
0goo0W`00goo0W`000@07g`0O01l06Eoo`00HWoo4g`03Goo1G`027oo00<07g`0O0000W`000@07goo
Oomoo`807`Al0004Ool07goo01l2Ool0100OOoml07`00Woo0P0O0W`00Woo0P0O0W`00goo1G`0I7oo
001QOolNO008Ool4O004Ool00`0OOomoo`02Ool4O00201l2Ool00`0OOoml0002O0000`0OOomoo`02
01l2Ool3O003Ool2O00017oo01moogoo0W`00P0O17`000<07g`0Ool0HGoo001POol8O00GOol5O007
Ool3O0000goo01moo`02Ool201l3Ool4O0001@0OOomoo`0OOol00W`000=oo`0OOol00goo0P0O0W`0
00<07gooOol00g`00P0O00=oog`0O0000Woo0W`000<07g`0O000HGoo001NOol7O00OOol4O006Ool4
O0000goo01l07`02Ool00`0OOol07`02Ool3O00017oo01moogoo0g`00Woo00<07goo01l00Woo0W`0
00Aoo`0OOol07`9l009oo`0401ml07`0Ool6O01OOol005eoo`Il02Eoo`=l00Aoo`0301moogoo009l
000801moogoo01moo`0OOol07`9oo`0301ml07`0009oo`0301moogoo00=l0004Ool07goo01l2Ool2
O000100OOomoogoo0W`000H07gooOoml07oo01l3O0000`0OO01oo`1MOol005aoo`Il02Uoo`Al0004
01moogooOol201l4O0000`0OOol07`02Ool201l017ooO01l000O0goo00D07gooO01l000O00Aoo`04
01ml07`0Ool201l00gooO01l0002Ool00g`001ml0003O0000`0OO01oo`1LOol005]oo`El02moo`04
01ml07`0Ool201l2Ool00`0OOoml0002O002Ool201l2Ool201l00g`0Ool07`02Ool201l2O002Ool2
01l2Ool017`0Oomoo`0O0Woo00=l000O01l00W`000=oog`0O0000P0O00=l07ooOol0FWoo001JOol3
O0000gooO01oo`0_Ool00`0OOomoo`02O003Ool201l2Ool0100OO01l000O0goo0P0O00=oog`0O000
0Woo00@07gooOomoo`9l000501moogoo01moo`02O00401l01W`0Ool07gooO01oo`El05]oo`00FGoo
0g`000=oog`0Ool0<7oo00D07gooOomoo`0O009l0005Ool07`0OOol07`02Ool0100OO01l07oo0P0O
0Woo00D07gooO01l000O009oo`0301moogoo009l000601moogooOol07g`017oo0W`00P0O00=l000O
01l017`0FWoo001HOol5O00bOol01@0OOomoogoo01l00Woo0W`000<07goo01l00Woo00<07gooOol0
0W`000@07gooOol07`9oo`0401ml07`001l3Ool201l00g`0Ool07`0201l00gooO01l000301l017oo
O01oogoo0g`000@07g`0O01l05Uoo`00Egoo17`0=7oo00D07gooOomoo`0O009oo`0301moo`0O009l
009oo`0401moogooOol201l017`001moogoo0P0O0Woo00Al07ooOol07`9oo`0401ml07`0Ool401l2
O000100OOomoog`00Woo00<07g`0Ool017`0F7oo001FOol4O00eOol01@0OOomoogoo01l00Woo00D0
7goo01l07goo009l000501moogoo01moo`0201l2O0001Woo01l07goo01moo`9l00<07`=oo`03O000
7goo00=oo`0301ml07`000807`9l00807`=l000301ml07`005Moo`00EGoo17`0=Woo00D07gooOomo
o`0O009oo`807`03Ool07goo009oo`9l0003Ool07goo00807`9oo`9l00807`04Ool07goo01l2O002
Ool201l00goo01ml000401l2Ool01G`0OomoogooO0000goo00=l000OO0000W`0EWoo001DOol4O00g
Ool01@0OOomoogoo01l00Woo0P0O00Eoo`0OOomoo`0O009oo`9l00807`9oo`0601moo`0OO01oo`0O
0Woo00<07gooOol00W`000=oo`0O01l00P0O0W`01@0O00Al000O01l07`9l00807`El05Eoo`00Dgoo
1G`0=goo00<07gooOol00P0O00Ioo`0OOol07goo01l2Ool01@0OOomoo`0OOol00W`000=oo`0OOol0
0P0O00Aoog`0O01oo`@07`04Ool07g`0Ool401l017ooO01l07oo0`0O00=l07oo01l00Woo00=l07oo
01l017`000<07gooOol0DWoo001BOol5O00hOol00`0OOomoo`0201l01Woo01moo`0OOol07`9oo`03
01moo`0O009oo`0601moog`0O0007goo0P0O00Ioo`0OO01l000OOol401l2O00601l01W`0Oomoogoo
01ml00@07`03O0007g`000Al05Aoo`00DGoo1G`0>Goo00<07gooOol00P0O00=oo`0OOol00P0O0Woo
0P0O00Aoo`0OOomoo`807`03Ool07g`000807`03Ool07goo00807`9l00D07`03Ooml07oo009oo`03
01moogoo009l009oo`0301ml07oo009oo`0301ml000O009l000301ml07`005=oo`00DGoo17`0>Woo
00<07gooOol00P0O00=oo`0OOol00P0O0Woo00<07goo01l00Woo100O0Woo00<07g`001l01P0O00El
07ooOomoo`0O009oo`9l0003Ool07goo00=oo`05O01oo`0OOoml0002Ool01P0OOoml07ooO0007`=l
059oo`00D7oo17`0>goo00<07gooOol00P0O00=oo`0OOol00P0O00Ioo`0O01moo`0OOol301l00goo
01moo`0301l2O00301l3Ool2O0000`0OOomoo`03Ool00g`001moo`04Ool2O002Ool2O0001P0OOomo
og`0Ool07`=l059oo`00D7oo17`0>goo00@07gooOol07`9oo`807`03Ool07goo00<07`03Ool07goo
00<07`03Ool07`0O00<07`04Ooml07`001l5Ool2O005Ool00`0OO01oo`03Ool00`0OOoml0003Ool0
1W`0OomoogooO0007`Al055oo`00Cgoo17`0?7oo00@07gooOol07`9oo`<07`9oo`<07`05Ool07goo
01moo`0501l4Ool00`0OO01oo`03Ool00`0OOomoo`02O002Ool0100OOomoog`00goo00@07gooOoml
009oo`0301ml07`0009oo`06O01oog`0O0007g`0D7oo001>Ool4O00mOol0100OOomoo`0O0Woo0`0O
00Uoo`0O01l07goo01moo`0OOol01@0O1Goo00@07gooO01l009oo`0301moogoo009oo`03O01oo`0O
00=oo`9l000301moogoo009oo`03O01oo`0O009oo`05O01oo`0OO01oo`04O01?Ool004ioo`=l03io
o`0401moogoo01l2Ool301l00goo01l07`0201l00goo01l07`0301l00goo01moo`04Ool00`0OOomo
o`02Ool2O0000`0OOomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool017`0
01ml07oo0g`000<07gooOol0CGoo001=Ool4O00nOol01`0OOomoo`0OOol07goo00807`04Ool07`0O
Ool601l2Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OO01l0004Ool00`0OO01oo`03Ool00`0O
Ooml0004Ool00`0OO01oo`02Ool01W`0Oomoog`0Ool07`=l04ioo`00CGoo17`0?Woo00/07gooOol0
7goo01moo`0OOol07goo00L07`=oo`0301moogoo009oo`0301moogoo00Aoo`0401moogooO002Ool0
0`0OOomoo`02O002Ool0100OOomoog`00Woo00@07gooOoml009oo`0601ml07ooOoml000O0W`000<0
7g`0Ool0C7oo001<Ool5O00nOol02@0OOomoo`0OOol07goo01moo`0701l4Ool00`0OOomoo`03Ool0
0`0OOomoo`03Ool00`0OOomoo`02Ool00g`0Ool07`04Ool00g`001moo`03Ool2O0002@0OOomoogoo
O01oo`0OOoml0002Ool01@0OO01l000OO000CGoo001<Ool4O00oOol01@0OOomoo`0OOol0100O00=o
o`0O01l0100O17oo00<07gooOol00Woo00<07gooOol017oo00<07gooOol00goo00=l07ooOol017oo
00<07gooOol017oo00=l07ooOol00Woo00Al000OOoml009oo`0301ml07`000=l04aoo`00C7oo17`0
?goo00D07goo01l07goo00T07`03Ool07goo00=oo`0301moogoo009oo`0301moogoo00Aoo`0301mo
ogoo00=oo`0301ml07`000Aoo`0301ml07oo00=oo`0301moog`000=oo`0701ml07ooOoml000OOol0
0W`000<07g`0O000C7oo001;Ool5O00oOol00`0OOol07`0201l00goo01l07`0501l00goo01moo`04
Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`03Ool01@0OOomoogooO0000Woo00@07goo
Ooml00=oo`0401moogooO002Ool00`0OOoml0002Ool01G`0Oomoog`001l00g`0Bgoo001;Ool5O00o
Ool00`0OOol07`0601l00goo01l07`02Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`03
Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00g`0Ool07`03Ool2O0000`0OOomoo`02Ool00g`0Ool0
7`02Ool017`0Ool07g`00Woo17`0Bgoo001:Ool3O0000gooO01l000oOol501l017oo01l07goo0`0O
0Woo00<07gooOol00Woo00<07gooOol00Woo00<07gooOol00goo00<07gooOol017oo00<07gooOol0
0goo00=l000OOol017oo00=l07ooOol00Woo00=l07oo01l00goo00=l000OO0000Woo00<07g`0O000
0W`0BWoo001:Ool3O0000gooO01l000mOol301l00goo01l07`0701l2Ool00`0OOomoo`03Ool00`0O
Oomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OO01oo`04Ool00`0O
O01oo`03Ool00g`0Oomoo`02Ool027`0Oomoog`0Ool07g`001l2O01:Ool004Uoo`Al0003Ooml07`0
03]oo`807`9oo`D07`03Ool07`0O00807`=oo`0301moogoo009oo`0301moogoo00=oo`0301moogoo
009oo`0301moogoo00Aoo`0301moogoo00Aoo`0401moog`0O002Ool0100OOomoog`00goo00<07g`0
Ool00Woo00L07g`0Oomoog`001moo`04O019Ool004Uoo`Al0003Ooml07`003Uoo`807`=oo`807`03
Ool07`0O00H07`=oo`0301moogoo009oo`0301moogoo009oo`0301moogoo00=oo`0301moogoo00Ao
o`0301moogoo00=oo`0301moogoo009oo`03O01oo`0O00=oo`03O01oo`0O009oo`06O01oogoo01mo
og`00Woo00<07gooO0000g`0BGoo0019Ool4O0000gooO01l000hOol0100OOomoogoo0P0O00Eoo`0O
01l07goo00H07`=oo`0301moogoo009oo`0301moogoo009oo`0301moogoo009oo`0301moogoo00Ao
o`0301moogoo00Aoo`0301moogoo00=oo`03O01oogoo00=oo`03O0007goo009oo`05O01oo`0OOoml
0002Ool00`0OO01oo`03O019Ool004Qoo`El0004Ooml07ooO00eOol201l3Ool00`0OOomoo`0201l0
0goo01l07`0501l3Ool00`0OOomoo`03Ool01@0OOomoogoo01l01Goo00<07gooOol017oo00<07goo
Ool00goo00<07gooOol017oo00<07g`0Ool017oo00=l07ooOol00Woo00Yl07ooOomoog`001moog`0
Ool07`=l04Qoo`00B7oo1G`000Aoog`0Ooml03Aoo`0301moogoo009oo`0501moogoo01moo`0901l3
Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomoo`04Ool00`0OOomoo`04
Ool00`0OOomoo`03Ool0100OOomoog`00goo00<07gooO0000goo00<07g`0Ool00Woo00El07ooOoml
000O00=l04Qoo`00B7oo1G`000Aoog`0Ooml03=oo`0401moogooOol201l2Ool01@0OOomoo`0OOol0
1@0O00=oo`0OOol00Woo00<07gooOol00Woo00D07gooOomoo`0O00Eoo`0301moogoo00Aoo`0301mo
ogoo00=oo`0301moogoo00Aoo`0401moogooO003Ool01P0OOomoog`0Ool07`9oo`05O01oogoo01ml
0002Ool5O017Ool004Moo`Il0004Ooml07ooO00aOol201l3Ool01@0OOomoogoo01l00Woo0P0O00=o
o`0O01l00`0O00Eoo`0OOomoo`0O00Eoo`0501moogooOol07`04Ool00`0OOomoo`04Ool00`0OOomo
o`04Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00g`0Ool07`04Ool00g`001moo`02Ool017`0Ool0
7g`00Woo00<07g`0O0000W`0Agoo0017Ool4O00017ooO01oog`00Woo00=l07ooOol0;Goo00<07goo
Ool00Woo00<07gooOol00Woo00@07goo01moo`H07`9oo`0401moogoo01l4Ool00`0OOomoo`02Ool0
0`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`03Ool0
0g`001moo`03Ool00g`001moo`03Ool01W`0Oomoog`001moo`El04Ioo`00Agoo17`000Aoog`0Ooml
009oo`03O01oogoo02aoo`0401moogooOol201l4Ool01@0OOomoo`0OOol01P0O00=oo`0OOol00Woo
00<07gooOol00Woo00D07gooOomoo`0O00Eoo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo
00=oo`0301moogoo00Aoo`0301ml07oo00=oo`0301ml07oo00=oo`06O01oogooOoml07oo1G`0AWoo
0017Ool4O0001gooO01oogooO01oog`002eoo`0501moogooOol07`05Ool0100OOomoo`0O0Woo1@0O
0Woo00D07gooOomoo`0O00=oo`0301moogoo009oo`0301moogoo009oo`0301moogoo00=oo`0301mo
ogoo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moog`000=oo`0301moog`0009oo`0301mo
og`0009oo`0301moogoo00Al04Ioo`00Agoo17`00Woo00El07ooO01oog`002aoo`0501moogooOol0
7`04Ool201l2Ool00`0OOomoo`0601l2Ool0100OOomoo`0O17oo00D07gooOomoo`0O00Eoo`0301mo
ogoo00=oo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00Aoo`0701moogooOoml07oo01l0
0goo00El07oo01moog`0009oo`0301ml07oo00El04Eoo`00AWoo1G`00Woo00=l07ooO0000Woo00=l
07ooOol0:7oo00D07gooOomoo`0O00Aoo`0301moogoo00807`9oo`L07`9oo`0401moogoo01l3Ool0
0`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`04Ool0
0`0OOomoo`04Ool00`0OOomoo`02Ool00g`001moo`02Ool00g`0Ool07`02Ool017`0Ool07g`00Woo
17`0AGoo0016Ool4O0001WooO01oog`0Ooml009oo`03O01oogoo02Moo`0501moogooOol07`04Ool0
100OOomoo`0O0Woo0`0O00=oo`0O01l00`0O0Woo00@07gooOol07`=oo`0501moogooOol07`05Ool0
0`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`03Ool0
0`0OO01oo`03Ool00g`0Oomoo`02Ool01G`0Oomoog`0Ool017`0AGoo0016Ool4O00017ooO01oog`0
0Woo00=l07ooO0009goo0P0O0goo00<07gooOol00Woo00@07gooOol07`9oo`0501moogoo01moo`05
01l2Ool0100OOomoo`0O0goo00D07gooOomoo`0O00Aoo`0301moogoo00=oo`0301moogoo00Aoo`03
01moogoo00Aoo`0301moogoo00=oo`0301moogoo00Aoo`0301moog`000=oo`0301ml07oo009oo`05
O01oogooO01oo`04O015Ool004Ioo`Al0004Ooml07ooO002Ool017`0Oomoog`09Goo00<07gooOol0
0Woo00<07gooOol00Woo00@07gooOol07`9oo`0401moogoo01l2Ool501l01Goo01moogoo01l00goo
00<07gooOol00Woo00<07gooOol00Woo00<07gooOol00goo00<07gooOol017oo00<07gooOol00goo
00<07gooOol017oo00<07gooOol00goo00T07gooOomoog`0Ool07gooO0000goo00H07g`0Oomoog`0
Ool3O015Ool004Ioo`Al0007Ooml07ooOoml07ooO0000Woo00=l07ooOol08Woo00<07gooOol00Woo
00<07gooOol00Woo00@07gooOol07`9oo`0401moogoo01l2Ool401l017oo01moo`0O0Woo00D07goo
Oomoo`0O00=oo`0301moogoo009oo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo00Aoo`03
01moogoo00=oo`0301moogoo00Aoo`0701moogooOoml07oo01l00Woo00Ul07ooOol07gooO01oog`0
Ool017`0A7oo0015Ool5O002Ool01G`0Ooml07ooO0000goo00=l07ooOol07goo0P0O17oo00<07goo
Ool00Woo00@07gooOol07`=oo`0301moo`0O009oo`D07`04Ool07goo01l2Ool0100OOomoo`0O17oo
00<07gooOol00Woo00<07gooOol00goo00<07gooOol00goo00<07gooOol017oo00<07gooOol017oo
00<07gooOol00goo00<07gooOol00goo00=l000OOol00Woo00El000OOomoog`0009oo`El04Aoo`00
AGoo1G`00Woo00=l07ooO0000Woo00Al07ooOoml021oo`0301moogoo00=oo`0401moogooOol201l2
Ool01@0OOomoogoo01l00Woo00@07goo01moo`D07`9oo`0401moogoo01l2Ool01@0OOomoogoo01l0
17oo00<07gooOol00goo00<07gooOol017oo00<07gooOol017oo00<07gooOol00goo00<07gooOol0
0goo00<07gooOol017oo00<07g`0Ool00goo00Ql07ooOomoog`0Ooml07oo0g`0A7oo0015Ool4O000
1WooO01oog`0Ooml009oo`05O01oogooOoml000NOol00`0OOomoo`03Ool01@0OOomoogoo01l00goo
00D07gooOomoo`0O009oo`0301moogoo00D07`04Ool07goo01l2Ool01@0OOomoogoo01l00goo00<0
7gooOol00Woo00<07gooOol00goo00<07gooOol00goo00<07gooOol017oo00<07gooOol017oo00<0
7gooOol00goo00<07gooOol017oo00<07g`0Ool00Woo00<07g`0Ool00Woo00=l07ooOol017`0A7oo
0015Ool3O0001GooO01l07ooO0000Woo00=l07ooO0000goo00=l07ooOol06goo00<07gooOol00goo
00D07gooOomoo`0O00Aoo`0401moogoo01l2Ool01@0OOomoo`0OOol0100O00Aoo`0OOol07`9oo`04
01moogoo01l3Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`04Ool0
0`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`04Ool0100OOomoog`00Woo00<07gooO0000goo
00=l07ooO0000g`0A7oo0015Ool3O0001GooO01l07ooO0000Woo00Al07ooOoml00=oo`03O01oogoo
01Uoo`0301moogoo00=oo`0501moogooOol07`04Ool01`0OOomoogoo01moo`0O009oo`0401moo`0O
Ool301l017oo01moo`0O0Woo00@07gooOol07`=oo`0301moogoo009oo`0301moogoo00=oo`0301mo
ogoo00=oo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00Aoo`0601mo
ogooOoml000O0goo00El07ooOoml07oo00Al04Aoo`00AGoo0g`000=oog`0O0000Woo00=l07ooO000
0Woo00El07ooOomoog`001Yoo`0301moogoo00=oo`0301moogoo009oo`0501moogooOol07`03Ool0
1P0OOomoo`0OOol07`9oo`807`07Ool07`0OOol07goo01l00Woo00@07gooOol07`=oo`0501moogoo
Ool07`05Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0O
Oomoo`04Ool00`0OOomoo`02Ool00g`001moo`02Ool01W`0OomoogooO01oo`Al04=oo`00A7oo17`0
00Qoog`0Ooml07ooO01oog`00goo00El07ooOomoog`001Qoo`0301moogoo009oo`807`Aoo`0501mo
ogooOol07`03Ool0100OOomoo`0O0Woo00@07goo01moo`@07`03Ool07`0O009oo`0401moogoo01l3
Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`04
Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`02Ool00`0OO01oo`03Ool01G`0Oomoog`0
Ool017`0@goo0014Ool4O0001WooO01oog`0Ooml009oo`04O01oogooO003Ool00g`0Oomoo`0EOol0
0`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`02Ool0100OOomoo`0O0Woo00@07gooOol07`9o
o`807`03Ool07`0O00807`05Ool07gooOol07`02Ool01@0OOomoogoo01l00goo00<07gooOol00goo
00<07gooOol00goo00<07gooOol017oo00<07gooOol017oo00<07gooOol00goo00<07gooOol017oo
00<07gooOol00goo00<07g`0Ool00goo00El07ooOoml07oo00Al04=oo`00A7oo17`000Ioog`0Ooml
07ooO002Ool017`0Oomoog`017oo00=l07ooOol04goo00<07gooOol00Woo00<07gooOol00goo00<0
7gooOol00Woo00@07gooOol07`9oo`0401moogoo01l2Ool0100OOol07goo100O00Aoo`0OOol07`9o
o`0501moogooOol07`04Ool00`0OOomoo`02Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomo
o`04Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`03Ool0100OOomoog`00goo00Al07oo
Oomoo`El04=oo`00A7oo1W`000Eoog`0Oomoog`0009oo`04O01oogooO004Ool00g`0Oomoo`0AOol0
0`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`02Ool0100OOomoo`0O0goo00T07gooOol07goo
01moo`0OOol01@0O00Aoo`0OOol07`9oo`0501moogooOol07`03Ool00`0OOomoo`03Ool00`0OOomo
o`03Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomo
o`02Ool01@0OOomoogooO00017oo00=l07ooOol01G`0@goo0014Ool6O002Ool00g`0Ooml0002Ool0
17`0Oomoog`017oo00=l07ooOol047oo00<07gooOol00goo00<07gooOol00Woo00<07gooOol00Woo
00@07gooOol07`=oo`0401moogoo01l2Ool0100OOol07goo0`0O00=oo`0O01l00Woo00@07gooOol0
7`=oo`0501moogooOol07`04Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0O
Oomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`02Ool01G`0OomoogooO0000Woo
1G`0@goo0014Ool6O002Ool017`0Oomoog`00Woo00Al07ooOoml00Aoo`03O01oogoo00ioo`0301mo
ogoo00=oo`0301moogoo009oo`0301moogoo009oo`0401moogoo01l3Ool02P0OOomoogoo01moo`0O
Ool07goo1@0O00Aoo`0OOol07`9oo`0501moogooOol07`04Ool00`0OOomoo`02Ool00`0OOomoo`03
Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`05Ool00`0OOomoo`03Ool00`0OOomoo`03
Ool00`0OOomoo`03Ool01G`0OomoogooO0000goo17`0@goo0014Ool5O0001gooO01oogooO01oog`0
009oo`05O01oogooOoml0004Ool00g`0Oomoo`0<Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0O
Oomoo`02Ool01@0OOomoogoo01l00goo00@07gooOol07`9oo`0401moo`0OOol501l017oo01moo`0O
0Woo00D07gooOomoo`0O00=oo`0301moogoo009oo`0301moogoo00=oo`0301moogoo00=oo`0301mo
ogoo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00Aoo`05O01o
ogooOoml0002Ool4O013Ool004Aoo`El0005Ooml07ooOoml0002Ool017`0Oomoog`00Woo00=l07oo
Ool00goo00=l07ooOol02Woo00<07gooOol00goo00<07gooOol00Woo00<07gooOol00Woo00D07goo
Oomoo`0O00=oo`0701moogooOol07goo01l00Woo00<07goo01l0100O00Aoo`0OOol07`9oo`0401mo
ogoo01l4Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0O
Oomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`05Ool01G`0OomoogooO0000Woo
17`0@goo0014Ool4O0001WooO01oog`0Ooml009oo`04O01oogooO003Ool00g`0Oomoo`02Ool00g`0
Oomoo`09Ool00`0OOomoo`03Ool00`0OOomoo`02Ool00`0OOomoo`02Ool01@0OOomoogoo01l017oo
00@07gooOol07`9oo`0601moo`0OOol07goo1@0O00Eoo`0OOomoo`0O00=oo`0501moogooOol07`04
Ool00`0OOomoo`02Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`05Ool00`0OOomoo`04
Ool00`0OOomoo`03Ool00`0OOomoo`06Ool01W`0OomoogooO01oo`Al04=oo`00A7oo1W`000Aoog`0
Ooml00=oo`04O01oogooO003Ool00g`0Oomoo`02Ool00g`0Oomoo`08Ool00`0OOomoo`02Ool00`0O
Oomoo`02Ool00`0OOomoo`02Ool01@0OOomoogoo01l017oo00L07gooOomoo`0OOol07`02Ool00`0O
Ool07`0601l01Goo01moogoo01l00Woo00<07gooOol00Woo00D07gooOomoo`0O00Eoo`0301moogoo
00=oo`0301moogoo00=oo`0301moogoo00Eoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo
00Moo`05O01oogooOoml0002Ool3O013Ool004Aoo`Il0005Ooml07ooOoml0002Ool017`0Oomoog`0
17oo00=l07ooOol00Woo00=l07ooOol01Woo00<07gooOol00Woo00<07gooOol00goo00D07gooOomo
o`0O00Aoo`0501moogooOol07`03Ool02@0OOomoo`0OOol07goo01moo`0601l017oo01moo`0O0goo
00D07gooOomoo`0O00Aoo`0301moogoo009oo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo
00Aoo`0301moogoo00Aoo`0301moogoo00=oo`0301moogoo00Uoo`04O01oogooO002Ool3O013Ool0
04Aoo`Il009oo`03O01oog`0009oo`05O01oogooOoml0003Ool00g`0Oomoo`03Ool00g`0Oomoo`04
Ool00`0OOomoo`02Ool00`0OOomoo`03Ool01@0OOomoogoo01l017oo00D07gooOomoo`0O00=oo`04
01moogoo01l2Ool0100OOol07goo100O00Ioo`0OOol07goo01l2Ool00`0OOomoo`02Ool01@0OOomo
ogoo01l017oo00<07gooOol017oo00<07gooOol00goo00<07gooOol01Goo00<07gooOol00goo00<0
7gooOol017oo00<07gooOol02Goo00Il07ooOomoog`0Ool3O013Ool004Aoo`El0006Ooml07ooO01o
og`00goo00El07ooOomoog`000=oo`03O01oogoo009oo`03O01oogoo00=oo`0301moogoo00=oo`03
01moogoo009oo`0301moogoo009oo`0501moogooOol07`04Ool0100OOomoo`0O0goo00L07gooOol0
7goo01moo`0501l017oo01moo`0O0goo00D07gooOomoo`0O00Aoo`0301moogoo009oo`0301moogoo
00=oo`0301moogoo00=oo`0301moogoo00Eoo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo
00]oo`03O01oogoo00El04=oo`00A7oo17`000=oog`0O0000Woo00=l07ooO0000Woo00El07ooOomo
og`000Aoo`03O01oogoo009oo`03O01oogoo009oo`0301moogoo009oo`0301moogoo009oo`0301mo
ogoo009oo`0501moogooOol07`04Ool01@0OOomoogoo01l00Woo00T07gooOol07goo01moo`0OOol0
100O00Aoo`0OOol07`9oo`0301moogoo009oo`0501moogooOol07`04Ool00`0OOomoo`03Ool00`0O
Oomoo`03Ool00`0OOomoo`05Ool00`0OOomoo`04Ool00`0OOomoo`03Ool00`0OOomoo`0<Ool00g`0
Oomoo`05O013Ool004Eoo`=l0008Ooml07ooO01oog`0Ooml00=oo`05O01oogooOoml0004Ool00g`0
Oomoo`02Ool017`0Oomoo`0O17oo00<07gooOol00goo00D07gooOomoo`0O00Aoo`0501moogooOol0
7`03Ool01@0OOomoogoo01l00Woo00@07goo01moo`H07`04Ool07goo01l2Ool01@0OOomoogoo01l0
17oo00D07gooOomoo`0O00Eoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301mo
ogoo00=oo`0301moogoo00eoo`04O01oogooOol4O013Ool004Eoo`Al0003Ooml07`0009oo`03O01o
og`000=oo`05O01oogooOoml0003Ool00g`0Oomoo`03Ool00g`001moo`03Ool00`0OOomoo`03Ool0
1@0OOomoogoo01l017oo00<07gooOol00Woo00@07gooOol07`=oo`0901moogoo01moo`0OOol07goo
00D07`03Ool07`0O00=oo`0401moogoo01l4Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomo
o`04Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`0>Ool00g`0Oomo
o`04O013Ool004Eoo`Al0003Ooml07`0009oo`04O01oogooO002Ool00g`0Oomoo`02Ool01G`0Oomo
ogooO00017oo00<07g`0Ool00Woo00<07gooOol00goo00<07gooOol00Woo00D07gooOomoo`0O00Ao
o`0501moogooOol07`02Ool02P0OOomoogoo01moo`0OOol07goo1P0O00Eoo`0OOomoo`0O00=oo`05
01moogooOol07`04Ool00`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`05Ool00`0OOomoo`03
Ool00`0OOomoo`04Ool00`0OOomoo`0?Ool00g`0Oomoo`04O013Ool004Eoo`Al0004Ooml07ooO002
Ool00g`0Ooml0003Ool01G`0OomoogooO00017oo00Ul07ooOomoo`0OOoml07oo01l01Goo00<07goo
Ool00Woo00D07gooOomoo`0O00Eoo`0401moogoo01l3Ool0100OOomoo`0O0Woo00@07goo01moo`@0
7`03Ool07`0O00=oo`0401moogoo01l4Ool01@0OOomoogoo01l01Goo00<07gooOol00goo00<07goo
Ool01Goo00<07gooOol00goo00<07gooOol017oo00<07gooOol04Goo00=l07ooO0000g`0@goo0015
Ool4O002Ool2O002Ool017`0Oomoog`00goo00El07ooOomoog`000Aoo`03O01oo`0O00=oo`03O01o
ogoo00Aoo`0501moogooOol07`04Ool00`0OOomoo`02Ool01@0OOomoogoo01l00Woo00L07gooOomo
o`0OOol07`02Ool00`0OOol07`0301l00goo01l07`02Ool01@0OOomoogoo01l00goo00<07gooOol0
0Woo00<07gooOol00Woo00<07gooOol00goo00<07gooOol01Goo00<07gooOol00goo00<07gooOol0
1Goo00<07gooOol04Goo00=l07ooO0000g`0@goo0015Ool5O0001WooO01oog`0Ooml009oo`03O01o
ogoo009oo`05O01oogooOoml0004Ool00g`0Oomoo`02Ool00`0OO01oo`03Ool01@0OOomoogoo01l0
17oo00<07gooOol00Woo00D07gooOomoo`0O00=oo`0401moogoo01l2Ool01P0OOol07goo01moo`<0
7`03Ool07`0O009oo`0401moogoo01l3Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomoo`04
Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`0BOol00g`0Ooml0003
O013Ool004Eoo`El009oo`9l009oo`04O01oogooO003Ool00g`0Oomoo`02Ool01W`0Oomoo`0OOoml
009oo`0401moogooO002Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomoo`02Ool01@0OOomo
ogoo01l00goo00H07gooOol07goo01l2Ool0100OOol07goo1@0O0Woo00D07gooOomoo`0O009oo`03
01moogoo009oo`0301moogoo00=oo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo00Aoo`03
01moogoo00Aoo`0301moogoo01=oo`03O01oog`0009l04Aoo`00AGoo17`000Qoog`0Ooml07ooO01o
og`00Woo00=l07ooOol00Woo00=l07ooOol00Woo00=l000OOol00Woo00=l000OOol00goo00=l000O
Ool00goo00<07gooOol00Woo00<07gooOol00Woo00D07gooOomoo`0O00=oo`0701moogooOol07goo
01l00Woo00@07goo01moo`D07`9oo`0401moogoo01l3Ool01@0OOomoogoo01l01Goo00<07gooOol0
0goo00<07gooOol017oo00<07gooOol017oo00<07gooOol017oo00<07gooOol05Goo17`0A7oo0015
Ool6O00017ooO01oog`00Woo00Al07ooOoml00Aoo`06O01oogooOol07g`017oo00=l07ooOol00goo
00El07ooOomoo`0O00Eoo`0501moogooOol07`04Ool01@0OOomoogoo01l00Woo00H07gooOol07goo
01l2Ool00`0OOol07`0401l01Goo01moogoo01l00goo00<07gooOol00Woo00<07gooOol00Woo00<0
7gooOol00goo00<07gooOol01Goo00<07gooOol00goo00<07gooOol017oo00<07gooOol05Woo17`0
A7oo0015Ool6O002Ool01G`0Ooml07ooO0000Woo00=l07ooOol00goo00Il07ooOol07gooO002Ool0
0`0OOoml0003Ool01@0OO01oogoo01l01Goo00D07gooOomoo`0O00Aoo`0501moogooOol07`03Ool0
0`0OOol07`02Ool01P0OOol07goo01moo`<07`9oo`0401moogoo01l2Ool00`0OOomoo`02Ool00`0O
Oomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`05Ool00`0OOomoo`03Ool00`0OOomoo`05Ool00`0O
Oomoo`0FOol4O014Ool004Ioo`Al0006Ooml07ooO01oog`00Woo00Al07ooOoml00Aoo`03O01oo`0O
00=oo`03O01oo`0O009oo`03O01oo`0O009oo`03O01oo`0O00Eoo`0501moogooOol07`03Ool00`0O
Oomoo`02Ool0100OOomoo`0O0Woo00<07goo01l00Woo00@07goo01moo`<07`05Ool07gooOol07`03
Ool01@0OOomoogoo01l01Goo00<07gooOol00Woo00<07gooOol01Goo00<07gooOol00goo00<07goo
Ool01Goo00<07gooOol05Woo1G`0A7oo0016Ool6O002Ool01G`0Ooml07ooO0000goo00=l07ooOol0
0Woo00=l000OOol00Woo00=l000OOol00goo00=l07ooOol00Woo00<07gooOol00goo00D07gooOomo
o`0O00Aoo`0501moogooOol07`03Ool01P0OOomoo`0OOol07`9oo`0401moo`0OOol201l2Ool0100O
Oomoo`0O0Woo00<07gooOol00Woo00<07gooOol00Woo00<07gooOol00goo00<07gooOol017oo00<0
7gooOol017oo00<07gooOol017oo00<07gooOol05goo17`0AGoo0016Ool5O0001WooO01oog`0Ooml
009oo`05O01oogooOoml0003Ool00`0OO01oo`02Ool00`0OO01oo`03Ool01`0OO01oogoo01moog`0
00=oo`0301moogoo009oo`0501moogooOol07`03Ool01@0OOomoogoo01l00goo00<07goo01l00Woo
00@07goo01moo`807`05Ool07gooOol07`02Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomo
o`03Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`0HOol4O015Ool0
04Moo`=l0003Ooml07`0009oo`03O01oog`0009oo`05O01oogooOoml0002Ool00`0OOoml0002Ool0
0`0OOoml0002Ool01P0OOomoog`0Ool07`9oo`9l0003Ool07goo009oo`0301moogoo009oo`0501mo
ogooOol07`03Ool0100OOomoo`0O0Woo00D07gooOol07goo00@07`07Ool07gooOol07goo01l017oo
00<07gooOol00Woo00<07gooOol00goo00<07gooOol017oo00<07gooOol017oo00<07gooOol017oo
00<07gooOol067oo1G`0AGoo0017Ool5O0001WooO01oog`0Ooml00=oo`06O01oogooOoml000O0goo
00=l000OOol00Woo00=l000OOol00goo00=l07ooOol00goo00=l07ooOol00Woo00D07gooOomoo`0O
00=oo`0501moogooOol07`03Ool00`0OOol07`02Ool0100OOol07goo100O0Woo00@07gooOol07`=o
o`0301moogoo009oo`0301moogoo00=oo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00Ao
o`0301moogoo01Uoo`Al04Ioo`00Agoo17`000=oog`0O0000Woo00=l07ooO0000goo00El07ooOomo
o`0O00=oo`0301ml07oo00=oo`9l00=oo`0301ml07oo009oo`0301moog`0009oo`0301moogoo009o
o`0501moogooOol07`03Ool0100OOomoo`0O0Woo00L07gooOol07goo01moo`0401l2Ool00`0OOol0
7`04Ool01@0OOomoogoo01l01Goo00<07gooOol017oo00<07gooOol017oo00<07gooOol017oo00<0
7gooOol06Woo17`0AWoo0018Ool3O0001WooO01oog`0Ooml009oo`09O01oogooOoml07oo01moog`0
009oo`0301moog`0009oo`0601moogooO01oo`0O0Woo0W`000Aoo`0OOomoo`9l000501moogooOol0
7`03Ool00`0OOomoo`02Ool0100OOomoo`0O0Woo00L07gooOol07goo01moo`0401l017oo01moo`0O
17oo00D07gooOomoo`0O00Eoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301mo
ogoo01Yoo`El04Ioo`00B7oo17`000=oog`0O0000Woo00Al07ooOoml00=oo`06O0007gooO01oo`0O
0goo00=l07oo01l00goo00=l000OOol00goo00=l07ooOol00Woo00<07g`0Ool00Woo00D07gooOomo
o`0O00=oo`0401moogoo01l3Ool01`0OOomoo`0OOol07goo00<07`9oo`0301moo`0O00=oo`0501mo
ogooOol07`05Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`0KOol5
O016Ool004Qoo`Al0004Ooml07ooO002Ool00g`0Ooml0003Ool01P0OO01oogooO0007`Aoo`03O01o
ogoo009oo`0301ml07oo00=oo`0301ml07oo009oo`0501moog`0O0007`03Ool00`0OOomoo`02Ool0
100OOomoo`0O0goo00D07gooOol07goo00D07`04Ool07goo01l3Ool01@0OOomoogoo01l01Goo00<0
7gooOol017oo00<07gooOol017oo00<07gooOol017oo00<07gooOol077oo17`0Agoo0019Ool2O000
27ooO01oog`0Ooml07ooO002Ool01G`0Oomoo`0OO0000Woo00<07g`0Ool00goo00<07g`0Ool00Woo
00<07gooO0000Woo00<07gooOol00W`000D07gooOomoo`0O009l009oo`0501moogooOol07`02Ool0
1@0OOomoogoo01l00Woo00<07gooOol01@0O00Aoo`0OOol07`9oo`0301moogoo009oo`0301moogoo
009oo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo01aoo`=l0003Ooml
07oo04Ioo`00BGoo17`00Woo0W`00Woo00El07ooOoml000O009oo`05O01oo`0OOoml0002Ool01P0O
Oomoog`0Ool07`=oo`03O0007goo00Aoo`05O01oogooOol07`02Ool00g`001moo`03Ool0100OOomo
o`0O0goo00@07gooOol07`9oo`H07`03Ool07goo009oo`0501moogooOol07`04Ool00`0OOomoo`04
Ool00`0OOomoo`04Ool00`0OOomoo`04Ool00`0OOomoo`0MOol5O017Ool004Uoo`=l0008Ooml07oo
O01oog`0Ooml00=oo`05O01oogooOoml0003Ool2O000100OOomoogoo0W`017oo00=l07ooOol00Woo
00D07gooO01oo`0O00Aoo`05O01oogooOol07`03Ool01@0OOomoogoo01l00Woo00<07gooOol01P0O
00Eoo`0OOomoo`0O00=oo`0301moogoo009oo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo
00Aoo`0301moogoo01eoo`El04Qoo`00BWoo17`00Woo0W`00Woo00Al07oo01ml00=oo`0301ml07oo
009oo`0301ml07oo009oo`0301moog`0009oo`0601moog`0O01oo`0O0goo0W`00goo00H07gooO01l
07oo01l3Ool01@0OOomoogoo01l00Woo00<07gooOol01@0O00Eoo`0OOomoo`0O00=oo`0301moogoo
009oo`0301moogoo00Aoo`0301moogoo00=oo`807`Ioo`0301moogoo01ioo`9l0003Ooml07`004Qo
o`00BWoo0g`000Ioog`0Ooml07ooO002Ool017`001moog`00Woo00<07gooO0000Woo00D07gooO01o
o`0O00=oo`03O0007goo00=oo`03O0007goo009oo`0301moog`0009oo`0501moogooOoml0003Ool0
1@0OOomoogoo01l00goo00<07gooOol01P0O0Woo00<07gooOol00Woo00D07gooOomoo`0O00Ioo`03
01moogoo00=oo`0301moogoo00Eoo`0301moogoo01ioo`Il04Qoo`00BWoo1G`00Woo00Il07ooO01o
og`001l2Ool00g`001moo`02Ool00g`001moo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00`0O
O01l0002Ool01@0OOomoog`001l017oo00D07g`0Oomoo`0O00=oo`0401moogoo01l2Ool401l00goo
01moo`02Ool01@0OOomoogoo01l00goo00<07gooOol017oo00<07gooOol00goo00<07gooOol01Goo
00<07gooOol07goo1G`0BGoo001;Ool3O0002GooO01oogooO01oog`001ml0003Ool01P0OOomoogoo
01ml00=oo`0301ml07oo009oo`0601moog`0O01oo`0O0goo0W`017oo0W`00Woo00<07gooOol00W`0
00@07gooOol07`=oo`0301moogoo00H07`9oo`0501moogooOol07`03Ool00`0OOomoo`03Ool201l5
Ool00`0OOomoo`04Ool201lQOol4O0000gooO01oo`18Ool004]oo`Al000=Ooml07ooO01oog`001mo
og`0Ool07gooO0000Woo00D07gooO01oo`0O009oo`03O01oo`0O00Aoo`03O0007goo00=oo`0501ml
07ooOol07`02Ool00g`0Ool07`03Ool01@0OO01oogoo01l00goo00<07goo01l01P0O00=oo`0OOol0
0Woo00D07gooOomoo`0O00Eoo`0301moogoo00Aoo`0301moogoo00Aoo`0301moogoo021oo`Ml04Uo
o`00C7oo0W`000Qoog`0Ooml07ooO01oog`00Woo00Il000OOomoog`001l3Ool00g`001moo`02Ool2
O004Ool00`0OO01oo`02Ool01P0OOomoog`0Ool07`=oo`9l00=oo`0501moog`0O0007`03Ool00`0O
Ool07`0201l00goo01moo`0201l2Ool201l3Ool00`0OOomoo`03Ool00`0OOomoo`03Ool201l6Ool0
0`0OOomoo`0POol7O01:Ool004aoo`Al000:Ooml07ooO01oo`0OO01oo`0OO003Ool00`0OOomoo`02
Ool01W`0Oomoogoo01moo`9l009oo`0601moog`0O01oo`0O0goo0W`00goo00D07gooO01l000O00=o
o`0601ml07`0Ool07goo1P0O00Eoo`0O01moo`0O00Aoo`0301moogoo00=oo`0301moogoo00=oo`03
01moogoo00Aoo`807b=oo`El0003Ooml07oo04Uoo`00CGoo0W`000Ioog`0Ooml07ooO002Ool017`0
01moog`00Woo00L07g`0Oomoo`0OOoml0002Ool01P0OOomoogooO0007`Aoo`03O01oogoo009oo`06
01moog`0O01oo`0O0goo00D07g`0Oomoo`0O009oo`9l0003Ool07`0O00@07`04Ool07goo01l4Ool0
0`0OOomoo`03Ool00`0OOomoo`03Ool00`0OOomoo`04Ool00`0OOomoo`0ROol7O01;Ool004eoo`Al
009oo`06O0007g`0Ooml000O0Woo00Al000OOomoo`9l000601moogooO01oo`0O17oo00=l07ooOol0
0Woo00<07g`0O0000Woo00@07gooOomoo`9l00=oo`0501moog`0O0007`03Ool01@0OO0007`0OOol0
1P0O17oo00<07gooOol00Woo0P0O17oo0P0O1Woo00<07gooOol08Woo1g`0C7oo001>Ool2O0002Goo
O01oogooO01oog`001ml0003Ool00g`0Oomoo`02Ool017`0Oomoogoo0W`00goo00@07gooO01l009o
o`0301moogoo009l000601moogooOol07goo0W`000=oo`0OOol00Woo0W`00Woo1@0O00Eoo`0O01mo
o`0O00Aoo`0301moogoo009oo`0301moogoo00=oo`0301moogoo00Aoo`807bAoo`Il0003Ooml07oo
04]oo`00CWoo0g`000Uoog`0Ooml07ooO0007gooO0000Woo00L07g`0Oomoo`0OOoml0002Ool00`0O
Ooml0002Ool01P0OOomoogooO0007`Aoo`0301ml07`0009oo`0401moogooOol2O002Ool00`0OOomo
o`02O00501l00g`001moo`0201l3Ool00`0OOomoo`02Ool00`0OOomoo`03Ool00`0OOomoo`04Ool0
0`0OOomoo`0SOol5O002Ool00g`0Oomoo`1;Ool004moo`=l0006Ooml000OO01oog`00Woo00Ml07oo
01moog`0Ool07`02Ool00g`0Ool07`02Ool2O0000`0OOomoo`02Ool2O003Ool00`0OOomoo`02O000
1P0OOomoogoo01moo`9l000801moogooOol07g`001ml00@07`03O0007`0O009oo`0301moogoo009o
o`0301moogoo009oo`807`Ioo`0301moogoo02=oo`Ql04ioo`00Cgoo0g`000Moog`001ml07oo01ml
0002Ool01G`0Oomoogoo01l017oo00=l07ooOol00Woo00<07g`0O0000goo00D07gooO01l000O00Ao
o`0601ml07`0O01oo`0O0goo00@07gooOomoo`@07`03O0007goo00807`04Ool07g`001l4Ool00`0O
Oomoo`02Ool00`0OOomoo`05Ool00`0OOomoo`0SOol7O01@Ool0051oo`=l000:Ooml07ooO0007goo
O01oo`0OO002Ool00`0OO01oo`02Ool00`0OO01oo`02Ool01P0OOomoog`0Ool07`Aoo`0301ml07oo
009oo`0401moogooOol2O003Ool0100OO01l07oo1P0O00Al000OO01oo`807`03Ooml07`000807`Ao
o`0301moogoo00Aoo`807bEoo`Ml055oo`00D7oo0g`000Eoo`0OO01oo`0O009oo`05O0007gooO000
7`02Ool2O0000`0OOomoo`02O0000`0OOomoo`02Ool2O003Ool00`0OOomoo`02O0000`0OOomoo`02
Ool01P0OOoml07`0Ool07`9oo`03O0007`0O00H07`03Ooml000O00=oo`0401moog`0O002Ool00`0O
Oomoo`04Ool00`0OOomoo`0TOol5O0000gooO01oo`1AOol0055oo`=l000801moog`001ml07oo01ml
009oo`03O01oogoo009oo`03O01oogoo009oo`9l00=oo`0601moog`0O01oo`0O17oo0g`00Woo00@0
7gooOomoo`9l009oo`@07`04O0007`0OOol401l2O0000`0OOomoo`02Ool201l2O004Ool00`0OOomo
o`0SOol9O01BOol0059oo`9l000;01moo`0OO01oog`001moog`0Ool07`02O002Ool01@0OO01l07oo
01l00Woo00Al07ooOol07`=oo`9l00Aoo`0301moogoo009l000601moogooOol07goo0W`01P0O0W`0
00<07gooOol00`0O00Eoog`0O01oo`0O00Aoo`9l00807bAoo`Yl05=oo`00Dgoo0g`000D07g`0Oomo
og`0009oo`06O0007gooOoml000O0goo0W`00goo0W`017oo00H07gooO01l07oo01l4Ool01P0OO01l
07`0Ool07`=oo`807`03O0007`0O00@07`04O0007`0OO004Ool0100OO01l07`00Woo0P0O00=oog`0
O0008Goo2G`000=oog`0Ool0Dgoo001COol2O0002WooO01oog`001moog`0Ool07g`00goo00<07goo
Ool00Woo00<07g`0Ool00Woo00<07g`0O0000Woo00@07gooOomoo`=l00=oo`0401moogooOol2O002
Ool301l01Woo01ml000OO01oo`807`03Ool07goo009l00807`Aoo`807`=l009oo`Al01]oo`Yl0003
Ooml07`005Aoo`00E7oo0W`000@07g`0Ooml009oo`9l0006Ooml07ooOol07g`00Woo00<07gooOol0
0W`000Aoo`0OOomoo`9l00Eoo`0501moog`0O0007`04Ool00`0OOoml000201l00goo01l07`0301l0
0goo01l07`02Ool01@0OOol07`0OOol017`000<07gooOol00goo1G`000=oog`0O0000g`04Goo2W`0
00Eoog`0O01l07oo009l05Eoo`00E7oo00L07g`0O0007g`001ml0002Ool01@0OO01oog`001l00Woo
0W`000<07gooOol00Woo0W`00goo00<07g`0O0000goo00@07gooOomoo`=l009oo`0301moo`0O00<0
7`04O0007`0OOol401l2O00201l5Ool201l5O006OolMO00017ooO01l07oo0W`000Aoog`0O01l05Io
o`00EGoo00h07g`001moog`0Ooml07oo01moog`0Ool07g`00goo00=l07ooOol00Woo00<07gooO000
0Woo00<07gooOol00g`017oo00<07gooOol00W`000<07goo01l01@0O00Al000OO01oo`807`04Ool0
7`0OOol3O00201l7OolQO002Ool2O00017ooO01l07oo0g`0Egoo001EOol02@0OOoml07`001ml07oo
O0007`02Ool00g`001moo`02O0001P0OOoml07`0Ool07`=oo`9l000301moogoo009oo`0501ml07`0
Ool07`05Ool00g`001l07`0301l01Woo01l07`0OOoml00<07`04O0007gooOol201l2Ool:O00;Ool>
O0001GooO01l07`0Ool00g`000Aoog`0O01oo`=l05Qoo`00EGoo00T07goo01moog`0Ooml07ooO000
0Woo00<07g`0Ool00Woo00Al07ooOomoo`9l00Aoo`0301ml07`0009oo`0401moogooOol3O003Ool6
01l00goo01l07`0201l00goo01l07`03Ool301l2O00<Ool;O004Ool8O0000gooO01l0002O0001Woo
O01l07`0Ooml009oo`9l0003Ooml07oo05Moo`00EWoo0P0O00]l000OO01oog`0Ooml07oo01moog`0
009oo`0701ml07`0Ool07gooO0000goo00<07gooOol00W`000<07gooOol00Woo00D07gooO01l07oo
00L07`03O0007g`000807`04Ool07gooOol201l4Ool6O00;Ool:O003Ool2O002Ool4O0001GooO01l
07`0Ool00W`000Ioog`0O01l07ooO01IOol005Moo`807`06O0007g`001ml07oo0W`00Woo00=l07oo
01l00Woo0W`00Woo0W`000=oo`0OOol00Woo00<07g`0O0000goo00@07gooOomoo`<07`04Ool07`0O
01l2Ool301l2O00301l00goo01moo`09Ool;O009Ool:O00017ooO01l07oo17`000Ioog`0Ooml07oo
O01JOol005Moo`807`09Ool07gooO01oog`0Ool07g`0009oo`9l00=oo`0301ml07oo009oo`9l00=o
o`0301moogoo00=l00=oo`@07`04O0007`0OOol201l017oo01l07goo0P0O00Aoog`0O0007`=l011o
oa9l009oo`9l000<Ooml07`0O01oog`0Ooml07ooO01oog`0Fgoo001HOol00`0OOol07`03O00027oo
O0007gooO01oo`0OOol2O0000goo01moo`02O0000goo01moo`02O0000goo01moo`03Ool00`0OO01l
000601l01Woo01l07g`001moo`<07`03Ool07goo009oo`0401moogooOol@O009Ool2O002Ool2O003
Ool2O0002WooO01l07ooO01oog`0Ooml07oo0g`0G7oo001IOol201l01Woo01ml07`0Ooml009oo`9l
00=oo`03O01oogoo009oo`9l00=oo`=l00=oo`/07`9oo`<07`=l000501moogooOol07`0HOol4O000
17ooO01l07`00Woo0g`000Aoog`0O01oo`9l0005Ooml07ooO01oo`02O01NOol005Yoo`0401moogoo
01l2O0001@0OO01l07oo01l00W`000Aoo`0OO01l00=oo`0501ml07`0Ool07`02Ool3O00401l01goo
01l07`0OO0007g`000D07`=oo`0501ml07`0O0007`0HO003Ool2O003Ool2O002Ool2O002Ool01g`0
Ooml07`0Ooml07oo009l05moo`00Fgoo0`0O00Eoog`001ml07oo009l009oo`04O0007gooOol2O000
100OOomoogoo0W`017oo200O00Moo`0O01l07goo01ml000201l3Ool01@0OOomoogoo01l05goo17`0
0Woo0g`000Aoog`0O01l009oo`Al009oo`Al061oo`00G7oo0`0O00=oog`0O0000W`000Ioog`0Oomo
o`0OO003Ool00g`0Oomoo`02Ool00`0OO0007`0=01l2Ool0100OOoml000O0g`000D07g`0O01l000O
015oo`Il00=oo`=l009oo`9l00=oo`9l0004Ooml07ooOol5O01QOol005eoo`D07`08O0007g`0Ooml
07oo01moo`9l000401moog`0O002Ool<01l2O000100OO01l000O0Woo0P0O0Woo0P0O0goo00<07g`0
O0003g`01Goo17`00Woo0g`00goo0W`000Aoog`0O01oo`9l0003Ooml07`006=oo`00GWoo200O00=o
og`0O0000goo00<07gooOol0200O00Eoo`0OO0007goo00807`9oo`807`03Ool07g`0009l000301ml
07oo00807`=oo`0301moogoo00moo`El00=oo`=l00Aoo`9l0004Ooml07`0Ool2O00017ooO01l07`0
I7oo001POolD01l047`001l07`0OOol07gooO0007g`0Ool07goo01moo`0O0Woo0P0O00Aoog`0O000
7`=l000301moogoo00Uoo`Il00Eoo`=l00Eoo`9l0004Ooml07`0Ool2O0001GooO01l07ooO000IGoo
001QOol?01l00g`001moo`0201l01W`001moogoo01moo`807`03Ooml000O009l000601moogoo01mo
o`0O0Woo0P0O0goo00<07g`0O0002G`02Goo0W`01Goo0g`000Aoog`0O01oo`9l009oo`04O01oog`0
O01VOol0069oo`D07`04O01oog`0Ool301l01G`001l07g`001l00Woo0P0O00El000OO01l000O00=o
o`807`03Ool07g`000=l000301moogoo00807`=oo`0301moogoo00ioo`Al00Eoo`9l009oo`9l009o
o`03O01oogoo009l0003Ooml07oo06Moo`00I7oo1`0O00El07oo01l07g`000807`03Ooml07`00080
7`05Ool07gooOol07`03O00201l017oo01moogoo0P0O00Aoog`0O0007`Al000301ml07`000il00Eo
o`Al009oo`9l009oo`9l0003Ooml07`0009oo`03O01oogoo06Moo`00IGoo200O00Al07oo01l07`9l
0007Ool07`0OO0007g`0Ool00P0O0Woo00D07gooO01l000O009oo`807`=oo`0301moogoo009oo`03
01moogoo00eoo`Il00=oo`=l009oo`9l009oo`03O01oogoo009l06Yoo`00J7oo00<07gooOol00W`0
0P0O0W`000Aoo`0O01ml00807`9oo`03O0007g`0009oo`0501moo`0O01moo`03O0001P0OO01l07`0
01ml00=oo`0301moogoo00Moo`Il00Eoo`Al009oo`=l009oo`9l0003Ooml07`006aoo`00JGoo100O
0W`000Aoo`0O01ml009oo`0401ml07`0Ool201l00gooO0007`02O00201l3Ool201l3Ool00`0OOoml
0002O0000`0OO01l0007O005Ool6O004Ool2O003Ool2O0000gooO01l001^Ool006aoo`0801moogoo
O0007g`0Ooml00807`9oo`03O0007`0O009oo`0501moo`0OO0007`03O0000`0OOomoo`02Ool00`0O
Oomoo`02Ool00`0OOomoo`06Ool6O006Ool4O002Ool6O01`Ool006aoo`D07`05Ooml000OO0007`02
O0002P0OOoml07`001ml07oo01moo`0O0goo00<07g`0O0000W`000<07g`0O0000W`000<07g`0O000
1W`01goo1G`00goo1W`0Lgoo001`Ool01P0OOomoo`0OOol07`9l000601ml07`0O0007goo0W`000H0
7g`0O01l07oo01l4Ool00`0OOomoo`02Ool00`0OOomoo`0:Ool3O004Ool7O01fOol0071oo`<07`03
Ool07goo00807`=l000401ml07`0O00201l3Ool00g`001ml0003O0000`0OO01l0002O0000`0OO01l
000:O0000gooO01l0004O00017ooO01l07`0NGoo001eOol201l2Ool00`0OOol07`02O0000gooO000
7`02O0000goo01l07`04Ool00`0OOomoo`02Ool00`0OOomoo`05Ool6O004Ool3O01lOol007Eoo`07
01moogooOol07goo01l00Woo0W`000D07g`0O01l000O00El000301ml07`0009l000301ml07`000El
00Eoo`El07moo`00NGoo0P0O17oo00H07gooOomoog`001l4O0000goo01moo`03Ool00`0OOomoo`04
Ool6O024Ool007moo`0301moogoo009oo`0301moogoo009oo`807`Al000301ml07`000Al08Yoo`00
Q7oo00<07gooOol00Woo00<07gooOol00goo00<07gooOol0SWoo0029Ool00`0OOomoo`03Ool00`0O
Oomoo`2>Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001
\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {326.75, 97.375}} -> {-0.399192, \
0.424522, 0.00348777, 0.00348777}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig4C = Show[Fig4A, ViewPoint \[Rule] {0, 2, 0}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
.5 .5 m
.5 .48233 L
s
.5 .51767 m
.5 .5 L
s
.50074 .49777 m
.50204 .48016 L
s
.49943 .51539 m
.50074 .49777 L
s
.50293 .49575 m
.50552 .47828 L
s
.50033 .51323 m
.50293 .49575 L
s
.50653 .49413 m
.51037 .4769 L
s
.50267 .51138 m
.50653 .49413 L
s
.49878 .52859 m
.50267 .51138 L
s
.50638 .51002 m
.51147 .49309 L
s
.50125 .52692 m
.50638 .51002 L
s
.49772 .53067 m
.50033 .51323 L
s
.51147 .49309 m
.51649 .47618 L
s
.51138 .50934 m
.51762 .4928 L
s
.50506 .52584 m
.51138 .50934 L
s
.49812 .53297 m
.49943 .51539 L
s
.5 .53528 m
.5 .51767 L
s
.5 .48233 m
.5 .46472 L
s
.51762 .4928 m
.52378 .47627 L
s
.51754 .50948 m
.52488 .49339 L
s
.5101 .52552 m
.51754 .50948 L
s
.50204 .48016 m
.50334 .4626 L
s
.50552 .47828 m
.50808 .46088 L
s
.51037 .4769 m
.51415 .45973 L
s
.52488 .49339 m
.53209 .4773 L
s
.49869 .54225 m
.50506 .52584 L
s
.52474 .51056 m
.53309 .49496 L
s
.51624 .52609 m
.52474 .51056 L
s
.49609 .54372 m
.50125 .52692 L
s
.50257 .54146 m
.5101 .52552 L
s
.49488 .54571 m
.49878 .52859 L
s
.51649 .47618 m
.52145 .45932 L
s
.50764 .5415 m
.51624 .52609 L
s
.49511 .54802 m
.49772 .53067 L
s
.49682 .55045 m
.49812 .53297 L
s
.53309 .49496 m
.54128 .47935 L
s
.52378 .47627 m
.52983 .45979 L
s
.53282 .51267 m
.5421 .49759 L
s
.52335 .52765 m
.53282 .51267 L
s
.5 .55279 m
.5 .53528 L
s
.5 .46472 m
.5 .44721 L
s
.51374 .5425 m
.52335 .52765 L
s
.50334 .4626 m
.50462 .44515 L
s
.53209 .4773 m
.53916 .46124 L
s
.50808 .46088 m
.51061 .44359 L
s
.49499 .55725 m
.50257 .54146 L
s
.5421 .49759 m
.55117 .48247 L
s
.49894 .55676 m
.50764 .5415 L
s
.49228 .55852 m
.49869 .54225 L
s
.51415 .45973 m
.51789 .44268 L
s
.53127 .53028 m
.54162 .51586 L
s
.52074 .54454 m
.53127 .53028 L
s
.49092 .56039 m
.49609 .54372 L
s
.54162 .51586 m
.55174 .50132 L
s
.504 .55717 m
.51374 .5425 L
s
.52145 .45932 m
.52631 .44258 L
s
.49098 .5627 m
.49488 .54571 L
s
.54128 .47935 m
.54928 .46375 L
s
.49251 .56523 m
.49511 .54802 L
s
.51004 .55859 m
.52074 .54454 L
s
.52983 .45979 m
.53576 .44342 L
s
.49552 .56778 m
.49682 .55045 L
s
.55174 .50132 m
.56161 .4867 L
s
.53985 .53401 m
.55099 .52015 L
s
.52847 .54767 m
.53985 .53401 L
s
.5 .57015 m
.5 .55279 L
s
.5 .44721 m
.5 .42985 L
s
.55117 .48247 m
.56001 .46735 L
s
.55099 .52015 m
.56186 .50614 L
s
.50462 .44515 m
.50589 .42787 L
s
.53916 .46124 m
.54606 .44528 L
s
.51689 .5611 m
.52847 .54767 L
s
.49018 .57181 m
.49894 .55676 L
s
.49417 .57162 m
.504 .55717 L
s
.51061 .44359 m
.51311 .42646 L
s
.48737 .57285 m
.49499 .55725 L
s
.48587 .5746 m
.49228 .55852 L
s
.49921 .5724 m
.51004 .55859 L
s
.51789 .44268 m
.52155 .42579 L
s
.48575 .57687 m
.49092 .56039 L
s
.54928 .46375 m
.55706 .44823 L
s
.56186 .50614 m
.57244 .49202 L
s
.54891 .53885 m
.56076 .52554 L
s
.53678 .55192 m
.54891 .53885 L
s
.56161 .4867 m
.5712 .47206 L
s
.52631 .44258 m
.53108 .426 L
s
.4871 .57949 m
.49098 .5627 L
s
.50515 .57424 m
.51689 .5611 L
s
.52441 .56472 m
.53678 .55192 L
s
.48993 .58224 m
.49251 .56523 L
s
.56076 .52554 m
.5723 .51204 L
s
.53576 .44342 m
.54154 .4272 L
s
.49424 .58491 m
.49552 .56778 L
s
.56001 .46735 m
.56858 .45228 L
s
.51184 .5772 m
.52441 .56472 L
s
.5 .58729 m
.5 .57015 L
s
.5 .42985 m
.5 .41271 L
s
.54606 .44528 m
.55277 .42946 L
s
.48427 .5858 m
.49417 .57162 L
s
.50589 .42787 m
.50714 .4108 L
s
.48828 .58592 m
.49921 .5724 L
s
.48137 .5866 m
.49018 .57181 L
s
.57244 .49202 m
.58267 .47783 L
s
.54551 .55727 m
.5583 .54476 L
s
.53243 .56946 m
.54551 .55727 L
s
.5723 .51204 m
.58348 .49838 L
s
.5583 .54476 m
.57078 .53197 L
s
.47973 .5882 m
.48737 .57285 L
s
.49328 .58707 m
.50515 .57424 L
s
.51311 .42646 m
.51556 .40956 L
s
.47945 .59044 m
.48587 .5746 L
s
.5712 .47206 m
.58046 .45742 L
s
.51912 .58128 m
.53243 .56946 L
s
.55706 .44823 m
.5646 .43283 L
s
.52155 .42579 m
.52513 .40913 L
s
.57078 .53197 m
.58289 .51894 L
s
.4991 .58932 m
.51184 .5772 L
s
.4806 .59311 m
.48575 .57687 L
s
.53108 .426 m
.53572 .40965 L
s
.48324 .59604 m
.4871 .57949 L
s
.48737 .59899 m
.48993 .58224 L
s
.5056 .59271 m
.51912 .58128 L
s
.58348 .49838 m
.59428 .48461 L
s
.56858 .45228 m
.57686 .4373 L
s
.54154 .4272 m
.54715 .4112 L
s
.5545 .56368 m
.56789 .55169 L
s
.5408 .57529 m
.5545 .56368 L
s
.58289 .51894 m
.59461 .50571 L
s
.49297 .60177 m
.49424 .58491 L
s
.56789 .55169 m
.5809 .53938 L
s
.58267 .47783 m
.59254 .46361 L
s
.52682 .58649 m
.5408 .57529 L
s
.47729 .59909 m
.48828 .58592 L
s
.47433 .59965 m
.48427 .5858 L
s
.5 .60417 m
.5 .58729 L
s
.5 .41271 m
.5 .39583 L
s
.48131 .59952 m
.49328 .58707 L
s
.55277 .42946 m
.55926 .41384 L
s
.47256 .60109 m
.48137 .5866 L
s
.48624 .60104 m
.4991 .58932 L
s
.50714 .4108 m
.50836 .39401 L
s
.5809 .53938 m
.59351 .52677 L
s
.47211 .60326 m
.47973 .5882 L
s
.5126 .59724 m
.52682 .58649 L
s
.58046 .45742 m
.58937 .44285 L
s
.51556 .40956 m
.51795 .39294 L
s
.47306 .60598 m
.47945 .59044 L
s
.49192 .60369 m
.5056 .59271 L
s
.5646 .43283 m
.57187 .4176 L
s
.52513 .40913 m
.52862 .39275 L
s
.59461 .50571 m
.60588 .49231 L
s
.47549 .60905 m
.4806 .59311 L
s
.56363 .57106 m
.57752 .55955 L
s
.54937 .58214 m
.56363 .57106 L
s
.59428 .48461 m
.60465 .47077 L
s
.5348 .59276 m
.54937 .58214 L
s
.53572 .40965 m
.54022 .39356 L
s
.59351 .52677 m
.60567 .51389 L
s
.47941 .61228 m
.48324 .59604 L
s
.57752 .55955 m
.591 .54765 L
s
.4982 .6075 m
.5126 .59724 L
s
.51996 .60287 m
.5348 .59276 L
s
.57686 .4373 m
.5848 .42247 L
s
.59254 .46361 m
.60198 .44941 L
s
.48484 .61543 m
.48737 .59899 L
s
.54715 .4112 m
.55257 .39546 L
s
.46928 .61156 m
.48131 .59952 L
s
.46627 .61187 m
.47729 .59909 L
s
.47329 .61231 m
.48624 .60104 L
s
.49172 .61831 m
.49297 .60177 L
s
.591 .54765 m
.60403 .53539 L
s
.46438 .61313 m
.47433 .59965 L
s
.47813 .61419 m
.49192 .60369 L
s
.5 .62071 m
.5 .60417 L
s
.5 .39583 m
.5 .37929 L
s
.55926 .41384 m
.5655 .39847 L
s
.46376 .61521 m
.47256 .60109 L
s
.5049 .61244 m
.51996 .60287 L
s
.58937 .44285 m
.59789 .42839 L
s
.60588 .49231 m
.61665 .47878 L
s
.50836 .39401 m
.50956 .37756 L
s
.60567 .51389 m
.61732 .5008 L
s
.46452 .61795 m
.47211 .60326 L
s
.48364 .61723 m
.4982 .6075 L
s
.51795 .39294 m
.52028 .37666 L
s
.60465 .47077 m
.61453 .4569 L
s
.57187 .4176 m
.57883 .4026 L
s
.46672 .62116 m
.47306 .60598 L
s
.60403 .53539 m
.61655 .52282 L
s
.52862 .39275 m
.53201 .37671 L
s
.47042 .62463 m
.47549 .60905 L
s
.48966 .62144 m
.5049 .61244 L
s
.54022 .39356 m
.54457 .37782 L
s
.60198 .44941 m
.61097 .43528 L
s
.47564 .62815 m
.47941 .61228 L
s
.5848 .42247 m
.59238 .40783 L
s
.4603 .62309 m
.47329 .61231 L
s
.45724 .62313 m
.46928 .61156 L
s
.46427 .62416 m
.47813 .61419 L
s
.48235 .6315 m
.48484 .61543 L
s
.45525 .6242 m
.46627 .61187 L
s
.55257 .39546 m
.55778 .38004 L
s
.61732 .5008 m
.62843 .48753 L
s
.46899 .6264 m
.48364 .61723 L
s
.61665 .47878 m
.62689 .46518 L
s
.4905 .63446 m
.49172 .61831 L
s
.45447 .62618 m
.46438 .61313 L
s
.61655 .52282 m
.62851 .50996 L
s
0 0 1 r
.5666 .40144 m
.55106 .39181 L
s
.58175 .41165 m
.5666 .40144 L
s
.55106 .39181 m
.53518 .38282 L
s
.59645 .42243 m
.58175 .41165 L
s
1 0 0 r
.5 .63685 m
.5 .62071 L
s
.5 .37929 m
.5 .36315 L
s
.45502 .62892 m
.46376 .61521 L
s
.5655 .39847 m
.57148 .3834 L
s
.59789 .42839 m
.60598 .41409 L
s
.4743 .62981 m
.48966 .62144 L
s
0 0 1 r
.53518 .38282 m
.51902 .37448 L
s
1 0 0 r
.61453 .4569 m
.6239 .44305 L
s
.50956 .37756 m
.51073 .36152 L
s
.45699 .63223 m
.46452 .61795 L
s
0 0 1 r
.61066 .43372 m
.59645 .42243 L
s
1 0 0 r
.52028 .37666 m
.52254 .36079 L
s
.57883 .4026 m
.58546 .38789 L
s
.46045 .63592 m
.46672 .62116 L
s
0 0 1 r
.51902 .37448 m
.50263 .36685 L
s
1 0 0 r
.53201 .37671 m
.53526 .36109 L
s
.46543 .63978 m
.47042 .62463 L
s
.61097 .43528 m
.61946 .42128 L
s
.62851 .50996 m
.63986 .49687 L
s
0 0 1 r
.62431 .44551 m
.61066 .43372 L
s
1 0 0 r
.62843 .48753 m
.63893 .47413 L
s
.45038 .63355 m
.46427 .62416 L
s
.4473 .63332 m
.4603 .62309 L
s
.54457 .37782 m
.54873 .36248 L
s
.45429 .63494 m
.46899 .6264 L
s
.44522 .63418 m
.45724 .62313 L
s
.47194 .64358 m
.47564 .62815 L
s
.59238 .40783 m
.59955 .39345 L
s
0 0 1 r
.55909 .38289 m
.54278 .37435 L
s
.57502 .39213 m
.55909 .38289 L
s
.59053 .40203 m
.57502 .39213 L
s
1 0 0 r
.62689 .46518 m
.63654 .45155 L
s
.44428 .63604 m
.45525 .6242 L
s
.45887 .63752 m
.4743 .62981 L
s
.47992 .64711 m
.48235 .6315 L
s
0 0 1 r
.54278 .37435 m
.52617 .36654 L
s
1 0 0 r
.55778 .38004 m
.56276 .36503 L
s
0 0 1 r
.50263 .36685 m
.48607 .35994 L
s
.60555 .41256 m
.59053 .40203 L
s
1 0 0 r
.44462 .63874 m
.45447 .62618 L
s
.48931 .65015 m
.4905 .63446 L
s
0 0 1 r
.63735 .45775 m
.62431 .44551 L
s
.52617 .36654 m
.5093 .35949 L
s
1 0 0 r
.6239 .44305 m
.6327 .42928 L
s
.60598 .41409 m
.61359 .40001 L
s
.44635 .64214 m
.45502 .62892 L
s
.57148 .3834 m
.57714 .36872 L
s
.5 .65252 m
.5 .63685 L
s
.5 .36315 m
.5 .34748 L
s
0 0 1 r
.62003 .42369 m
.60555 .41256 L
s
1 0 0 r
.51073 .36152 m
.51185 .34596 L
s
.44955 .64602 m
.45699 .63223 L
s
.63986 .49687 m
.65055 .48357 L
s
0 0 1 r
.48607 .35994 m
.4694 .35381 L
s
.5093 .35949 m
.49223 .35324 L
s
1 0 0 r
.58546 .38789 m
.59171 .37353 L
s
.52254 .36079 m
.5247 .34541 L
s
.63893 .47413 m
.64878 .46064 L
s
.45428 .6502 m
.46045 .63592 L
s
0 0 1 r
.6339 .43537 m
.62003 .42369 L
s
1 0 0 r
.4396 .64282 m
.45429 .63494 L
s
.43652 .64231 m
.45038 .63355 L
s
.61946 .42128 m
.62741 .40745 L
s
0 0 1 r
.56693 .37336 m
.55025 .36519 L
s
.58321 .3823 m
.56693 .37336 L
s
1 0 0 r
.53526 .36109 m
.53838 .34595 L
s
.43436 .64295 m
.4473 .63332 L
s
.44343 .64452 m
.45887 .63752 L
s
0 0 1 r
.64971 .4704 m
.63735 .45775 L
s
.55025 .36519 m
.53322 .35782 L
s
1 0 0 r
.46054 .65443 m
.46543 .63978 L
s
0 0 1 r
.59903 .39197 m
.58321 .3823 L
s
1 0 0 r
.63654 .45155 m
.64556 .43794 L
s
.43327 .64466 m
.44522 .63418 L
s
.59955 .39345 m
.60628 .37939 L
s
.54873 .36248 m
.5527 .34762 L
s
0 0 1 r
.53322 .35782 m
.51592 .35128 L
s
1 0 0 r
.46832 .65851 m
.47194 .64358 L
s
0 0 1 r
.61431 .40235 m
.59903 .39197 L
s
.49223 .35324 m
.47504 .34781 L
s
1 0 0 r
.4334 .64731 m
.44428 .63604 L
s
.47756 .6622 m
.47992 .64711 L
s
0 0 1 r
.64711 .44759 m
.6339 .43537 L
s
1 0 0 r
.56276 .36503 m
.56746 .35047 L
s
0 0 1 r
.4694 .35381 m
.45268 .34848 L
s
1 0 0 r
.43488 .65075 m
.44462 .63874 L
s
0 0 1 r
.51592 .35128 m
.49841 .34561 L
s
.62901 .41341 m
.61431 .40235 L
s
1 0 0 r
.6327 .42928 m
.64088 .41563 L
s
.48816 .66531 m
.48931 .65015 L
s
.61359 .40001 m
.62068 .38621 L
s
.65055 .48357 m
.66051 .47013 L
s
.4378 .6548 m
.44635 .64214 L
s
.57714 .36872 m
.58248 .35448 L
s
.5 .66764 m
.5 .65252 L
s
.5 .34748 m
.5 .33236 L
s
0 0 1 r
.66135 .48342 m
.64971 .4704 L
s
1 0 0 r
.64878 .46064 m
.65792 .44711 L
s
0 0 1 r
.47504 .34781 m
.45778 .34326 L
s
.49841 .34561 m
.48075 .34084 L
s
1 0 0 r
.44224 .65926 m
.44955 .64602 L
s
.51185 .34596 m
.51293 .33095 L
s
.42497 .64998 m
.4396 .64282 L
s
.42803 .65076 m
.44343 .64452 L
s
0 0 1 r
.64305 .42509 m
.62901 .41341 L
s
.55748 .35549 m
.5401 .34848 L
s
.5745 .36337 m
.55748 .35549 L
s
.59108 .37211 m
.5745 .36337 L
s
1 0 0 r
.42274 .65038 m
.43652 .64231 L
s
0 0 1 r
.65958 .46028 m
.64711 .44759 L
s
1 0 0 r
.59171 .37353 m
.59755 .35959 L
s
.5247 .34541 m
.52678 .33059 L
s
0 0 1 r
.5401 .34848 m
.52241 .34237 L
s
1 0 0 r
.44823 .6639 m
.45428 .6502 L
s
0 0 1 r
.60716 .38166 m
.59108 .37211 L
s
1 0 0 r
.42151 .65192 m
.43436 .64295 L
s
.62741 .40745 m
.63476 .39386 L
s
.64556 .43794 m
.65387 .42441 L
s
0 0 1 r
.45268 .34848 m
.43597 .344 L
s
1 0 0 r
.53838 .34595 m
.54135 .33136 L
s
0 0 1 r
.52241 .34237 m
.5045 .33721 L
s
1 0 0 r
.42144 .65449 m
.43327 .64466 L
s
.45576 .66851 m
.46054 .65443 L
s
0 0 1 r
.62267 .39199 m
.60716 .38166 L
s
.48075 .34084 m
.46302 .337 L
s
1 0 0 r
.60628 .37939 m
.61252 .36572 L
s
.5527 .34762 m
.55645 .33332 L
s
0 0 1 r
.65637 .43738 m
.64305 .42509 L
s
1 0 0 r
.4648 .67284 m
.46832 .65851 L
s
.42266 .65795 m
.4334 .64731 L
s
0 0 1 r
.67218 .49678 m
.66135 .48342 L
s
.45778 .34326 m
.44053 .33961 L
s
.5045 .33721 m
.48642 .33302 L
s
1 0 0 r
.66051 .47013 m
.66969 .45659 L
s
0 0 1 r
.63754 .40307 m
.62267 .39199 L
s
1 0 0 r
.47526 .67668 m
.47756 .6622 L
s
.56746 .35047 m
.57188 .33646 L
s
.64088 .41563 m
.64838 .40218 L
s
.42529 .66213 m
.43488 .65075 L
s
0 0 1 r
.67126 .47342 m
.65958 .46028 L
s
1 0 0 r
.48705 .67984 m
.48816 .66531 L
s
.62068 .38621 m
.6272 .37276 L
s
.65792 .44711 m
.66628 .43359 L
s
.42941 .66684 m
.4378 .6548 L
s
.41274 .6562 m
.42803 .65076 L
s
0 0 1 r
.46302 .337 m
.44527 .33413 L
s
1 0 0 r
.58248 .35448 m
.58744 .34076 L
s
0 0 1 r
.56443 .34543 m
.54672 .33868 L
s
.58175 .35313 m
.56443 .34543 L
s
.48642 .33302 m
.46825 .32982 L
s
1 0 0 r
.5 .68213 m
.5 .66764 L
s
.5 .33236 m
.5 .31787 L
s
.41046 .65636 m
.42497 .64998 L
s
0 0 1 r
.54672 .33868 m
.52869 .33292 L
s
.5986 .36176 m
.58175 .35313 L
s
.6517 .41486 m
.63754 .40307 L
s
.66889 .45022 m
.65637 .43738 L
s
.43597 .344 m
.41935 .34042 L
s
1 0 0 r
.40911 .65771 m
.42274 .65038 L
s
.43509 .67186 m
.44224 .65926 L
s
0 0 1 r
.52869 .33292 m
.5104 .32818 L
s
1 0 0 r
.51293 .33095 m
.51396 .31658 L
s
0 0 1 r
.6149 .37128 m
.5986 .36176 L
s
1 0 0 r
.59755 .35959 m
.60295 .34614 L
s
.40883 .66017 m
.42151 .65192 L
s
0 0 1 r
.44053 .33961 m
.42335 .3369 L
s
1 0 0 r
.65387 .42441 m
.66143 .41101 L
s
.52678 .33059 m
.52874 .31641 L
s
.63476 .39386 m
.64145 .38057 L
s
.44233 .67697 m
.44823 .6639 L
s
0 0 1 r
.5104 .32818 m
.49194 .32448 L
s
.68215 .51042 m
.67218 .49678 L
s
.6306 .38166 m
.6149 .37128 L
s
.46825 .32982 m
.45007 .32765 L
s
.68207 .48696 m
.67126 .47342 L
s
1 0 0 r
.40979 .66361 m
.42144 .65449 L
s
.54135 .33136 m
.54413 .31743 L
s
0 0 1 r
.66508 .42733 m
.6517 .41486 L
s
1 0 0 r
.45112 .68192 m
.45576 .66851 L
s
0 0 1 r
.44527 .33413 m
.4276 .33224 L
s
1 0 0 r
.66969 .45659 m
.67801 .443 L
s
.61252 .36572 m
.61822 .35251 L
s
0 0 1 r
.49194 .32448 m
.47338 .32185 L
s
1 0 0 r
.4121 .66789 m
.42266 .65795 L
s
.55645 .33332 m
.55994 .31965 L
s
0 0 1 r
.68055 .46358 m
.66889 .45022 L
s
.6456 .39288 m
.6306 .38166 L
s
1 0 0 r
.4614 .6865 m
.4648 .67284 L
s
.64838 .40218 m
.65514 .38898 L
s
.47306 .69048 m
.47526 .67668 L
s
.41589 .67281 m
.42529 .66213 L
s
.57188 .33646 m
.57596 .32307 L
s
0 0 1 r
.41935 .34042 m
.40289 .33777 L
s
1 0 0 r
.39763 .66079 m
.41274 .6562 L
s
.66628 .43359 m
.6738 .42015 L
s
0 0 1 r
.55304 .32862 m
.53468 .32311 L
s
.57105 .33519 m
.55304 .32862 L
s
.45007 .32765 m
.43196 .32653 L
s
.58864 .34281 m
.57105 .33519 L
s
1 0 0 r
.6272 .37276 m
.6331 .35973 L
s
0 0 1 r
.47338 .32185 m
.45481 .32031 L
s
1 0 0 r
.39615 .66193 m
.41046 .65636 L
s
0 0 1 r
.42335 .3369 m
.40632 .33518 L
s
.53468 .32311 m
.51606 .31869 L
s
1 0 0 r
.48598 .69366 m
.48705 .67984 L
s
0 0 1 r
.67761 .44043 m
.66508 .42733 L
s
.60572 .35143 m
.58864 .34281 L
s
.65984 .40488 m
.6456 .39288 L
s
1 0 0 r
.42122 .67817 m
.42941 .66684 L
s
.58744 .34076 m
.59199 .32764 L
s
0 0 1 r
.51606 .31869 m
.49724 .3154 L
s
1 0 0 r
.39568 .66424 m
.40911 .65771 L
s
.5 .6959 m
.5 .68213 L
s
.5 .31787 m
.5 .3041 L
s
0 0 1 r
.62222 .36103 m
.60572 .35143 L
s
.69118 .52429 m
.68215 .51042 L
s
.69194 .50086 m
.68207 .48696 L
s
.4276 .33224 m
.41008 .33139 L
s
1 0 0 r
.42813 .68375 m
.43509 .67186 L
s
.51396 .31658 m
.51493 .30295 L
s
0 0 1 r
.69128 .47742 m
.68055 .46358 L
s
1 0 0 r
.39637 .66763 m
.40883 .66017 L
s
.66143 .41101 m
.66816 .3978 L
s
0 0 1 r
.49724 .3154 m
.47833 .31325 L
s
.63806 .37158 m
.62222 .36103 L
s
1 0 0 r
.60295 .34614 m
.60785 .33327 L
s
.64145 .38057 m
.64744 .36766 L
s
0 0 1 r
.45481 .32031 m
.4363 .31989 L
s
1 0 0 r
.52874 .31641 m
.53057 .30298 L
s
0 0 1 r
.67324 .41763 m
.65984 .40488 L
s
1 0 0 r
.43663 .6893 m
.44233 .67697 L
s
0 0 1 r
.43196 .32653 m
.41399 .3265 L
s
1 0 0 r
.39836 .67196 m
.40979 .66361 L
s
.67801 .443 m
.68541 .42942 L
s
0 0 1 r
.68921 .45411 m
.67761 .44043 L
s
1 0 0 r
.54413 .31743 m
.54672 .30423 L
s
0 0 1 r
.47833 .31325 m
.45939 .31227 L
s
1 0 0 r
.44665 .69459 m
.45112 .68192 L
s
0 0 1 r
.65316 .38303 m
.63806 .37158 L
s
1 0 0 r
.61822 .35251 m
.62334 .33984 L
s
0 0 1 r
.40289 .33777 m
.38666 .33609 L
s
1 0 0 r
.40179 .67705 m
.4121 .66789 L
s
0 0 1 r
.40632 .33518 m
.38953 .33446 L
s
1 0 0 r
.55994 .31965 m
.56317 .30672 L
s
.45814 .69939 m
.4614 .6865 L
s
.38278 .66446 m
.39763 .66079 L
s
.65514 .38898 m
.66111 .3761 L
s
0 0 1 r
.55902 .31848 m
.54036 .31312 L
s
.57731 .32499 m
.55902 .31848 L
s
.4363 .31989 m
.41794 .32062 L
s
.41008 .33139 m
.39278 .3316 L
s
.54036 .31312 m
.52142 .30894 L
s
1 0 0 r
.6738 .42015 m
.68041 .40685 L
s
0 0 1 r
.59515 .33262 m
.57731 .32499 L
s
.68572 .43109 m
.67324 .41763 L
s
.70079 .51505 m
.69194 .50086 L
s
.45939 .31227 m
.44052 .31247 L
s
1 0 0 r
.40675 .68271 m
.41589 .67281 L
s
0 0 1 r
.52142 .30894 m
.50227 .30596 L
s
1 0 0 r
.38211 .6666 m
.39615 .66193 L
s
.47096 .70348 m
.47306 .69048 L
s
0 0 1 r
.61244 .34134 m
.59515 .33262 L
s
1 0 0 r
.57596 .32307 m
.57969 .3104 L
s
0 0 1 r
.70099 .49167 m
.69128 .47742 L
s
.69919 .53834 m
.69118 .52429 L
s
.66744 .39534 m
.65316 .38303 L
s
1 0 0 r
.6331 .35973 m
.63833 .34721 L
s
0 0 1 r
.41399 .3265 m
.39626 .32759 L
s
.50227 .30596 m
.48302 .3042 L
s
1 0 0 r
.48498 .70668 m
.48598 .69366 L
s
0 0 1 r
.62911 .35113 m
.61244 .34134 L
s
1 0 0 r
.38253 .6699 m
.39568 .66424 L
s
0 0 1 r
.69979 .46834 m
.68921 .45411 L
s
1 0 0 r
.41328 .68872 m
.42122 .67817 L
s
.59199 .32764 m
.5961 .31522 L
s
.5 .70884 m
.5 .6959 L
s
.5 .3041 m
.5 .29116 L
s
0 0 1 r
.48302 .3042 m
.46374 .30368 L
s
.44052 .31247 m
.4218 .31388 L
s
1 0 0 r
.66816 .3978 m
.67401 .38487 L
s
0 0 1 r
.64507 .36193 m
.62911 .35113 L
s
1 0 0 r
.3842 .67423 m
.39637 .66763 L
s
0 0 1 r
.41794 .32062 m
.39982 .32251 L
s
1 0 0 r
.42142 .69483 m
.42813 .68375 L
s
0 0 1 r
.68082 .40848 m
.66744 .39534 L
s
1 0 0 r
.51493 .30295 m
.51584 .29015 L
s
0 0 1 r
.6972 .4452 m
.68572 .43109 L
s
1 0 0 r
.64744 .36766 m
.65266 .3552 L
s
.68541 .42942 m
.69181 .41592 L
s
.60785 .33327 m
.6122 .32107 L
s
0 0 1 r
.38953 .33446 m
.37306 .33481 L
s
.38666 .33609 m
.37076 .33543 L
s
1 0 0 r
.53057 .30298 m
.53227 .29038 L
s
.43114 .70081 m
.43663 .6893 L
s
0 0 1 r
.39278 .3316 m
.37582 .33291 L
s
.46374 .30368 m
.44453 .30443 L
s
1 0 0 r
.38724 .67945 m
.39836 .67196 L
s
0 0 1 r
.66024 .37372 m
.64507 .36193 L
s
.70961 .50628 m
.70099 .49167 L
s
.39626 .32759 m
.37886 .32981 L
s
1 0 0 r
.54672 .30423 m
.5491 .29187 L
s
0 0 1 r
.70855 .52948 m
.70079 .51505 L
s
1 0 0 r
.44239 .70641 m
.44665 .69459 L
s
0 0 1 r
.4218 .31388 m
.40334 .31651 L
s
1 0 0 r
.36826 .66717 m
.38278 .66446 L
s
0 0 1 r
.54571 .30317 m
.52646 .29912 L
s
.56466 .30847 m
.54571 .30317 L
s
1 0 0 r
.62334 .33984 m
.62783 .3278 L
s
0 0 1 r
.58321 .31501 m
.56466 .30847 L
s
.70929 .48305 m
.69979 .46834 L
s
1 0 0 r
.39179 .68536 m
.40179 .67705 L
s
0 0 1 r
.52646 .29912 m
.50699 .29636 L
s
.69322 .42239 m
.68082 .40848 L
s
.60127 .32276 m
.58321 .31501 L
s
.70612 .5525 m
.69919 .53834 L
s
1 0 0 r
.68041 .40685 m
.68604 .39376 L
s
.66111 .3761 m
.66621 .36362 L
s
0 0 1 r
.44453 .30443 m
.42549 .30644 L
s
1 0 0 r
.56317 .30672 m
.56608 .29461 L
s
.45505 .7114 m
.45814 .69939 L
s
0 0 1 r
.50699 .29636 m
.48741 .2949 L
s
.39982 .32251 m
.38204 .32559 L
s
.67452 .38645 m
.66024 .37372 L
s
1 0 0 r
.36842 .67033 m
.38211 .6666 L
s
0 0 1 r
.61876 .33169 m
.60127 .32276 L
s
.7076 .45992 m
.6972 .4452 L
s
1 0 0 r
.3979 .69175 m
.40675 .68271 L
s
0 0 1 r
.48741 .2949 m
.4678 .29476 L
s
1 0 0 r
.46898 .71559 m
.47096 .70348 L
s
.57969 .3104 m
.58302 .29855 L
s
0 0 1 r
.63557 .34175 m
.61876 .33169 L
s
1 0 0 r
.63833 .34721 m
.64282 .33527 L
s
.36974 .67462 m
.38253 .6699 L
s
.48403 .71879 m
.48498 .70668 L
s
0 0 1 r
.40334 .31651 m
.38522 .32038 L
s
.42549 .30644 m
.40671 .30973 L
s
1 0 0 r
.40564 .69838 m
.41328 .68872 L
s
0 0 1 r
.4678 .29476 m
.44828 .29595 L
s
.37582 .33291 m
.35926 .33534 L
s
.68784 .40007 m
.67452 .38645 L
s
.70454 .43703 m
.69322 .42239 L
s
1 0 0 r
.5961 .31522 m
.59971 .30359 L
s
0 0 1 r
.37306 .33481 m
.357 .33624 L
s
.65163 .35292 m
.63557 .34175 L
s
1 0 0 r
.67401 .38487 m
.6789 .37228 L
s
.5 .72086 m
.5 .70884 L
s
.5 .29116 m
.5 .27914 L
s
0 0 1 r
.37886 .32981 m
.36188 .33319 L
s
1 0 0 r
.37239 .6799 m
.3842 .67423 L
s
0 0 1 r
.37076 .33543 m
.35528 .33584 L
s
1 0 0 r
.69181 .41592 m
.69715 .40257 L
s
0 0 1 r
.71706 .5212 m
.70961 .50628 L
s
.71763 .49819 m
.70929 .48305 L
s
1 0 0 r
.41499 .70501 m
.42142 .69483 L
s
.65266 .3552 m
.65704 .34328 L
s
.51584 .29015 m
.51667 .2783 L
s
0 0 1 r
.44828 .29595 m
.42892 .29848 L
s
.38204 .32559 m
.3647 .32987 L
s
.71514 .54409 m
.70855 .52948 L
s
1 0 0 r
.6122 .32107 m
.61597 .30962 L
s
0 0 1 r
.66683 .36514 m
.65163 .35292 L
s
.71685 .47518 m
.7076 .45992 L
s
.40671 .30973 m
.38829 .31432 L
s
1 0 0 r
.37649 .686 m
.38724 .67945 L
s
.53227 .29038 m
.53382 .27873 L
s
.42592 .71139 m
.43114 .70081 L
s
0 0 1 r
.55073 .29345 m
.53117 .28944 L
s
.56996 .2988 m
.55073 .29345 L
s
.71188 .56671 m
.70612 .5525 L
s
.70011 .41452 m
.68784 .40007 L
s
1 0 0 r
.35417 .66886 m
.36826 .66717 L
s
0 0 1 r
.53117 .28944 m
.5114 .2868 L
s
.58876 .30548 m
.56996 .2988 L
s
.38522 .32038 m
.36756 .32549 L
s
.5114 .2868 m
.49149 .28554 L
s
.42892 .29848 m
.40984 .30235 L
s
.60704 .31344 m
.58876 .30548 L
s
1 0 0 r
.5491 .29187 m
.55123 .28045 L
s
0 0 1 r
.71472 .45233 m
.70454 .43703 L
s
1 0 0 r
.68604 .39376 m
.69062 .38096 L
s
.43835 .71728 m
.44239 .70641 L
s
.62783 .3278 m
.63162 .31649 L
s
0 0 1 r
.68109 .37837 m
.66683 .36514 L
s
.49149 .28554 m
.47156 .28568 L
s
1 0 0 r
.38215 .69272 m
.39179 .68536 L
s
.66621 .36362 m
.67039 .35163 L
s
0 0 1 r
.62469 .32267 m
.60704 .31344 L
s
1 0 0 r
.35515 .67305 m
.36842 .67033 L
s
.56608 .29461 m
.56866 .28343 L
s
.45214 .72244 m
.45505 .7114 L
s
0 0 1 r
.47156 .28568 m
.45172 .28723 L
s
.36188 .33319 m
.34543 .33775 L
s
.35926 .33534 m
.34323 .33892 L
s
.38829 .31432 m
.37034 .32019 L
s
.64163 .33311 m
.62469 .32267 L
s
1 0 0 r
.38943 .69982 m
.3979 .69175 L
s
0 0 1 r
.40984 .30235 m
.39115 .30758 L
s
.3647 .32987 m
.34789 .33536 L
s
.357 .33624 m
.34146 .3388 L
s
.71124 .42976 m
.70011 .41452 L
s
.72471 .51369 m
.71763 .49819 L
s
1 0 0 r
.46714 .7267 m
.46898 .71559 L
s
.35739 .67834 m
.36974 .67462 L
s
.58302 .29855 m
.58592 .28761 L
s
.64282 .33527 m
.64651 .32401 L
s
0 0 1 r
.72325 .53636 m
.71706 .5212 L
s
.69432 .39256 m
.68109 .37837 L
s
.45172 .28723 m
.43206 .2902 L
s
.72484 .49093 m
.71685 .47518 L
s
.35528 .33584 m
.34031 .33735 L
s
.65776 .34472 m
.64163 .33311 L
s
.36756 .32549 m
.35044 .33185 L
s
1 0 0 r
.48316 .72987 m
.48403 .71879 L
s
0 0 1 r
.72048 .55881 m
.71514 .54409 L
s
1 0 0 r
.39835 .70706 m
.40564 .69838 L
s
.6789 .37228 m
.68275 .36012 L
s
.69715 .40257 m
.70134 .38945 L
s
0 0 1 r
.72365 .46823 m
.71472 .45233 L
s
1 0 0 r
.59971 .30359 m
.60279 .29286 L
s
0 0 1 r
.43206 .2902 m
.41269 .29457 L
s
1 0 0 r
.36103 .68456 m
.37239 .6799 L
s
.5 .73183 m
.5 .72086 L
s
.5 .27914 m
.5 .26817 L
s
0 0 1 r
.39115 .30758 m
.37294 .31414 L
s
.67297 .35747 m
.65776 .34472 L
s
.37034 .32019 m
.35296 .32736 L
s
1 0 0 r
.65704 .34328 m
.66053 .33199 L
s
.4089 .71419 m
.41499 .70501 L
s
0 0 1 r
.70643 .40764 m
.69432 .39256 L
s
.71639 .58089 m
.71188 .56671 L
s
1 0 0 r
.51667 .2783 m
.51742 .26749 L
s
0 0 1 r
.72115 .44572 m
.71124 .42976 L
s
.53558 .2801 m
.51549 .27749 L
s
.55544 .28417 m
.53558 .2801 L
s
.57494 .28967 m
.55544 .28417 L
s
1 0 0 r
.61597 .30962 m
.61909 .29904 L
s
0 0 1 r
.51549 .27749 m
.49526 .27634 L
s
1 0 0 r
.3406 .66946 m
.35417 .66886 L
s
0 0 1 r
.41269 .29457 m
.39373 .30035 L
s
1 0 0 r
.36619 .69154 m
.37649 .686 L
s
0 0 1 r
.59399 .29658 m
.57494 .28967 L
s
.49526 .27634 m
.47501 .27667 L
s
1 0 0 r
.53382 .27873 m
.5352 .26813 L
s
.42101 .72094 m
.42592 .71139 L
s
0 0 1 r
.61247 .30486 m
.59399 .29658 L
s
.34543 .33775 m
.32961 .34352 L
s
.68718 .37128 m
.67297 .35747 L
s
.34789 .33536 m
.33172 .34208 L
s
.47501 .27667 m
.45484 .27849 L
s
1 0 0 r
.69062 .38096 m
.69407 .36852 L
s
0 0 1 r
.34323 .33892 m
.32783 .34368 L
s
.7315 .50709 m
.72484 .49093 L
s
.35044 .33185 m
.33399 .33947 L
s
.73045 .52947 m
.72471 .51369 L
s
.37294 .31414 m
.35533 .32204 L
s
.63028 .31447 m
.61247 .30486 L
s
1 0 0 r
.55123 .28045 m
.55309 .27009 L
s
.34242 .67469 m
.35515 .67305 L
s
.63162 .31649 m
.63466 .306 L
s
.43458 .72708 m
.43835 .71728 L
s
.37296 .69905 m
.38215 .69272 L
s
0 0 1 r
.73127 .48466 m
.72365 .46823 L
s
1 0 0 r
.67039 .35163 m
.67355 .34021 L
s
0 0 1 r
.45484 .27849 m
.43488 .2818 L
s
.34146 .3388 m
.32655 .34252 L
s
.71732 .42355 m
.70643 .40764 L
s
.39373 .30035 m
.37529 .30752 L
s
.72811 .55168 m
.72325 .53636 L
s
.64733 .32537 m
.63028 .31447 L
s
.35296 .32736 m
.33627 .33581 L
s
.70028 .3861 m
.68718 .37128 L
s
1 0 0 r
.56866 .28343 m
.57088 .27331 L
s
.44945 .73239 m
.45214 .72244 L
s
0 0 1 r
.72974 .46232 m
.72115 .44572 L
s
.43488 .2818 m
.41523 .28658 L
s
.34031 .33735 m
.32597 .34001 L
s
.72448 .57356 m
.72048 .55881 L
s
1 0 0 r
.34557 .68097 m
.35739 .67834 L
s
.38139 .70684 m
.38943 .69982 L
s
0 0 1 r
.6635 .33752 m
.64733 .32537 L
s
1 0 0 r
.64651 .32401 m
.64935 .31353 L
s
.46545 .73668 m
.46714 .7267 L
s
.58592 .28761 m
.58834 .2777 L
s
0 0 1 r
.35533 .32204 m
.33844 .33125 L
s
.37529 .30752 m
.35746 .31607 L
s
.41523 .28658 m
.396 .29283 L
s
1 0 0 r
.70134 .38945 m
.70429 .37663 L
s
.68275 .36012 m
.6855 .34847 L
s
0 0 1 r
.72692 .44022 m
.71732 .42355 L
s
.71219 .40186 m
.70028 .3861 L
s
1 0 0 r
.48238 .7398 m
.48316 .72987 L
s
0 0 1 r
.67869 .35085 m
.6635 .33752 L
s
1 0 0 r
.39149 .71466 m
.39835 .70706 L
s
0 0 1 r
.33172 .34208 m
.31632 .35003 L
s
.33399 .33947 m
.31832 .34834 L
s
.71957 .59497 m
.71639 .58089 L
s
1 0 0 r
.3502 .68813 m
.36103 .68456 L
s
.60279 .29286 m
.60528 .28312 L
s
0 0 1 r
.32961 .34352 m
.31455 .35049 L
s
.73675 .52358 m
.7315 .50709 L
s
.73747 .50154 m
.73127 .48466 L
s
.396 .29283 m
.37732 .30053 L
s
1 0 0 r
.5 .74164 m
.5 .73183 L
s
.5 .26817 m
.5 .25836 L
s
0 0 1 r
.33627 .33581 m
.32038 .34553 L
s
.53972 .27133 m
.51931 .26864 L
s
.55988 .27555 m
.53972 .27133 L
s
.51931 .26864 m
.49875 .26751 L
s
.57965 .28129 m
.55988 .27555 L
s
.73478 .54547 m
.73045 .52947 L
s
1 0 0 r
.66053 .33199 m
.66304 .32143 L
s
0 0 1 r
.49875 .26751 m
.47816 .26794 L
s
.32783 .34368 m
.31316 .34964 L
s
1 0 0 r
.32767 .66893 m
.3406 .66946 L
s
0 0 1 r
.35746 .31607 m
.34038 .32597 L
s
1 0 0 r
.4032 .72224 m
.4089 .71419 L
s
0 0 1 r
.69281 .3653 m
.67869 .35085 L
s
.59893 .28851 m
.57965 .28129 L
s
.73693 .47949 m
.72974 .46232 L
s
.47816 .26794 m
.45767 .26994 L
s
1 0 0 r
.51742 .26749 m
.51808 .25786 L
s
0 0 1 r
.61761 .29718 m
.59893 .28851 L
s
1 0 0 r
.61909 .29904 m
.62152 .28943 L
s
0 0 1 r
.33844 .33125 m
.32236 .34176 L
s
1 0 0 r
.35642 .69597 m
.36619 .69154 L
s
0 0 1 r
.72282 .4185 m
.71219 .40186 L
s
.73154 .56708 m
.72811 .55168 L
s
.45767 .26994 m
.43738 .27349 L
s
.37732 .30053 m
.35929 .30965 L
s
.32655 .34252 m
.31237 .34744 L
s
1 0 0 r
.69407 .36852 m
.69631 .35655 L
s
0 0 1 r
.63557 .30726 m
.61761 .29718 L
s
1 0 0 r
.5352 .26813 m
.53638 .25872 L
s
.41645 .72934 m
.42101 .72094 L
s
0 0 1 r
.73513 .45757 m
.72692 .44022 L
s
.43738 .27349 m
.41743 .2786 L
s
.70576 .38081 m
.69281 .3653 L
s
1 0 0 r
.33032 .67519 m
.34242 .67469 L
s
0 0 1 r
.6527 .3187 m
.63557 .30726 L
s
1 0 0 r
.67355 .34021 m
.67564 .32948 L
s
.55309 .27009 m
.55466 .26091 L
s
.3643 .70424 m
.37296 .69905 L
s
0 0 1 r
.34038 .32597 m
.32416 .3372 L
s
1 0 0 r
.63466 .306 m
.63689 .29644 L
s
0 0 1 r
.72705 .58825 m
.72448 .57356 L
s
.41743 .2786 m
.39793 .28524 L
s
1 0 0 r
.43111 .7357 m
.43458 .72708 L
s
0 0 1 r
.32597 .34001 m
.31236 .34386 L
s
.31832 .34834 m
.30355 .35844 L
s
.35929 .30965 m
.34204 .32017 L
s
.32038 .34553 m
.3054 .3565 L
s
.66889 .33144 m
.6527 .3187 L
s
.31632 .35003 m
.3018 .3592 L
s
.73207 .43592 m
.72282 .4185 L
s
.74219 .5188 m
.73747 .50154 L
s
1 0 0 r
.57088 .27331 m
.57268 .26435 L
s
0 0 1 r
.39793 .28524 m
.37901 .29338 L
s
.71744 .3973 m
.70576 .38081 L
s
.74264 .49715 m
.73693 .47949 L
s
1 0 0 r
.447 .74112 m
.44945 .73239 L
s
0 0 1 r
.32236 .34176 m
.30723 .35354 L
s
1 0 0 r
.33439 .68245 m
.34557 .68097 L
s
0 0 1 r
.74051 .54032 m
.73675 .52358 L
s
.31455 .35049 m
.30035 .35869 L
s
1 0 0 r
.37386 .7127 m
.38139 .70684 L
s
0 0 1 r
.68403 .34541 m
.66889 .33144 L
s
1 0 0 r
.70429 .37663 m
.70594 .36422 L
s
.64935 .31353 m
.65126 .30393 L
s
0 0 1 r
.74186 .47552 m
.73513 .45757 L
s
.7376 .56159 m
.73478 .54547 L
s
1 0 0 r
.46393 .74542 m
.46545 .73668 L
s
.58834 .2777 m
.59024 .26894 L
s
0 0 1 r
.72133 .60884 m
.71957 .59497 L
s
.34204 .32017 m
.32567 .33203 L
s
.37901 .29338 m
.36077 .30299 L
s
1 0 0 r
.6855 .34847 m
.68706 .33745 L
s
0 0 1 r
.32416 .3372 m
.3089 .3497 L
s
.31316 .34964 m
.29936 .35682 L
s
.69803 .36055 m
.68403 .34541 L
s
1 0 0 r
.48168 .74846 m
.48238 .7398 L
s
0 0 1 r
.72776 .41468 m
.71744 .3973 L
s
1 0 0 r
.34001 .69053 m
.3502 .68813 L
s
.3851 .72106 m
.39149 .71466 L
s
0 0 1 r
.5229 .26047 m
.50199 .25927 L
s
.54364 .26332 m
.5229 .26047 L
s
.5641 .26778 m
.54364 .26332 L
s
.50199 .25927 m
.48106 .25971 L
s
.73986 .45404 m
.73207 .43592 L
s
.58415 .27383 m
.5641 .26778 L
s
.48106 .25971 m
.46022 .26179 L
s
.73347 .58247 m
.73154 .56708 L
s
1 0 0 r
.60528 .28312 m
.60713 .27452 L
s
0 0 1 r
.36077 .30299 m
.34335 .31404 L
s
.60366 .28145 m
.58415 .27383 L
s
1 0 0 r
.31547 .6672 m
.32767 .66893 L
s
0 0 1 r
.46022 .26179 m
.4396 .26551 L
s
1 0 0 r
.5 .75016 m
.5 .74164 L
s
.5 .25836 m
.5 .24984 L
s
0 0 1 r
.3054 .3565 m
.29146 .3687 L
s
1 0 0 r
.66304 .32143 m
.66452 .3117 L
s
0 0 1 r
.31237 .34744 m
.29905 .35356 L
s
.62252 .29059 m
.60366 .28145 L
s
.32567 .33203 m
.31032 .34519 L
s
.30723 .35354 m
.29316 .36654 L
s
.4396 .26551 m
.41934 .27085 L
s
.30355 .35844 m
.28979 .36976 L
s
.71079 .37677 m
.69803 .36055 L
s
1 0 0 r
.39795 .72907 m
.4032 .72224 L
s
0 0 1 r
.6406 .3012 m
.62252 .29059 L
s
.74679 .51519 m
.74264 .49715 L
s
1 0 0 r
.51808 .25786 m
.51864 .24954 L
s
0 0 1 r
.74533 .53632 m
.74219 .5188 L
s
.41934 .27085 m
.39955 .27779 L
s
1 0 0 r
.34727 .6992 m
.35642 .69597 L
s
0 0 1 r
.74705 .49396 m
.74186 .47552 L
s
1 0 0 r
.62152 .28943 m
.62319 .28091 L
s
0 0 1 r
.3018 .3592 m
.28829 .36959 L
s
.3089 .3497 m
.29474 .36344 L
s
1 0 0 r
.69631 .35655 m
.69726 .34514 L
s
0 0 1 r
.34335 .31404 m
.32686 .32646 L
s
.73663 .43286 m
.72776 .41468 L
s
.65779 .31322 m
.6406 .3012 L
s
.72813 .60279 m
.72705 .58825 L
s
.39955 .27779 m
.38036 .28629 L
s
.74268 .55722 m
.74051 .54032 L
s
1 0 0 r
.31896 .67447 m
.33032 .67519 L
s
.53638 .25872 m
.53736 .25062 L
s
.41229 .73647 m
.41645 .72934 L
s
0 0 1 r
.31236 .34386 m
.29961 .34893 L
s
.7222 .39399 m
.71079 .37677 L
s
.74611 .47277 m
.73986 .45404 L
s
.67397 .32659 m
.65779 .31322 L
s
.30035 .35869 m
.28714 .3681 L
s
1 0 0 r
.67564 .32948 m
.67658 .31952 L
s
0 0 1 r
.31032 .34519 m
.29608 .35959 L
s
.38036 .28629 m
.36191 .29631 L
s
.32686 .32646 m
.31141 .3402 L
s
1 0 0 r
.35624 .70821 m
.3643 .70424 L
s
.55466 .26091 m
.55591 .25304 L
s
.63689 .29644 m
.63824 .28793 L
s
0 0 1 r
.73884 .57774 m
.7376 .56159 L
s
1 0 0 r
.42798 .74301 m
.43111 .7357 L
s
0 0 1 r
.68904 .34124 m
.67397 .32659 L
s
.74397 .45175 m
.73663 .43286 L
s
.36191 .29631 m
.34431 .30781 L
s
.29316 .36654 m
.28026 .38071 L
s
.73218 .41212 m
.7222 .39399 L
s
1 0 0 r
.32394 .6827 m
.33439 .68245 L
s
0 0 1 r
.29146 .3687 m
.27868 .38207 L
s
.29936 .35682 m
.28655 .36522 L
s
.29474 .36344 m
.28177 .37835 L
s
1 0 0 r
.57268 .26435 m
.57405 .2567 L
s
0 0 1 r
.72159 .62242 m
.72133 .60884 L
s
1 0 0 r
.70594 .36422 m
.7062 .35232 L
s
0 0 1 r
.70289 .35708 m
.68904 .34124 L
s
1 0 0 r
.44483 .74851 m
.447 .74112 L
s
0 0 1 r
.7506 .5128 m
.74705 .49396 L
s
.31141 .3402 m
.29712 .35519 L
s
.7493 .53352 m
.74679 .51519 L
s
1 0 0 r
.36692 .71729 m
.37386 .7127 L
s
0 0 1 r
.28979 .36976 m
.27717 .38227 L
s
.34431 .30781 m
.32767 .32071 L
s
.29608 .35959 m
.28308 .37517 L
s
.73381 .59775 m
.73347 .58247 L
s
.75074 .49199 m
.74611 .47277 L
s
1 0 0 r
.65126 .30393 m
.65218 .29534 L
s
.68706 .33745 m
.68736 .32716 L
s
0 0 1 r
.74683 .55402 m
.74533 .53632 L
s
1 0 0 r
.46261 .75278 m
.46393 .74542 L
s
.59024 .26894 m
.59158 .26146 L
s
0 0 1 r
.71541 .37402 m
.70289 .35708 L
s
.52633 .25318 m
.50507 .25181 L
s
.54741 .25625 m
.52633 .25318 L
s
.50507 .25181 m
.48377 .25218 L
s
.74064 .43105 m
.73218 .41212 L
s
.56817 .26103 m
.54741 .25625 L
s
.48377 .25218 m
.46256 .25426 L
s
.58849 .26747 m
.56817 .26103 L
s
.46256 .25426 m
.44159 .25807 L
s
.29905 .35356 m
.28672 .36093 L
s
.28829 .36959 m
.2759 .38118 L
s
.32767 .32071 m
.31213 .33495 L
s
.7497 .47123 m
.74397 .45175 L
s
1 0 0 r
.33055 .69167 m
.34001 .69053 L
s
0 0 1 r
.60822 .27554 m
.58849 .26747 L
s
.44159 .25807 m
.42098 .26356 L
s
1 0 0 r
.30413 .66422 m
.31547 .6672 L
s
.37927 .72616 m
.3851 .72106 L
s
.48108 .75572 m
.48168 .74846 L
s
0 0 1 r
.62725 .2852 m
.60822 .27554 L
s
.29712 .35519 m
.2841 .37136 L
s
.42098 .26356 m
.40088 .27071 L
s
.7432 .57417 m
.74268 .55722 L
s
.72652 .39196 m
.71541 .37402 L
s
1 0 0 r
.60713 .27452 m
.6083 .26716 L
s
0 0 1 r
.64543 .29639 m
.62725 .2852 L
s
.40088 .27071 m
.38142 .27949 L
s
.28177 .37835 m
.27013 .39437 L
s
.28026 .38071 m
.26867 .39601 L
s
1 0 0 r
.66452 .3117 m
.66488 .30293 L
s
0 0 1 r
.31213 .33495 m
.29779 .35045 L
s
1 0 0 r
.5 .75724 m
.5 .75016 L
s
.5 .24984 m
.5 .24276 L
s
0 0 1 r
.72762 .61708 m
.72813 .60279 L
s
.66266 .30903 m
.64543 .29639 L
s
.28308 .37517 m
.27143 .39184 L
s
.7475 .45067 m
.74064 .43105 L
s
.38142 .27949 m
.36272 .28984 L
s
.28714 .3681 m
.27506 .37873 L
s
1 0 0 r
.39321 .73455 m
.39795 .72907 L
s
0 0 1 r
.27868 .38207 m
.26718 .39658 L
s
1 0 0 r
.69726 .34514 m
.69684 .33439 L
s
0 0 1 r
.6788 .32305 m
.66266 .30903 L
s
.75368 .51159 m
.75074 .49199 L
s
.75246 .53192 m
.7506 .5128 L
s
.29961 .34893 m
.28784 .35525 L
s
.73612 .4108 m
.72652 .39196 L
s
1 0 0 r
.33885 .70114 m
.34727 .6992 L
s
0 0 1 r
.36272 .28984 m
.34491 .3017 L
s
1 0 0 r
.51864 .24954 m
.5191 .24266 L
s
0 0 1 r
.73841 .59381 m
.73884 .57774 L
s
.2841 .37136 m
.27246 .38861 L
s
1 0 0 r
.62319 .28091 m
.62405 .27361 L
s
0 0 1 r
.75375 .4912 m
.7497 .47123 L
s
1 0 0 r
.30845 .67249 m
.31896 .67447 L
s
0 0 1 r
.29779 .35045 m
.28476 .36713 L
s
.7501 .55202 m
.7493 .53352 L
s
.69376 .33838 m
.6788 .32305 L
s
.34491 .3017 m
.32813 .31501 L
s
.27717 .38227 m
.26582 .39593 L
s
1 0 0 r
.53736 .25062 m
.53811 .24397 L
s
.40859 .7422 m
.41229 .73647 L
s
0 0 1 r
.70741 .35491 m
.69376 .33838 L
s
.75269 .47086 m
.7475 .45067 L
s
.74414 .43043 m
.73612 .4108 L
s
.28655 .36522 m
.27486 .37485 L
s
1 0 0 r
.67658 .31952 m
.67628 .31046 L
s
0 0 1 r
.32813 .31501 m
.31248 .32967 L
s
.7466 .57178 m
.74683 .55402 L
s
.27143 .39184 m
.26122 .40952 L
s
.28476 .36713 m
.27314 .38489 L
s
.27013 .39437 m
.25991 .41142 L
s
1 0 0 r
.34889 .71084 m
.35624 .70821 L
s
0 0 1 r
.71967 .37254 m
.70741 .35491 L
s
1 0 0 r
.63824 .28793 m
.63866 .28059 L
s
0 0 1 r
.72027 .6356 m
.72159 .62242 L
s
1 0 0 r
.55591 .25304 m
.55681 .24661 L
s
0 0 1 r
.31248 .32967 m
.29807 .34561 L
s
.27246 .38861 m
.26229 .40684 L
s
.73249 .61281 m
.73381 .59775 L
s
1 0 0 r
.42525 .74889 m
.42798 .74301 L
s
.7062 .35232 m
.70498 .34102 L
s
0 0 1 r
.26867 .39601 m
.25848 .41236 L
s
.2759 .38118 m
.26477 .39394 L
s
1 0 0 r
.31435 .68165 m
.32394 .6827 L
s
0 0 1 r
.75049 .45071 m
.74414 .43043 L
s
.75606 .51151 m
.75375 .4912 L
s
.75486 .53146 m
.75368 .51159 L
s
.73043 .39116 m
.71967 .37254 L
s
.29807 .34561 m
.28503 .36272 L
s
.74199 .59105 m
.7432 .57417 L
s
1 0 0 r
.57405 .2567 m
.57495 .25047 L
s
0 0 1 r
.75614 .49149 m
.75269 .47086 L
s
.27314 .38489 m
.26304 .40361 L
s
.75254 .5512 m
.75246 .53192 L
s
1 0 0 r
.44296 .75441 m
.44483 .74851 L
s
0 0 1 r
.28672 .36093 m
.2755 .36954 L
s
.26718 .39658 m
.25707 .41216 L
s
.50805 .24534 m
.48637 .24556 L
s
.52968 .24693 m
.50805 .24534 L
s
1 0 0 r
.36065 .7205 m
.36692 .71729 L
s
0 0 1 r
.55111 .25031 m
.52968 .24693 L
s
.48637 .24556 m
.46477 .24757 L
s
.73962 .41066 m
.73043 .39116 L
s
.57218 .25546 m
.55111 .25031 L
s
.46477 .24757 m
.44341 .25137 L
s
1 0 0 r
.68736 .32716 m
.68632 .3177 L
s
0 0 1 r
.59276 .26234 m
.57218 .25546 L
s
.44341 .25137 m
.42244 .25694 L
s
1 0 0 r
.65218 .29534 m
.65203 .28787 L
s
0 0 1 r
.28503 .36272 m
.27344 .3809 L
s
.6127 .27092 m
.59276 .26234 L
s
.42244 .25694 m
.40199 .26423 L
s
.75511 .47152 m
.75049 .45071 L
s
.63186 .28113 m
.6127 .27092 L
s
.26229 .40684 m
.2537 .42596 L
s
.40199 .26423 m
.38222 .27321 L
s
.26122 .40952 m
.25257 .42811 L
s
.74912 .57058 m
.7501 .55202 L
s
1 0 0 r
.59158 .26146 m
.59232 .25539 L
s
0 0 1 r
.65012 .29291 m
.63186 .28113 L
s
1 0 0 r
.4615 .75863 m
.46261 .75278 L
s
0 0 1 r
.27506 .37873 m
.26424 .39054 L
s
.38222 .27321 m
.36325 .2838 L
s
1 0 0 r
.29378 .65994 m
.30413 .66422 L
s
0 0 1 r
.74715 .43089 m
.73962 .41066 L
s
.66735 .30618 m
.65012 .29291 L
s
.36325 .2838 m
.34521 .29595 L
s
.26304 .40361 m
.25453 .42318 L
s
1 0 0 r
.32193 .69147 m
.33055 .69167 L
s
0 0 1 r
.25991 .41142 m
.25123 .4294 L
s
.27344 .3809 m
.2634 .40004 L
s
.72545 .63101 m
.72762 .61708 L
s
.68342 .32085 m
.66735 .30618 L
s
.34521 .29595 m
.32824 .30958 L
s
.73626 .60969 m
.73841 .59381 L
s
.26582 .39593 m
.25586 .41068 L
s
.75781 .51243 m
.75614 .49149 L
s
.75657 .53205 m
.75606 .51151 L
s
1 0 0 r
.37407 .72982 m
.37927 .72616 L
s
0 0 1 r
.69822 .33683 m
.68342 .32085 L
s
1 0 0 r
.4806 .76143 m
.48108 .75572 L
s
0 0 1 r
.32824 .30958 m
.31246 .32459 L
s
.75296 .45174 m
.74715 .43089 L
s
.75795 .49272 m
.75511 .47152 L
s
.71164 .35401 m
.69822 .33683 L
s
.31246 .32459 m
.29798 .34089 L
s
.75423 .55146 m
.75486 .53146 L
s
1 0 0 r
.6083 .26716 m
.60874 .26118 L
s
0 0 1 r
.28784 .35525 m
.2772 .36284 L
s
.7446 .58948 m
.7466 .57178 L
s
.2634 .40004 m
.25498 .41999 L
s
.25848 .41236 m
.24982 .42967 L
s
1 0 0 r
.66488 .30293 m
.66406 .29523 L
s
0 0 1 r
.72358 .37227 m
.71164 .35401 L
s
.29798 .34089 m
.2849 .35836 L
s
.2537 .42596 m
.24677 .44584 L
s
.25453 .42318 m
.2477 .44349 L
s
1 0 0 r
.69684 .33439 m
.69497 .32443 L
s
.5 .76276 m
.5 .75724 L
s
.5 .24276 m
.5 .23724 L
s
0 0 1 r
.73395 .3915 m
.72358 .37227 L
s
.757 .47306 m
.75296 .45174 L
s
.2849 .35836 m
.27333 .3769 L
s
.27486 .37485 m
.26442 .38569 L
s
.25257 .42811 m
.24557 .44749 L
s
.75081 .57051 m
.75254 .5512 L
s
1 0 0 r
.38904 .73854 m
.39321 .73455 L
s
.33125 .70169 m
.33885 .70114 L
s
0 0 1 r
.25498 .41999 m
.24828 .44064 L
s
1 0 0 r
.29893 .66917 m
.30845 .67249 L
s
0 0 1 r
.74269 .41155 m
.73395 .3915 L
s
.27333 .3769 m
.26334 .39636 L
s
.26477 .39394 m
.25504 .40783 L
s
1 0 0 r
.5191 .24266 m
.51943 .23737 L
s
0 0 1 r
.75897 .51417 m
.75795 .49272 L
s
.75764 .53354 m
.75781 .51243 L
s
1 0 0 r
.62405 .27361 m
.62404 .26765 L
s
0 0 1 r
.7497 .4323 m
.74269 .41155 L
s
.25707 .41216 m
.24849 .42874 L
s
.26334 .39636 m
.25503 .41662 L
s
.75922 .49471 m
.757 .47306 L
s
.72944 .62754 m
.73249 .61281 L
s
.2477 .44349 m
.24263 .46439 L
s
.73899 .60775 m
.74199 .59105 L
s
.75523 .55267 m
.75657 .53205 L
s
.25123 .4294 m
.24419 .44823 L
s
.24828 .44064 m
.24334 .46185 L
s
.7173 .64826 m
.72027 .6356 L
s
.75495 .45359 m
.7497 .4323 L
s
.25503 .41662 m
.24844 .43755 L
s
1 0 0 r
.67628 .31046 m
.67469 .30241 L
s
.53811 .24397 m
.53862 .23891 L
s
.4054 .7464 m
.40859 .7422 L
s
0 0 1 r
.74631 .58907 m
.74912 .57058 L
s
.24677 .44584 m
.24159 .46636 L
s
.75838 .47528 m
.75495 .45359 L
s
.24844 .43755 m
.24365 .45898 L
s
.75958 .51653 m
.75922 .49471 L
s
.75813 .53572 m
.75897 .51417 L
s
.75176 .57144 m
.75423 .55146 L
s
1 0 0 r
.34233 .71204 m
.34889 .71084 L
s
.70498 .34102 m
.70222 .33046 L
s
0 0 1 r
.24334 .46185 m
.24022 .48346 L
s
1 0 0 r
.63866 .28059 m
.63808 .27455 L
s
0 0 1 r
.75996 .49722 m
.75838 .47528 L
s
.24365 .45898 m
.24068 .48078 L
s
.2755 .36954 m
.26555 .3794 L
s
1 0 0 r
.55681 .24661 m
.55733 .24177 L
s
.30573 .67922 m
.31435 .68165 L
s
0 0 1 r
.24557 .44749 m
.2403 .46756 L
s
.7556 .55466 m
.75764 .53354 L
s
.24263 .46439 m
.23937 .48574 L
s
1 0 0 r
.42294 .75318 m
.42525 .74889 L
s
0 0 1 r
.24982 .42967 m
.2428 .44786 L
s
.26424 .39054 m
.25481 .40352 L
s
.25586 .41068 m
.24743 .42648 L
s
.75967 .51925 m
.75996 .49722 L
s
.24068 .48078 m
.23958 .50279 L
s
.75807 .53836 m
.75958 .51653 L
s
.24073 .47793 m
.23979 .5 L
s
.24353 .45602 m
.24073 .47793 L
s
.24819 .43443 m
.24353 .45602 L
s
.25466 .41331 m
.24819 .43443 L
s
.26289 .39282 m
.25466 .41331 L
s
.27283 .3731 m
.26289 .39282 L
s
.28441 .35429 m
.27283 .3731 L
s
.29755 .33653 m
.28441 .35429 L
s
.31214 .31995 m
.29755 .33653 L
s
.32809 .30467 m
.31214 .31995 L
s
.34527 .29079 m
.32809 .30467 L
s
.36357 .27843 m
.34527 .29079 L
s
.38285 .26765 m
.36357 .27843 L
s
.40298 .25856 m
.38285 .26765 L
s
.42381 .2512 m
.40298 .25856 L
s
.44518 .24563 m
.42381 .2512 L
s
.46695 .2419 m
.44518 .24563 L
s
.48896 .24003 m
.46695 .2419 L
s
.51104 .24003 m
.48896 .24003 L
s
.53305 .2419 m
.51104 .24003 L
s
.55482 .24563 m
.53305 .2419 L
s
.57619 .2512 m
.55482 .24563 L
s
.59702 .25856 m
.57619 .2512 L
s
.61715 .26765 m
.59702 .25856 L
s
.63643 .27843 m
.61715 .26765 L
s
.65473 .29079 m
.63643 .27843 L
s
.67191 .30467 m
.65473 .29079 L
s
.68786 .31995 m
.67191 .30467 L
s
.70245 .33653 m
.68786 .31995 L
s
.71559 .35429 m
.70245 .33653 L
s
.72717 .3731 m
.71559 .35429 L
s
.73711 .39282 m
.72717 .3731 L
s
.74534 .41331 m
.73711 .39282 L
s
.75181 .43443 m
.74534 .41331 L
s
.75647 .45602 m
.75181 .43443 L
s
.75927 .47793 m
.75647 .45602 L
s
.76021 .5 m
.75927 .47793 L
s
.75927 .52207 m
.76021 .5 L
s
.75647 .54398 m
.75927 .52207 L
s
.75181 .56557 m
.75647 .54398 L
s
.74534 .58669 m
.75181 .56557 L
s
.73711 .60718 m
.74534 .58669 L
s
.72717 .6269 m
.73711 .60718 L
s
.71559 .64571 m
.72717 .6269 L
s
.70245 .66347 m
.71559 .64571 L
s
.68786 .68005 m
.70245 .66347 L
s
.67191 .69533 m
.68786 .68005 L
s
.65473 .70921 m
.67191 .69533 L
s
.63643 .72157 m
.65473 .70921 L
s
.61715 .73235 m
.63643 .72157 L
s
.59702 .74144 m
.61715 .73235 L
s
.57619 .7488 m
.59702 .74144 L
s
.55482 .75437 m
.57619 .7488 L
s
.53305 .7581 m
.55482 .75437 L
s
.51104 .75997 m
.53305 .7581 L
s
.48896 .75997 m
.51104 .75997 L
s
.46695 .7581 m
.48896 .75997 L
s
.44518 .75437 m
.46695 .7581 L
s
.42381 .7488 m
.44518 .75437 L
s
.40298 .74144 m
.42381 .7488 L
s
.38285 .73235 m
.40298 .74144 L
s
.36357 .72157 m
.38285 .73235 L
s
.34527 .70921 m
.36357 .72157 L
s
.32809 .69533 m
.34527 .70921 L
s
.31214 .68005 m
.32809 .69533 L
s
.29755 .66347 m
.31214 .68005 L
s
.28441 .64571 m
.29755 .66347 L
s
.27283 .6269 m
.28441 .64571 L
s
.26289 .60718 m
.27283 .6269 L
s
.25466 .58669 m
.26289 .60718 L
s
.24819 .56557 m
.25466 .58669 L
s
.24353 .54398 m
.24819 .56557 L
s
.24073 .52207 m
.24353 .54398 L
s
.23979 .5 m
.24073 .52207 L
s
.24022 .48346 m
.23895 .50533 L
s
.75751 .5412 m
.75967 .51925 L
s
.23958 .50279 m
.24035 .52484 L
s
.74075 .60699 m
.7446 .58948 L
s
.73231 .62525 m
.73626 .60969 L
s
.74722 .58971 m
.75081 .57051 L
s
1 0 0 r
.57495 .25047 m
.57533 .24581 L
s
0 0 1 r
.7554 .55721 m
.75813 .53572 L
s
.24159 .46636 m
.23821 .48738 L
s
.75202 .57323 m
.75523 .55267 L
s
1 0 0 r
.68632 .3177 m
.68386 .3092 L
s
.44143 .75869 m
.44296 .75441 L
s
0 0 1 r
.72154 .64446 m
.72545 .63101 L
s
.75348 .56293 m
.75751 .5412 L
s
.24035 .52484 m
.24301 .54678 L
s
1 0 0 r
.35514 .72222 m
.36065 .7205 L
s
0 0 1 r
.75468 .56005 m
.75807 .53836 L
s
1 0 0 r
.28454 .65432 m
.29378 .65994 L
s
.65203 .28787 m
.65076 .28165 L
s
0 0 1 r
.24419 .44823 m
.23889 .46777 L
s
.23937 .48574 m
.23797 .50739 L
s
.23895 .50533 m
.23958 .52729 L
s
.74759 .58427 m
.75348 .56293 L
s
.24301 .54678 m
.24753 .56845 L
s
.75168 .57566 m
.7556 .55466 L
s
.24849 .42874 m
.24155 .44624 L
s
1 0 0 r
.59232 .25539 m
.5924 .25087 L
s
.46063 .76281 m
.4615 .75863 L
s
.31427 .68984 m
.32193 .69147 L
s
0 0 1 r
.7399 .60506 m
.74759 .58427 L
s
.24753 .56845 m
.2539 .58969 L
s
.2772 .36284 m
.26781 .37172 L
s
.74942 .58144 m
.75468 .56005 L
s
.74739 .59127 m
.75176 .57144 L
s
.2403 .46756 m
.23685 .48817 L
s
.25504 .40783 m
.24683 .42279 L
s
.75079 .57848 m
.7554 .55721 L
s
.26442 .38569 m
.25538 .39774 L
s
.23958 .52729 m
.2421 .5492 L
s
.73044 .62515 m
.7399 .60506 L
s
.74163 .60734 m
.74631 .58907 L
s
.2539 .58969 m
.26208 .61035 L
s
1 0 0 r
.36958 .73195 m
.37407 .72982 L
s
0 0 1 r
.23821 .48738 m
.23671 .50875 L
s
.23797 .50739 m
.23847 .5292 L
s
1 0 0 r
.48024 .76544 m
.4806 .76143 L
s
0 0 1 r
.73414 .62414 m
.73899 .60775 L
s
.71927 .64438 m
.73044 .62515 L
s
.26208 .61035 m
.27201 .63025 L
s
1 0 0 r
.69497 .32443 m
.69158 .31538 L
s
0 0 1 r
.74231 .60237 m
.74942 .58144 L
s
1 0 0 r
.66406 .29523 m
.66199 .28872 L
s
.60874 .26118 m
.60838 .25672 L
s
0 0 1 r
.2428 .44786 m
.23752 .46682 L
s
.74691 .59356 m
.75202 .57323 L
s
.72459 .64181 m
.72944 .62754 L
s
.70648 .66262 m
.71927 .64438 L
s
.2421 .5492 m
.24652 .57088 L
s
.27201 .63025 m
.28362 .64926 L
s
1 0 0 r
.5 .76657 m
.5 .76276 L
s
.5 .23724 m
.5 .23343 L
s
.29052 .66446 m
.29893 .66917 L
s
0 0 1 r
.74431 .59938 m
.75079 .57848 L
s
.74586 .59635 m
.75168 .57566 L
s
.69215 .67972 m
.70648 .66262 L
s
.28362 .64926 m
.29685 .66723 L
s
1 0 0 r
.32458 .70077 m
.33125 .70169 L
s
0 0 1 r
.74172 .60866 m
.74722 .58971 L
s
.73338 .62268 m
.74231 .60237 L
s
.24743 .42648 m
.24064 .44323 L
s
.71261 .66028 m
.7173 .64826 L
s
1 0 0 r
.38552 .74094 m
.38904 .73854 L
s
0 0 1 r
.23889 .46777 m
.23542 .48791 L
s
.67638 .69554 m
.69215 .67972 L
s
.29685 .66723 m
.31159 .68402 L
s
.23847 .5292 m
.24089 .55099 L
s
.24652 .57088 m
.25282 .59216 L
s
.65929 .70998 m
.67638 .69554 L
s
1 0 0 r
.51943 .23737 m
.51963 .2338 L
s
0 0 1 r
.31159 .68402 m
.32774 .69951 L
s
1 0 0 r
.62404 .26765 m
.6231 .26316 L
s
0 0 1 r
.23685 .48817 m
.23528 .50918 L
s
.23671 .50875 m
.23712 .53032 L
s
.73502 .62417 m
.74075 .60699 L
s
.25481 .40352 m
.2469 .41761 L
s
.64099 .7229 m
.65929 .70998 L
s
.32774 .69951 m
.34519 .71356 L
s
.26555 .3794 m
.25699 .3905 L
s
.72269 .6422 m
.73338 .62268 L
s
.74112 .61079 m
.74739 .59127 L
s
1 0 0 r
.67469 .30241 m
.67172 .2955 L
s
0 0 1 r
.73597 .61974 m
.74431 .59938 L
s
.62164 .73421 m
.64099 .7229 L
s
.34519 .71356 m
.3638 .72608 L
s
.25282 .59216 m
.26097 .6129 L
s
1 0 0 r
.70222 .33046 m
.69784 .32075 L
s
0 0 1 r
.60136 .74383 m
.62164 .73421 L
s
.72651 .64036 m
.73231 .62525 L
s
1 0 0 r
.53862 .23891 m
.53886 .23558 L
s
0 0 1 r
.3638 .72608 m
.38343 .73695 L
s
1 0 0 r
.40277 .74895 m
.4054 .7464 L
s
0 0 1 r
.24155 .44624 m
.23636 .46455 L
s
.7399 .61352 m
.74691 .59356 L
s
.58031 .75167 m
.60136 .74383 L
s
.73816 .61659 m
.74586 .59635 L
s
.38343 .73695 m
.40395 .74611 L
s
.24089 .55099 m
.24524 .5726 L
s
.55864 .75768 m
.58031 .75167 L
s
.40395 .74611 m
.42519 .75346 L
s
.7103 .66079 m
.72269 .6422 L
s
1 0 0 r
.33668 .7117 m
.34233 .71204 L
s
0 0 1 r
.53653 .76179 m
.55864 .75768 L
s
.42519 .75346 m
.447 .75897 L
s
1 0 0 r
.29821 .67534 m
.30573 .67922 L
s
0 0 1 r
.51414 .76399 m
.53653 .76179 L
s
.447 .75897 m
.4692 .76257 L
s
.26097 .6129 m
.27093 .63292 L
s
.49164 .76425 m
.51414 .76399 L
s
.4692 .76257 m
.49164 .76425 L
s
1 0 0 r
.63808 .27455 m
.63644 .26994 L
s
0 0 1 r
.73504 .62524 m
.74163 .60734 L
s
.71585 .65729 m
.72154 .64446 L
s
1 0 0 r
.55733 .24177 m
.55744 .23866 L
s
0 0 1 r
.23752 .46682 m
.23408 .48642 L
s
.72581 .63939 m
.73597 .61974 L
s
.23712 .53032 m
.23948 .55193 L
s
1 0 0 r
.42111 .75576 m
.42294 .75318 L
s
0 0 1 r
.24683 .42279 m
.24027 .43876 L
s
.69629 .67829 m
.7103 .66079 L
s
.27093 .63292 m
.28262 .65206 L
s
.23542 .48791 m
.23384 .5085 L
s
.23528 .50918 m
.23565 .53045 L
s
.24524 .5726 m
.25151 .59387 L
s
1 0 0 r
.68386 .3092 m
.67993 .30178 L
s
0 0 1 r
.7274 .64007 m
.73414 .62414 L
s
.73431 .6272 m
.74172 .60866 L
s
1 0 0 r
.27656 .64732 m
.28454 .65432 L
s
.57533 .24581 m
.57516 .24287 L
s
0 0 1 r
.25538 .39774 m
.24788 .41094 L
s
.7286 .63621 m
.73816 .61659 L
s
.68076 .69457 m
.69629 .67829 L
s
1 0 0 r
.44028 .76122 m
.44143 .75869 L
s
0 0 1 r
.26781 .37172 m
.25983 .38189 L
s
1 0 0 r
.35048 .72235 m
.35514 .72222 L
s
0 0 1 r
.28262 .65206 m
.29599 .67018 L
s
1 0 0 r
.65076 .28165 m
.64829 .27681 L
s
0 0 1 r
.73293 .62985 m
.74112 .61079 L
s
.71389 .65819 m
.72581 .63939 L
s
.731 .63294 m
.7399 .61352 L
s
.24064 .44323 m
.23561 .46085 L
s
.66383 .70947 m
.68076 .69457 L
s
1 0 0 r
.30768 .68671 m
.31427 .68984 L
s
0 0 1 r
.71789 .65549 m
.72459 .64181 L
s
.25151 .59387 m
.25968 .61462 L
s
.23948 .55193 m
.24381 .57341 L
s
.29599 .67018 m
.31093 .68711 L
s
1 0 0 r
.5924 .25087 m
.59179 .24802 L
s
.46001 .76519 m
.46063 .76281 L
s
0 0 1 r
.72737 .64087 m
.73502 .62417 L
s
.6456 .72289 m
.66383 .70947 L
s
.31093 .68711 m
.32733 .70273 L
s
.23636 .46455 m
.23302 .48357 L
s
.70028 .67596 m
.71389 .65819 L
s
1 0 0 r
.69158 .31538 m
.6866 .30735 L
s
0 0 1 r
.23565 .53045 m
.23801 .55181 L
s
1 0 0 r
.36588 .7324 m
.36958 .73195 L
s
0 0 1 r
.71722 .65505 m
.7286 .63621 L
s
.2469 .41761 m
.24066 .43277 L
s
1 0 0 r
.48001 .76762 m
.48024 .76544 L
s
0 0 1 r
.62622 .7347 m
.6456 .72289 L
s
1 0 0 r
.66199 .28872 m
.6586 .28353 L
s
0 0 1 r
.25968 .61462 m
.26971 .63468 L
s
.70614 .67153 m
.71261 .66028 L
s
.23408 .48642 m
.23256 .50654 L
s
.23384 .5085 m
.23423 .52941 L
s
.32733 .70273 m
.34508 .7169 L
s
1 0 0 r
.28335 .65831 m
.29052 .66446 L
s
0 0 1 r
.72653 .64263 m
.73504 .62524 L
s
1 0 0 r
.60838 .25672 m
.60719 .25391 L
s
0 0 1 r
.71882 .65488 m
.72651 .64036 L
s
.60583 .7448 m
.62622 .7347 L
s
.24381 .57341 m
.2501 .59459 L
s
.72024 .65165 m
.731 .63294 L
s
.34508 .7169 m
.36405 .7295 L
s
.25699 .3905 m
.24997 .40282 L
s
1 0 0 r
.5 .76851 m
.5 .76657 L
s
.5 .23343 m
.5 .23149 L
s
0 0 1 r
.68507 .69255 m
.70028 .67596 L
s
1 0 0 r
.31896 .69828 m
.32458 .70077 L
s
0 0 1 r
.72499 .64517 m
.73431 .6272 L
s
.72285 .64826 m
.73293 .62985 L
s
.58459 .75311 m
.60583 .7448 L
s
.36405 .7295 m
.38408 .74042 L
s
1 0 0 r
.38272 .7416 m
.38552 .74094 L
s
0 0 1 r
.26971 .63468 m
.28154 .6539 L
s
.24027 .43876 m
.23548 .45565 L
s
.56267 .75955 m
.58459 .75311 L
s
.70409 .67293 m
.71722 .65505 L
s
.38408 .74042 m
.40502 .74957 L
s
1 0 0 r
.51963 .2338 m
.51969 .2321 L
s
.6231 .26316 m
.62118 .26028 L
s
.69784 .32075 m
.69177 .31202 L
s
0 0 1 r
.54023 .76406 m
.56267 .75955 L
s
.40502 .74957 m
.42672 .75688 L
s
1 0 0 r
.67172 .2955 m
.66732 .28986 L
s
0 0 1 r
.23801 .55181 m
.24237 .5731 L
s
.66836 .70783 m
.68507 .69255 L
s
.71875 .6554 m
.7274 .64007 L
s
.70832 .66938 m
.71585 .65729 L
s
.51746 .7666 m
.54023 .76406 L
s
.42672 .75688 m
.44899 .76227 L
s
.49454 .76715 m
.51746 .7666 L
s
.44899 .76227 m
.47166 .7657 L
s
.2501 .59459 m
.25834 .61529 L
s
.47166 .7657 m
.49454 .76715 L
s
.28154 .6539 m
.29509 .67209 L
s
1 0 0 r
.40077 .7497 m
.40277 .74895 L
s
.53886 .23558 m
.53881 .23412 L
s
0 0 1 r
.23561 .46085 m
.23245 .47924 L
s
1 0 0 r
.29192 .66997 m
.29821 .67534 L
s
.33202 .70973 m
.33668 .7117 L
s
0 0 1 r
.23423 .52941 m
.23664 .55046 L
s
.24788 .41094 m
.24204 .42527 L
s
.70765 .66948 m
.72024 .65165 L
s
.65026 .72164 m
.66836 .70783 L
s
.7178 .65694 m
.72737 .64087 L
s
1 0 0 r
.63644 .26994 m
.63367 .26688 L
s
0 0 1 r
.23302 .48357 m
.23163 .50316 L
s
.68927 .68971 m
.70409 .67293 L
s
.23256 .50654 m
.23304 .52702 L
s
1 0 0 r
.55744 .23866 m
.55712 .2374 L
s
0 0 1 r
.29509 .67209 m
.31028 .68911 L
s
1 0 0 r
.26997 .63891 m
.27656 .64732 L
s
0 0 1 r
.25983 .38189 m
.25339 .39333 L
s
1 0 0 r
.41981 .7565 m
.42111 .75576 L
s
0 0 1 r
.71091 .66588 m
.72285 .64826 L
s
.7093 .66844 m
.71789 .65549 L
s
.7161 .65935 m
.72653 .64263 L
s
1 0 0 r
.67993 .30178 m
.67444 .29558 L
s
0 0 1 r
.25834 .61529 m
.2685 .63534 L
s
.71376 .66241 m
.72499 .64517 L
s
.63092 .73387 m
.65026 .72164 L
s
.24237 .5731 m
.24874 .59413 L
s
.31028 .68911 m
.32699 .7048 L
s
1 0 0 r
.57516 .24287 m
.5744 .24177 L
s
0 0 1 r
.24066 .43277 m
.23621 .44891 L
s
1 0 0 r
.34677 .72076 m
.35048 .72235 L
s
.43954 .76184 m
.44028 .76122 L
s
.64829 .27681 m
.64458 .27347 L
s
0 0 1 r
.67287 .70522 m
.68927 .68971 L
s
.61048 .7444 m
.63092 .73387 L
s
.69332 .68628 m
.70765 .66948 L
s
1 0 0 r
.3023 .68202 m
.30768 .68671 L
s
0 0 1 r
.70921 .66866 m
.71882 .65488 L
s
.32699 .7048 m
.3451 .71903 L
s
.23664 .55046 m
.24109 .57149 L
s
.2685 .63534 m
.28051 .65456 L
s
.69784 .68187 m
.70614 .67153 L
s
1 0 0 r
.59179 .24802 m
.59045 .24701 L
s
.45968 .76563 m
.46001 .76519 L
s
.6866 .30735 m
.67998 .30048 L
s
0 0 1 r
.23548 .45565 m
.23259 .47336 L
s
.58911 .75313 m
.61048 .7444 L
s
.24997 .40282 m
.24463 .41632 L
s
.3451 .71903 m
.36447 .73166 L
s
.24874 .59413 m
.25711 .61472 L
s
.65499 .71931 m
.67287 .70522 L
s
1 0 0 r
.27757 .65069 m
.28335 .65831 L
s
0 0 1 r
.69715 .68253 m
.71091 .66588 L
s
.70817 .66997 m
.71875 .6554 L
s
1 0 0 r
.36306 .73108 m
.36588 .7324 L
s
0 0 1 r
.23304 .52702 m
.23556 .54772 L
s
1 0 0 r
.6586 .28353 m
.65383 .2798 L
s
0 0 1 r
.56696 .75997 m
.58911 .75313 L
s
.23245 .47924 m
.23127 .49826 L
s
1 0 0 r
.47993 .76783 m
.48001 .76762 L
s
0 0 1 r
.23163 .50316 m
.23226 .52317 L
s
.36447 .73166 m
.38494 .74258 L
s
1 0 0 r
.60719 .25391 m
.60511 .25288 L
s
0 0 1 r
.28051 .65456 m
.29431 .67278 L
s
.7063 .67222 m
.7178 .65694 L
s
.54423 .76486 m
.56696 .75997 L
s
.70067 .67875 m
.71376 .66241 L
s
.67732 .70187 m
.69332 .68628 L
s
.38494 .74258 m
.40636 .75169 L
s
.69891 .68059 m
.70832 .66938 L
s
1 0 0 r
.31451 .69414 m
.31896 .69828 L
s
0 0 1 r
.70376 .67523 m
.7161 .65935 L
s
1 0 0 r
.5 .76845 m
.5 .76851 L
s
.5 .23149 m
.5 .23155 L
s
0 0 1 r
.52111 .76774 m
.54423 .76486 L
s
1 0 0 r
.69177 .31202 m
.68399 .3044 L
s
0 0 1 r
.40636 .75169 m
.42854 .7589 L
s
.63577 .73186 m
.65499 .71931 L
s
1 0 0 r
.3807 .74042 m
.38272 .7416 L
s
0 0 1 r
.24204 .42527 m
.23801 .44065 L
s
.49778 .76859 m
.52111 .76774 L
s
.42854 .7589 m
.4513 .76415 L
s
.24109 .57149 m
.24761 .59232 L
s
.47444 .76739 m
.49778 .76859 L
s
.4513 .76415 m
.47444 .76739 L
s
1 0 0 r
.62118 .26028 m
.61824 .25914 L
s
.66732 .28986 m
.66143 .28562 L
s
0 0 1 r
.25711 .61472 m
.26746 .6347 L
s
1 0 0 r
.51969 .2321 m
.5196 .23242 L
s
0 0 1 r
.29431 .67278 m
.30981 .68983 L
s
.69881 .6805 m
.7093 .66844 L
s
.68165 .69804 m
.69715 .68253 L
s
1 0 0 r
.28699 .66305 m
.29192 .66997 L
s
0 0 1 r
.61535 .74272 m
.63577 .73186 L
s
.65975 .7161 m
.67732 .70187 L
s
.25339 .39333 m
.24863 .40603 L
s
1 0 0 r
.39946 .74854 m
.40077 .7497 L
s
.53881 .23412 m
.53846 .23468 L
s
0 0 1 r
.23621 .44891 m
.23366 .46594 L
s
.23556 .54772 m
.24019 .56844 L
s
1 0 0 r
.32848 .70603 m
.33202 .70973 L
s
.26492 .62908 m
.26997 .63891 L
s
0 0 1 r
.30981 .68983 m
.32688 .70555 L
s
1 0 0 r
.63367 .26688 m
.62975 .26552 L
s
0 0 1 r
.69768 .68155 m
.70921 .66866 L
s
.23259 .47336 m
.23169 .49179 L
s
1 0 0 r
.67444 .29558 m
.66736 .29071 L
s
0 0 1 r
.68576 .69402 m
.70067 .67875 L
s
1 0 0 r
.55712 .2374 m
.55634 .23816 L
s
0 0 1 r
.23226 .52317 m
.23499 .54346 L
s
.26746 .6347 m
.27973 .65389 L
s
.5939 .75179 m
.61535 .74272 L
s
1 0 0 r
.41907 .75525 m
.41981 .7565 L
s
0 0 1 r
.23127 .49826 m
.23214 .51777 L
s
.24761 .59232 m
.25619 .61276 L
s
.69567 .68362 m
.70817 .66997 L
s
.32688 .70555 m
.3454 .71979 L
s
.68956 .6901 m
.70376 .67523 L
s
.64074 .72883 m
.65975 .7161 L
s
.69291 .68654 m
.7063 .67222 L
s
.68769 .69117 m
.69784 .68187 L
s
1 0 0 r
.5744 .24177 m
.57302 .24265 L
s
0 0 1 r
.57159 .75898 m
.5939 .75179 L
s
.24463 .41632 m
.2411 .43094 L
s
1 0 0 r
.3441 .71737 m
.34677 .72076 L
s
0 0 1 r
.66449 .71226 m
.68165 .69804 L
s
1 0 0 r
.64458 .27347 m
.63956 .27177 L
s
.43924 .76042 m
.43954 .76184 L
s
.29825 .67568 m
.3023 .68202 L
s
0 0 1 r
.3454 .71979 m
.36523 .73242 L
s
1 0 0 r
.67998 .30048 m
.67167 .2949 L
s
0 0 1 r
.27973 .65389 m
.29384 .67208 L
s
.54862 .7642 m
.57159 .75898 L
s
.24019 .56844 m
.24692 .58903 L
s
1 0 0 r
.59045 .24701 m
.58833 .24794 L
s
.45965 .76399 m
.45968 .76563 L
s
0 0 1 r
.36523 .73242 m
.38619 .7433 L
s
1 0 0 r
.27331 .64157 m
.27757 .65069 L
s
0 0 1 r
.68761 .69076 m
.69891 .68059 L
s
.62044 .73992 m
.64074 .72883 L
s
.52517 .76739 m
.54862 .7642 L
s
.23801 .44065 m
.2359 .45699 L
s
.25619 .61276 m
.26679 .63263 L
s
1 0 0 r
.65383 .2798 m
.64765 .27764 L
s
0 0 1 r
.66913 .70806 m
.68576 .69402 L
s
1 0 0 r
.36119 .72787 m
.36306 .73108 L
s
0 0 1 r
.38619 .7433 m
.4081 .75233 L
s
1 0 0 r
.48001 .76592 m
.47993 .76783 L
s
0 0 1 r
.50145 .76852 m
.52517 .76739 L
s
.23499 .54346 m
.23986 .56385 L
s
.4081 .75233 m
.43079 .75943 L
s
.29384 .67208 m
.3097 .68913 L
s
1 0 0 r
.60511 .25288 m
.6021 .25376 L
s
0 0 1 r
.64581 .72503 m
.66449 .71226 L
s
1 0 0 r
.68399 .3044 m
.67443 .29803 L
s
0 0 1 r
.68641 .69153 m
.69881 .6805 L
s
.47767 .76756 m
.50145 .76852 L
s
1 0 0 r
.31133 .68828 m
.31451 .69414 L
s
0 0 1 r
.23366 .46594 m
.23315 .48375 L
s
.43079 .75943 m
.45405 .76452 L
s
.45405 .76452 m
.47767 .76756 L
s
.67357 .70379 m
.68956 .6901 L
s
1 0 0 r
.5 .76626 m
.5 .76845 L
s
.5 .23155 m
.5 .23374 L
s
0 0 1 r
.599 .74924 m
.62044 .73992 L
s
.23214 .51777 m
.23514 .53763 L
s
.23169 .49179 m
.23289 .51078 L
s
.68425 .6934 m
.69768 .68155 L
s
1 0 0 r
.37954 .73727 m
.3807 .74042 L
s
.66143 .28562 m
.654 .28289 L
s
0 0 1 r
.24863 .40603 m
.24569 .41993 L
s
.67767 .69975 m
.69291 .68654 L
s
.68128 .6962 m
.69567 .68362 L
s
1 0 0 r
.61824 .25914 m
.61422 .25987 L
s
0 0 1 r
.3097 .68913 m
.32719 .70484 L
s
1 0 0 r
.5196 .23242 m
.51935 .23488 L
s
0 0 1 r
.26679 .63263 m
.27937 .65173 L
s
.24692 .58903 m
.25577 .60928 L
s
1 0 0 r
.28355 .65454 m
.28699 .66305 L
s
.26154 .61784 m
.26492 .62908 L
s
0 0 1 r
.5766 .75668 m
.599 .74924 L
s
.62572 .7362 m
.64581 .72503 L
s
.65088 .72071 m
.66913 .70806 L
s
1 0 0 r
.3989 .74533 m
.39946 .74854 L
s
.53846 .23468 m
.53778 .23738 L
s
.32615 .70052 m
.32848 .70603 L
s
0 0 1 r
.32719 .70484 m
.34617 .71906 L
s
1 0 0 r
.62975 .26552 m
.62461 .26598 L
s
.66736 .29071 m
.65865 .28732 L
s
0 0 1 r
.2411 .43094 m
.23952 .44662 L
s
.67568 .69928 m
.68769 .69117 L
s
.55344 .76216 m
.5766 .75668 L
s
.23986 .56385 m
.24688 .58416 L
s
1 0 0 r
.55634 .23816 m
.55507 .24104 L
s
.41895 .7519 m
.41907 .75525 L
s
0 0 1 r
.27937 .65173 m
.29385 .66987 L
s
.65587 .71616 m
.67357 .70379 L
s
.34617 .71906 m
.36649 .73165 L
s
.2359 .45699 m
.23584 .4742 L
s
.60439 .74564 m
.62572 .7362 L
s
.25577 .60928 m
.26669 .629 L
s
.67442 .69975 m
.68761 .69076 L
s
.52972 .7656 m
.55344 .76216 L
s
1 0 0 r
.29565 .66767 m
.29825 .67568 L
s
0 0 1 r
.23514 .53763 m
.24033 .55766 L
s
1 0 0 r
.63956 .27177 m
.63321 .27184 L
s
.57302 .24265 m
.571 .24565 L
s
.34256 .71209 m
.3441 .71737 L
s
.67167 .2949 m
.66166 .29074 L
s
.43941 .75685 m
.43924 .76042 L
s
0 0 1 r
.36649 .73165 m
.38797 .74248 L
s
.63113 .73181 m
.65088 .72071 L
s
.23315 .48375 m
.23475 .50221 L
s
.66065 .71167 m
.67767 .69975 L
s
.23289 .51078 m
.23625 .53019 L
s
.67212 .70138 m
.68641 .69153 L
s
1 0 0 r
.2707 .63094 m
.27331 .64157 L
s
0 0 1 r
.50566 .76696 m
.52972 .7656 L
s
.66506 .70755 m
.68128 .6962 L
s
.29385 .66987 m
.31014 .68688 L
s
.66894 .70404 m
.68425 .6934 L
s
.38797 .74248 m
.41041 .75143 L
s
1 0 0 r
.58833 .24794 m
.5854 .25095 L
s
.45995 .76014 m
.45965 .76399 L
s
0 0 1 r
.48147 .76621 m
.50566 .76696 L
s
.41041 .75143 m
.43362 .75841 L
s
1 0 0 r
.64765 .27764 m
.64 .27719 L
s
0 0 1 r
.582 .75322 m
.60439 .74564 L
s
1 0 0 r
.67443 .29803 m
.6631 .29303 L
s
0 0 1 r
.45738 .76336 m
.48147 .76621 L
s
1 0 0 r
.36037 .72268 m
.36119 .72787 L
s
0 0 1 r
.43362 .75841 m
.45738 .76336 L
s
.24688 .58416 m
.25607 .60419 L
s
1 0 0 r
.48024 .76177 m
.48001 .76592 L
s
0 0 1 r
.24569 .41993 m
.2447 .43497 L
s
.26669 .629 m
.27965 .648 L
s
1 0 0 r
.6021 .25376 m
.59813 .25668 L
s
.30955 .68065 m
.31133 .68828 L
s
0 0 1 r
.63658 .72703 m
.65587 .71616 L
s
.31014 .68688 m
.3281 .70256 L
s
.61003 .74122 m
.63113 .73181 L
s
1 0 0 r
.5 .76181 m
.5 .76626 L
s
.5 .23374 m
.5 .23819 L
s
.654 .28289 m
.64502 .28182 L
s
0 0 1 r
.55874 .75886 m
.582 .75322 L
s
1 0 0 r
.37932 .73205 m
.37954 .73727 L
s
0 0 1 r
.24033 .55766 m
.24772 .57767 L
s
1 0 0 r
.25997 .60521 m
.26154 .61784 L
s
.28173 .64442 m
.28355 .65454 L
s
.61422 .25987 m
.6091 .26258 L
s
0 0 1 r
.23952 .44662 m
.23999 .46325 L
s
1 0 0 r
.51935 .23488 m
.51893 .23962 L
s
0 0 1 r
.64195 .72216 m
.66065 .71167 L
s
.3281 .70256 m
.34758 .71675 L
s
.66182 .70605 m
.67568 .69928 L
s
.23625 .53019 m
.24183 .54985 L
s
.53483 .76247 m
.55874 .75886 L
s
.27965 .648 m
.29457 .66607 L
s
.23584 .4742 m
.23792 .49214 L
s
1 0 0 r
.32514 .69314 m
.32615 .70052 L
s
.39913 .73999 m
.3989 .74533 L
s
.65865 .28732 m
.64829 .28552 L
s
.53778 .23738 m
.53677 .24235 L
s
0 0 1 r
.23475 .50221 m
.23854 .52118 L
s
.25607 .60419 m
.26739 .62375 L
s
.65939 .70742 m
.67442 .69975 L
s
.64709 .71749 m
.66506 .70755 L
s
.58776 .74882 m
.61003 .74122 L
s
1 0 0 r
.62461 .26598 m
.61823 .26836 L
s
0 0 1 r
.34758 .71675 m
.36843 .72931 L
s
.61584 .73626 m
.63658 .72703 L
s
.656 .70989 m
.67212 .70138 L
s
.65184 .71332 m
.66894 .70404 L
s
.51048 .76399 m
.53483 .76247 L
s
1 0 0 r
.55507 .24104 m
.55329 .24618 L
s
.4195 .74634 m
.41895 .7519 L
s
.66166 .29074 m
.64992 .28813 L
s
0 0 1 r
.36843 .72931 m
.39045 .74008 L
s
1 0 0 r
.29461 .65796 m
.29565 .66767 L
s
.63321 .27184 m
.62549 .27377 L
s
0 0 1 r
.48592 .7634 m
.51048 .76399 L
s
.29457 .66607 m
.31133 .68302 L
s
1 0 0 r
.34225 .70483 m
.34256 .71209 L
s
.571 .24565 m
.5683 .25086 L
s
.26986 .61882 m
.2707 .63094 L
s
0 0 1 r
.24772 .57767 m
.25731 .59748 L
s
1 0 0 r
.44009 .75101 m
.43941 .75685 L
s
0 0 1 r
.39045 .74008 m
.41344 .74896 L
s
.56451 .7545 m
.58776 .74882 L
s
.46141 .76067 m
.48592 .7634 L
s
.62171 .73105 m
.64195 .72216 L
s
.41344 .74896 m
.43716 .75585 L
s
.43716 .75585 m
.46141 .76067 L
s
1 0 0 r
.6631 .29303 m
.65 .28955 L
s
0 0 1 r
.26739 .62375 m
.28079 .64263 L
s
.2447 .43497 m
.24576 .45107 L
s
1 0 0 r
.5854 .25095 m
.58164 .25614 L
s
.46059 .75398 m
.45995 .76014 L
s
.64 .27719 m
.63088 .27856 L
s
0 0 1 r
.59382 .74372 m
.61584 .73626 L
s
.24183 .54985 m
.24965 .56957 L
s
.31133 .68302 m
.3298 .69867 L
s
1 0 0 r
.36066 .71542 m
.36037 .72268 L
s
0 0 1 r
.23999 .46325 m
.24261 .48071 L
s
.6275 .7259 m
.64709 .71749 L
s
.5405 .75816 m
.56451 .7545 L
s
1 0 0 r
.48066 .75528 m
.48024 .76177 L
s
.30926 .67121 m
.30955 .68065 L
s
.59813 .25668 m
.59318 .26174 L
s
0 0 1 r
.23854 .52118 m
.24458 .54048 L
s
.23792 .49214 m
.24222 .51069 L
s
1 0 0 r
.26032 .59124 m
.25997 .60521 L
s
0 0 1 r
.64615 .71136 m
.66182 .70605 L
s
1 0 0 r
.64502 .28182 m
.63446 .28251 L
s
0 0 1 r
.63303 .7211 m
.65184 .71332 L
s
1 0 0 r
.5 .755 m
.5 .76181 L
s
.5 .23819 m
.5 .245 L
s
.28164 .63271 m
.28173 .64442 L
s
0 0 1 r
.3298 .69867 m
.34983 .71284 L
s
.64256 .71362 m
.65939 .70742 L
s
1 0 0 r
.38008 .72468 m
.37932 .73205 L
s
0 0 1 r
.25731 .59748 m
.26909 .61687 L
s
.28079 .64263 m
.29618 .66063 L
s
.63812 .71693 m
.656 .70989 L
s
.51594 .75975 m
.5405 .75816 L
s
1 0 0 r
.6091 .26258 m
.60285 .26738 L
s
0 0 1 r
.57071 .7493 m
.59382 .74372 L
s
.60008 .73822 m
.62171 .73105 L
s
1 0 0 r
.51893 .23962 m
.51833 .24672 L
s
.64829 .28552 m
.63629 .28543 L
s
.32555 .68385 m
.32514 .69314 L
s
0 0 1 r
.34983 .71284 m
.37123 .72536 L
s
1 0 0 r
.40021 .73241 m
.39913 .73999 L
s
.53677 .24235 m
.5354 .24968 L
s
0 0 1 r
.4911 .75922 m
.51594 .75975 L
s
1 0 0 r
.61823 .26836 m
.61059 .27278 L
s
0 0 1 r
.24965 .56957 m
.25972 .58916 L
s
.37123 .72536 m
.39379 .73611 L
s
1 0 0 r
.64992 .28813 m
.63648 .28719 L
s
0 0 1 r
.29618 .66063 m
.31346 .67754 L
s
.60641 .73262 m
.6275 .7259 L
s
.46621 .75656 m
.4911 .75922 L
s
1 0 0 r
.55329 .24618 m
.55099 .25365 L
s
.42074 .73848 m
.4195 .74634 L
s
0 0 1 r
.54671 .75289 m
.57071 .7493 L
s
1 0 0 r
.29524 .64653 m
.29461 .65796 L
s
.27092 .60524 m
.26986 .61882 L
s
0 0 1 r
.24576 .45107 m
.24899 .46811 L
s
.39379 .73611 m
.41731 .74495 L
s
.26909 .61687 m
.28298 .63564 L
s
.44153 .75179 m
.46621 .75656 L
s
1 0 0 r
.62549 .27377 m
.61639 .27768 L
s
0 0 1 r
.24458 .54048 m
.2529 .55993 L
s
.41731 .74495 m
.44153 .75179 L
s
1 0 0 r
.34325 .69555 m
.34225 .70483 L
s
.65 .28955 m
.63517 .2877 L
s
0 0 1 r
.57725 .74354 m
.60008 .73822 L
s
1 0 0 r
.5683 .25086 m
.56491 .25839 L
s
0 0 1 r
.24261 .48071 m
.24747 .49887 L
s
1 0 0 r
.4413 .74282 m
.44009 .75101 L
s
0 0 1 r
.61264 .72723 m
.63303 .7211 L
s
.24222 .51069 m
.24878 .52966 L
s
.31346 .67754 m
.33248 .69317 L
s
1 0 0 r
.63088 .27856 m
.62029 .28185 L
s
0 0 1 r
.52207 .75442 m
.54671 .75289 L
s
.61858 .72234 m
.63812 .71693 L
s
1 0 0 r
.58164 .25614 m
.57703 .26361 L
s
.46158 .74542 m
.46059 .75398 L
s
0 0 1 r
.62874 .71507 m
.64615 .71136 L
s
.62402 .71822 m
.64256 .71362 L
s
1 0 0 r
.36213 .70605 m
.36066 .71542 L
s
.26269 .57599 m
.26032 .59124 L
s
.31057 .65994 m
.30926 .67121 L
s
0 0 1 r
.25972 .58916 m
.272 .60841 L
s
1 0 0 r
.48125 .74636 m
.48066 .75528 L
s
0 0 1 r
.28298 .63564 m
.2989 .65358 L
s
1 0 0 r
.59318 .26174 m
.58724 .26903 L
s
0 0 1 r
.58401 .73754 m
.60641 .73262 L
s
1 0 0 r
.63446 .28251 m
.62235 .28506 L
s
0 0 1 r
.33248 .69317 m
.35306 .70734 L
s
1 0 0 r
.28339 .61942 m
.28164 .63271 L
s
0 0 1 r
.55341 .74692 m
.57725 .74354 L
s
.49703 .75386 m
.52207 .75442 L
s
1 0 0 r
.5 .74574 m
.5 .755 L
s
.5 .245 m
.5 .25426 L
s
.38189 .7151 m
.38008 .72468 L
s
.60285 .26738 m
.59547 .27435 L
s
0 0 1 r
.2529 .55993 m
.26348 .57933 L
s
1 0 0 r
.63629 .28543 m
.62267 .28715 L
s
0 0 1 r
.35306 .70734 m
.37501 .71988 L
s
1 0 0 r
.51833 .24672 m
.51756 .25627 L
s
0 0 1 r
.47185 .75117 m
.49703 .75386 L
s
.59084 .73159 m
.61264 .72723 L
s
1 0 0 r
.32745 .67261 m
.32555 .68385 L
s
0 0 1 r
.2989 .65358 m
.31672 .67048 L
s
.24899 .46811 m
.25443 .48595 L
s
.24878 .52966 m
.25763 .54888 L
s
1 0 0 r
.40219 .72254 m
.40021 .73241 L
s
0 0 1 r
.37501 .71988 m
.39811 .73064 L
s
1 0 0 r
.5354 .24968 m
.53368 .25944 L
s
.63648 .28719 m
.62138 .28802 L
s
0 0 1 r
.44679 .74637 m
.47185 .75117 L
s
1 0 0 r
.61059 .27278 m
.6017 .27932 L
s
0 0 1 r
.52881 .74826 m
.55341 .74692 L
s
.24747 .49887 m
.25459 .51757 L
s
.272 .60841 m
.28642 .6271 L
s
.39811 .73064 m
.42212 .73951 L
s
1 0 0 r
.27396 .59027 m
.27092 .60524 L
s
0 0 1 r
.42212 .73951 m
.44679 .74637 L
s
.59754 .72602 m
.61858 .72234 L
s
.5605 .74054 m
.58401 .73754 L
s
1 0 0 r
.29765 .6334 m
.29524 .64653 L
s
.63517 .2877 m
.61866 .28759 L
s
.55099 .25365 m
.54816 .26354 L
s
.4227 .72825 m
.42074 .73848 L
s
0 0 1 r
.60391 .72109 m
.62402 .71822 L
s
1 0 0 r
.61639 .27768 m
.60594 .28365 L
s
0 0 1 r
.6097 .71707 m
.62874 .71507 L
s
1 0 0 r
.34563 .68422 m
.34325 .69555 L
s
0 0 1 r
.31672 .67048 m
.3363 .68613 L
s
1 0 0 r
.56491 .25839 m
.56083 .26829 L
s
0 0 1 r
.5037 .74753 m
.52881 .74826 L
s
1 0 0 r
.44307 .7322 m
.4413 .74282 L
s
0 0 1 r
.26348 .57933 m
.2763 .59848 L
s
1 0 0 r
.26718 .55956 m
.26269 .57599 L
s
.62029 .28185 m
.60825 .28713 L
s
0 0 1 r
.56781 .73408 m
.59084 .73159 L
s
1 0 0 r
.57703 .26361 m
.57157 .27341 L
s
0 0 1 r
.28642 .6271 m
.30289 .64502 L
s
1 0 0 r
.46295 .7344 m
.46158 .74542 L
s
0 0 1 r
.53609 .74155 m
.5605 .74054 L
s
1 0 0 r
.31356 .64685 m
.31057 .65994 L
s
.36486 .69452 m
.36213 .70605 L
s
0 0 1 r
.3363 .68613 m
.35743 .70035 L
s
.47833 .74469 m
.5037 .74753 L
s
1 0 0 r
.28706 .60461 m
.28339 .61942 L
s
.62235 .28506 m
.60872 .28955 L
s
0 0 1 r
.25763 .54888 m
.26877 .56815 L
s
1 0 0 r
.48203 .73495 m
.48125 .74636 L
s
.58724 .26903 m
.5803 .2786 L
s
0 0 1 r
.57517 .72785 m
.59754 .72602 L
s
.25459 .51757 m
.26402 .53662 L
s
.25443 .48595 m
.26215 .50445 L
s
.35743 .70035 m
.37992 .71296 L
s
1 0 0 r
.5 .73398 m
.5 .74574 L
s
.5 .25426 m
.5 .26602 L
s
.62267 .28715 m
.60749 .29078 L
s
0 0 1 r
.45299 .73977 m
.47833 .74469 L
s
1 0 0 r
.38479 .70327 m
.38189 .7151 L
s
.59547 .27435 m
.58696 .28356 L
s
0 0 1 r
.30289 .64502 m
.32127 .66195 L
s
.37992 .71296 m
.40351 .72381 L
s
.2763 .59848 m
.29128 .61714 L
s
1 0 0 r
.51756 .25627 m
.5166 .26831 L
s
0 0 1 r
.42796 .73278 m
.45299 .73977 L
s
.58237 .72215 m
.60391 .72109 L
s
1 0 0 r
.62138 .28802 m
.60471 .29071 L
s
0 0 1 r
.51104 .74051 m
.53609 .74155 L
s
1 0 0 r
.33091 .65944 m
.32745 .67261 L
s
0 0 1 r
.40351 .72381 m
.42796 .73278 L
s
.54377 .7346 m
.56781 .73408 L
s
1 0 0 r
.27906 .574 m
.27396 .59027 L
s
.61866 .28759 m
.60058 .28931 L
s
0 0 1 r
.58917 .71725 m
.6097 .71707 L
s
1 0 0 r
.4051 .71034 m
.40219 .72254 L
s
.6017 .27932 m
.59157 .28802 L
s
.53368 .25944 m
.53159 .27169 L
s
.3019 .61863 m
.29765 .6334 L
s
.54816 .26354 m
.5448 .27589 L
s
0 0 1 r
.32127 .66195 m
.34139 .67768 L
s
.26877 .56815 m
.28214 .58724 L
s
1 0 0 r
.42542 .71563 m
.4227 .72825 L
s
.60594 .28365 m
.59416 .29173 L
s
0 0 1 r
.48563 .7374 m
.51104 .74051 L
s
1 0 0 r
.34945 .67085 m
.34563 .68422 L
s
.27383 .54209 m
.26718 .55956 L
s
0 0 1 r
.55168 .72775 m
.57517 .72785 L
s
1 0 0 r
.56083 .26829 m
.55606 .28062 L
s
0 0 1 r
.29128 .61714 m
.3083 .6351 L
s
1 0 0 r
.4454 .71913 m
.44307 .7322 L
s
.60825 .28713 m
.59481 .29447 L
s
0 0 1 r
.26402 .53662 m
.27571 .55582 L
s
.51896 .73311 m
.54377 .7346 L
s
.34139 .67768 m
.36305 .69202 L
s
.26215 .50445 m
.27214 .52341 L
s
.46013 .73221 m
.48563 .7374 L
s
1 0 0 r
.57157 .27341 m
.56527 .28558 L
s
.31829 .632 m
.31356 .64685 L
s
.4647 .72089 m
.46295 .7344 L
s
.29273 .58837 m
.28706 .60461 L
s
0 0 1 r
.5596 .72129 m
.58237 .72215 L
s
1 0 0 r
.60872 .28955 m
.59365 .29605 L
s
.36887 .68084 m
.36486 .69452 L
s
0 0 1 r
.36305 .69202 m
.38601 .70479 L
s
1 0 0 r
.483 .72103 m
.48203 .73495 L
s
0 0 1 r
.43484 .725 m
.46013 .73221 L
s
1 0 0 r
.5803 .2786 m
.57238 .29048 L
s
.60749 .29078 m
.59084 .29635 L
s
0 0 1 r
.56731 .71554 m
.58917 .71725 L
s
.28214 .58724 m
.29767 .60595 L
s
.3083 .6351 m
.32722 .65213 L
s
.38601 .70479 m
.41004 .71582 L
s
.41004 .71582 m
.43484 .725 L
s
1 0 0 r
.60471 .29071 m
.58657 .29532 L
s
.5 .7197 m
.5 .73398 L
s
.5 .26602 m
.5 .2803 L
s
0 0 1 r
.49366 .72958 m
.51896 .73311 L
s
1 0 0 r
.38882 .6892 m
.38479 .70327 L
s
0 0 1 r
.52729 .72566 m
.55168 .72775 L
s
1 0 0 r
.60058 .28931 m
.58106 .29293 L
s
.58696 .28356 m
.57737 .29502 L
s
.28627 .55654 m
.27906 .574 L
s
.336 .64437 m
.33091 .65944 L
s
.5166 .26831 m
.51546 .28287 L
s
0 0 1 r
.27571 .55582 m
.28963 .57495 L
s
1 0 0 r
.59157 .28802 m
.58026 .29892 L
s
.30804 .6023 m
.3019 .61863 L
s
.40895 .69582 m
.4051 .71034 L
s
.53159 .27169 m
.52915 .28642 L
s
0 0 1 r
.32722 .65213 m
.34785 .66802 L
s
1 0 0 r
.28268 .52371 m
.27383 .54209 L
s
0 0 1 r
.46815 .72401 m
.49366 .72958 L
s
.53583 .71848 m
.5596 .72129 L
s
.27214 .52341 m
.28438 .54263 L
s
1 0 0 r
.59416 .29173 m
.58112 .30195 L
s
.5448 .27589 m
.54091 .29068 L
s
0 0 1 r
.29767 .60595 m
.31522 .62403 L
s
1 0 0 r
.4289 .70062 m
.42542 .71563 L
s
.35474 .65547 m
.34945 .67085 L
s
0 0 1 r
.50228 .72156 m
.52729 .72566 L
s
.34785 .66802 m
.36997 .68257 L
s
1 0 0 r
.55606 .28062 m
.55061 .29535 L
s
.59481 .29447 m
.58006 .30388 L
s
0 0 1 r
.44273 .71643 m
.46815 .72401 L
s
1 0 0 r
.44831 .70363 m
.4454 .71913 L
s
0 0 1 r
.54435 .71189 m
.56731 .71554 L
s
1 0 0 r
.30042 .57081 m
.29273 .58837 L
s
.3248 .61545 m
.31829 .632 L
s
.59365 .29605 m
.57725 .30458 L
s
0 0 1 r
.36997 .68257 m
.39334 .69559 L
s
1 0 0 r
.56527 .28558 m
.55816 .30011 L
s
0 0 1 r
.41769 .70693 m
.44273 .71643 L
s
1 0 0 r
.46683 .70492 m
.4647 .72089 L
s
.37419 .66505 m
.36887 .68084 L
s
0 0 1 r
.28963 .57495 m
.30567 .59379 L
s
1 0 0 r
.59084 .29635 m
.57285 .30392 L
s
0 0 1 r
.39334 .69559 m
.41769 .70693 L
s
.31522 .62403 m
.33463 .64126 L
s
1 0 0 r
.58106 .29293 m
.56026 .29849 L
s
.58657 .29532 m
.56711 .30189 L
s
.48415 .70462 m
.483 .72103 L
s
.57238 .29048 m
.56354 .30466 L
s
0 0 1 r
.47693 .71546 m
.50228 .72156 L
s
.51131 .71369 m
.53583 .71848 L
s
1 0 0 r
.29559 .53806 m
.28627 .55654 L
s
0 0 1 r
.28438 .54263 m
.2988 .5619 L
s
1 0 0 r
.5 .70294 m
.5 .7197 L
s
.5 .2803 m
.5 .29706 L
s
.39399 .67293 m
.38882 .6892 L
s
.57737 .29502 m
.56674 .30872 L
s
.2937 .50462 m
.28268 .52371 L
s
.34273 .6275 m
.336 .64437 L
s
.51546 .28287 m
.51413 .29989 L
s
.3161 .58452 m
.30804 .6023 L
s
0 0 1 r
.33463 .64126 m
.35571 .65741 L
s
.45154 .70739 m
.47693 .71546 L
s
1 0 0 r
.58026 .29892 m
.56783 .312 L
s
0 0 1 r
.52051 .70627 m
.54435 .71189 L
s
1 0 0 r
.41376 .67902 m
.40895 .69582 L
s
0 0 1 r
.30567 .59379 m
.3237 .61209 L
s
1 0 0 r
.52915 .28642 m
.52636 .3036 L
s
.58112 .30195 m
.56691 .31429 L
s
0 0 1 r
.48631 .70691 m
.51131 .71369 L
s
.35571 .65741 m
.37821 .67228 L
s
1 0 0 r
.54091 .29068 m
.53652 .30788 L
s
0 0 1 r
.42642 .69742 m
.45154 .70739 L
s
1 0 0 r
.43315 .68328 m
.4289 .70062 L
s
.36152 .63817 m
.35474 .65547 L
s
.58006 .30388 m
.56412 .31537 L
s
.31013 .5521 m
.30042 .57081 L
s
0 0 1 r
.37821 .67228 m
.40187 .68567 L
s
1 0 0 r
.55061 .29535 m
.54451 .31244 L
s
0 0 1 r
.40187 .68567 m
.42642 .69742 L
s
.2988 .5619 m
.3153 .58096 L
s
1 0 0 r
.56026 .29849 m
.5384 .30601 L
s
.57725 .30458 m
.55963 .31513 L
s
.45178 .68575 m
.44831 .70363 L
s
.33309 .59733 m
.3248 .61545 L
s
.57285 .30392 m
.55368 .31348 L
s
.56711 .30189 m
.54651 .31042 L
s
0 0 1 r
.3237 .61209 m
.34353 .62962 L
s
1 0 0 r
.55816 .30011 m
.55028 .31695 L
s
.30702 .51873 m
.29559 .53806 L
s
.46933 .68654 m
.46683 .70492 L
s
.38083 .64723 m
.37419 .66505 L
s
0 0 1 r
.46114 .69821 m
.48631 .70691 L
s
.49608 .69871 m
.52051 .70627 L
s
1 0 0 r
.30685 .48503 m
.2937 .50462 L
s
.56354 .30466 m
.55382 .3211 L
s
.48549 .68581 m
.48415 .70462 L
s
0 0 1 r
.34353 .62962 m
.36495 .64615 L
s
1 0 0 r
.5 .68377 m
.5 .70294 L
s
.5 .29706 m
.5 .31623 L
s
.40029 .65455 m
.39399 .67293 L
s
.56674 .30872 m
.55516 .32461 L
s
.3511 .60893 m
.34273 .6275 L
s
.32607 .56545 m
.3161 .58452 L
s
0 0 1 r
.43611 .68765 m
.46114 .69821 L
s
.3153 .58096 m
.33371 .5996 L
s
1 0 0 r
.51413 .29989 m
.51264 .3193 L
s
.56783 .312 m
.5544 .32721 L
s
0 0 1 r
.36495 .64615 m
.3877 .66146 L
s
.47133 .68924 m
.49608 .69871 L
s
1 0 0 r
.41952 .66005 m
.41376 .67902 L
s
0 0 1 r
.41152 .67535 m
.43611 .68765 L
s
1 0 0 r
.52636 .3036 m
.52323 .32313 L
s
.5384 .30601 m
.51571 .31545 L
s
.56691 .31429 m
.55166 .3287 L
s
.32183 .53241 m
.31013 .5521 L
s
0 0 1 r
.3877 .66146 m
.41152 .67535 L
s
1 0 0 r
.36978 .61906 m
.36152 .63817 L
s
.53652 .30788 m
.53165 .3274 L
s
.56412 .31537 m
.54711 .32889 L
s
.54651 .31042 m
.52499 .32089 L
s
.43814 .66371 m
.43315 .68328 L
s
.55963 .31513 m
.54098 .32767 L
s
.55368 .31348 m
.53352 .32499 L
s
.32047 .49877 m
.30702 .51873 L
s
0 0 1 r
.33371 .5996 m
.35385 .61755 L
s
1 0 0 r
.32204 .46516 m
.30685 .48503 L
s
.34316 .5778 m
.33309 .59733 L
s
.54451 .31244 m
.53781 .33179 L
s
.4558 .66561 m
.45178 .68575 L
s
0 0 1 r
.44658 .67796 m
.47133 .68924 L
s
1 0 0 r
.55028 .31695 m
.54169 .33599 L
s
.38877 .62752 m
.38083 .64723 L
s
.47219 .66587 m
.46933 .68654 L
s
0 0 1 r
.35385 .61755 m
.37548 .63458 L
s
1 0 0 r
.55382 .3211 m
.54331 .33968 L
s
.487 .6647 m
.48549 .68581 L
s
.33789 .54529 m
.32607 .56545 L
s
0 0 1 r
.42214 .66498 m
.44658 .67796 L
s
1 0 0 r
.51571 .31545 m
.49245 .32675 L
s
.36107 .58884 m
.3511 .60893 L
s
.4077 .6342 m
.40029 .65455 L
s
.55516 .32461 m
.54273 .34258 L
s
.5 .66233 m
.5 .68377 L
s
.5 .31623 m
.5 .33767 L
s
0 0 1 r
.37548 .63458 m
.39834 .65046 L
s
.39834 .65046 m
.42214 .66498 L
s
1 0 0 r
.33912 .44526 m
.32204 .46516 L
s
.5544 .32721 m
.54007 .34445 L
s
.51264 .3193 m
.51098 .34096 L
s
.33544 .51196 m
.32183 .53241 L
s
.52499 .32089 m
.5028 .33321 L
s
.33585 .47842 m
.32047 .49877 L
s
.42618 .63903 m
.41952 .66005 L
s
.55166 .3287 m
.53551 .34509 L
s
.52323 .32313 m
.5198 .34487 L
s
.53352 .32499 m
.51259 .33837 L
s
.54711 .32889 m
.52923 .34433 L
s
.54098 .32767 m
.5215 .3421 L
s
.37947 .59833 m
.36978 .61906 L
s
.53165 .3274 m
.52634 .34908 L
s
.35493 .55705 m
.34316 .5778 L
s
.44385 .64205 m
.43814 .66371 L
s
.49245 .32675 m
.46892 .33982 L
s
.53781 .33179 m
.53057 .35325 L
s
.46035 .64335 m
.4558 .66561 L
s
.35792 .4256 m
.33912 .44526 L
s
.54169 .33599 m
.53247 .35708 L
s
.39796 .6061 m
.38877 .62752 L
s
.35149 .52425 m
.33789 .54529 L
s
.47538 .64309 m
.47219 .66587 L
s
.5028 .33321 m
.48021 .3473 L
s
.54331 .33968 m
.53211 .36025 L
s
.353 .45793 m
.33585 .47842 L
s
.48868 .64149 m
.487 .6647 L
s
.35084 .49101 m
.33544 .51196 L
s
.37259 .56742 m
.36107 .58884 L
s
.46892 .33982 m
.44541 .35451 L
s
.54273 .34258 m
.52957 .36249 L
s
.41617 .61206 m
.4077 .6342 L
s
.5 .6388 m
.5 .66233 L
s
.5 .33767 m
.5 .3612 L
s
.51259 .33837 m
.49115 .35351 L
s
.54007 .34445 m
.52502 .36357 L
s
.37822 .40644 m
.35792 .4256 L
s
.51098 .34096 m
.50918 .36468 L
s
.5215 .3421 m
.50142 .3583 L
s
.53551 .34509 m
.51865 .36331 L
s
.52923 .34433 m
.51069 .36157 L
s
.43371 .61618 m
.42618 .63903 L
s
.5198 .34487 m
.51609 .36863 L
s
.36831 .53532 m
.35493 .55705 L
s
.39052 .57618 m
.37947 .59833 L
s
.44541 .35451 m
.42226 .37065 L
s
.48021 .3473 m
.45751 .36298 L
s
.39976 .38804 m
.37822 .40644 L
s
.52634 .34908 m
.52066 .37272 L
s
.37174 .43757 m
.353 .45793 L
s
.45023 .61852 m
.44385 .64205 L
s
.42226 .37065 m
.39976 .38804 L
s
.36672 .50259 m
.35149 .52425 L
s
.53057 .35325 m
.52286 .37662 L
s
.36788 .46981 m
.35084 .49101 L
s
.46538 .6192 m
.46035 .64335 L
s
.40832 .58318 m
.39796 .6061 L
s
.49115 .35351 m
.46948 .37024 L
s
.53247 .35708 m
.52273 .38002 L
s
.47889 .61842 m
.47538 .64309 L
s
.38554 .54492 m
.37259 .56742 L
s
.45751 .36298 m
.43501 .38008 L
s
.53211 .36025 m
.52035 .38261 L
s
.39183 .41763 m
.37174 .43757 L
s
.4905 .6164 m
.48868 .64149 L
s
.50142 .3583 m
.48099 .37609 L
s
.52957 .36249 m
.51585 .38414 L
s
.42561 .58836 m
.41617 .61206 L
s
.51069 .36157 m
.4917 .38042 L
s
.5 .61342 m
.5 .6388 L
s
.5 .3612 m
.5 .38658 L
s
.52502 .36357 m
.50942 .38438 L
s
.51865 .36331 m
.50128 .38317 L
s
.43501 .38008 m
.41302 .39838 L
s
.38316 .51287 m
.36831 .53532 L
s
.41302 .39838 m
.39183 .41763 L
s
.50918 .36468 m
.50725 .3902 L
s
.38634 .44866 m
.36788 .46981 L
s
.44203 .59173 m
.43371 .61618 L
s
.40282 .55287 m
.39052 .57618 L
s
.38343 .48059 m
.36672 .50259 L
s
.46948 .37024 m
.44787 .38836 L
s
.51609 .36863 m
.51215 .39414 L
s
.52066 .37272 m
.51466 .39806 L
s
.45721 .59337 m
.45023 .61852 L
s
.52286 .37662 m
.51478 .40163 L
s
.48099 .37609 m
.4605 .39528 L
s
.40601 .42784 m
.38634 .44866 L
s
.47085 .59344 m
.46538 .6192 L
s
.41974 .55904 m
.40832 .58318 L
s
.44787 .38836 m
.42662 .40765 L
s
.39979 .52163 m
.38554 .54492 L
s
.52273 .38002 m
.51259 .40454 L
s
.48267 .59213 m
.47889 .61842 L
s
.4917 .38042 m
.47253 .40066 L
s
.52035 .38261 m
.50818 .4065 L
s
.42662 .40765 m
.40601 .42784 L
s
.40141 .45856 m
.38343 .48059 L
s
.39932 .49 m
.38316 .51287 L
s
.51585 .38414 m
.50173 .40726 L
s
.50128 .38317 m
.48363 .40445 L
s
.49244 .58972 m
.4905 .6164 L
s
.50942 .38438 m
.49347 .40662 L
s
.43594 .5634 m
.42561 .58836 L
s
.5 .58649 m
.5 .61342 L
s
.5 .38658 m
.5 .41351 L
s
.4605 .39528 m
.44021 .4156 L
s
.41623 .52869 m
.40282 .55287 L
s
.50725 .3902 m
.50522 .41723 L
s
.45104 .56599 m
.44203 .59173 L
s
.42042 .43679 m
.40141 .45856 L
s
.51215 .39414 m
.50803 .42111 L
s
.44021 .4156 m
.42042 .43679 L
s
.47253 .40066 m
.45344 .42204 L
s
.51466 .39806 m
.50842 .4248 L
s
.46472 .56692 m
.45721 .59337 L
s
.41517 .49784 m
.39979 .52163 L
s
.41658 .46703 m
.39932 .49 L
s
.4321 .53398 m
.41974 .55904 L
s
.51478 .40163 m
.50643 .42799 L
s
.47667 .56637 m
.47085 .59344 L
s
.48363 .40445 m
.46595 .42687 L
s
.51259 .40454 m
.50216 .43036 L
s
.50818 .4065 m
.49575 .43163 L
s
.48666 .56457 m
.48267 .59213 L
s
.49347 .40662 m
.47738 .43003 L
s
.50173 .40726 m
.48741 .43158 L
s
.45344 .42204 m
.4347 .44427 L
s
.44702 .53748 m
.43594 .5634 L
s
.49449 .56179 m
.49244 .58972 L
s
.4347 .44427 m
.41658 .46703 L
s
.4306 .50397 m
.41623 .52869 L
s
.5 .55835 m
.5 .58649 L
s
.5 .41351 m
.5 .44165 L
s
.43147 .47389 m
.41517 .49784 L
s
.50522 .41723 m
.50311 .44542 L
s
.46064 .53928 m
.45104 .56599 L
s
.46595 .42687 m
.44848 .45012 L
s
.50803 .42111 m
.50378 .44918 L
s
.44523 .50834 m
.4321 .53398 L
s
.50842 .4248 m
.50202 .4526 L
s
.47265 .5395 m
.46472 .56692 L
s
.47738 .43003 m
.46139 .45429 L
s
.44848 .45012 m
.43147 .47389 L
s
.50643 .42799 m
.49792 .45534 L
s
.48279 .53835 m
.47667 .56637 L
s
.50216 .43036 m
.4916 .45712 L
s
.48741 .43158 m
.47308 .45677 L
s
.44572 .47905 m
.4306 .50397 L
s
.49575 .43163 m
.48325 .45767 L
s
.49083 .53608 m
.48666 .56457 L
s
.4587 .51097 m
.44702 .53748 L
s
.49661 .53299 m
.49449 .56179 L
s
.46139 .45429 m
.44572 .47905 L
s
.5 .52939 m
.5 .55835 L
s
.5 .44165 m
.5 .47061 L
s
.47069 .51197 m
.46064 .53928 L
s
.45896 .48248 m
.44523 .50834 L
s
.50311 .44542 m
.50095 .47438 L
s
.50378 .44918 m
.49945 .47797 L
s
.47308 .45677 m
.45896 .48248 L
s
.48091 .5115 m
.47265 .5395 L
s
.50202 .4526 m
.49556 .48105 L
s
.48325 .45767 m
.47084 .48424 L
s
.49792 .45534 m
.48938 .48331 L
s
.4916 .45712 m
.48107 .48445 L
s
.47084 .48424 m
.4587 .51097 L
s
.48912 .50978 m
.48279 .53835 L
s
.49512 .50708 m
.49083 .53608 L
s
.49877 .50371 m
.49661 .53299 L
s
.48107 .48445 m
.47069 .51197 L
s
.5 .5 m
.5 .52939 L
s
.5 .47061 m
.5 .5 L
s
.50095 .47438 m
.49877 .50371 L
s
.48938 .48331 m
.48091 .5115 L
s
.49945 .47797 m
.49512 .50708 L
s
.49556 .48105 m
.48912 .50978 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002?Ool00g`0Oomoo`03Ool0
0g`0Oomoo`28Ool008moo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo08=oo`00RWoo1@0O
00=l000O01l00P0O0W`017oo00=l07ooOol00Woo00=l07ooOol0OWoo0023Ool701l5Ool00g`0Oomo
o`02Ool00g`001l07`0301l00g`001moo`02Ool00g`0Oomoo`02Ool2O01jOol007ioo`D07`Ioo`H0
7`03O0007`0O00807`03O0007`0O00807`9l0004Ool07`0OO00201l2Ool00g`0Ooml0003Ool00g`0
Oomoo`1dOol007]oo`<07`Eoo`H07`Ioo`03O01oogoo009oo`03O01oogoo009oo`9l00<07`03O000
7goo00807`03O01oog`0009oo`=l07Eoo`00N7oo0`0O0Woo4P0O00=l000O01l00P0O00=l000O01l0
0P0O0W`00goo0W`00`0O00El000O01l07goo009l009oo`=l075oo`00MGoo200O0goo0`0O37oo00=l
07ooOol00Woo00=l07ooOol00Woo00=l000O01l00P0O00El000OOomoog`000<07`9l000401ml07oo
O002Ool00g`0Oomoo`1_Ool0079oo`H07`Aoo`@07`Qoo`L07`03O0007`0O00807`03O0007`0O0080
7`07O01oogooOoml07ooO0000P0O00Al000O01ml00<07`9l00807`03Ooml07oo00=l06eoo`00Kgoo
0`0O00=oo`0O01l00Woo1@0O1Woo1P0O1goo00=l07ooOol00Woo00=l07ooOol00Woo00Ul000O01l0
7g`001ml07ooO0000Woo0W`000<07gooOol00W`000<07goo01l00W`00Woo00=l07ooOol0Jgoo001]
Ool201l2Ool201l2Ool201l5Ool601l5Ool801l00g`001l07`02Ool017`0Oomoogoo0W`00goo0W`0
00D07g`001l07goo009l0004Ool07`0OO002Ool0100OO01l07oo0P0O00Aoog`0O01l06Yoo`00Jgoo
0P0O0Woo0P0O0Woo0P0O0Woo1@0O1Goo1P0O27oo00=l07ooOol00P0O00El000O01l07g`000<07`05
O01oog`0Ooml0002Ool00`0OO0007`02Ool00g`001l07`02O00017oo01l07goo0W`000<07gooOol0
0W`0J7oo001YOol201l2Ool201l2Ool201l017oo01l07`0O17oo1P0O3Woo00=l07ooOol00Woo00Al
07ooOomoo`9l009oo`04O0007`0OO003Ool2O0001Woo01ml000OOoml00807`05Ooml07`0O0007`07
O01WOol006Qoo`0301moogoo00807`9oo`807`03Ool07`0O009oo`D07`Eoo`l07`05O0007`0O01ml
000201l2Ool2O002Ool017`0Ooml07`00`0O00El07ooOoml07oo009l00807`04Ooml07`001l2O002
01l7O01UOol006Moo`0401moo`0O01l2Ool201l00goo01l07`02Ool201l5Ool501l?Ool017`0Oomo
ogoo0W`000=oo`0OO000100O00Al07ooO01l00=oo`03O0007g`000807`9l009oo`04O0007g`0O002
01l2O00201l00goo01ml0003O01TOol006Eoo`807`04Ool07gooOol201l00goo01l07`02Ool201l5
Ool201l:Ool:01l017`0Oomoogoo0W`00Woo0W`00Woo00Ml000O01l07g`001moo`02O0001WooO01o
ogooO0007`9l0004Ooml000O01l>O01ROol006Aoo`0501moo`0O01moo`0201l2Ool00`0OOomoo`02
01l4Ool301l6Ool601l:Ool01W`001l07`0OO0007`9oo`9l009oo`04O01oog`0O002Ool0100OO000
7g`00Woo0g`000<07g`0O0004W`0HGoo001SOol301l2Ool00`0OOomoo`0201l00goo01l07`03Ool3
01l4Ool501l@Ool017`0Oomoogoo0W`00P0O00Il000O01l07g`0Ool2O002Ool2O0001gooO0007g`0
Ooml07oo00Ml0003Ooml07oo009oo`807`Ql061oo`00HWoo0P0O0Woo0P0O00=oo`0O01l00`0O0Woo
0`0O0Woo1@0O17oo400O00=oog`0Ool00Woo0W`00Woo0W`00Woo00Al000O01ml00807`el00807`03
Ooml07oo00807`06Ooml07oo01moo`0O1g`0GWoo001POol301l017oo01l07goo100O0goo0P0O0goo
0P0O17oo1@0O47oo00<07g`001l00P0O00]l000O01l07g`001moog`0Ooml07oo00el000301moog`0
009oo`807`=oo`0601ml07ooOol07goo100O00Aoog`0O01l05eoo`00Ggoo1@0O00=oo`0O01l00P0O
0Woo0`0O0Woo0`0O00=oo`0O01l00`0O5Woo00El07ooOomoog`000=oo`9l000301ml07oo00=l0003
Ooml07`0009l0003Ooml07`0009l00=oo`807`=oo`03O0007`0O009oo`04O0007gooOol201l01Goo
01ml000OOol00g`0G7oo001NOol201l00goo01moo`0201l017oo01moogoo0P0O0Woo0`0O0Woo0P0O
17oo5`0O00El000O01l07g`000=oo`El000301ml000O00=l0003Ooml07`0009l00<07`9oo`05O01o
o`0O01ml0003Ool201l01W`0Ool07`0OO01oo`807`05O0007`0OO01oo`02O01KOol005eoo`807`05
Ool07goo01moo`0201l017oo01l07goo0`0O0Woo0`0O00=oo`0O01l00`0O5goo00El07ooOomoog`0
00<07`=l009oo`03O01oog`000Ql00=oo`<07`=oo`807`Aoo`0401moogooOol201l2Ool01P0OOol0
7`0OO01oo`9l05Yoo`00Fgoo0`0O00Moo`0OOol07goo01moo`0201l00goo01l07`03Ool201l2Ool2
01l9Ool@01l3Ool01G`0OomoogooO0000Woo0W`000@07g`001l07`Ql00807`03O01oogoo009oo`07
O01oo`0O01moog`0Ool00P0O00=oog`0Ool00P0O00Qoog`0Ool07gooO0007goo0`0O0g`0FGoo001J
Ool0200OOol07goo01moo`0OOol301l00goo01l07`02OolB01l@Ool301l017`001moogoo1G`000=o
og`0O0000g`000<07g`0O0000W`00goo0`0O0Woo00Al07ooOomoo`807`=oo`0301ml07oo009oo`80
7`9oo`0901ml07oo01moo`0OOoml07oo009l05Qoo`00FGoo00H07goo01moo`0OOol401l017oo01l0
7goo2P0O2Woo2P0O2Woo00=l07ooO0000W`00P0O17`000Eoog`0O01l07oo00=l00=oo`04O01oogoo
Ool201l4Ool017`0Ool07`0O0Woo0P0O0Woo00=l07oo01l00Woo0P0O00Ioo`0OO0007g`001l2O01H
Ool005Qoo`0301moo`0O00807`04Ool07`0OOol301l00goo01l07`0201l2Ool201l3Ool;01l:Ool5
01l5Ool2O002Ool00g`0Oomoo`03O0000`0OO01l0005O0001Goo01l07gooO00017oo00=l000O01l0
0Woo00Il07ooOomoo`0OO002Ool201l03W`0Oomoo`0OOoml07oo01moo`0OOol07goo01l2O01GOol0
05Moo`0401moo`0O01l2Ool00`0OOol07`0201l2Ool301l00goo01l07`0601l4Ool:01l<Ool301l3
O003Ool7O0000gooO01l0003O004Ool301l2Ool017`0Oomoogoo0P0O00=l07ooOol00Woo0P0O0goo
00H07gooOomoo`0OO002Ool01P0OOol07goo01moo`9l05Moo`00Egoo0`0O00Qoo`0O01moo`0OOol0
7goo0`0O00=oo`0O01l0300O2Woo2`0O0Woo0W`00Woo00=l000O01l00W`000<07gooO0000W`000=o
og`0O0000g`000<07gooOol00Woo00=l07ooOol00P0O00=l07ooOol00Woo00=l000O01l00goo00Il
07oo01l07g`0Ool201l00gooO0007`02Ool01G`001moo`0OO0000P0O00=oog`0Ool0EGoo001FOol3
01l017oo01l07goo0`0O00=oo`0O01l07`0O1goo0W`00`0O00=oog`0O0000g`000Aoog`0O0007`Il
0004Ooml000O01l2Ool00g`0Oomoo`02Ool301l2Ool01W`0Oomoo`0OOoml00Aoo`0B01moogooOol0
7g`0Ool07gooO01oo`0OOol07gooO0007g`0EWoo001EOol301l017oo01l07goo0P0O00=oo`0O01l0
6`0O1Woo1@0O0W`01Goo0W`00P0O17`000Aoog`0O0007`Al0004Ooml07ooOol301l3Ool017`0Oomo
ogoo0P0O00Al07ooOomoo`807`Aoo`03O0007goo009oo`05O0007goo01ml0002Ool0100OO0007g`0
0P0O00=l07ooOol0Dgoo001DOol201l01Goo01l07`0OOol02P0O4Goo1@0O00=oo`0O01l00`0O1Goo
00=l000O01l00P0O00Eoog`0O01oog`0009oo`9l0003Ooml07`000Il000301ml07oo00=oo`06O01o
o`0O01moog`017oo00=l000O01l00Woo00Al07oo01l07`9oo`05O01oo`0O01ml0002Ool0100OOol0
7`0O0Woo00@07goo01moo`807eEoo`00Dgoo0P0O00=oo`0O01l02@0O6Woo0`0O0goo0`0O0W`017oo
0W`00P0O00=oog`0Ool00W`000Ioo`0OO0007g`0Ool3O002Ool201l3Ool017`0Oomoogoo0`0O0goo
00=l07ooOol00P0O00Il07ooOomoo`0OO004Ool03W`0Oomoogoo01ml07oo01ml07oo01moo`0OOol2
01mDOol005=oo`0301moo`0O00P07b1oo`807`9oo`9l009oo`<07`03O01oogoo009oo`0401ml07`0
01l6O0000`0OO01l0003Ool00g`0Ool07`0201l4Ool00g`0Oomoo`0201l00gooO01oo`02Ool00g`0
01l07`03Ool201l3Ool01W`001moogooO0007`9oo`0501moogoo01ml000301mDOol0059oo`X07bAo
o`9l00807`Aoo`05O01oo`0O01moo`03O002Ool00g`001l07`06O000100OOomoog`00goo00=l000O
01l00Woo00=l07ooOol00Woo0P0O0goo00Il07ooOol07gooO002Ool201l00g`0Oomoo`0201l02g`0
Ool07gooO0007goo01ml07ooO0000P0ODgoo001AOol901lUOol00g`0Oomoo`02Ool301l00g`0Oomo
o`02Ool00g`001l07`04O00017ooO01l000O0g`00Woo0P0O00El07ooOomoog`0009oo`<07`Aoo`06
O01oo`0O01moog`00goo0P0O17oo00<07gooOol00Woo00/07gooOol07g`0Ool07g`001moog`000<0
7e9oo`00D7oo0P0O00=oo`0O01l0100O9Goo00=l07ooOol017oo0W`000Eoo`0O01moog`000=oo`03
O0007goo00El0003Ooml000O00=oo`05O0007`0O01ml0004Ool01W`0Ool07`0OOoml00Aoo`807`=o
o`08O01oo`0O01moog`0Ool07`9oo`06O01oo`0OOoml000O0Woo00El07oo01ml07oo00807e9oo`00
D7oo00<07goo01l0100O9Woo00=l07ooOol017oo00=l07ooOol00goo00Al000O01moo`9l0004Ool0
7g`001l6O00201l00gooO01oo`02Ool201l3Ool01W`0Oomoogoo01ml00Aoo`03O01oo`0O009oo`06
O01oogooOol07g`00Woo0P0O00el07ooOol07g`0Ool07gooO0007goo01moo`0301mAOol004moo`L0
7bEoo`9l00Ioo`03O01oogoo009oo`9l00=oo`04O0007g`0Ool2O0000gooO0007`02O0001WooO01o
ogoo01ml00=oo`03O01oo`0O00807`Aoo`06O01oo`0O01moog`00goo0P0O00Il07ooOomoog`001l4
Ool01G`0Oomoogoo01l00Woo00L07g`0Ool07g`001moo`0201mAOol004eoo`P07bEoo`03O01oogoo
00Aoo`9l00Aoo`03O01oogoo009oo`03O01oogoo009l0003Ooml07`000Al0003Ooml07oo009oo`05
O0007`0OOoml0003Ool00g`001l07`02Ool017`0Oomoogoo0P0O17oo00=l000O01l00Woo00=l07oo
01l00Woo00Ml07oo01moog`0Ool07`02Ool01P0OOol07g`001moo`<07e1oo`00C7oo00<07goo01l0
1@0O9Goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00Ul07ooOomoog`0Ool07g`0
Ool017`00P0O0Woo00Al07ooOomoo`807`=oo`03O01oogoo00807`Aoo`03O01oo`0O00=oo`06O01o
ogoo01moog`00Woo00<07gooO0000Woo00d07g`0Oomoo`0OOoml000OOol07goo01moo`0201m@Ool0
04]oo`0301moo`0O00D07bAoo`9l00Ioo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009o
o`03O01oog`000Ml0004Ool07`0O01l3Ool01W`0Ool07`0OOoml00=oo`03O0007`0O009oo`06O01o
ogoo01moog`017oo00<07gooOol00Woo00<07gooOol00Woo00T07gooOomoo`0OOol07goo01l00Woo
100OCgoo001;Ool701lTOol00g`0Oomoo`04Ool2O005Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool9
O0000`0OO01oo`02Ool01G`001l07gooO0000goo0P0O0goo00=l07ooOol00P0O00Al07ooOomoo`80
7`Aoo`03O0007`0O009oo`07O0007gooOoml07oo01l00Woo00H07gooOol07g`001l2Ool401m>Ool0
04Yoo`L07bAoo`03O01oogoo00Aoo`03O01oogoo00=oo`9l00Aoo`03O01oogoo009oo`04O01oog`0
Ool6O0000goo01l07`02Ool01G`0Oomoo`0OO0000goo00El07oo01l07g`000Aoo`03O0007goo009o
o`03O01oo`0O00=oo`05O01oogoo01ml0002Ool201l01g`0Oomoo`0OOoml000O009oo`0401moo`0O
Ool401m>Ool004Uoo`L07b=oo`9l00Ioo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo009o
o`05O01oog`0O01oo`07O002Ool201l3Ool01W`0Ool07`0OOoml00=oo`0301moogoo009oo`03O01o
o`0O009oo`03O01oogoo00807`03O01oogoo009oo`0301moogoo009oo`05O01oogooOol07`02Ool0
1`0OO01oo`0OOol07goo00@07deoo`00BGoo0P0O00Aoo`0O01l07b=oo`03O01oogoo00Eoo`03O01o
ogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009l0003Ooml07`000=l0003Ooml
07oo009oo`05O0007`0OOoml0003Ool201l3Ool01G`001l07gooO0000goo0P0O1Goo0P0O0goo00Ml
000OOomoog`0Ool07`02Ool02W`001moogoo01moo`0OOol07goo100OCGoo0018Ool701lROol00g`0
Oomoo`04Ool2O005Ool00g`0Oomoo`03Ool017`0Oomoogoo0W`00Woo00=l07ooO0001W`000=oog`0
Ool00Woo00Al07ooOol07`Aoo`05O01oo`0OOoml0003Ool00`0OO01oo`03Ool00g`001moo`02Ool0
1W`0Oomoo`0OOoml009oo`0301moog`0009oo`0=01ml07ooOol07gooO0007goo01moo`0OOol0100O
C7oo0018Ool601lROol00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool01G`0Oomoogoo
O0000goo00El07ooOoml07oo00Al009oo`05O01oogooOoml0002Ool01G`001moogooO0000goo00<0
7g`0Ool00goo0P0O0Woo00Al07ooOol07`9oo`06O01oogooOol07g`00goo00<07gooOol00Woo00Ul
07ooOomoo`0OOol07goo01l00Woo00<07goo01l00P0OC7oo0017Ool601lQOol2O006Ool00g`0Oomo
o`03Ool2O005Ool01G`0OomoogooO0000goo00Il07ooOomoog`0Ool4O002Ool017`0Oomoog`00goo
00El07oo01l07g`000=oo`03O0007`0O009oo`03O01oogoo00807`04O01oogooOol201l4Ool00g`0
01moo`02Ool00g`001moo`02Ool01G`001moogoo01l00Woo00<07goo01l00Woo1@0OBgoo0017Ool6
01lPOol00g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool01G`0OomoogooO00017oo00=l
07ooOol01W`00Woo00El07ooOomoog`000=oo`05O01oogooO0007`03Ool01W`0Oomoo`0OOoml00=o
o`03O0007goo00=oo`03O0007goo009oo`05O01oo`0OOoml0002Ool00`0OOoml0002Ool0100OOoml
000O0Woo00H07goo01moo`0OOol301m;Ool004Moo`D07b1oo`03O01oogoo00Eoo`03O01oogoo00=o
o`03O01oogoo00Aoo`03O01oogoo009oo`05O01oogooOoml0002Ool017`0Ooml07oo0g`00Woo00Al
07ooOoml00=oo`09O01oogooOoml07oo01moog`000Aoo`0501moogooOoml0002Ool0100OOomoog`0
0Woo00<07gooO0000goo00<07g`0Ool00Woo00H07g`0Oomoo`0OO002Ool00`0OOomoo`0201l2Ool4
01m;Ool004Ioo`807`04Ool07`0O01lOOol00g`0Oomoo`04Ool2O005Ool00g`0Oomoo`04Ool00g`0
Oomoo`02Ool01G`0OomoogooO0000Woo00El07ooO01l07oo00=l009oo`04O01oogooO003Ool017`0
Oomoog`00goo0P0O17oo00El000O01moog`000=oo`807`Aoo`807`=oo`03O0007goo009oo`03O000
7goo009oo`0<01moogooOol07goo01moo`0OOol07goo0`0OBWoo0016Ool501lOOol00g`0Oomoo`04
Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00=l07oo
O0001G`00Woo00Al07ooOoml00=oo`04O01oogooO003Ool00g`0Ool07`02Ool01G`0Oomoogoo01l0
17oo00=l07oo01l00goo00El07oo01moog`0009oo`807`08Ooml07oo01moog`0Ool07`9oo`0301mo
ogoo00807`9oo`@07dYoo`00AWoo1@0O7Woo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol0
17oo00=l07ooOol00Woo00El07ooOomoog`000=oo`04O01oog`0Ool5O002Ool017`0Oomoog`00Woo
00El07ooOomoog`000=oo`03O01oogoo00807`=oo`03O01oo`0O00=oo`06O01oogoo01moog`00goo
00<07g`0Ool00goo00H07gooOol07gooO002Ool02`0OOomoo`0OOol07goo01moo`0OOol00P0OBWoo
0016Ool401lNOol00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool0
1G`0OomoogooO0000goo00Il07ooO01oog`0Ool3O0001GooO01oogooO0000goo00Al07ooOoml00Ao
o`05O01oogooOoml000201l017ooO01oogoo0P0O00=l07ooOol00Woo0P0O0goo00=l000OOol00goo
00El000OOomoo`0O00Aoo`0301moo`0O009oo`0401moo`0OOol401m9Ool004Eoo`D07aeoo`03O01o
ogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`05O01oogooOoml0003Ool0
0g`0Ooml0002Ool01g`0Ooml07ooO01oog`0009oo`04O01oogooO003Ool01G`0OomoogooO0000goo
00El07ooOomoo`0O00Aoo`03O0007goo00=oo`03O01oo`0O009oo`03O01oo`0O009oo`03O01oo`0O
009oo`03O0007goo009oo`0401moogoo01l2Ool201l00goo01l07`0201m9Ool004Eoo`D07aaoo`03
O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`05O01oogooOoml0004
Ool017`0Ooml07oo17`000Aoog`0Ooml009oo`04O01oogooO002Ool00g`0Oomoo`02Ool017`0Oomo
og`017oo00=l000OOol00Woo00=l07oo01l00Woo00Il07ooOomoo`0OO003Ool00`0OOoml0002Ool0
1@0OO01oogoo01l00goo00T07gooOol07goo01moo`0OOol00`0OBGoo0015Ool401lLOol00g`0Oomo
o`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool01G`0OomoogooO00017oo00=l
07ooO0000Woo17`000Aoog`0Ooml009oo`04O01oogooO002Ool01G`0OomoogooO0000goo00=l07oo
Ool00Woo00El07oo01l07g`000=oo`807`03O01oogoo009oo`0301moogoo009oo`0301moogoo009o
o`05O01oogooOol07`03Ool00`0OOol07`02Ool201l00goo01l07`0201m8Ool004Aoo`D07a]oo`03
O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo009oo`07
O01oogooOoml07ooO0000Woo00=l07ooO0000W`000Aoog`0Ooml009oo`03O01oog`0009oo`03O01o
ogoo009oo`04O01oogooO004Ool00g`0Oomoo`02Ool00`0OOomoo`02Ool00g`001moo`02Ool00g`0
Ool07`03Ool01g`001moogooO01oo`0O00=oo`0401moogoo01l2Ool0100OOol07goo1@0OB7oo0014
Ool501lJOol00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0
Oomoo`02Ool00g`0Oomoo`02Ool00g`0Ooml0002Ool027`0Ooml07`0Ooml07ooO002Ool017`0Oomo
og`00Woo00El07ooOomoog`000=oo`03O01oogoo009oo`07O01oogooOoml07oo01l00goo00=l07oo
01l00Woo00Il07ooOol07gooO002Ool00`0OOoml0002Ool01@0OOomoogoo01l00Woo00<07goo01l0
0Woo0P0O00Aoo`0O01l07dQoo`00A7oo100O6Woo00=l07ooOol017oo00=l07ooOol017oo00=l07oo
Ool017oo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00Woo00=l07ooO0000Woo00=l07oo
Ool00W`000Aoog`0Ooml009oo`03O01oog`0009oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool0
1G`0OomoogooO0000goo0P0O00Il07ooOomoo`0OO004Ool00`0OOomoo`02Ool00`0OOomoo`02Ool0
1`0OOomoogoo01moo`0O009oo`0401moo`0OOol501m7Ool004=oo`D07aUoo`03O01oogoo00Aoo`03
O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`04
O01oogooO002Ool00g`0Ooml0002O00017ooO01oog`00Woo00=l07ooO0000Woo00El07ooOomoog`0
00=oo`03O01oogoo009oo`05O01oogooOoml0005Ool01W`0OomoogooO0007`Aoo`0301moogoo009o
o`03O0007goo00=oo`0401moogoo01l2Ool00`0OOol07`02Ool601m7Ool004=oo`D07aQoo`03O01o
ogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00=oo`05O01o
ogooOoml0002Ool017`0Oomoog`00Woo0g`000Ioog`0Ooml07ooO002Ool017`0Oomoog`00Woo00El
07ooOomoog`000Aoo`05O01oogooOoml0005Ool00g`0Ool07`02Ool00g`0Ool07`02Ool00g`0Ool0
7`02Ool00g`0Ool07`05Ool0100OOomoo`0O0Woo00H07goo01moo`0OOol401m7Ool004=oo`@07aQo
o`03O01oogoo00Eoo`03O01oogoo00=oo`03O01oogoo00Eoo`03O01oogoo00=oo`03O01oogoo009o
o`03O01oogoo009oo`04O01oogooO002Ool00g`0Oomoo`03O0000gooO01l0002Ool00g`0Ooml0002
Ool01G`0OomoogooO0000goo00El07ooOomoog`000Aoo`03O01oogoo009oo`06O01oogoo01moog`0
0goo00<07g`0Ool00Woo00<07gooO0000Woo00<07gooOol00Woo00T07gooOomoo`0OOol07goo01l0
0Woo1P0OAWoo0013Ool401lGOol00g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`05Ool00g`0
Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool017`0Oomoog`00Woo00=l07ooOol01G`000Ao
og`0Ooml009oo`04O01oogooO002Ool01G`0OomoogooO00017oo00El07ooOomoog`000Eoo`05O01o
ogooOol07`05Ool00`0OOomoo`02Ool00`0OOomoo`02Ool00`0OOomoo`02Ool0100OOomoo`0O0Woo
00@07goo01moo`H07dIoo`00@goo100O5goo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol0
1Goo00=l07ooOol00goo00=l07ooOol00goo00El07ooOomoog`000=oo`04O01oogooO002Ool5O000
17ooO01oog`00Woo00=l07ooO0000goo00El07ooOomoog`000=oo`03O01oogoo009oo`03O01oogoo
009oo`07O01oogooOoml07oo01l00goo00=l07oo01l00goo00=l000OOol00goo00<07gooOol00Woo
00/07gooOol07goo01moo`0OOol07goo00@07dIoo`00@goo0`0O00=oo`0OOol057oo00=l07ooOol0
17oo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol0
0Woo00Al07ooOoml00=oo`05O01oogooO01oo`03O00017ooO01oog`00Woo00=l07ooO0000Woo00El
07ooOomoog`000=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo009oo`04O01oogoo01l2
Ool01W`0Oomoo`0OOoml009oo`0501moogooOol07`04Ool0100OOomoo`0O0Woo0P0O0Woo1@0OAWoo
0012Ool401l00goo01moo`0COol00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0
Oomoo`04Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00=l07ooOol00W`0
00aoog`0O01l07ooO01oog`0Ooml07ooO003Ool01G`0OomoogooO0000Woo00=l07ooOol00goo00El
07ooOomoog`000Aoo`03O01oogoo009oo`0301ml07oo00=oo`0301moogoo009oo`0501moogooOol0
7`04Ool02@0OOomoo`0OOol07goo01moo`0501m6Ool0049oo`@07`03Ool07goo019oo`03O01oogoo
00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo009oo`03O01oogoo
009oo`05O01oogooOoml0003Ool00g`0Oomoo`02O0000gooO01l0002O0001gooO01oogooO01oog`0
009oo`05O01oogooOoml0003Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0001Goo
00=l000OOol00Woo00=l07oo01l017oo00D07gooOomoo`0O00=oo`0401moogoo01l2Ool201l2Ool4
01m6Ool0049oo`@07`03Ool07goo019oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Eo
o`03O01oogoo00=oo`03O01oogoo00=oo`05O01oogooOoml0004Ool017`0Oomoog`00Woo00Al07oo
O01oo`Al0006Ooml07ooO01oog`00goo00Al07ooOoml00=oo`03O01oogoo009oo`03O01oogoo009o
o`05O01oogooOoml0006Ool01G`0Ool07gooO0000goo00D07gooOomoo`0O00Aoo`0701moogooOol0
7goo01l00Woo00@07goo01moo`@07dIoo`00@Woo100O0Woo00<07gooOol03goo00=l07ooOol017oo
00=l07ooOol00goo00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo
00El07ooOomoog`000=oo`03O01oogoo009l0003Ooml07`000=l0006Ooml07ooO01oog`00Woo00El
07ooOomoog`0009oo`03O01oogoo00=oo`05O01oogooOoml0004Ool00g`0Oomoo`03Ool01G`0Oomo
ogoo01l01Goo00D07gooOomoo`0O00=oo`0501moogooOol07`02Ool00`0OOomoo`0201l00goo01l0
7`0201m6Ool0049oo`@07`9oo`0301moogoo00ioo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01o
ogoo00Eoo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`04O01o
ogooO003Ool2O0000gooO01l0003O0001WooO01oog`0Ooml009oo`04O01oogooO003Ool00g`0Oomo
o`02Ool01G`0OomoogooO00017oo00=l07ooOol00goo00=l07ooOol00Woo00=l000OOol00goo00<0
7gooOol00Woo00D07gooOomoo`0O00=oo`0301moo`0O009oo`807`03Ool07`0O00807dIoo`00@Woo
100O0goo00<07gooOol03Goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07oo
Ool017oo00=l07ooOol00goo00El07ooOomoog`000Aoo`05O01oogooOoml0002Ool017`0Ooml07oo
1W`000Aoog`0Ooml009oo`05O01oogooOoml0002Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0
OomoogooO0001Goo00=l07ooOol00Woo00Al07ooOol07`Aoo`0301moogoo009oo`0501moogooOol0
7`02Ool01`0OOomoo`0OOol07goo00807`03Ool07`0O04Ioo`00@Woo1@0O0Woo00<07gooOol037oo
00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol00goo
00=l07ooOol00Woo00El07ooOomoog`000=oo`08O01oogooOoml07ooO01oo`Al0006Ooml07ooO01o
og`00Woo00Al07ooOoml00=oo`05O01oogooOoml0004Ool01G`0OomoogooO0001Goo00=l07ooOol0
0Woo00=l07ooOol00Woo00<07gooOol00Woo00D07gooOomoo`0O00=oo`0701moogooOol07goo01l0
0Woo0P0O00Aoo`0O01l07dIoo`00@Woo1@0O0Woo00<07gooOol02goo00=l07ooOol00goo00=l07oo
Ool017oo00=l07ooOol01Goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00=l07oo
Ool00Woo00El07ooOomoog`000=oo`9l0003Ooml07oo00Al0004Ooml07ooO002Ool017`0Oomoog`0
0goo00=l07ooOol00Woo00El07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo009oo`03O01o
ogoo00=oo`0301moogoo00=oo`0501moogooOol07`03Ool0100OOomoogoo0P0O0Woo00<07goo01l0
100OAGoo0012Ool301l00goo01moo`02Ool00`0OOomoo`09Ool00g`0Oomoo`04Ool00g`0Oomoo`03
Ool00g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool01G`0Oomoogoo
O0000goo00Ql07ooOomoog`0Ooml07oo1W`000Aoog`0Ooml009oo`04O01oogooO002Ool00g`0Oomo
o`02Ool01G`0OomoogooO00017oo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol017oo00<0
7gooOol00Woo00<07gooOol00Woo00@07gooOol07`=oo`0301moo`0O009oo`H07dEoo`00@Woo0`0O
0Woo00@07gooOol07`]oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo
00Aoo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`05O01oogooOoml0003Ool017`0
Ooml07oo1W`000Ioog`0Ooml07ooO002Ool01G`0OomoogooO0000goo00=l07ooOol00Woo00El07oo
Oomoog`000Eoo`03O01oogoo009oo`03O01oogoo00Ioo`0301moogoo009oo`0501moogooOol07`03
Ool01P0OOomoo`0OOol07`9oo`H07dEoo`00@Woo0`0O0Woo00D07gooOomoo`0O00Uoo`03O01oogoo
00=oo`03O01oogoo00Aoo`03O01oogoo00Eoo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo
00=oo`05O01oogooOoml0003Ool01G`0OomoogooO0000Woo00=l07ooO0001W`000Aoog`0Ooml009o
o`05O01oogooOoml0003Ool00g`0Oomoo`02Ool01G`0OomoogooO0001Goo00=l07ooOol00Woo00=l
07ooOol027oo00<07gooOol00Woo00D07gooOomoo`0O009oo`0801moogooOol07goo01moo`H07dEo
o`00@Woo100O00=oo`0OOol00Woo00<07gooOol01Woo00=l07ooOol00goo00=l07ooOol017oo00=l
07ooOol01Goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00Woo00=l07ooOol00Woo00El
07ooOomoog`000=oo`06O01oog`0Ooml07oo17`000Ioog`0Ooml07ooO002Ool017`0Oomoog`017oo
00El07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00Uoo`0301moogoo
00=oo`0401moogoo01l3Ool01`0OOomoo`0OOol07goo00807`04Ool07`0O01m5Ool0049oo`@07`9o
o`0401moogoo01l7Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03
Ool00g`0Oomoo`04Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000goo00Ml07oo
Ooml07ooO01oo`05O00017ooO01oog`00Woo00El07ooOomoog`000=oo`05O01oogooOoml0004Ool0
0g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`0:Ool00`0OOomoo`02Ool01@0OOomoogoo01l0
0Woo00@07gooOol07`9oo`0301moo`0O00@07dEoo`00@Woo100O0Woo00D07gooOomoo`0O00Ioo`03
O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03
O01oogoo00=oo`03O01oogoo009oo`05O01oogooOoml0003Ool01g`0Oomoog`0Ooml07oo00El0004
Ooml07ooO002Ool017`0Oomoog`00goo00El07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo
00=oo`03O01oogoo00aoo`0301moogoo009oo`0401moogoo01l3Ool00`0OOol07`02Ool00`0OOol0
7`0401m5Ool0049oo`@07`=oo`0401moogoo01l5Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0
Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0
Oomoo`02Ool01G`0OomoogooO0000Woo00El07ooO01l07oo00=l0004Ooml07ooO002Ool01G`0Oomo
ogooO0000Woo00El07ooOomoog`000Aoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00io
o`0301moogoo009oo`0401moogoo01l2Ool0100OOomoo`0O0Woo1P0OAGoo0012Ool501l2Ool01@0O
Oomoogoo01l017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo
00=l07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00El07ooOomoog`000=oo`07O01oogoo
O01oog`0Ool01G`000Ioog`0Ooml07ooO003Ool01G`0OomoogooO0000Woo00=l07ooOol00Woo00=l
07ooOol00Woo00=l07ooOol00goo00=l07ooOol03goo00<07gooOol00Woo00@07gooOol07`9oo`04
01moogoo01l2Ool601m5Ool0049oo`D07`9oo`0501moogooOol07`03Ool00g`0Oomoo`03Ool00g`0
Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool00g`0
Oomoo`02Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00Al07ooO01oo`Al0004Ooml07ooO002
Ool017`0Oomoog`00goo00Al07ooOoml00Aoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo
015oo`0301moogoo009oo`0401moogoo01l2Ool01@0OOomoo`0OOol01P0OAGoo0012Ool501l3Ool0
1@0OOomoogoo01l00Woo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol0
17oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol00Woo00El07ooOomoog`000=oo`04O01o
ogooO002Ool00g`0Ooml0003O0001WooO01oog`0Ooml009oo`05O01oogooOoml0002Ool00g`0Oomo
o`02Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`0COol01@0OOomoogoo01l00Woo00@0
7gooOol07`9oo`0301moo`0O00D07dEoo`00@Woo100O00Eoo`0OOomoo`0O00Aoo`0301ml07oo00Ao
o`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=o
o`03O01oogoo00=oo`05O01oogooOoml0003Ool017`0Oomoog`00Woo0W`000Eoog`0O01l07oo009l
009oo`04O01oogooO002Ool017`0Oomoog`017oo00=l07ooOol00goo00=l07ooOol00Woo00=l07oo
Ool057oo00<07gooOol00Woo00@07gooOol07`9oo`0601moo`0OOol07goo100OAGoo0012Ool401l0
1Goo01moogoo01l017oo00<07g`0Ool00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol0
17oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00El07ooOomo
og`0009oo`06O01oog`0Ooml07oo17`000Aoog`0Ooml009oo`04O01oogooO002Ool00g`0Oomoo`02
Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`0FOol01@0OOomoogoo01l00Woo00T07goo
Ool07goo01moo`0OOol00`0OAWoo0012Ool401l00goo01moo`02Ool01P0OOomoogooO0007`Aoo`03
O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03
O01oogoo00=oo`05O01oogooOoml0003Ool017`0Oomoog`00Woo00Al07ooO01oo`9l0005Ooml07`0
Ooml0002Ool017`0Oomoog`00goo00El07ooOomoog`000Aoo`9l00Aoo`03O01oogoo01Moo`0301mo
ogoo009oo`0601moogoo01moo`0O0Woo0P0O00Aoo`0O01l07dIoo`00@Woo1@0O00Eoo`0OOomoo`0O
00=oo`03O0007goo009oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo
00Aoo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo009oo`05O01oogooOoml0002Ool01g`0
Oomoog`0Ooml07oo00=l0006Ooml07ooO01oog`00Woo00El07ooOomoog`000=oo`03O01oogoo009o
o`03O01oogoo00=oo`03O01oogoo01Uoo`0501moogooOol07`02Ool01@0OOomoo`0OOol00P0O00Ao
o`0O01l07dIoo`00@goo100O00=oo`0OOol00Woo00<07gooO0000Woo00@07gooOoml00Eoo`03O01o
ogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00=oo`03O01o
ogoo009oo`05O01oogooOoml0002Ool01g`0Oomoog`0Ooml07oo00Al0007Ooml07ooOoml07ooO000
0goo00=l07ooOol00Woo00El07ooOomoog`000Eoo`03O01oogoo01Yoo`0301moogoo009oo`0301mo
o`0O009oo`0501moo`0O01moo`0301m6Ool004=oo`@07`9oo`0601moogooOol07g`00goo00<07g`0
Ool01Goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07ooOol00goo00=l07oo
Ool00goo00=l07ooOol00Woo00El07ooOomoog`0009oo`04O01oogooO002Ool00g`0Ooml0002O000
1GooO01oogooO0000Woo00Al07ooOoml00Aoo`05O01oogooOoml0005Ool00g`0Oomoo`0LOol01@0O
Oomoogoo01l00Woo00@07goo01moo`807`04Ool07`0O01m6Ool004=oo`<07`04Ool07goo01l3Ool0
0`0OOomoo`02Ool00`0OO01oo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool0
0g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool01G`0OomoogooO0000Woo00Al07ooOoml
009oo`Il009oo`04O01oogooO003Ool01G`0OomoogooO0000goo00=l07ooOol00goo00=l07ooOol0
7Goo00D07gooOomoo`0O009oo`0601moo`0OOol07goo100OAWoo0013Ool501l2Ool01@0OOomoog`0
01l00goo00=l000OOol017oo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07oo
Ool00goo00=l07ooOol00goo00=l07ooOol00Woo00El07ooOomoog`000=oo`07O01oogooO01oog`0
Ool00g`000Aoog`0Ooml009oo`05O01oogooOoml0002Ool2O003Ool00g`0Oomoo`03Ool00g`0Oomo
o`0OOol0100OOomoo`0O0Woo00<07goo01l00Woo100OAgoo0013Ool401l01Woo01moo`0OOoml009o
o`0601moogooO01oo`0O0goo00=l07ooOol00goo00=l07ooOol017oo00=l07ooOol017oo00=l07oo
Ool017oo00=l07ooOol00goo00=l07ooOol00Woo00El07ooOomoog`000=oo`05O01oogooO01oo`06
O002Ool00g`0Ooml0003Ool017`0Oomoog`017oo00=l07ooOol00Woo0W`08Woo00L07gooOomoo`0O
Ool07`02Ool00`0OOol07`0301m7Ool004=oo`@07`06Ool07gooOol07g`00goo00D07gooO01oo`0O
00=oo`03O01oogoo00=oo`03O01oogoo00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo
00=oo`03O01oogoo009oo`03O01oogoo009oo`04O01oogooO002Ool00g`0Oomoo`05O002Ool017`0
Oomoog`00Woo00Al07ooOoml00Aoo`03O01oogoo009oo`03O01oogoo02=oo`0601moogoo01moo`0O
0Woo00<07goo01l00`0OAgoo0014Ool501l3Ool01P0OOomoogoo01ml00=oo`0301moog`000Eoo`03
O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo009oo`05
O01oogooOoml0003Ool017`0Oomoog`00Woo1G`000Eoog`0Oomoog`0009oo`04O01oogooO004Ool0
0g`0Oomoo`02Ool00g`0Oomoo`0TOol0100OOomoo`0O0Woo00@07goo01moo`@07dMoo`00A7oo100O
00Eoo`0OOomoo`0O00Aoo`0301moogoo009oo`0301ml07oo00Aoo`03O01oogoo00=oo`03O01oogoo
00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00=oo`05O01oogooOoml0003Ool017`0
Oomoog`00Woo1W`00Woo00Al07ooOoml009oo`03O01oogoo009oo`04O01oogooOol2O00XOol00`0O
Ool07`02Ool0100OOol07goo100OAgoo0014Ool401l01Woo01moog`0Ool07`9oo`03O01oo`0O00=o
o`03O0007goo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00Eoo`03O01oogoo00=o
o`03O01oogoo009oo`03O01oogoo009oo`05O01oogooOoml0002Ool00g`0Oomoo`08O002Ool017`0
Oomoog`017oo00El07ooOomoog`002Yoo`0901moogoo01moo`0OOol07goo00<07dQoo`00A7oo1@0O
00=oo`0OO0000Woo00D07gooO01oo`0O00=oo`03O01oo`0O00=oo`03O01oogoo00=oo`03O01oogoo
00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00=oo`05O01oogooOoml0003Ool01G`0
OomoogooO0000Woo1W`00Woo0W`00Woo00=l07ooOol00Woo00El07ooOomoog`002]oo`0601moogoo
01moo`0O0Woo100OB7oo0015Ool401l00goo01ml0002Ool00`0OOoml0002Ool00`0OOoml0003Ool0
0`0OOoml0006Ool00g`0Oomoo`03Ool00g`0Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`02Ool0
0g`0Oomoo`02Ool01G`0OomoogooO0000goo00=l07ooO0001G`00Woo00=l07ooOol00W`017oo00El
07ooOomoog`002eoo`0301moo`0O009oo`0301moo`0O00<07dQoo`00AGoo100O0Woo00D07gooOomo
o`0O00Aoo`0301ml07oo00=oo`0301ml07oo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01o
ogoo00=oo`03O01oogoo00=oo`05O01oogooOoml0004Ool017`0Oomoog`00Woo1W`000Eoog`0Oomo
og`000Eoo`05O01oogooOoml000^Ool00`0OOol07`02Ool00`0OOol07`0301m8Ool004Eoo`D07`03
O01oo`0O009oo`0301moogoo009oo`03O0007goo00=oo`03O0007goo00Aoo`03O01oogoo00=oo`03
O01oogoo00Eoo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo009oo`05
O01oogooO01oo`08O002Ool00g`0Oomoo`02Ool2O003Ool00g`0Oomoo`0]Ool01`0OOomoo`0OOol0
7goo00@07dQoo`00AWoo100O00Ml07ooOol07g`0Ool07`03Ool00g`001moo`03Ool00g`0Ool07`03
Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool01G`0Oomoogoo
O00017oo00Il07ooOomoog`0Ool5O0001GooO01l07ooO00017oo00=l07ooOol00Woo00=l07ooOol0
;Woo00D07gooOol07goo00D07dUoo`00AWoo1@0O0Woo00D07g`0Oomoo`0O009oo`03O01oo`0O009o
o`04O01oogoo01l3Ool00g`0Oomoo`03Ool00g`0Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`03
Ool01G`0OomoogooO00017oo00Il07ooOomoog`0Ool5O0001GooO01oogooO0000goo00Al07ooOomo
o`9l039oo`0401moo`0OOol501m9Ool004Moo`<07`05O0007gooOol07`03Ool00`0OO01oo`02Ool0
0`0OOoml0003Ool00`0OOoml0006Ool00g`0Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`03Ool0
0g`0Oomoo`02Ool00g`0Oomoo`02Ool017`0Oomoogoo1G`000Ioog`0O01l07ooO002Ool2O003Ool0
0g`0Oomoo`0bOol0100OOol07goo1@0OBGoo0017Ool301l01W`0Ool07g`0Ool07`=oo`0301moogoo
009oo`0301moogoo00=oo`0301ml07oo00Aoo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo
00=oo`05O01oogooOoml0005Ool017`0Oomoogoo1g`000=oog`0O0000Woo00=l07ooOol00Woo00=l
07ooOol0<goo00@07goo01moo`D07dUoo`00B7oo0`0O00=oo`0OO0000Woo00D07gooO01oo`0O00=o
o`03O0007goo00Aoo`0301moogoo00=oo`03O01oogoo00Aoo`03O01oogoo00=oo`03O01oogoo00=o
o`03O01oogoo009oo`03O01oogoo009oo`04O01oogooOol3O00017ooO01l07oo0g`000=oog`0O000
0goo0W`0=Woo00@07goo01moo`@07dYoo`00B7oo100O00Moog`0Oomoo`0OOoml0002Ool01P0OOomo
og`0Ool07`=oo`03O01oo`0O00=oo`03O01oogoo00Aoo`03O01oogoo00Aoo`03O01oogoo00=oo`03
O01oogoo009oo`03O01oogoo009oo`04O01oogooOol8O0000gooO01l0003Ool2O00iOol201l00goo
01l07`0201m:Ool004Qoo`807`05O0007gooO0007`02Ool00`0OO01oo`02Ool00`0OO01oo`02Ool0
100OOomoog`00Woo00@07gooOoml00Ioo`03O01oogoo00Aoo`03O01oogoo009oo`03O01oogoo00=o
o`03O01oogoo009oo`04O01oogooOol4O0000gooO01l0003O002Ool2O00kOol201l00goo01l07`02
01m:Ool004Uoo`@07`06O01oo`0OOoml000O17oo00<07gooOol00Woo00<07g`0Ool00goo0P0O00=l
07ooOol017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo00=l
07ooOol02G`000Aoog`0O01l03eoo`807`04Ool07`0O01m;Ool004Uoo`807`03O0007g`0009oo`03
01ml000O00=oo`03O0007goo00Aoo`0301moogoo00=oo`03O0007goo00Aoo`03O01oogoo00Aoo`03
O01oogoo00=oo`03O01oogoo009oo`03O01oogoo009oo`03O01oogoo00=l0004Ooml07`0Ool3O000
0gooO01oo`0nOol201l017oo01l07`0OBgoo0019Ool501l2Ool0100OO01oo`0O0Woo00=l07oo01l0
17oo00=l000OOol00goo00=l07oo01l017oo00=l07ooOol00goo00=l07ooOol00goo00=l07ooOol0
0goo00=l07ooOol00Woo00=l07ooO0000W`000=oog`0O0001g`0?goo1@0OC7oo001:Ool201l00goo
O0007`02Ool01P0OOomoo`0OOoml009oo`0401moogooO002Ool201l2Ool017`0Oomoo`0O0Woo00=l
07ooOol017oo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooO0001W`000Io
og`0O01l07ooO00oOol501m<Ool004Yoo`<07`06O0007`0OO01oo`0O0Woo00<07gooOol00Woo00<0
7gooO00017oo00<07g`0Ool00goo00<07gooO0001Goo00=l07ooOol017oo00=l07ooOol00Woo00=l
07ooOol00Woo00=l07ooO0002g`000=oog`0Ool0?Woo100OCGoo001;Ool501l01g`0Oomoo`0OOoml
000O00Aoo`0301moogoo00Aoo`03O01oogoo00=oo`807`Eoo`03O01oogoo00Aoo`03O01oogoo009o
o`03O01oogoo009oo`]l0005Ooml07ooOoml000nOol501m=Ool004]oo`807`04O0007`0OO002Ool0
1@0OOoml07oo01l00goo00=l000OOol00goo00=l07oo01l017oo00=l07oo01l017oo00=l07ooOol0
0goo00=l07ooOol00goo00=l07ooOol00Woo1g`000Ioog`0Ooml07ooO002Ool00g`0Oomoo`0lOol5
01m=Ool004aoo`0601ml000O01ml000O0Woo00L07g`0Oomoo`0OOoml0002Ool201l2Ool017`0Oomo
o`0O0Woo00El07ooOomoo`0O009oo`03O01oogoo00Aoo`03O01oogoo009oo`03O01oogoo009oo`Ml
0007Ooml07`0Ooml07ooO0000Woo00=l07ooOol0?7oo100OCWoo001=Ool301l01W`0Ool07gooO000
7`=oo`0301ml07oo00=oo`0301ml07oo00=oo`807`03O01oogoo009oo`807`03O01oogoo00=oo`03
O01oogoo00=oo`03O01oogoo00Ul0004Ooml07`0O002Ool017`0Oomoog`0?Woo100OCWoo001>Ool0
0g`001l07`02Ool00`0OO0007`03Ool00g`001moo`04Ool00`0OOomoo`04Ool00`0OOomoo`03Ool0
0g`001l07`04Ool00g`0Oomoo`03Ool00g`0Ooml0005O0001GooO01l07`0Ool00g`00Woo00Al07oo
Ooml03eoo`@07dmoo`00CWoo00Ul000O01l07goo01ml07oo01l00Woo00=l07oo01l017oo00=l000O
01l00goo00=l07oo01l017oo00=l07ooOol00P0O00=oog`0Ool017oo00=l07ooO0000W`000=oog`0
Ool00W`000Aoog`0Oomoo`=l009oo`04O01oogooO00mOol401m?Ool004moo`0601ml000O01moo`0O
0Woo0P0O00Al07ooOol07`9oo`05O01oogooOol07`02Ool00g`0Oomoo`0201l2Ool00g`0Oomoo`02
Ool00`0OO01oo`04Ool4O0001GooO01oog`0Ool00g`000=oog`0Ool00W`00Woo00Al07ooOoml03ao
o`@07e1oo`00D7oo100O00=l000OOol00Woo00L07gooOomoo`0OOoml0004Ool00`0OO01oo`04Ool2
01l5Ool00g`001l07`02Ool5O0001gooO01l07`0Ooml07oo009l0003Ooml07oo009l0003Ooml07`0
009oo`03O01oogoo03Uoo`@07e5oo`00DGoo0`0O00=l07oo01l00Woo00=l000O01l00Woo0P0O1Goo
00=l000OOol017oo00=l000O01l00goo00=l07ooO0000P0O0g`000Aoog`0O01oo`9l0004Ooml07oo
O002Ool2O0000gooO01oo`02O002Ool00g`0Oomoo`0iOol401mAOol0055oo`<07`06O0007goo01mo
og`00Woo00D07gooO01oo`0O00Aoo`04O01oo`0O01l2Ool01G`0Oomoogoo01l01g`000D07g`0Ooml
07oo00=l0005Ooml07ooOoml0002Ool2O0000gooO01oo`02O002Ool00g`0Oomoo`0hOol401mBOol0
059oo`807`06O0007`0OO0007g`00goo00@07g`0Oomoo`807`03Ooml07oo00=oo`0301moog`000Al
00807`Al0004Ooml07`001l2O0001gooO01oogooO01oog`000=oo`9l0003Ooml07oo009l009oo`03
O01oogoo03Moo`D07e9oo`00DWoo00=l000O01l00`0O00=l000OO0000g`000<07g`0Ool00Woo00<0
7g`0O00017`00P0O1W`00P0O00Il07ooO01l07ooO00201l017ooO01oog`00Woo00Ul07ooOoml07oo
O01oog`0Ool00W`00Woo00=l07ooOol0=Woo1@0ODgoo001COol00g`001l07`0201l00g`0Ool07`02
Ool00g`0Ool07`04O00201l2Ool4O0000`0OO01l0004O00017oo01l07goo0W`000=oog`0Ool00P0O
00Eoog`0Oomoog`0009oo`04O01oog`0O002Ool2O002Ool00g`0Oomoo`0eOol501mDOol005Aoo`D0
7`9l00807`=l000301ml07`000=l00807`05Ooml07`0O01oo`0201l00gooO01l0002Ool01g`0Ool0
7g`0Ooml07oo009l0004Ool07`0OOol2O002Ool017`0Ooml07`00Woo00El07ooOomoog`003Moo`@0
7eEoo`00EGoo00El000O01ml000O00=oo`0801moogooOol07gooO01oo`=l000401ml07ooOol2O000
0goo01l07`02Ool017`0Ooml07`00P0O0Woo0W`000=oog`0Ool00P0O0goo0W`000Eoog`0Oomoog`0
00=oo`03O01oogoo03Aoo`@07eIoo`00EWoo0P0O00Al000O01l07`9l00807`9l00807`03O01oogoo
009oo`04O0007g`0Ool2O0001gooO0007`0OOoml07oo009l0007Ool07`0OOoml07ooO0000Woo00Ql
000O01ml07ooO01oog`00Woo00El07ooOomoog`003Eoo`@07eMoo`00Egoo00L07g`001l07goo01ml
0002Ool0100OOomoog`00P0O17`000=oo`0O01l00Woo0W`00Woo00<07gooOol00W`00Woo00Al000O
O01l00=oo`03O01oogoo00807`9l00=oo`05O01oogooOoml000dOol401mHOol005Qoo`L07`9oo`80
7`=l00807`06O01oog`0O01oo`0O0W`00goo00Al000O01ml009oo`04O01oogooO00201l00gooO01l
0002Ool00g`0Ooml000201l2Ool01G`0OomoogooO000<Woo1@0OFGoo001IOol401l2O0001@0OO01l
07`001l017oo00<07g`0Ool00Woo00=l000O01l00Woo00Al07ooOoml00807`05Ooml07ooOoml0002
Ool201l01G`0Oomoog`0Ool00W`000Aoo`0O01ml00=oo`03O01oogoo02moo`0301moo`0O00807eYo
o`00FWoo1@0O00Eoo`0OOoml07oo00807`=l00807`05Ooml07ooO01oo`0201l3Ool00g`0Oomoo`02
01l00gooO01l0003Ool017`001l07g`00Woo0W`00Woo00=l000O01l00Woo00=l07ooOol0;Woo00<0
7goo01l00P0OFgoo001KOol201l01G`001l07goo01l00g`000Aoo`0OOoml009oo`0301moogoo009l
009oo`807`9l009oo`04O01oo`0OO003Ool2O002Ool301l017ooO01oogoo0W`000Aoo`0O01ml02mo
o`0301moo`0O00807eaoo`00G7oo00<07g`001l01@0O0goo0P0O0W`000Aoo`0O01ml00Aoo`05O000
7`0OOoml0003Ool017`001l07goo0W`00Woo00=l07ooO000100O0W`00goo00=l000O01l00P0O:Goo
1P0OGGoo001MOol00`0OO0007`0201l00g`0Ool07`02Ool2O00201l2Ool00g`001l07`02Ool017`0
Ooml07oo0`0O0Woo00=l07ooOol00P0O00=l07ooO0000Woo00=l07ooO0000Woo00=l000O01l00Woo
00=l07ooOol00Woo0`0O9Goo1P0OGWoo001NOol601l017oo01ml07`00goo0P0O00=l07ooOol00P0O
0Woo00=l07ooO0000Woo0P0O0goo00=l07oo01l00P0O0Woo0W`00goo0W`000=oo`0O01l00P0O1Woo
100O87oo1P0OGgoo001POol201l017`001l07g`00P0O0goo00=l07oo01l00goo00=l000O01l00W`0
17oo00Il000O01l07gooO002Ool00g`001l07`0201l3Ool00g`0Oomoo`02Ool00g`0Ool07`0201l7
Ool401lHOol901mPOol0065oo`0301ml000O00<07`04O0007`0OO002Ool017`001l07g`00Woo00Al
000O01l07`9oo`9l009oo`06O0007`0O01moog`00Woo0W`00`0O00=l07ooOol00Woo00=l07ooOol0
0Woo100O1goo7`0OHWoo001SOol501l00g`0Ool07`0201l3O00201l00gooO01l0002Ool201l027oo
O01oogooO01oog`0Ool401l2O003Ool401l00gooO01oo`07Ool501l>OolB01mSOol006Aoo`<07`03
O0007`0O00=oo`807`=oo`0301ml000O00=oo`05O0007`0OOoml0002Ool00g`0Ooml0003Ool301l2
Ool017`0Oomoogoo1P0O2Goo3P0O17oo1@0O00=oo`0O01l0100OIGoo001UOol701l2O00017oo01l0
7goo0W`000Moo`0O01ml07ooO01oo`0301l017ooO01oog`00Woo00Al07ooO01oo`@07`=oo`03O01o
ogoo009ooad07`9oo`L07fIoo`00Igoo100O00=l000O01l00goo0`0O0goo0P0O00El07ooOoml07oo
00@07`9oo`03O01oog`000=oo`03O01oo`0O00@07aEoo`L07`=oo`T07fMoo`00J7oo100O00Al000O
01l07`=l0006Ool07`0OO01oog`00`0O0goo0W`000=oo`0O01l0100O0Woo00=l07ooOol00Woo00=l
07oo01l0500O1Goo300OJGoo001YOol301l017`001l07g`00`0O0goo0P0O00Al07ooOoml00@07`04
O01oogooOol2O002Ool701l00g`0Oomoo`0BOolB01mZOol006]oo`L07`04O0007`0O01l2Ool301l3
Ool00g`0Ool07`0501l4Ool00g`0Oomoo`02OolE01l3Ool=01m/Ool006eoo``07`03Ooml000O0080
7`9l00Aoo`9l00@07`03O0007`0O009oo`03O01oogoo011ooa007fioo`00L7oo200O00=l000O01l0
0P0O00=oog`001l0100O0W`017oo00=l07ooOol00P0O00=l000O01l0400O0Woo2`0OLGoo001cOol0
0g`001l07`0801l00g`001moo`03Ool701l4Ool00g`0Oomoo`0>Ool801l00goo01l07`0201mcOol0
07Ioo`T07`03O0007`0O00807`03O01oogoo009oo`9l00@07`03O0007`0O01T07gEoo`00N7oo00=l
000O01l00`0O00=l000O01l03`0O1Woo4P0ON7oo001lOol801l00g`001l07`0201l00g`001l07`03
01l00g`001l07`0B01mlOol0081oob007h1oo`00QGoo5@0OQWoo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {585.688, 356.313}} -> {-0.399192, \
1.55342, 0.00348777, 0.00348777}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Generation of the Linearly Polarized Photon Electric and Magnetic Vector \
Field\
\>", "Section",
  TextJustification->1],

Cell[TextData[{
  StyleBox["Figure 5.  The field-line pattern given by Eqs. (5) and (10) from \
three orthogonal perspectives of a LP photon-e&mvf corresponding to the first \
great circle magnetic field line and the second great circle electric field \
line shown with 6 degree increments of the angle \[Theta] about each of the \
(",
    TextJustification->1,
    FontFamily->"New York"],
  Cell[BoxData[
      \(TraditionalForm\`i\_x\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`i\_y\)]],
  ",0",
  Cell[BoxData[
      \(TraditionalForm\`i\_z\)]],
  StyleBox[")- and (",
    TextJustification->1,
    FontFamily->"New York"],
  Cell[BoxData[
      \(TraditionalForm\`i\_x\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(-i\_y\)\)]],
  ",0",
  Cell[BoxData[
      \(TraditionalForm\`i\_z\)]],
  ")",
  StyleBox["-axes.  (Electric field lines blue; Magnetic field lines red).  ",
    
    TextJustification->1,
    FontFamily->"New York"]
}], "Text",
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Fig5 = Show[Fig2A, Fig4A];\)\)], "Input",
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.49116 .5 m
.50884 .5 L
s
.47352 .5 m
.49116 .5 L
s
1 0 0 r
.5 .49116 m
.5 .50884 L
s
.5 .47352 m
.5 .49116 L
s
0 0 1 r
.50884 .5 m
.52648 .5 L
s
1 0 0 r
.5 .50884 m
.5 .52648 L
s
0 0 1 r
.49343 .48459 m
.51112 .48465 L
s
.47577 .48462 m
.49343 .48459 L
s
1 0 0 r
.48459 .49343 m
.48465 .51112 L
s
.48462 .47577 m
.48459 .49343 L
s
.51541 .49343 m
.51535 .51112 L
s
.51538 .47577 m
.51541 .49343 L
s
0 0 1 r
.50657 .48459 m
.52423 .48462 L
s
.48888 .48465 m
.50657 .48459 L
s
.47123 .4848 m
.48888 .48465 L
s
.51112 .48465 m
.52877 .4848 L
s
1 0 0 r
.48465 .51112 m
.4848 .52877 L
s
.51535 .51112 m
.5152 .52877 L
s
0 0 1 r
.45595 .5 m
.47352 .5 L
s
1 0 0 r
.5 .45595 m
.5 .47352 L
s
0 0 1 r
.52648 .5 m
.54405 .5 L
s
1 0 0 r
.5 .52648 m
.5 .54405 L
s
0 0 1 r
.45818 .48474 m
.47577 .48462 L
s
1 0 0 r
.48474 .45818 m
.48462 .47577 L
s
.51526 .45818 m
.51538 .47577 L
s
0 0 1 r
.52423 .48462 m
.54182 .48474 L
s
.49579 .46929 m
.51349 .46953 L
s
.47809 .46923 m
.49579 .46929 L
s
1 0 0 r
.46929 .49579 m
.46953 .51349 L
s
.46923 .47809 m
.46929 .49579 L
s
0 0 1 r
.50421 .46929 m
.52191 .46923 L
s
.48651 .46953 m
.50421 .46929 L
s
1 0 0 r
.53071 .49579 m
.53047 .51349 L
s
.53077 .47809 m
.53071 .49579 L
s
0 0 1 r
.45367 .48504 m
.47123 .4848 L
s
.52877 .4848 m
.54633 .48504 L
s
1 0 0 r
.4848 .52877 m
.48504 .54633 L
s
.5152 .52877 m
.51496 .54633 L
s
0 0 1 r
.46884 .46994 m
.48651 .46953 L
s
.51349 .46953 m
.53116 .46994 L
s
1 0 0 r
.46953 .51349 m
.46994 .53116 L
s
.53047 .51349 m
.53006 .53116 L
s
0 0 1 r
.46046 .46934 m
.47809 .46923 L
s
1 0 0 r
.46934 .46046 m
.46923 .47809 L
s
.53066 .46046 m
.53077 .47809 L
s
0 0 1 r
.52191 .46923 m
.53954 .46934 L
s
.45126 .47053 m
.46884 .46994 L
s
.53116 .46994 m
.54874 .47053 L
s
1 0 0 r
.46994 .53116 m
.47053 .54874 L
s
.53006 .53116 m
.52947 .54874 L
s
0 0 1 r
.4385 .5 m
.45595 .5 L
s
1 0 0 r
.5 .4385 m
.5 .45595 L
s
0 0 1 r
.54405 .5 m
.5615 .5 L
s
1 0 0 r
.5 .54405 m
.5 .5615 L
s
0 0 1 r
.44071 .48495 m
.45818 .48474 L
s
1 0 0 r
.48495 .44071 m
.48474 .45818 L
s
.51505 .44071 m
.51526 .45818 L
s
0 0 1 r
.54182 .48474 m
.55929 .48495 L
s
.49831 .45424 m
.51606 .45478 L
s
.48056 .45397 m
.49831 .45424 L
s
1 0 0 r
.45424 .49831 m
.45478 .51606 L
s
.45397 .48056 m
.45424 .49831 L
s
0 0 1 r
.50169 .45424 m
.51944 .45397 L
s
.48394 .45478 m
.50169 .45424 L
s
1 0 0 r
.54576 .49831 m
.54522 .51606 L
s
.54603 .48056 m
.54576 .49831 L
s
0 0 1 r
.46625 .45557 m
.48394 .45478 L
s
.51606 .45478 m
.53375 .45557 L
s
1 0 0 r
.45478 .51606 m
.45557 .53375 L
s
.54522 .51606 m
.54443 .53375 L
s
0 0 1 r
.43624 .48537 m
.45367 .48504 L
s
.54633 .48504 m
.56376 .48537 L
s
1 0 0 r
.48504 .54633 m
.48537 .56376 L
s
.51496 .54633 m
.51463 .56376 L
s
0 0 1 r
.46287 .45397 m
.48056 .45397 L
s
1 0 0 r
.45397 .46287 m
.45397 .48056 L
s
.54603 .46287 m
.54603 .48056 L
s
0 0 1 r
.51944 .45397 m
.53713 .45397 L
s
.44294 .46964 m
.46046 .46934 L
s
1 0 0 r
.46964 .44294 m
.46934 .46046 L
s
.53036 .44294 m
.53066 .46046 L
s
0 0 1 r
.53954 .46934 m
.55706 .46964 L
s
.44865 .45664 m
.46625 .45557 L
s
.53375 .45557 m
.55135 .45664 L
s
1 0 0 r
.45557 .53375 m
.45664 .55135 L
s
.54443 .53375 m
.54336 .55135 L
s
0 0 1 r
.43383 .4713 m
.45126 .47053 L
s
.54874 .47053 m
.56617 .4713 L
s
1 0 0 r
.47053 .54874 m
.4713 .56617 L
s
.52947 .54874 m
.5287 .56617 L
s
0 0 1 r
.44529 .45423 m
.46287 .45397 L
s
1 0 0 r
.45423 .44529 m
.45397 .46287 L
s
.54577 .44529 m
.54603 .46287 L
s
0 0 1 r
.53713 .45397 m
.55471 .45423 L
s
.50108 .43961 m
.51888 .44056 L
s
.48328 .43901 m
.50108 .43961 L
s
1 0 0 r
.43961 .50108 m
.44056 .51888 L
s
.43901 .48328 m
.43961 .50108 L
s
.56039 .50108 m
.55944 .51888 L
s
.56099 .48328 m
.56039 .50108 L
s
0 0 1 r
.49892 .43961 m
.51672 .43901 L
s
.48112 .44056 m
.49892 .43961 L
s
.42342 .48525 m
.44071 .48495 L
s
1 0 0 r
.48525 .42342 m
.48495 .44071 L
s
.51475 .42342 m
.51505 .44071 L
s
0 0 1 r
.55929 .48495 m
.57658 .48525 L
s
.42125 .5 m
.4385 .5 L
s
1 0 0 r
.5 .42125 m
.5 .4385 L
s
0 0 1 r
.5615 .5 m
.57875 .5 L
s
1 0 0 r
.5 .5615 m
.5 .57875 L
s
0 0 1 r
.46339 .44185 m
.48112 .44056 L
s
.51888 .44056 m
.53661 .44185 L
s
1 0 0 r
.44056 .51888 m
.44185 .53661 L
s
.55944 .51888 m
.55815 .53661 L
s
0 0 1 r
.46552 .43877 m
.48328 .43901 L
s
1 0 0 r
.43877 .46552 m
.43901 .48328 L
s
.56123 .46552 m
.56099 .48328 L
s
0 0 1 r
.51672 .43901 m
.53448 .43877 L
s
.42559 .47012 m
.44294 .46964 L
s
1 0 0 r
.47012 .42559 m
.46964 .44294 L
s
.52988 .42559 m
.53036 .44294 L
s
0 0 1 r
.55706 .46964 m
.57441 .47012 L
s
.419 .48578 m
.43624 .48537 L
s
.56376 .48537 m
.581 .48578 L
s
1 0 0 r
.48537 .56376 m
.48578 .581 L
s
.51463 .56376 m
.51422 .581 L
s
0 0 1 r
.43122 .45796 m
.44865 .45664 L
s
.55135 .45664 m
.56878 .45796 L
s
1 0 0 r
.45664 .55135 m
.45796 .56878 L
s
.54336 .55135 m
.54204 .56878 L
s
0 0 1 r
.44578 .4435 m
.46339 .44185 L
s
.53661 .44185 m
.55422 .4435 L
s
1 0 0 r
.44185 .53661 m
.4435 .55422 L
s
.55815 .53661 m
.5565 .55422 L
s
0 0 1 r
.44785 .43888 m
.46552 .43877 L
s
1 0 0 r
.43888 .44785 m
.43877 .46552 L
s
.56112 .44785 m
.56123 .46552 L
s
0 0 1 r
.53448 .43877 m
.55215 .43888 L
s
.42787 .45477 m
.44529 .45423 L
s
1 0 0 r
.45477 .42787 m
.45423 .44529 L
s
.54523 .42787 m
.54577 .44529 L
s
0 0 1 r
.55471 .45423 m
.57213 .45477 L
s
.41661 .47225 m
.43383 .4713 L
s
.56617 .4713 m
.58339 .47225 L
s
1 0 0 r
.4713 .56617 m
.47225 .58339 L
s
.5287 .56617 m
.52775 .58339 L
s
0 0 1 r
.50418 .42555 m
.52202 .42702 L
s
.48631 .42451 m
.50418 .42555 L
s
1 0 0 r
.42555 .50418 m
.42702 .52202 L
s
.42451 .48631 m
.42555 .50418 L
s
0 0 1 r
.49582 .42555 m
.51369 .42451 L
s
.47798 .42702 m
.49582 .42555 L
s
1 0 0 r
.57445 .50418 m
.57298 .52202 L
s
.57549 .48631 m
.57445 .50418 L
s
0 0 1 r
.46022 .42892 m
.47798 .42702 L
s
.52202 .42702 m
.53978 .42892 L
s
1 0 0 r
.42702 .52202 m
.42892 .53978 L
s
.57298 .52202 m
.57108 .53978 L
s
0 0 1 r
.46847 .42392 m
.48631 .42451 L
s
1 0 0 r
.42392 .46847 m
.42451 .48631 L
s
.57608 .46847 m
.57549 .48631 L
s
0 0 1 r
.51369 .42451 m
.53153 .42392 L
s
.40636 .48563 m
.42342 .48525 L
s
1 0 0 r
.48563 .40636 m
.48525 .42342 L
s
.51437 .40636 m
.51475 .42342 L
s
0 0 1 r
.57658 .48525 m
.59364 .48563 L
s
.42835 .44548 m
.44578 .4435 L
s
.55422 .4435 m
.57165 .44548 L
s
1 0 0 r
.4435 .55422 m
.44548 .57165 L
s
.5565 .55422 m
.55452 .57165 L
s
0 0 1 r
.40423 .5 m
.42125 .5 L
s
1 0 0 r
.5 .40423 m
.5 .42125 L
s
0 0 1 r
.57875 .5 m
.59577 .5 L
s
1 0 0 r
.5 .57875 m
.5 .59577 L
s
0 0 1 r
.40847 .47077 m
.42559 .47012 L
s
1 0 0 r
.47077 .40847 m
.47012 .42559 L
s
.52923 .40847 m
.52988 .42559 L
s
0 0 1 r
.57441 .47012 m
.59153 .47077 L
s
.43035 .43936 m
.44785 .43888 L
s
1 0 0 r
.43936 .43035 m
.43888 .44785 L
s
.56064 .43035 m
.56112 .44785 L
s
0 0 1 r
.55215 .43888 m
.56965 .43936 L
s
.414 .45955 m
.43122 .45796 L
s
.56878 .45796 m
.586 .45955 L
s
1 0 0 r
.45796 .56878 m
.45955 .586 L
s
.54204 .56878 m
.54045 .586 L
s
0 0 1 r
.44261 .43125 m
.46022 .42892 L
s
.53978 .42892 m
.55739 .43125 L
s
1 0 0 r
.42892 .53978 m
.43125 .55739 L
s
.57108 .53978 m
.56875 .55739 L
s
0 0 1 r
.40202 .48629 m
.419 .48578 L
s
.581 .48578 m
.59798 .48629 L
s
1 0 0 r
.48578 .581 m
.48629 .59798 L
s
.51422 .581 m
.51371 .59798 L
s
0 0 1 r
.45072 .42376 m
.46847 .42392 L
s
1 0 0 r
.42376 .45072 m
.42392 .46847 L
s
.57624 .45072 m
.57608 .46847 L
s
0 0 1 r
.53153 .42392 m
.54928 .42376 L
s
.41067 .45557 m
.42787 .45477 L
s
1 0 0 r
.45557 .41067 m
.45477 .42787 L
s
.54443 .41067 m
.54523 .42787 L
s
0 0 1 r
.57213 .45477 m
.58933 .45557 L
s
.39964 .47337 m
.41661 .47225 L
s
.58339 .47225 m
.60036 .47337 L
s
1 0 0 r
.47225 .58339 m
.47337 .60036 L
s
.52775 .58339 m
.52663 .60036 L
s
0 0 1 r
.50765 .41221 m
.52552 .41431 L
s
.48973 .41062 m
.50765 .41221 L
s
1 0 0 r
.41221 .50765 m
.41431 .52552 L
s
.41062 .48973 m
.41221 .50765 L
s
0 0 1 r
.49235 .41221 m
.51027 .41062 L
s
.47448 .41431 m
.49235 .41221 L
s
1 0 0 r
.58779 .50765 m
.58569 .52552 L
s
.58938 .48973 m
.58779 .50765 L
s
0 0 1 r
.45671 .41692 m
.47448 .41431 L
s
.52552 .41431 m
.54329 .41692 L
s
1 0 0 r
.41431 .52552 m
.41692 .54329 L
s
.58569 .52552 m
.58308 .54329 L
s
0 0 1 r
.42519 .434 m
.44261 .43125 L
s
.55739 .43125 m
.57481 .434 L
s
1 0 0 r
.43125 .55739 m
.434 .57481 L
s
.56875 .55739 m
.566 .57481 L
s
0 0 1 r
.47182 .40956 m
.48973 .41062 L
s
1 0 0 r
.40956 .47182 m
.41062 .48973 L
s
.59044 .47182 m
.58938 .48973 L
s
0 0 1 r
.51027 .41062 m
.52818 .40956 L
s
.41115 .44782 m
.42835 .44548 L
s
.57165 .44548 m
.58885 .44782 L
s
1 0 0 r
.44548 .57165 m
.44782 .58885 L
s
.55452 .57165 m
.55218 .58885 L
s
0 0 1 r
.43311 .42406 m
.45072 .42376 L
s
1 0 0 r
.42406 .43311 m
.42376 .45072 L
s
.57594 .43311 m
.57624 .45072 L
s
0 0 1 r
.54928 .42376 m
.56689 .42406 L
s
.41305 .4402 m
.43035 .43936 L
s
1 0 0 r
.4402 .41305 m
.43936 .43035 L
s
.5598 .41305 m
.56064 .43035 L
s
0 0 1 r
.56965 .43936 m
.58695 .4402 L
s
.43911 .42003 m
.45671 .41692 L
s
.54329 .41692 m
.56089 .42003 L
s
1 0 0 r
.41692 .54329 m
.42003 .56089 L
s
.58308 .54329 m
.57997 .56089 L
s
0 0 1 r
.45397 .40902 m
.47182 .40956 L
s
1 0 0 r
.40902 .45397 m
.40956 .47182 L
s
.59098 .45397 m
.59044 .47182 L
s
0 0 1 r
.52818 .40956 m
.54603 .40902 L
s
.38959 .48611 m
.40636 .48563 L
s
1 0 0 r
.48611 .38959 m
.48563 .40636 L
s
.51389 .38959 m
.51437 .40636 L
s
0 0 1 r
.59364 .48563 m
.61041 .48611 L
s
.39706 .4614 m
.414 .45955 L
s
.586 .45955 m
.60294 .4614 L
s
1 0 0 r
.45955 .586 m
.4614 .60294 L
s
.54045 .586 m
.5386 .60294 L
s
0 0 1 r
.38752 .5 m
.40423 .5 L
s
1 0 0 r
.5 .38752 m
.5 .40423 L
s
0 0 1 r
.59577 .5 m
.61248 .5 L
s
1 0 0 r
.5 .59577 m
.5 .61248 L
s
0 0 1 r
.39164 .47162 m
.40847 .47077 L
s
1 0 0 r
.47162 .39164 m
.47077 .40847 L
s
.52838 .39164 m
.52923 .40847 L
s
0 0 1 r
.59153 .47077 m
.60836 .47162 L
s
.38534 .48688 m
.40202 .48629 L
s
.59798 .48629 m
.61466 .48688 L
s
1 0 0 r
.48629 .59798 m
.48688 .61466 L
s
.51371 .59798 m
.51312 .61466 L
s
0 0 1 r
.40803 .43718 m
.42519 .434 L
s
.57481 .434 m
.59197 .43718 L
s
1 0 0 r
.434 .57481 m
.43718 .59197 L
s
.566 .57481 m
.56282 .59197 L
s
0 0 1 r
.39376 .45666 m
.41067 .45557 L
s
1 0 0 r
.45666 .39376 m
.45557 .41067 L
s
.54334 .39376 m
.54443 .41067 L
s
0 0 1 r
.58933 .45557 m
.60624 .45666 L
s
.42174 .42364 m
.43911 .42003 L
s
.56089 .42003 m
.57826 .42364 L
s
1 0 0 r
.42003 .56089 m
.42364 .57826 L
s
.57997 .56089 m
.57636 .57826 L
s
0 0 1 r
.51153 .39972 m
.52941 .40255 L
s
.49358 .39749 m
.51153 .39972 L
s
1 0 0 r
.39972 .51153 m
.40255 .52941 L
s
.39749 .49358 m
.39972 .51153 L
s
.60028 .51153 m
.59745 .52941 L
s
.60251 .49358 m
.60028 .51153 L
s
0 0 1 r
.48847 .39972 m
.50642 .39749 L
s
.47059 .40255 m
.48847 .39972 L
s
.4157 .42481 m
.43311 .42406 L
s
1 0 0 r
.42481 .4157 m
.42406 .43311 L
s
.57519 .4157 m
.57594 .43311 L
s
0 0 1 r
.56689 .42406 m
.5843 .42481 L
s
.45285 .40596 m
.47059 .40255 L
s
.52941 .40255 m
.54715 .40596 L
s
1 0 0 r
.40255 .52941 m
.40596 .54715 L
s
.59745 .52941 m
.59404 .54715 L
s
0 0 1 r
.43625 .40902 m
.45397 .40902 L
s
1 0 0 r
.40902 .43625 m
.40902 .45397 L
s
.59098 .43625 m
.59098 .45397 L
s
0 0 1 r
.54603 .40902 m
.56375 .40902 L
s
.4756 .39585 m
.49358 .39749 L
s
1 0 0 r
.39585 .4756 m
.39749 .49358 L
s
.60415 .4756 m
.60251 .49358 L
s
0 0 1 r
.50642 .39749 m
.5244 .39585 L
s
.39425 .45049 m
.41115 .44782 L
s
.58885 .44782 m
.60575 .45049 L
s
1 0 0 r
.44782 .58885 m
.45049 .60575 L
s
.55218 .58885 m
.54951 .60575 L
s
0 0 1 r
.383 .47467 m
.39964 .47337 L
s
.60036 .47337 m
.617 .47467 L
s
1 0 0 r
.47337 .60036 m
.47467 .617 L
s
.52663 .60036 m
.52533 .617 L
s
0 0 1 r
.4353 .40995 m
.45285 .40596 L
s
.54715 .40596 m
.5647 .40995 L
s
1 0 0 r
.40596 .54715 m
.40995 .5647 L
s
.59404 .54715 m
.59005 .5647 L
s
0 0 1 r
.39603 .44141 m
.41305 .4402 L
s
1 0 0 r
.44141 .39603 m
.4402 .41305 L
s
.55859 .39603 m
.5598 .41305 L
s
0 0 1 r
.58695 .4402 m
.60397 .44141 L
s
.45767 .39482 m
.4756 .39585 L
s
1 0 0 r
.39482 .45767 m
.39585 .4756 L
s
.60518 .45767 m
.60415 .4756 L
s
0 0 1 r
.5244 .39585 m
.54233 .39482 L
s
.40465 .42775 m
.42174 .42364 L
s
.57826 .42364 m
.59535 .42775 L
s
1 0 0 r
.42364 .57826 m
.42775 .59535 L
s
.57636 .57826 m
.57225 .59535 L
s
0 0 1 r
.38046 .4635 m
.39706 .4614 L
s
.60294 .4614 m
.61954 .4635 L
s
1 0 0 r
.4614 .60294 m
.4635 .61954 L
s
.5386 .60294 m
.5365 .61954 L
s
0 0 1 r
.41801 .4145 m
.4353 .40995 L
s
.5647 .40995 m
.58199 .4145 L
s
1 0 0 r
.40995 .5647 m
.4145 .58199 L
s
.59005 .5647 m
.5855 .58199 L
s
0 0 1 r
.41872 .40957 m
.43625 .40902 L
s
1 0 0 r
.40957 .41872 m
.40902 .43625 L
s
.59043 .41872 m
.59098 .43625 L
s
0 0 1 r
.56375 .40902 m
.58128 .40957 L
s
.37319 .48669 m
.38959 .48611 L
s
1 0 0 r
.48669 .37319 m
.48611 .38959 L
s
.51331 .37319 m
.51389 .38959 L
s
0 0 1 r
.61041 .48611 m
.62681 .48669 L
s
.39119 .44077 m
.40803 .43718 L
s
.59197 .43718 m
.60881 .44077 L
s
1 0 0 r
.43718 .59197 m
.44077 .60881 L
s
.56282 .59197 m
.55923 .60881 L
s
0 0 1 r
.37517 .47264 m
.39164 .47162 L
s
1 0 0 r
.47264 .37517 m
.47162 .39164 L
s
.52736 .37517 m
.52838 .39164 L
s
0 0 1 r
.60836 .47162 m
.62483 .47264 L
s
.37117 .5 m
.38752 .5 L
s
1 0 0 r
.5 .37117 m
.5 .38752 L
s
0 0 1 r
.61248 .5 m
.62883 .5 L
s
1 0 0 r
.5 .61248 m
.5 .62883 L
s
0 0 1 r
.51583 .38823 m
.53368 .39188 L
s
.49787 .38525 m
.51583 .38823 L
s
1 0 0 r
.38823 .51583 m
.39188 .53368 L
s
.38525 .49787 m
.38823 .51583 L
s
.61177 .51583 m
.60812 .53368 L
s
.61475 .49787 m
.61177 .51583 L
s
0 0 1 r
.48417 .38823 m
.50213 .38525 L
s
.46632 .39188 m
.48417 .38823 L
s
.39856 .42602 m
.4157 .42481 L
s
1 0 0 r
.42602 .39856 m
.42481 .4157 L
s
.57398 .39856 m
.57519 .4157 L
s
0 0 1 r
.5843 .42481 m
.60144 .42602 L
s
.44865 .39617 m
.46632 .39188 L
s
.53368 .39188 m
.55135 .39617 L
s
1 0 0 r
.39188 .53368 m
.39617 .55135 L
s
.60812 .53368 m
.60383 .55135 L
s
0 0 1 r
.43985 .39441 m
.45767 .39482 L
s
1 0 0 r
.39441 .43985 m
.39482 .45767 L
s
.60559 .43985 m
.60518 .45767 L
s
0 0 1 r
.54233 .39482 m
.56015 .39441 L
s
.37719 .45802 m
.39376 .45666 L
s
1 0 0 r
.45802 .37719 m
.45666 .39376 L
s
.54198 .37719 m
.54334 .39376 L
s
0 0 1 r
.60624 .45666 m
.62281 .45802 L
s
.47987 .38294 m
.49787 .38525 L
s
1 0 0 r
.38294 .47987 m
.38525 .49787 L
s
.61706 .47987 m
.61475 .49787 L
s
0 0 1 r
.50213 .38525 m
.52013 .38294 L
s
.36904 .48756 m
.38534 .48688 L
s
.61466 .48688 m
.63096 .48756 L
s
1 0 0 r
.48688 .61466 m
.48756 .63096 L
s
.51312 .61466 m
.51244 .63096 L
s
0 0 1 r
.4312 .40111 m
.44865 .39617 L
s
.55135 .39617 m
.5688 .40111 L
s
1 0 0 r
.39617 .55135 m
.40111 .5688 L
s
.60383 .55135 m
.59889 .5688 L
s
0 0 1 r
.3777 .45351 m
.39425 .45049 L
s
.60575 .45049 m
.6223 .45351 L
s
1 0 0 r
.45049 .60575 m
.45351 .6223 L
s
.54951 .60575 m
.54649 .6223 L
s
0 0 1 r
.40104 .41961 m
.41801 .4145 L
s
.58199 .4145 m
.59896 .41961 L
s
1 0 0 r
.4145 .58199 m
.41961 .59896 L
s
.5855 .58199 m
.58039 .59896 L
s
0 0 1 r
.46188 .38131 m
.47987 .38294 L
s
1 0 0 r
.38131 .46188 m
.38294 .47987 L
s
.61869 .46188 m
.61706 .47987 L
s
0 0 1 r
.52013 .38294 m
.53812 .38131 L
s
.37935 .44299 m
.39603 .44141 L
s
1 0 0 r
.44299 .37935 m
.44141 .39603 L
s
.55701 .37935 m
.55859 .39603 L
s
0 0 1 r
.60397 .44141 m
.62065 .44299 L
s
.38791 .43234 m
.40465 .42775 L
s
.59535 .42775 m
.61209 .43234 L
s
1 0 0 r
.42775 .59535 m
.43234 .61209 L
s
.57225 .59535 m
.56766 .61209 L
s
0 0 1 r
.36675 .47615 m
.383 .47467 L
s
.617 .47467 m
.63325 .47615 L
s
1 0 0 r
.47467 .617 m
.47615 .63325 L
s
.52533 .617 m
.52385 .63325 L
s
0 0 1 r
.41405 .40667 m
.4312 .40111 L
s
.5688 .40111 m
.58595 .40667 L
s
1 0 0 r
.40111 .5688 m
.40667 .58595 L
s
.59889 .5688 m
.59333 .58595 L
s
0 0 1 r
.42219 .39464 m
.43985 .39441 L
s
1 0 0 r
.39464 .42219 m
.39441 .43985 L
s
.60536 .42219 m
.60559 .43985 L
s
0 0 1 r
.56015 .39441 m
.57781 .39464 L
s
.40144 .41066 m
.41872 .40957 L
s
1 0 0 r
.41066 .40144 m
.40957 .41872 L
s
.58934 .40144 m
.59043 .41872 L
s
0 0 1 r
.58128 .40957 m
.59856 .41066 L
s
.46171 .38238 m
.47947 .37784 L
s
.44416 .38764 m
.46171 .38238 L
s
.53829 .38238 m
.55584 .38764 L
s
.52053 .37784 m
.53829 .38238 L
s
1 0 0 r
.38238 .53829 m
.38764 .55584 L
s
.37784 .52053 m
.38238 .53829 L
s
.61762 .53829 m
.61236 .55584 L
s
.62216 .52053 m
.61762 .53829 L
s
0 0 1 r
.50263 .37403 m
.52053 .37784 L
s
1 0 0 r
.37403 .50263 m
.37784 .52053 L
s
.62597 .50263 m
.62216 .52053 L
s
0 0 1 r
.47947 .37784 m
.49737 .37403 L
s
.37473 .44478 m
.39119 .44077 L
s
.60881 .44077 m
.62527 .44478 L
s
1 0 0 r
.44077 .60881 m
.44478 .62527 L
s
.55923 .60881 m
.55522 .62527 L
s
0 0 1 r
.44397 .38039 m
.46188 .38131 L
s
1 0 0 r
.38039 .44397 m
.38131 .46188 L
s
.61961 .44397 m
.61869 .46188 L
s
0 0 1 r
.53812 .38131 m
.55603 .38039 L
s
.36427 .46587 m
.38046 .4635 L
s
.61954 .4635 m
.63573 .46587 L
s
1 0 0 r
.4635 .61954 m
.46587 .63573 L
s
.5365 .61954 m
.53413 .63573 L
s
0 0 1 r
.42688 .39358 m
.44416 .38764 L
s
.55584 .38764 m
.57312 .39358 L
s
1 0 0 r
.38764 .55584 m
.39358 .57312 L
s
.61236 .55584 m
.60642 .57312 L
s
0 0 1 r
.38175 .4277 m
.39856 .42602 L
s
1 0 0 r
.4277 .38175 m
.42602 .39856 L
s
.5723 .38175 m
.57398 .39856 L
s
0 0 1 r
.60144 .42602 m
.61825 .4277 L
s
.48463 .37095 m
.50263 .37403 L
s
1 0 0 r
.37095 .48463 m
.37403 .50263 L
s
.62905 .48463 m
.62597 .50263 L
s
0 0 1 r
.49737 .37403 m
.51537 .37095 L
s
.39726 .41284 m
.41405 .40667 L
s
.58595 .40667 m
.60274 .41284 L
s
1 0 0 r
.40667 .58595 m
.41284 .60274 L
s
.59333 .58595 m
.58716 .60274 L
s
0 0 1 r
.38445 .42527 m
.40104 .41961 L
s
.59896 .41961 m
.61555 .42527 L
s
1 0 0 r
.41961 .59896 m
.42527 .61555 L
s
.58039 .59896 m
.57473 .61555 L
s
0 0 1 r
.35721 .48735 m
.37319 .48669 L
s
1 0 0 r
.48735 .35721 m
.48669 .37319 L
s
.51265 .35721 m
.51331 .37319 L
s
0 0 1 r
.62681 .48669 m
.64279 .48735 L
s
.35911 .47386 m
.37517 .47264 L
s
1 0 0 r
.47386 .35911 m
.47264 .37517 L
s
.52614 .35911 m
.52736 .37517 L
s
0 0 1 r
.62483 .47264 m
.64089 .47386 L
s
.35525 .5 m
.37117 .5 L
s
1 0 0 r
.5 .35525 m
.5 .37117 L
s
0 0 1 r
.62883 .5 m
.64475 .5 L
s
1 0 0 r
.5 .62883 m
.5 .64475 L
s
0 0 1 r
.40995 .4002 m
.42688 .39358 L
s
.57312 .39358 m
.59005 .4002 L
s
1 0 0 r
.39358 .57312 m
.4002 .59005 L
s
.60642 .57312 m
.5998 .59005 L
s
0 0 1 r
.36104 .45967 m
.37719 .45802 L
s
1 0 0 r
.45967 .36104 m
.45802 .37719 L
s
.54033 .36104 m
.54198 .37719 L
s
0 0 1 r
.62281 .45802 m
.63896 .45967 L
s
.46662 .36863 m
.48463 .37095 L
s
1 0 0 r
.36863 .46662 m
.37095 .48463 L
s
.63137 .46662 m
.62905 .48463 L
s
0 0 1 r
.51537 .37095 m
.53338 .36863 L
s
.36159 .45686 m
.3777 .45351 L
s
.6223 .45351 m
.63841 .45686 L
s
1 0 0 r
.45351 .6223 m
.45686 .63841 L
s
.54649 .6223 m
.54314 .63841 L
s
0 0 1 r
.37159 .43741 m
.38791 .43234 L
s
.61209 .43234 m
.62841 .43741 L
s
1 0 0 r
.43234 .61209 m
.43741 .62841 L
s
.56766 .61209 m
.56259 .62841 L
s
0 0 1 r
.40477 .3955 m
.42219 .39464 L
s
1 0 0 r
.3955 .40477 m
.39464 .42219 L
s
.6045 .40477 m
.60536 .42219 L
s
0 0 1 r
.57781 .39464 m
.59523 .3955 L
s
.35318 .48834 m
.36904 .48756 L
s
.63096 .48756 m
.64682 .48834 L
s
1 0 0 r
.48756 .63096 m
.48834 .64682 L
s
.51244 .63096 m
.51166 .64682 L
s
0 0 1 r
.4262 .38018 m
.44397 .38039 L
s
1 0 0 r
.38018 .4262 m
.38039 .44397 L
s
.61982 .4262 m
.61961 .44397 L
s
0 0 1 r
.55603 .38039 m
.5738 .38018 L
s
.38448 .41232 m
.40144 .41066 L
s
1 0 0 r
.41232 .38448 m
.41066 .40144 L
s
.58768 .38448 m
.58934 .40144 L
s
0 0 1 r
.59856 .41066 m
.61552 .41232 L
s
.5432 .37416 m
.56054 .38041 L
s
.52559 .36866 m
.5432 .37416 L
s
1 0 0 r
.37416 .5432 m
.38041 .56054 L
s
.36866 .52559 m
.37416 .5432 L
s
0 0 1 r
.4568 .37416 m
.47441 .36866 L
s
.43946 .38041 m
.4568 .37416 L
s
1 0 0 r
.62584 .5432 m
.61959 .56054 L
s
.63134 .52559 m
.62584 .5432 L
s
0 0 1 r
.36308 .44494 m
.37935 .44299 L
s
1 0 0 r
.44494 .36308 m
.44299 .37935 L
s
.55506 .36308 m
.55701 .37935 L
s
0 0 1 r
.62065 .44299 m
.63692 .44494 L
s
.5078 .36394 m
.52559 .36866 L
s
1 0 0 r
.36394 .5078 m
.36866 .52559 L
s
.63606 .5078 m
.63134 .52559 L
s
0 0 1 r
.47441 .36866 m
.4922 .36394 L
s
.42243 .38741 m
.43946 .38041 L
s
.56054 .38041 m
.57757 .38741 L
s
1 0 0 r
.38041 .56054 m
.38741 .57757 L
s
.61959 .56054 m
.61259 .57757 L
s
0 0 1 r
.39342 .40747 m
.40995 .4002 L
s
.59005 .4002 m
.60658 .40747 L
s
1 0 0 r
.4002 .59005 m
.40747 .60658 L
s
.5998 .59005 m
.59253 .60658 L
s
0 0 1 r
.3809 .41961 m
.39726 .41284 L
s
.60274 .41284 m
.6191 .41961 L
s
1 0 0 r
.41284 .60274 m
.41961 .6191 L
s
.58716 .60274 m
.58039 .6191 L
s
0 0 1 r
.35095 .4778 m
.36675 .47615 L
s
.63325 .47615 m
.64905 .4778 L
s
1 0 0 r
.47615 .63325 m
.4778 .64905 L
s
.52385 .63325 m
.5222 .64905 L
s
0 0 1 r
.44864 .36709 m
.46662 .36863 L
s
1 0 0 r
.36709 .44864 m
.36863 .46662 L
s
.63291 .44864 m
.63137 .46662 L
s
0 0 1 r
.53338 .36863 m
.55136 .36709 L
s
.48987 .36002 m
.5078 .36394 L
s
1 0 0 r
.36002 .48987 m
.36394 .5078 L
s
.63998 .48987 m
.63606 .5078 L
s
0 0 1 r
.4922 .36394 m
.51013 .36002 L
s
.40579 .39512 m
.42243 .38741 L
s
.57757 .38741 m
.59421 .39512 L
s
1 0 0 r
.38741 .57757 m
.39512 .59421 L
s
.61259 .57757 m
.60488 .59421 L
s
0 0 1 r
.35874 .4492 m
.37473 .44478 L
s
.62527 .44478 m
.64126 .4492 L
s
1 0 0 r
.44478 .62527 m
.4492 .64126 L
s
.55522 .62527 m
.5508 .64126 L
s
0 0 1 r
.36832 .43147 m
.38445 .42527 L
s
.61555 .42527 m
.63168 .43147 L
s
1 0 0 r
.42527 .61555 m
.43147 .63168 L
s
.57473 .61555 m
.56853 .63168 L
s
0 0 1 r
.36534 .42985 m
.38175 .4277 L
s
1 0 0 r
.42985 .36534 m
.4277 .38175 L
s
.57015 .36534 m
.5723 .38175 L
s
0 0 1 r
.61825 .4277 m
.63466 .42985 L
s
.34855 .4685 m
.36427 .46587 L
s
.63573 .46587 m
.65145 .4685 L
s
1 0 0 r
.46587 .63573 m
.4685 .65145 L
s
.53413 .63573 m
.5315 .65145 L
s
0 0 1 r
.47188 .35692 m
.48987 .36002 L
s
1 0 0 r
.35692 .47188 m
.36002 .48987 L
s
.64308 .47188 m
.63998 .48987 L
s
0 0 1 r
.51013 .36002 m
.52812 .35692 L
s
.40864 .38069 m
.4262 .38018 L
s
1 0 0 r
.38069 .40864 m
.38018 .4262 L
s
.61931 .40864 m
.61982 .4262 L
s
0 0 1 r
.5738 .38018 m
.59136 .38069 L
s
.38961 .40352 m
.40579 .39512 L
s
.59421 .39512 m
.61039 .40352 L
s
1 0 0 r
.39512 .59421 m
.40352 .61039 L
s
.60488 .59421 m
.59648 .61039 L
s
0 0 1 r
.37735 .41539 m
.39342 .40747 L
s
.60658 .40747 m
.62265 .41539 L
s
1 0 0 r
.40747 .60658 m
.41539 .62265 L
s
.59253 .60658 m
.58461 .62265 L
s
0 0 1 r
.5483 .36725 m
.56535 .37455 L
s
.53094 .36074 m
.5483 .36725 L
s
1 0 0 r
.36725 .5483 m
.37455 .56535 L
s
.36074 .53094 m
.36725 .5483 L
s
.63275 .5483 m
.62545 .56535 L
s
.63926 .53094 m
.63275 .5483 L
s
0 0 1 r
.4517 .36725 m
.46906 .36074 L
s
.43465 .37455 m
.4517 .36725 L
s
.38766 .39701 m
.40477 .3955 L
s
1 0 0 r
.39701 .38766 m
.3955 .40477 L
s
.60299 .38766 m
.6045 .40477 L
s
0 0 1 r
.59523 .3955 m
.61234 .39701 L
s
.41797 .38262 m
.43465 .37455 L
s
.56535 .37455 m
.58203 .38262 L
s
1 0 0 r
.37455 .56535 m
.38262 .58203 L
s
.62545 .56535 m
.61738 .58203 L
s
0 0 1 r
.43078 .36634 m
.44864 .36709 L
s
1 0 0 r
.36634 .43078 m
.36709 .44864 L
s
.63366 .43078 m
.63291 .44864 L
s
0 0 1 r
.55136 .36709 m
.56922 .36634 L
s
.51333 .35506 m
.53094 .36074 L
s
1 0 0 r
.35506 .51333 m
.36074 .53094 L
s
.64494 .51333 m
.63926 .53094 L
s
0 0 1 r
.46906 .36074 m
.48667 .35506 L
s
.35575 .44296 m
.37159 .43741 L
s
.62841 .43741 m
.64425 .44296 L
s
1 0 0 r
.43741 .62841 m
.44296 .64425 L
s
.56259 .62841 m
.55704 .64425 L
s
0 0 1 r
.40172 .39143 m
.41797 .38262 L
s
.58203 .38262 m
.59828 .39143 L
s
1 0 0 r
.38262 .58203 m
.39143 .59828 L
s
.61738 .58203 m
.60857 .59828 L
s
0 0 1 r
.34355 .47526 m
.35911 .47386 L
s
1 0 0 r
.47526 .34355 m
.47386 .35911 L
s
.52474 .34355 m
.52614 .35911 L
s
0 0 1 r
.64089 .47386 m
.65645 .47526 L
s
.34173 .48811 m
.35721 .48735 L
s
1 0 0 r
.48811 .34173 m
.48735 .35721 L
s
.51189 .34173 m
.51265 .35721 L
s
0 0 1 r
.64279 .48735 m
.65827 .48811 L
s
.36503 .42697 m
.3809 .41961 L
s
.6191 .41961 m
.63497 .42697 L
s
1 0 0 r
.41961 .6191 m
.42697 .63497 L
s
.58039 .6191 m
.57303 .63497 L
s
0 0 1 r
.34537 .4616 m
.36104 .45967 L
s
1 0 0 r
.4616 .34537 m
.45967 .36104 L
s
.5384 .34537 m
.54033 .36104 L
s
0 0 1 r
.63896 .45967 m
.65463 .4616 L
s
.33985 .5 m
.35525 .5 L
s
1 0 0 r
.5 .33985 m
.5 .35525 L
s
0 0 1 r
.64475 .5 m
.66015 .5 L
s
1 0 0 r
.5 .64475 m
.5 .66015 L
s
0 0 1 r
.34598 .46055 m
.36159 .45686 L
s
.63841 .45686 m
.65402 .46055 L
s
1 0 0 r
.45686 .63841 m
.46055 .65402 L
s
.54314 .63841 m
.53945 .65402 L
s
0 0 1 r
.36792 .41454 m
.38448 .41232 L
s
1 0 0 r
.41454 .36792 m
.41232 .38448 L
s
.58546 .36792 m
.58768 .38448 L
s
0 0 1 r
.61552 .41232 m
.63208 .41454 L
s
.49555 .35024 m
.51333 .35506 L
s
1 0 0 r
.35024 .49555 m
.35506 .51333 L
s
.64976 .49555 m
.64494 .51333 L
s
0 0 1 r
.48667 .35506 m
.50445 .35024 L
s
.4539 .35467 m
.47188 .35692 L
s
1 0 0 r
.35467 .4539 m
.35692 .47188 L
s
.64533 .4539 m
.64308 .47188 L
s
0 0 1 r
.52812 .35692 m
.5461 .35467 L
s
.38598 .40097 m
.40172 .39143 L
s
.59828 .39143 m
.61402 .40097 L
s
1 0 0 r
.39143 .59828 m
.40097 .61402 L
s
.60857 .59828 m
.59903 .61402 L
s
0 0 1 r
.37394 .4126 m
.38961 .40352 L
s
.61039 .40352 m
.62606 .4126 L
s
1 0 0 r
.40352 .61039 m
.4126 .62606 L
s
.59648 .61039 m
.5874 .62606 L
s
0 0 1 r
.33784 .4892 m
.35318 .48834 L
s
.64682 .48834 m
.66216 .4892 L
s
1 0 0 r
.48834 .64682 m
.4892 .66216 L
s
.51166 .64682 m
.5108 .66216 L
s
0 0 1 r
.34729 .44728 m
.36308 .44494 L
s
1 0 0 r
.44728 .34729 m
.44494 .36308 L
s
.55272 .34729 m
.55506 .36308 L
s
0 0 1 r
.63692 .44494 m
.65271 .44728 L
s
.42986 .37005 m
.44652 .36169 L
s
.41363 .3792 m
.42986 .37005 L
s
.57014 .37005 m
.58637 .3792 L
s
.55348 .36169 m
.57014 .37005 L
s
1 0 0 r
.37005 .57014 m
.3792 .58637 L
s
.36169 .55348 m
.37005 .57014 L
s
.62995 .57014 m
.6208 .58637 L
s
.63831 .55348 m
.62995 .57014 L
s
0 0 1 r
.53646 .35415 m
.55348 .36169 L
s
1 0 0 r
.35415 .53646 m
.36169 .55348 L
s
.64585 .53646 m
.63831 .55348 L
s
0 0 1 r
.44652 .36169 m
.46354 .35415 L
s
.35272 .43819 m
.36832 .43147 L
s
.63168 .43147 m
.64728 .43819 L
s
1 0 0 r
.43147 .63168 m
.43819 .64728 L
s
.56853 .63168 m
.56181 .64728 L
s
0 0 1 r
.39788 .38911 m
.41363 .3792 L
s
.58637 .3792 m
.60212 .38911 L
s
1 0 0 r
.3792 .58637 m
.38911 .60212 L
s
.6208 .58637 m
.61089 .60212 L
s
0 0 1 r
.36183 .42394 m
.37735 .41539 L
s
.62265 .41539 m
.63817 .42394 L
s
1 0 0 r
.41539 .62265 m
.42394 .63817 L
s
.58461 .62265 m
.57606 .63817 L
s
0 0 1 r
.47766 .34629 m
.49555 .35024 L
s
1 0 0 r
.34629 .47766 m
.35024 .49555 L
s
.65371 .47766 m
.64976 .49555 L
s
0 0 1 r
.50445 .35024 m
.52234 .34629 L
s
.34327 .45403 m
.35874 .4492 L
s
.64126 .4492 m
.65673 .45403 L
s
1 0 0 r
.4492 .64126 m
.45403 .65673 L
s
.5508 .64126 m
.54597 .65673 L
s
0 0 1 r
.39137 .38195 m
.40864 .38069 L
s
1 0 0 r
.38195 .39137 m
.38069 .40864 L
s
.61805 .39137 m
.61931 .40864 L
s
0 0 1 r
.59136 .38069 m
.60863 .38195 L
s
.51914 .34748 m
.53646 .35415 L
s
1 0 0 r
.34748 .51914 m
.35415 .53646 L
s
.65252 .51914 m
.64585 .53646 L
s
0 0 1 r
.46354 .35415 m
.48086 .34748 L
s
.41311 .3664 m
.43078 .36634 L
s
1 0 0 r
.3664 .41311 m
.36634 .43078 L
s
.6336 .41311 m
.63366 .43078 L
s
0 0 1 r
.56922 .36634 m
.58689 .3664 L
s
.33569 .47963 m
.35095 .4778 L
s
.64905 .4778 m
.66431 .47963 L
s
1 0 0 r
.4778 .64905 m
.47963 .66431 L
s
.5222 .64905 m
.52037 .66431 L
s
0 0 1 r
.38269 .39974 m
.39788 .38911 L
s
.60212 .38911 m
.61731 .39974 L
s
1 0 0 r
.38911 .60212 m
.39974 .61731 L
s
.61089 .60212 m
.60026 .61731 L
s
0 0 1 r
.3708 .41118 m
.38598 .40097 L
s
.61402 .40097 m
.6292 .41118 L
s
1 0 0 r
.40097 .61402 m
.41118 .6292 L
s
.59903 .61402 m
.58882 .6292 L
s
0 0 1 r
.34941 .43248 m
.36534 .42985 L
s
1 0 0 r
.43248 .34941 m
.42985 .36534 L
s
.56752 .34941 m
.57015 .36534 L
s
0 0 1 r
.63466 .42985 m
.65059 .43248 L
s
.37092 .39919 m
.38766 .39701 L
s
1 0 0 r
.39919 .37092 m
.39701 .38766 L
s
.60081 .37092 m
.60299 .38766 L
s
0 0 1 r
.61234 .39701 m
.62908 .39919 L
s
.43599 .35328 m
.4539 .35467 L
s
1 0 0 r
.35328 .43599 m
.35467 .4539 L
s
.64672 .43599 m
.64533 .4539 L
s
0 0 1 r
.5461 .35467 m
.56401 .35328 L
s
.40958 .3771 m
.42526 .36688 L
s
.39444 .38807 m
.40958 .3771 L
s
.59042 .3771 m
.60556 .38807 L
s
.57474 .36688 m
.59042 .3771 L
s
1 0 0 r
.3771 .59042 m
.38807 .60556 L
s
.36688 .57474 m
.3771 .59042 L
s
.6229 .59042 m
.61193 .60556 L
s
.63312 .57474 m
.6229 .59042 L
s
0 0 1 r
.55859 .35747 m
.57474 .36688 L
s
1 0 0 r
.35747 .55859 m
.36688 .57474 L
s
.64253 .55859 m
.63312 .57474 L
s
0 0 1 r
.42526 .36688 m
.44141 .35747 L
s
.35886 .42232 m
.37394 .4126 L
s
.62606 .4126 m
.64114 .42232 L
s
1 0 0 r
.4126 .62606 m
.42232 .64114 L
s
.5874 .62606 m
.57768 .64114 L
s
0 0 1 r
.34974 .43491 m
.36503 .42697 L
s
.63497 .42697 m
.65026 .43491 L
s
1 0 0 r
.42697 .63497 m
.43491 .65026 L
s
.57303 .63497 m
.56509 .65026 L
s
0 0 1 r
.50159 .34169 m
.51914 .34748 L
s
1 0 0 r
.34169 .50159 m
.34748 .51914 L
s
.65831 .50159 m
.65252 .51914 L
s
0 0 1 r
.48086 .34748 m
.49841 .34169 L
s
.3799 .39977 m
.39444 .38807 L
s
.60556 .38807 m
.6201 .39977 L
s
1 0 0 r
.38807 .60556 m
.39977 .6201 L
s
.61193 .60556 m
.60023 .6201 L
s
0 0 1 r
.54202 .3489 m
.55859 .35747 L
s
1 0 0 r
.3489 .54202 m
.35747 .55859 L
s
.6511 .54202 m
.64253 .55859 L
s
0 0 1 r
.44141 .35747 m
.45798 .3489 L
s
.3681 .41106 m
.38269 .39974 L
s
.61731 .39974 m
.6319 .41106 L
s
1 0 0 r
.39974 .61731 m
.41106 .6319 L
s
.60026 .61731 m
.58894 .6319 L
s
0 0 1 r
.33339 .47139 m
.34855 .4685 L
s
.65145 .4685 m
.66661 .47139 L
s
1 0 0 r
.4685 .65145 m
.47139 .66661 L
s
.5315 .65145 m
.52861 .66661 L
s
0 0 1 r
.34049 .44898 m
.35575 .44296 L
s
.64425 .44296 m
.65951 .44898 L
s
1 0 0 r
.44296 .64425 m
.44898 .65951 L
s
.55704 .64425 m
.55102 .65951 L
s
0 0 1 r
.45973 .34324 m
.47766 .34629 L
s
1 0 0 r
.34324 .45973 m
.34629 .47766 L
s
.65676 .45973 m
.65371 .47766 L
s
0 0 1 r
.52234 .34629 m
.54027 .34324 L
s
.59401 .37624 m
.60843 .38822 L
s
.579 .365 m
.59401 .37624 L
s
1 0 0 r
.37624 .59401 m
.38822 .60843 L
s
.365 .579 m
.37624 .59401 L
s
.62376 .59401 m
.61178 .60843 L
s
.635 .579 m
.62376 .59401 L
s
0 0 1 r
.40599 .37624 m
.421 .365 L
s
.39157 .38822 m
.40599 .37624 L
s
.37778 .40092 m
.39157 .38822 L
s
.60843 .38822 m
.62222 .40092 L
s
1 0 0 r
.38822 .60843 m
.40092 .62222 L
s
.61178 .60843 m
.59908 .62222 L
s
0 0 1 r
.56346 .35456 m
.579 .365 L
s
1 0 0 r
.35456 .56346 m
.365 .579 L
s
.64544 .56346 m
.635 .579 L
s
0 0 1 r
.421 .365 m
.43654 .35456 L
s
.36601 .41214 m
.3799 .39977 L
s
.6201 .39977 m
.63399 .41214 L
s
1 0 0 r
.39977 .6201 m
.41214 .63399 L
s
.60023 .6201 m
.58786 .63399 L
s
0 0 1 r
.35626 .42205 m
.3708 .41118 L
s
.6292 .41118 m
.64374 .42205 L
s
1 0 0 r
.41118 .6292 m
.42205 .64374 L
s
.58882 .6292 m
.57795 .64374 L
s
0 0 1 r
.5251 .34121 m
.54202 .3489 L
s
1 0 0 r
.34121 .5251 m
.3489 .54202 L
s
.65879 .5251 m
.6511 .54202 L
s
0 0 1 r
.45798 .3489 m
.4749 .34121 L
s
.35182 .41734 m
.36792 .41454 L
s
1 0 0 r
.41734 .35182 m
.41454 .36792 L
s
.58266 .35182 m
.58546 .36792 L
s
0 0 1 r
.63208 .41454 m
.64818 .41734 L
s
.3647 .41426 m
.37778 .40092 L
s
.62222 .40092 m
.6353 .41426 L
s
1 0 0 r
.40092 .62222 m
.41426 .6353 L
s
.59908 .62222 m
.58574 .6353 L
s
0 0 1 r
.34693 .43308 m
.36183 .42394 L
s
.63817 .42394 m
.65307 .43308 L
s
1 0 0 r
.42394 .63817 m
.43308 .65307 L
s
.57606 .63817 m
.56692 .65307 L
s
0 0 1 r
.48388 .33683 m
.50159 .34169 L
s
1 0 0 r
.33683 .48388 m
.34169 .50159 L
s
.66317 .48388 m
.65831 .50159 L
s
0 0 1 r
.49841 .34169 m
.51612 .33683 L
s
.32856 .47685 m
.34355 .47526 L
s
1 0 0 r
.47685 .32856 m
.47526 .34355 L
s
.52315 .32856 m
.52474 .34355 L
s
0 0 1 r
.65645 .47526 m
.67144 .47685 L
s
.54746 .34497 m
.56346 .35456 L
s
1 0 0 r
.34497 .54746 m
.35456 .56346 L
s
.65503 .54746 m
.64544 .56346 L
s
0 0 1 r
.43654 .35456 m
.45254 .34497 L
s
.32683 .48896 m
.34173 .48811 L
s
1 0 0 r
.48896 .32683 m
.48811 .34173 L
s
.51104 .32683 m
.51189 .34173 L
s
0 0 1 r
.65827 .48811 m
.67317 .48896 L
s
.33095 .46458 m
.34598 .46055 L
s
.65402 .46055 m
.66905 .46458 L
s
1 0 0 r
.46055 .65402 m
.46458 .66905 L
s
.53945 .65402 m
.53542 .66905 L
s
0 0 1 r
.3542 .42304 m
.3681 .41106 L
s
.6319 .41106 m
.6458 .42304 L
s
1 0 0 r
.41106 .6319 m
.42304 .6458 L
s
.58894 .6319 m
.57696 .6458 L
s
0 0 1 r
.33028 .46381 m
.34537 .4616 L
s
1 0 0 r
.46381 .33028 m
.4616 .34537 L
s
.53619 .33028 m
.5384 .34537 L
s
0 0 1 r
.65463 .4616 m
.66972 .46381 L
s
.39569 .36729 m
.41311 .3664 L
s
1 0 0 r
.36729 .39569 m
.3664 .41311 L
s
.63271 .39569 m
.6336 .41311 L
s
0 0 1 r
.58689 .3664 m
.60431 .36729 L
s
.33772 .44544 m
.35272 .43819 L
s
.64728 .43819 m
.66228 .44544 L
s
1 0 0 r
.43819 .64728 m
.44544 .66228 L
s
.56181 .64728 m
.55456 .66228 L
s
0 0 1 r
.41823 .35279 m
.43599 .35328 L
s
1 0 0 r
.35279 .41823 m
.35328 .43599 L
s
.64721 .41823 m
.64672 .43599 L
s
0 0 1 r
.56401 .35328 m
.58177 .35279 L
s
.32503 .5 m
.33985 .5 L
s
1 0 0 r
.5 .32503 m
.5 .33985 L
s
0 0 1 r
.66015 .5 m
.67497 .5 L
s
1 0 0 r
.5 .66015 m
.5 .67497 L
s
0 0 1 r
.35237 .42822 m
.3647 .41426 L
s
.6353 .41426 m
.64763 .42822 L
s
1 0 0 r
.41426 .6353 m
.42822 .64763 L
s
.58574 .6353 m
.57178 .64763 L
s
0 0 1 r
.35285 .42515 m
.36601 .41214 L
s
.63399 .41214 m
.64715 .42515 L
s
1 0 0 r
.41214 .63399 m
.42515 .64715 L
s
.58786 .63399 m
.57485 .64715 L
s
0 0 1 r
.37445 .38396 m
.39137 .38195 L
s
1 0 0 r
.38396 .37445 m
.38195 .39137 L
s
.61604 .37445 m
.61805 .39137 L
s
0 0 1 r
.60863 .38195 m
.62555 .38396 L
s
.50789 .33444 m
.5251 .34121 L
s
1 0 0 r
.33444 .50789 m
.34121 .5251 L
s
.66556 .50789 m
.65879 .5251 L
s
0 0 1 r
.4749 .34121 m
.49211 .33444 L
s
.34444 .43266 m
.35886 .42232 L
s
.64114 .42232 m
.65556 .43266 L
s
1 0 0 r
.42232 .64114 m
.43266 .65556 L
s
.57768 .64114 m
.56734 .65556 L
s
0 0 1 r
.33207 .45001 m
.34729 .44728 L
s
1 0 0 r
.45001 .33207 m
.44728 .34729 L
s
.54999 .33207 m
.55272 .34729 L
s
0 0 1 r
.65271 .44728 m
.66793 .45001 L
s
.44182 .34114 m
.45973 .34324 L
s
1 0 0 r
.34114 .44182 m
.34324 .45973 L
s
.65886 .44182 m
.65676 .45973 L
s
0 0 1 r
.54027 .34324 m
.55818 .34114 L
s
.53105 .33627 m
.54746 .34497 L
s
1 0 0 r
.33627 .53105 m
.34497 .54746 L
s
.66373 .53105 m
.65503 .54746 L
s
0 0 1 r
.45254 .34497 m
.46895 .33627 L
s
.32311 .49016 m
.33784 .4892 L
s
.66216 .4892 m
.67689 .49016 L
s
1 0 0 r
.4892 .66216 m
.49016 .67689 L
s
.5108 .66216 m
.50984 .67689 L
s
0 0 1 r
.32841 .45925 m
.34327 .45403 L
s
.65673 .45403 m
.67159 .45925 L
s
1 0 0 r
.45403 .65673 m
.45925 .67159 L
s
.54597 .65673 m
.54075 .67159 L
s
0 0 1 r
.34243 .43355 m
.35626 .42205 L
s
.64374 .42205 m
.65757 .43355 L
s
1 0 0 r
.42205 .64374 m
.43355 .65757 L
s
.57795 .64374 m
.56645 .65757 L
s
0 0 1 r
.33509 .44339 m
.34974 .43491 L
s
.65026 .43491 m
.66491 .44339 L
s
1 0 0 r
.43491 .65026 m
.44339 .66491 L
s
.56509 .65026 m
.55661 .66491 L
s
0 0 1 r
.35464 .40204 m
.37092 .39919 L
s
1 0 0 r
.40204 .35464 m
.39919 .37092 L
s
.59796 .35464 m
.60081 .37092 L
s
0 0 1 r
.62908 .39919 m
.64536 .40204 L
s
.46608 .33293 m
.48388 .33683 L
s
1 0 0 r
.33293 .46608 m
.33683 .48388 L
s
.66707 .46608 m
.66317 .48388 L
s
0 0 1 r
.51612 .33683 m
.53392 .33293 L
s
.34085 .44273 m
.35237 .42822 L
s
.64763 .42822 m
.65915 .44273 L
s
1 0 0 r
.42822 .64763 m
.44273 .65915 L
s
.57178 .64763 m
.55727 .65915 L
s
0 0 1 r
.34105 .43563 m
.3542 .42304 L
s
.6458 .42304 m
.65895 .43563 L
s
1 0 0 r
.42304 .6458 m
.43563 .65895 L
s
.57696 .6458 m
.56437 .65895 L
s
0 0 1 r
.33403 .43559 m
.34941 .43248 L
s
1 0 0 r
.43559 .33403 m
.43248 .34941 L
s
.56441 .33403 m
.56752 .34941 L
s
0 0 1 r
.65059 .43248 m
.66597 .43559 L
s
.34048 .43875 m
.35285 .42515 L
s
.64715 .42515 m
.65952 .43875 L
s
1 0 0 r
.42515 .64715 m
.43875 .65952 L
s
.57485 .64715 m
.56125 .65952 L
s
0 0 1 r
.32106 .48164 m
.33569 .47963 L
s
.66431 .47963 m
.67894 .48164 L
s
1 0 0 r
.47963 .66431 m
.48164 .67894 L
s
.52037 .66431 m
.51836 .67894 L
s
0 0 1 r
.49046 .32863 m
.50789 .33444 L
s
1 0 0 r
.32863 .49046 m
.33444 .50789 L
s
.67137 .49046 m
.66556 .50789 L
s
0 0 1 r
.49211 .33444 m
.50954 .32863 L
s
.5143 .3285 m
.53105 .33627 L
s
1 0 0 r
.3285 .5143 m
.33627 .53105 L
s
.6715 .5143 m
.66373 .53105 L
s
0 0 1 r
.46895 .33627 m
.4857 .3285 L
s
.33271 .4428 m
.34693 .43308 L
s
.65307 .43308 m
.66729 .4428 L
s
1 0 0 r
.43308 .65307 m
.4428 .66729 L
s
.56692 .65307 m
.5572 .66729 L
s
0 0 1 r
.32587 .45545 m
.34049 .44898 L
s
.65951 .44898 m
.67413 .45545 L
s
1 0 0 r
.44898 .65951 m
.45545 .67413 L
s
.55102 .65951 m
.54455 .67413 L
s
0 0 1 r
.40069 .3532 m
.41823 .35279 L
s
1 0 0 r
.3532 .40069 m
.35279 .41823 L
s
.6468 .40069 m
.64721 .41823 L
s
0 0 1 r
.58177 .35279 m
.59931 .3532 L
s
.37861 .36903 m
.39569 .36729 L
s
1 0 0 r
.36903 .37861 m
.36729 .39569 L
s
.63097 .37861 m
.63271 .39569 L
s
0 0 1 r
.60431 .36729 m
.62139 .36903 L
s
.31887 .47454 m
.33339 .47139 L
s
.66661 .47139 m
.68113 .47454 L
s
1 0 0 r
.47139 .66661 m
.47454 .68113 L
s
.52861 .66661 m
.52546 .68113 L
s
0 0 1 r
.33021 .45775 m
.34085 .44273 L
s
.65915 .44273 m
.66979 .45775 L
s
1 0 0 r
.44273 .65915 m
.45775 .66979 L
s
.55727 .65915 m
.54225 .66979 L
s
0 0 1 r
.42402 .33999 m
.44182 .34114 L
s
1 0 0 r
.33999 .42402 m
.34114 .44182 L
s
.66001 .42402 m
.65886 .44182 L
s
0 0 1 r
.55818 .34114 m
.57598 .33999 L
s
.33075 .44358 m
.34444 .43266 L
s
.65556 .43266 m
.66925 .44358 L
s
1 0 0 r
.43266 .65556 m
.44358 .66925 L
s
.56734 .65556 m
.55642 .66925 L
s
0 0 1 r
.33628 .42072 m
.35182 .41734 L
s
1 0 0 r
.42072 .33628 m
.41734 .35182 L
s
.57928 .33628 m
.58266 .35182 L
s
0 0 1 r
.64818 .41734 m
.66372 .42072 L
s
.44825 .33002 m
.46608 .33293 L
s
1 0 0 r
.33002 .44825 m
.33293 .46608 L
s
.66998 .44825 m
.66707 .46608 L
s
0 0 1 r
.53392 .33293 m
.55175 .33002 L
s
.32895 .45289 m
.34048 .43875 L
s
.65952 .43875 m
.67105 .45289 L
s
1 0 0 r
.43875 .65952 m
.45289 .67105 L
s
.56125 .65952 m
.54711 .67105 L
s
0 0 1 r
.35798 .38674 m
.37445 .38396 L
s
1 0 0 r
.38674 .35798 m
.38396 .37445 L
s
.61326 .35798 m
.61604 .37445 L
s
0 0 1 r
.62555 .38396 m
.64202 .38674 L
s
.32937 .44563 m
.34243 .43355 L
s
.65757 .43355 m
.67063 .44563 L
s
1 0 0 r
.43355 .65757 m
.44563 .67063 L
s
.56645 .65757 m
.55437 .67063 L
s
0 0 1 r
.32341 .45318 m
.33772 .44544 L
s
.66228 .44544 m
.67659 .45318 L
s
1 0 0 r
.44544 .66228 m
.45318 .67659 L
s
.55456 .66228 m
.54682 .67659 L
s
0 0 1 r
.32871 .44878 m
.34105 .43563 L
s
.65895 .43563 m
.67129 .44878 L
s
1 0 0 r
.43563 .65895 m
.44878 .67129 L
s
.56437 .65895 m
.55122 .67129 L
s
0 0 1 r
.47288 .32381 m
.49046 .32863 L
s
1 0 0 r
.32381 .47288 m
.32863 .49046 L
s
.67619 .47288 m
.67137 .49046 L
s
0 0 1 r
.50954 .32863 m
.52712 .32381 L
s
.49727 .32171 m
.5143 .3285 L
s
1 0 0 r
.32171 .49727 m
.3285 .5143 L
s
.67829 .49727 m
.6715 .5143 L
s
0 0 1 r
.4857 .3285 m
.50273 .32171 L
s
.31658 .46893 m
.33095 .46458 L
s
.66905 .46458 m
.68342 .46893 L
s
1 0 0 r
.46458 .66905 m
.46893 .68342 L
s
.53542 .66905 m
.53107 .68342 L
s
0 0 1 r
.31423 .47863 m
.32856 .47685 L
s
1 0 0 r
.47863 .31423 m
.47685 .32856 L
s
.52137 .31423 m
.52315 .32856 L
s
0 0 1 r
.67144 .47685 m
.68577 .47863 L
s
.3126 .4899 m
.32683 .48896 L
s
1 0 0 r
.4899 .3126 m
.48896 .32683 L
s
.5101 .3126 m
.51104 .32683 L
s
0 0 1 r
.67317 .48896 m
.6874 .4899 L
s
.31584 .46632 m
.33028 .46381 L
s
1 0 0 r
.46632 .31584 m
.46381 .33028 L
s
.53368 .31584 m
.53619 .33028 L
s
0 0 1 r
.66972 .46381 m
.68416 .46632 L
s
.32116 .45242 m
.33509 .44339 L
s
.66491 .44339 m
.67884 .45242 L
s
1 0 0 r
.44339 .66491 m
.45242 .67884 L
s
.55661 .66491 m
.54758 .67884 L
s
0 0 1 r
.3205 .47321 m
.33021 .45775 L
s
.66979 .45775 m
.6795 .47321 L
s
1 0 0 r
.45775 .66979 m
.47321 .6795 L
s
.54225 .66979 m
.52679 .6795 L
s
0 0 1 r
.31089 .5 m
.32503 .5 L
s
1 0 0 r
.5 .31089 m
.5 .32503 L
s
0 0 1 r
.67497 .5 m
.68911 .5 L
s
1 0 0 r
.5 .67497 m
.5 .68911 L
s
0 0 1 r
.3175 .45312 m
.33207 .45001 L
s
1 0 0 r
.45312 .3175 m
.45001 .33207 L
s
.54688 .3175 m
.54999 .33207 L
s
0 0 1 r
.66793 .45001 m
.6825 .45312 L
s
.33891 .40557 m
.35464 .40204 L
s
1 0 0 r
.40557 .33891 m
.40204 .35464 L
s
.59443 .33891 m
.59796 .35464 L
s
0 0 1 r
.64536 .40204 m
.66109 .40557 L
s
.31426 .46487 m
.32841 .45925 L
s
.67159 .45925 m
.68574 .46487 L
s
1 0 0 r
.45925 .67159 m
.46487 .68574 L
s
.54075 .67159 m
.53513 .68574 L
s
0 0 1 r
.31927 .45308 m
.33271 .4428 L
s
.66729 .4428 m
.68073 .45308 L
s
1 0 0 r
.4428 .66729 m
.45308 .68073 L
s
.5572 .66729 m
.54692 .68073 L
s
0 0 1 r
.4064 .33983 m
.42402 .33999 L
s
1 0 0 r
.33983 .4064 m
.33999 .42402 L
s
.66017 .4064 m
.66001 .42402 L
s
0 0 1 r
.57598 .33999 m
.5936 .33983 L
s
.30907 .49121 m
.32311 .49016 L
s
.67689 .49016 m
.69093 .49121 L
s
1 0 0 r
.49016 .67689 m
.49121 .69093 L
s
.50984 .67689 m
.50879 .69093 L
s
0 0 1 r
.38345 .35455 m
.40069 .3532 L
s
1 0 0 r
.35455 .38345 m
.3532 .40069 L
s
.64545 .38345 m
.6468 .40069 L
s
0 0 1 r
.59931 .3532 m
.61655 .35455 L
s
.31834 .46752 m
.32895 .45289 L
s
.67105 .45289 m
.68166 .46752 L
s
1 0 0 r
.45289 .67105 m
.46752 .68166 L
s
.54711 .67105 m
.53248 .68166 L
s
0 0 1 r
.43048 .32814 m
.44825 .33002 L
s
1 0 0 r
.32814 .43048 m
.33002 .44825 L
s
.67186 .43048 m
.66998 .44825 L
s
0 0 1 r
.55175 .33002 m
.56952 .32814 L
s
.31931 .43919 m
.33403 .43559 L
s
1 0 0 r
.43919 .31931 m
.43559 .33403 L
s
.56081 .31931 m
.56441 .33403 L
s
0 0 1 r
.66597 .43559 m
.68069 .43919 L
s
.45523 .32005 m
.47288 .32381 L
s
1 0 0 r
.32005 .45523 m
.32381 .47288 L
s
.67995 .45523 m
.67619 .47288 L
s
0 0 1 r
.52712 .32381 m
.54477 .32005 L
s
.48003 .31596 m
.49727 .32171 L
s
1 0 0 r
.31596 .48003 m
.32171 .49727 L
s
.68404 .48003 m
.67829 .49727 L
s
0 0 1 r
.50273 .32171 m
.51997 .31596 L
s
.31788 .45507 m
.33075 .44358 L
s
.66925 .44358 m
.68212 .45507 L
s
1 0 0 r
.44358 .66925 m
.45507 .68212 L
s
.55642 .66925 m
.54493 .68212 L
s
0 0 1 r
.36194 .37162 m
.37861 .36903 L
s
1 0 0 r
.37162 .36194 m
.36903 .37861 L
s
.62838 .36194 m
.63097 .37861 L
s
0 0 1 r
.62139 .36903 m
.63806 .37162 L
s
.31727 .46247 m
.32871 .44878 L
s
.67129 .44878 m
.68273 .46247 L
s
1 0 0 r
.44878 .67129 m
.46247 .68273 L
s
.55122 .67129 m
.53753 .68273 L
s
0 0 1 r
.31716 .45826 m
.32937 .44563 L
s
.67063 .44563 m
.68284 .45826 L
s
1 0 0 r
.44563 .67063 m
.45826 .68284 L
s
.55437 .67063 m
.54174 .68284 L
s
0 0 1 r
.31198 .46237 m
.32587 .45545 L
s
.67413 .45545 m
.68802 .46237 L
s
1 0 0 r
.45545 .67413 m
.46237 .68802 L
s
.54455 .67413 m
.53763 .68802 L
s
0 0 1 r
.30713 .48382 m
.32106 .48164 L
s
.67894 .48164 m
.69287 .48382 L
s
1 0 0 r
.48164 .67894 m
.48382 .69287 L
s
.51836 .67894 m
.51618 .69287 L
s
0 0 1 r
.31179 .48907 m
.3205 .47321 L
s
.6795 .47321 m
.68821 .48907 L
s
1 0 0 r
.47321 .6795 m
.48907 .68821 L
s
.52679 .6795 m
.51093 .68821 L
s
0 0 1 r
.34204 .39031 m
.35798 .38674 L
s
1 0 0 r
.39031 .34204 m
.38674 .35798 L
s
.60969 .34204 m
.61326 .35798 L
s
0 0 1 r
.64202 .38674 m
.65796 .39031 L
s
.32137 .42469 m
.33628 .42072 L
s
1 0 0 r
.42469 .32137 m
.42072 .33628 L
s
.57531 .32137 m
.57928 .33628 L
s
0 0 1 r
.66372 .42072 m
.67863 .42469 L
s
.30987 .46142 m
.32341 .45318 L
s
.67659 .45318 m
.69013 .46142 L
s
1 0 0 r
.45318 .67659 m
.46142 .69013 L
s
.54682 .67659 m
.53858 .69013 L
s
0 0 1 r
.30508 .47794 m
.31887 .47454 L
s
.68113 .47454 m
.69492 .47794 L
s
1 0 0 r
.47454 .68113 m
.47794 .69492 L
s
.52546 .68113 m
.52206 .69492 L
s
0 0 1 r
.30871 .4826 m
.31834 .46752 L
s
.68166 .46752 m
.69129 .4826 L
s
1 0 0 r
.46752 .68166 m
.4826 .69129 L
s
.53248 .68166 m
.5174 .69129 L
s
0 0 1 r
.30806 .46195 m
.32116 .45242 L
s
.67884 .45242 m
.69194 .46195 L
s
1 0 0 r
.45242 .67884 m
.46195 .69194 L
s
.54758 .67884 m
.53805 .69194 L
s
0 0 1 r
.46265 .31129 m
.48003 .31596 L
s
1 0 0 r
.31129 .46265 m
.31596 .48003 L
s
.68871 .46265 m
.68404 .48003 L
s
0 0 1 r
.51997 .31596 m
.53735 .31129 L
s
.41284 .32731 m
.43048 .32814 L
s
1 0 0 r
.32731 .41284 m
.32814 .43048 L
s
.67269 .41284 m
.67186 .43048 L
s
0 0 1 r
.56952 .32814 m
.58716 .32731 L
s
.43757 .31736 m
.45523 .32005 L
s
1 0 0 r
.31736 .43757 m
.32005 .45523 L
s
.68264 .43757 m
.67995 .45523 L
s
0 0 1 r
.54477 .32005 m
.56243 .31736 L
s
.38905 .34068 m
.4064 .33983 L
s
1 0 0 r
.34068 .38905 m
.33983 .4064 L
s
.65932 .38905 m
.66017 .4064 L
s
0 0 1 r
.5936 .33983 m
.61095 .34068 L
s
.30298 .47361 m
.31658 .46893 L
s
.68342 .46893 m
.69702 .47361 L
s
1 0 0 r
.46893 .68342 m
.47361 .69702 L
s
.53107 .68342 m
.52639 .69702 L
s
0 0 1 r
.36661 .35685 m
.38345 .35455 L
s
1 0 0 r
.35685 .36661 m
.35455 .38345 L
s
.64315 .36661 m
.64545 .38345 L
s
0 0 1 r
.61655 .35455 m
.63339 .35685 L
s
.30678 .47663 m
.31727 .46247 L
s
.68273 .46247 m
.69322 .47663 L
s
1 0 0 r
.46247 .68273 m
.47663 .69322 L
s
.53753 .68273 m
.52337 .69322 L
s
0 0 1 r
.30668 .46388 m
.31927 .45308 L
s
.68073 .45308 m
.69332 .46388 L
s
1 0 0 r
.45308 .68073 m
.46388 .69332 L
s
.54692 .68073 m
.53612 .69332 L
s
0 0 1 r
.3238 .40979 m
.33891 .40557 L
s
1 0 0 r
.40979 .3238 m
.40557 .33891 L
s
.59021 .3238 m
.59443 .33891 L
s
0 0 1 r
.66109 .40557 m
.6762 .40979 L
s
.30065 .4806 m
.31423 .47863 L
s
1 0 0 r
.4806 .30065 m
.47863 .31423 L
s
.5194 .30065 m
.52137 .31423 L
s
0 0 1 r
.68577 .47863 m
.69935 .4806 L
s
.30214 .46912 m
.31584 .46632 L
s
1 0 0 r
.46912 .30214 m
.46632 .31584 L
s
.53088 .30214 m
.53368 .31584 L
s
0 0 1 r
.68416 .46632 m
.69786 .46912 L
s
.30589 .4714 m
.31716 .45826 L
s
.68284 .45826 m
.69411 .4714 L
s
1 0 0 r
.45826 .68284 m
.4714 .69411 L
s
.54174 .68284 m
.5286 .69411 L
s
0 0 1 r
.30591 .46708 m
.31788 .45507 L
s
.68212 .45507 m
.69409 .46708 L
s
1 0 0 r
.45507 .68212 m
.46708 .69409 L
s
.54493 .68212 m
.53292 .69409 L
s
0 0 1 r
.29913 .49094 m
.3126 .4899 L
s
1 0 0 r
.49094 .29913 m
.4899 .3126 L
s
.50906 .29913 m
.5101 .3126 L
s
0 0 1 r
.6874 .4899 m
.70087 .49094 L
s
.30367 .45663 m
.3175 .45312 L
s
1 0 0 r
.45663 .30367 m
.45312 .3175 L
s
.54337 .30367 m
.54688 .3175 L
s
0 0 1 r
.6825 .45312 m
.69633 .45663 L
s
.34579 .3751 m
.36194 .37162 L
s
1 0 0 r
.3751 .34579 m
.37162 .36194 L
s
.6249 .34579 m
.62838 .36194 L
s
0 0 1 r
.63806 .37162 m
.65421 .3751 L
s
.30414 .50525 m
.31179 .48907 L
s
.68821 .48907 m
.69586 .50525 L
s
1 0 0 r
.48907 .68821 m
.50525 .69586 L
s
.51093 .68821 m
.49475 .69586 L
s
0 0 1 r
.30089 .47088 m
.31426 .46487 L
s
.68574 .46487 m
.69911 .47088 L
s
1 0 0 r
.46487 .68574 m
.47088 .69911 L
s
.53513 .68574 m
.52912 .69911 L
s
0 0 1 r
.29752 .5 m
.31089 .5 L
s
1 0 0 r
.5 .29752 m
.5 .31089 L
s
0 0 1 r
.68911 .5 m
.70248 .5 L
s
1 0 0 r
.5 .68911 m
.5 .70248 L
s
0 0 1 r
.30533 .44329 m
.31931 .43919 L
s
1 0 0 r
.44329 .30533 m
.43919 .31931 L
s
.55671 .30533 m
.56081 .31931 L
s
0 0 1 r
.68069 .43919 m
.69467 .44329 L
s
.29581 .49234 m
.30907 .49121 L
s
.69093 .49121 m
.70419 .49234 L
s
1 0 0 r
.49121 .69093 m
.49234 .70419 L
s
.50879 .69093 m
.50766 .70419 L
s
0 0 1 r
.29893 .46972 m
.31198 .46237 L
s
.68802 .46237 m
.70107 .46972 L
s
1 0 0 r
.46237 .68802 m
.46972 .70107 L
s
.53763 .68802 m
.53028 .70107 L
s
0 0 1 r
.30013 .49805 m
.30871 .4826 L
s
.69129 .4826 m
.69987 .49805 L
s
1 0 0 r
.4826 .69129 m
.49805 .69987 L
s
.5174 .69129 m
.50195 .69987 L
s
0 0 1 r
.32672 .39466 m
.34204 .39031 L
s
1 0 0 r
.39466 .32672 m
.39031 .34204 L
s
.60534 .32672 m
.60969 .34204 L
s
0 0 1 r
.65796 .39031 m
.67328 .39466 L
s
.44521 .30774 m
.46265 .31129 L
s
1 0 0 r
.30774 .44521 m
.31129 .46265 L
s
.69226 .44521 m
.68871 .46265 L
s
0 0 1 r
.53735 .31129 m
.55479 .30774 L
s
.41999 .31579 m
.43757 .31736 L
s
1 0 0 r
.31579 .41999 m
.31736 .43757 L
s
.68421 .41999 m
.68264 .43757 L
s
0 0 1 r
.56243 .31736 m
.58001 .31579 L
s
.39542 .32758 m
.41284 .32731 L
s
1 0 0 r
.32758 .39542 m
.32731 .41284 L
s
.67242 .39542 m
.67269 .41284 L
s
0 0 1 r
.58716 .32731 m
.60458 .32758 L
s
.294 .48618 m
.30713 .48382 L
s
.69287 .48382 m
.706 .48618 L
s
1 0 0 r
.48382 .69287 m
.48618 .706 L
s
.51618 .69287 m
.51382 .706 L
s
0 0 1 r
.30721 .42926 m
.32137 .42469 L
s
1 0 0 r
.42926 .30721 m
.42469 .32137 L
s
.57074 .30721 m
.57531 .32137 L
s
0 0 1 r
.67863 .42469 m
.69279 .42926 L
s
.2972 .47012 m
.30987 .46142 L
s
.69013 .46142 m
.7028 .47012 L
s
1 0 0 r
.46142 .69013 m
.47012 .7028 L
s
.53858 .69013 m
.52988 .7028 L
s
0 0 1 r
.37205 .34258 m
.38905 .34068 L
s
1 0 0 r
.34258 .37205 m
.34068 .38905 L
s
.65742 .37205 m
.65932 .38905 L
s
0 0 1 r
.61095 .34068 m
.62795 .34258 L
s
.29733 .49122 m
.30678 .47663 L
s
.69322 .47663 m
.70267 .49122 L
s
1 0 0 r
.47663 .69322 m
.49122 .70267 L
s
.52337 .69322 m
.50878 .70267 L
s
0 0 1 r
.35025 .36012 m
.36661 .35685 L
s
1 0 0 r
.36012 .35025 m
.35685 .36661 L
s
.63988 .35025 m
.64315 .36661 L
s
0 0 1 r
.63339 .35685 m
.64975 .36012 L
s
.29585 .47197 m
.30806 .46195 L
s
.69194 .46195 m
.70415 .47197 L
s
1 0 0 r
.46195 .69194 m
.47197 .70415 L
s
.53805 .69194 m
.52803 .70415 L
s
0 0 1 r
.2976 .5217 m
.30414 .50525 L
s
.69586 .50525 m
.7024 .5217 L
s
1 0 0 r
.50525 .69586 m
.5217 .7024 L
s
.49475 .69586 m
.4783 .7024 L
s
0 0 1 r
.29212 .48159 m
.30508 .47794 L
s
.69492 .47794 m
.70788 .48159 L
s
1 0 0 r
.47794 .69492 m
.48159 .70788 L
s
.52206 .69492 m
.51841 .70788 L
s
0 0 1 r
.29563 .485 m
.30589 .4714 L
s
.69411 .4714 m
.70437 .485 L
s
1 0 0 r
.4714 .69411 m
.485 .70437 L
s
.5286 .69411 m
.515 .70437 L
s
0 0 1 r
.29504 .47518 m
.30668 .46388 L
s
.69332 .46388 m
.70496 .47518 L
s
1 0 0 r
.46388 .69332 m
.47518 .70496 L
s
.53612 .69332 m
.52482 .70496 L
s
0 0 1 r
.29491 .47958 m
.30591 .46708 L
s
.69409 .46708 m
.70509 .47958 L
s
1 0 0 r
.46708 .69409 m
.47958 .70509 L
s
.53292 .69409 m
.52042 .70509 L
s
0 0 1 r
.30943 .41472 m
.3238 .40979 L
s
1 0 0 r
.41472 .30943 m
.40979 .3238 L
s
.58528 .30943 m
.59021 .3238 L
s
0 0 1 r
.6762 .40979 m
.69057 .41472 L
s
.33024 .37947 m
.34579 .3751 L
s
1 0 0 r
.37947 .33024 m
.3751 .34579 L
s
.62053 .33024 m
.6249 .34579 L
s
0 0 1 r
.65421 .3751 m
.66976 .37947 L
s
.29023 .47861 m
.30298 .47361 L
s
.69702 .47361 m
.70977 .47861 L
s
1 0 0 r
.47361 .69702 m
.47861 .70977 L
s
.52639 .69702 m
.52139 .70977 L
s
0 0 1 r
.29268 .51382 m
.30013 .49805 L
s
.69987 .49805 m
.70732 .51382 L
s
1 0 0 r
.49805 .69987 m
.51382 .70732 L
s
.50195 .69987 m
.48618 .70732 L
s
0 0 1 r
.42779 .30537 m
.44521 .30774 L
s
1 0 0 r
.30537 .42779 m
.30774 .44521 L
s
.69463 .42779 m
.69226 .44521 L
s
0 0 1 r
.55479 .30774 m
.57221 .30537 L
s
.2893 .47221 m
.30214 .46912 L
s
1 0 0 r
.47221 .2893 m
.46912 .30214 L
s
.52779 .2893 m
.53088 .30214 L
s
0 0 1 r
.69786 .46912 m
.7107 .47221 L
s
.28793 .48277 m
.30065 .4806 L
s
1 0 0 r
.48277 .28793 m
.4806 .30065 L
s
.51723 .28793 m
.5194 .30065 L
s
0 0 1 r
.69935 .4806 m
.71207 .48277 L
s
.40258 .31539 m
.41999 .31579 L
s
1 0 0 r
.31539 .40258 m
.31579 .41999 L
s
.68461 .40258 m
.68421 .41999 L
s
0 0 1 r
.58001 .31579 m
.59742 .31539 L
s
.29069 .46053 m
.30367 .45663 L
s
1 0 0 r
.46053 .29069 m
.45663 .30367 L
s
.53947 .29069 m
.54337 .30367 L
s
0 0 1 r
.69633 .45663 m
.70931 .46053 L
s
.28652 .49208 m
.29913 .49094 L
s
1 0 0 r
.49208 .28652 m
.49094 .29913 L
s
.50792 .28652 m
.50906 .29913 L
s
0 0 1 r
.70087 .49094 m
.71348 .49208 L
s
.28842 .47725 m
.30089 .47088 L
s
.69911 .47088 m
.71158 .47725 L
s
1 0 0 r
.47088 .69911 m
.47725 .71158 L
s
.52912 .69911 m
.52275 .71158 L
s
0 0 1 r
.37832 .32897 m
.39542 .32758 L
s
1 0 0 r
.32897 .37832 m
.32758 .39542 L
s
.67103 .37832 m
.67242 .39542 L
s
0 0 1 r
.60458 .32758 m
.62168 .32897 L
s
.28503 .5 m
.29752 .5 L
s
1 0 0 r
.5 .28503 m
.5 .29752 L
s
0 0 1 r
.70248 .5 m
.71497 .5 L
s
1 0 0 r
.5 .70248 m
.5 .71497 L
s
0 0 1 r
.29218 .44788 m
.30533 .44329 L
s
1 0 0 r
.44788 .29218 m
.44329 .30533 L
s
.55212 .29218 m
.55671 .30533 L
s
0 0 1 r
.69467 .44329 m
.70782 .44788 L
s
.31212 .39982 m
.32672 .39466 L
s
1 0 0 r
.39982 .31212 m
.39466 .32672 L
s
.60018 .31212 m
.60534 .32672 L
s
0 0 1 r
.67328 .39466 m
.68788 .39982 L
s
.289 .50618 m
.29733 .49122 L
s
.70267 .49122 m
.711 .50618 L
s
1 0 0 r
.49122 .70267 m
.50618 .711 L
s
.50878 .70267 m
.49382 .711 L
s
0 0 1 r
.3555 .34554 m
.37205 .34258 L
s
1 0 0 r
.34554 .3555 m
.34258 .37205 L
s
.65446 .3555 m
.65742 .37205 L
s
0 0 1 r
.62795 .34258 m
.6445 .34554 L
s
.28679 .47749 m
.29893 .46972 L
s
.70107 .46972 m
.71321 .47749 L
s
1 0 0 r
.46972 .70107 m
.47749 .71321 L
s
.53028 .70107 m
.52251 .71321 L
s
0 0 1 r
.29225 .53833 m
.2976 .5217 L
s
.7024 .5217 m
.70775 .53833 L
s
1 0 0 r
.5217 .7024 m
.53833 .70775 L
s
.4783 .7024 m
.46167 .70775 L
s
0 0 1 r
.28344 .49357 m
.29581 .49234 L
s
.70419 .49234 m
.71656 .49357 L
s
1 0 0 r
.49234 .70419 m
.49357 .71656 L
s
.50766 .70419 m
.50643 .71656 L
s
0 0 1 r
.28647 .49901 m
.29563 .485 L
s
.70437 .485 m
.71353 .49901 L
s
1 0 0 r
.485 .70437 m
.49901 .71353 L
s
.515 .70437 m
.50099 .71353 L
s
0 0 1 r
.33446 .36439 m
.35025 .36012 L
s
1 0 0 r
.36439 .33446 m
.36012 .35025 L
s
.63561 .33446 m
.63988 .35025 L
s
0 0 1 r
.64975 .36012 m
.66554 .36439 L
s
.28549 .47926 m
.2972 .47012 L
s
.7028 .47012 m
.71451 .47926 L
s
1 0 0 r
.47012 .7028 m
.47926 .71451 L
s
.52988 .7028 m
.52074 .71451 L
s
0 0 1 r
.29388 .43443 m
.30721 .42926 L
s
1 0 0 r
.43443 .29388 m
.42926 .30721 L
s
.56557 .29388 m
.57074 .30721 L
s
0 0 1 r
.69279 .42926 m
.70612 .43443 L
s
.28465 .48246 m
.29585 .47197 L
s
.70415 .47197 m
.71535 .48246 L
s
1 0 0 r
.47197 .70415 m
.48246 .71535 L
s
.52803 .70415 m
.51754 .71535 L
s
0 0 1 r
.28499 .49252 m
.29491 .47958 L
s
.70509 .47958 m
.71501 .49252 L
s
1 0 0 r
.47958 .70509 m
.49252 .71501 L
s
.52042 .70509 m
.50748 .71501 L
s
0 0 1 r
.28443 .48693 m
.29504 .47518 L
s
.70496 .47518 m
.71557 .48693 L
s
1 0 0 r
.47518 .70496 m
.48693 .71557 L
s
.52482 .70496 m
.51307 .71557 L
s
0 0 1 r
.28179 .48871 m
.294 .48618 L
s
.706 .48618 m
.71821 .48871 L
s
1 0 0 r
.48618 .706 m
.48871 .71821 L
s
.51382 .706 m
.51129 .71821 L
s
0 0 1 r
.41048 .30422 m
.42779 .30537 L
s
1 0 0 r
.30422 .41048 m
.30537 .42779 L
s
.69578 .41048 m
.69463 .42779 L
s
0 0 1 r
.57221 .30537 m
.58952 .30422 L
s
.28642 .52984 m
.29268 .51382 L
s
.70732 .51382 m
.71358 .52984 L
s
1 0 0 r
.51382 .70732 m
.52984 .71358 L
s
.48618 .70732 m
.47016 .71358 L
s
0 0 1 r
.31539 .38474 m
.33024 .37947 L
s
1 0 0 r
.38474 .31539 m
.37947 .33024 L
s
.61526 .31539 m
.62053 .33024 L
s
0 0 1 r
.66976 .37947 m
.68461 .38474 L
s
.2801 .48548 m
.29212 .48159 L
s
.70788 .48159 m
.7199 .48548 L
s
1 0 0 r
.48159 .70788 m
.48548 .7199 L
s
.51841 .70788 m
.51452 .7199 L
s
0 0 1 r
.38543 .31618 m
.40258 .31539 L
s
1 0 0 r
.31618 .38543 m
.31539 .40258 L
s
.68382 .38543 m
.68461 .40258 L
s
0 0 1 r
.59742 .31539 m
.61457 .31618 L
s
.29589 .42035 m
.30943 .41472 L
s
1 0 0 r
.42035 .29589 m
.41472 .30943 L
s
.57965 .29589 m
.58528 .30943 L
s
0 0 1 r
.69057 .41472 m
.70411 .42035 L
s
.36162 .33152 m
.37832 .32897 L
s
1 0 0 r
.33152 .36162 m
.32897 .37832 L
s
.66848 .36162 m
.67103 .37832 L
s
0 0 1 r
.62168 .32897 m
.63838 .33152 L
s
.27845 .48391 m
.29023 .47861 L
s
.70977 .47861 m
.72155 .48391 L
s
1 0 0 r
.47861 .70977 m
.48391 .72155 L
s
.52139 .70977 m
.51609 .72155 L
s
0 0 1 r
.28186 .52145 m
.289 .50618 L
s
.711 .50618 m
.71814 .52145 L
s
1 0 0 r
.50618 .711 m
.52145 .71814 L
s
.49382 .711 m
.47855 .71814 L
s
0 0 1 r
.28815 .55508 m
.29225 .53833 L
s
.70775 .53833 m
.71185 .55508 L
s
1 0 0 r
.53833 .70775 m
.55508 .71185 L
s
.46167 .70775 m
.44492 .71185 L
s
0 0 1 r
.3395 .34959 m
.3555 .34554 L
s
1 0 0 r
.34959 .3395 m
.34554 .3555 L
s
.65041 .3395 m
.65446 .3555 L
s
0 0 1 r
.6445 .34554 m
.6605 .34959 L
s
.27741 .47558 m
.2893 .47221 L
s
1 0 0 r
.47558 .27741 m
.47221 .2893 L
s
.52442 .27741 m
.52779 .2893 L
s
0 0 1 r
.7107 .47221 m
.72259 .47558 L
s
.27617 .48512 m
.28793 .48277 L
s
1 0 0 r
.48512 .27617 m
.48277 .28793 L
s
.51488 .27617 m
.51723 .28793 L
s
0 0 1 r
.71207 .48277 m
.72383 .48512 L
s
.27694 .48398 m
.28842 .47725 L
s
.71158 .47725 m
.72306 .48398 L
s
1 0 0 r
.47725 .71158 m
.48398 .72306 L
s
.52275 .71158 m
.51602 .72306 L
s
0 0 1 r
.29833 .40579 m
.31212 .39982 L
s
1 0 0 r
.40579 .29833 m
.39982 .31212 L
s
.59421 .29833 m
.60018 .31212 L
s
0 0 1 r
.68788 .39982 m
.70167 .40579 L
s
.27866 .46482 m
.29069 .46053 L
s
1 0 0 r
.46482 .27866 m
.46053 .29069 L
s
.53518 .27866 m
.53947 .29069 L
s
0 0 1 r
.70931 .46053 m
.72134 .46482 L
s
.27849 .51337 m
.28647 .49901 L
s
.71353 .49901 m
.72151 .51337 L
s
1 0 0 r
.49901 .71353 m
.51337 .72151 L
s
.50099 .71353 m
.48663 .72151 L
s
0 0 1 r
.27488 .4933 m
.28652 .49208 L
s
1 0 0 r
.4933 .27488 m
.49208 .28652 L
s
.5067 .27488 m
.50792 .28652 L
s
0 0 1 r
.71348 .49208 m
.72512 .4933 L
s
.31936 .36966 m
.33446 .36439 L
s
1 0 0 r
.36966 .31936 m
.36439 .33446 L
s
.63034 .31936 m
.63561 .33446 L
s
0 0 1 r
.66554 .36439 m
.68064 .36966 L
s
.27999 .45297 m
.29218 .44788 L
s
1 0 0 r
.45297 .27999 m
.44788 .29218 L
s
.54703 .27999 m
.55212 .29218 L
s
0 0 1 r
.70782 .44788 m
.72001 .45297 L
s
.27569 .48565 m
.28679 .47749 L
s
.71321 .47749 m
.72431 .48565 L
s
1 0 0 r
.47749 .71321 m
.48565 .72431 L
s
.52251 .71321 m
.51435 .72431 L
s
0 0 1 r
.27352 .5 m
.28503 .5 L
s
1 0 0 r
.5 .27352 m
.5 .28503 L
s
0 0 1 r
.71497 .5 m
.72648 .5 L
s
1 0 0 r
.5 .71497 m
.5 .72648 L
s
0 0 1 r
.27623 .50584 m
.28499 .49252 L
s
.71501 .49252 m
.72377 .50584 L
s
1 0 0 r
.49252 .71501 m
.50584 .72377 L
s
.50748 .71501 m
.49416 .72377 L
s
0 0 1 r
.39336 .30434 m
.41048 .30422 L
s
1 0 0 r
.30434 .39336 m
.30422 .41048 L
s
.69566 .39336 m
.69578 .41048 L
s
0 0 1 r
.58952 .30422 m
.60664 .30434 L
s
.27485 .48882 m
.28549 .47926 L
s
.71451 .47926 m
.72515 .48882 L
s
1 0 0 r
.47926 .71451 m
.48882 .72515 L
s
.52074 .71451 m
.51118 .72515 L
s
0 0 1 r
.28143 .54604 m
.28642 .52984 L
s
.71358 .52984 m
.71857 .54604 L
s
1 0 0 r
.52984 .71358 m
.54604 .71857 L
s
.47016 .71358 m
.45396 .71857 L
s
0 0 1 r
.27496 .4991 m
.28443 .48693 L
s
.71557 .48693 m
.72504 .4991 L
s
1 0 0 r
.48693 .71557 m
.4991 .72504 L
s
.51307 .71557 m
.5009 .72504 L
s
0 0 1 r
.27455 .49336 m
.28465 .48246 L
s
.71535 .48246 m
.72545 .49336 L
s
1 0 0 r
.48246 .71535 m
.49336 .72545 L
s
.51754 .71535 m
.50664 .72545 L
s
0 0 1 r
.28149 .4402 m
.29388 .43443 L
s
1 0 0 r
.4402 .28149 m
.43443 .29388 L
s
.5598 .28149 m
.56557 .29388 L
s
0 0 1 r
.70612 .43443 m
.71851 .4402 L
s
.36863 .31821 m
.38543 .31618 L
s
1 0 0 r
.31821 .36863 m
.31618 .38543 L
s
.68179 .36863 m
.68382 .38543 L
s
0 0 1 r
.61457 .31618 m
.63137 .31821 L
s
.27208 .49488 m
.28344 .49357 L
s
.71656 .49357 m
.72792 .49488 L
s
1 0 0 r
.49357 .71656 m
.49488 .72792 L
s
.50643 .71656 m
.50512 .72792 L
s
0 0 1 r
.30135 .39093 m
.31539 .38474 L
s
1 0 0 r
.39093 .30135 m
.38474 .31539 L
s
.60907 .30135 m
.61526 .31539 L
s
0 0 1 r
.68461 .38474 m
.69865 .39093 L
s
.34543 .33524 m
.36162 .33152 L
s
1 0 0 r
.33524 .34543 m
.33152 .36162 L
s
.66476 .34543 m
.66848 .36162 L
s
0 0 1 r
.63838 .33152 m
.65457 .33524 L
s
.27059 .4914 m
.28179 .48871 L
s
.71821 .48871 m
.72941 .4914 L
s
1 0 0 r
.48871 .71821 m
.4914 .72941 L
s
.51129 .71821 m
.5086 .72941 L
s
0 0 1 r
.71185 .55508 m
.71464 .57184 L
s
1 0 0 r
.55508 .71185 m
.57184 .71464 L
s
0 0 1 r
.28536 .57184 m
.28815 .55508 L
s
1 0 0 r
.44492 .71185 m
.42816 .71464 L
s
0 0 1 r
.28329 .42668 m
.29589 .42035 L
s
1 0 0 r
.42668 .28329 m
.42035 .29589 L
s
.57332 .28329 m
.57965 .29589 L
s
0 0 1 r
.70411 .42035 m
.71671 .42668 L
s
.27599 .53695 m
.28186 .52145 L
s
.71814 .52145 m
.72401 .53695 L
s
1 0 0 r
.52145 .71814 m
.53695 .72401 L
s
.47855 .71814 m
.46305 .72401 L
s
0 0 1 r
.32416 .35475 m
.3395 .34959 L
s
1 0 0 r
.35475 .32416 m
.34959 .3395 L
s
.64525 .32416 m
.65041 .3395 L
s
0 0 1 r
.6605 .34959 m
.67584 .35475 L
s
.26912 .48961 m
.2801 .48548 L
s
.7199 .48548 m
.73088 .48961 L
s
1 0 0 r
.48548 .7199 m
.48961 .73088 L
s
.51452 .7199 m
.51039 .73088 L
s
0 0 1 r
.27178 .52802 m
.27849 .51337 L
s
.72151 .51337 m
.72822 .52802 L
s
1 0 0 r
.51337 .72151 m
.52802 .72822 L
s
.48663 .72151 m
.47198 .72822 L
s
0 0 1 r
.26774 .48951 m
.27845 .48391 L
s
.72155 .48391 m
.73226 .48951 L
s
1 0 0 r
.48391 .72155 m
.48951 .73226 L
s
.51609 .72155 m
.51049 .73226 L
s
0 0 1 r
.28549 .41257 m
.29833 .40579 L
s
1 0 0 r
.41257 .28549 m
.40579 .29833 L
s
.58743 .28549 m
.59421 .29833 L
s
0 0 1 r
.70167 .40579 m
.71451 .41257 L
s
.30505 .37595 m
.31936 .36966 L
s
1 0 0 r
.37595 .30505 m
.36966 .31936 L
s
.62405 .30505 m
.63034 .31936 L
s
0 0 1 r
.68064 .36966 m
.69495 .37595 L
s
.37655 .30577 m
.39336 .30434 L
s
1 0 0 r
.30577 .37655 m
.30434 .39336 L
s
.69423 .37655 m
.69566 .39336 L
s
0 0 1 r
.60664 .30434 m
.62345 .30577 L
s
.27779 .56233 m
.28143 .54604 L
s
.71857 .54604 m
.72221 .56233 L
s
1 0 0 r
.54604 .71857 m
.56233 .72221 L
s
.45396 .71857 m
.43767 .72221 L
s
0 0 1 r
.26657 .49106 m
.27694 .48398 L
s
.72306 .48398 m
.73343 .49106 L
s
1 0 0 r
.48398 .72306 m
.49106 .73343 L
s
.51602 .72306 m
.50894 .73343 L
s
0 0 1 r
.26873 .5195 m
.27623 .50584 L
s
.72377 .50584 m
.73127 .5195 L
s
1 0 0 r
.50584 .72377 m
.5195 .73127 L
s
.49416 .72377 m
.4805 .73127 L
s
0 0 1 r
.2666 .47925 m
.27741 .47558 L
s
1 0 0 r
.47925 .2666 m
.47558 .27741 L
s
.52075 .2666 m
.52442 .27741 L
s
0 0 1 r
.72259 .47558 m
.7334 .47925 L
s
.2677 .4695 m
.27866 .46482 L
s
1 0 0 r
.4695 .2677 m
.46482 .27866 L
s
.5305 .2677 m
.53518 .27866 L
s
0 0 1 r
.72134 .46482 m
.7323 .4695 L
s
.3523 .32152 m
.36863 .31821 L
s
1 0 0 r
.32152 .3523 m
.31821 .36863 L
s
.67848 .3523 m
.68179 .36863 L
s
0 0 1 r
.63137 .31821 m
.6477 .32152 L
s
.26549 .48766 m
.27617 .48512 L
s
1 0 0 r
.48766 .26549 m
.48512 .27617 L
s
.51234 .26549 m
.51488 .27617 L
s
0 0 1 r
.72383 .48512 m
.73451 .48766 L
s
.26573 .49418 m
.27569 .48565 L
s
.72431 .48565 m
.73427 .49418 L
s
1 0 0 r
.48565 .72431 m
.49418 .73427 L
s
.51435 .72431 m
.50582 .73427 L
s
0 0 1 r
.26886 .45855 m
.27999 .45297 L
s
1 0 0 r
.45855 .26886 m
.45297 .27999 L
s
.54145 .26886 m
.54703 .27999 L
s
0 0 1 r
.72001 .45297 m
.73114 .45855 L
s
.26673 .51163 m
.27496 .4991 L
s
.72504 .4991 m
.73327 .51163 L
s
1 0 0 r
.4991 .72504 m
.51163 .73327 L
s
.5009 .72504 m
.48837 .73327 L
s
0 0 1 r
.26433 .49462 m
.27488 .4933 L
s
1 0 0 r
.49462 .26433 m
.4933 .27488 L
s
.50538 .26433 m
.5067 .27488 L
s
0 0 1 r
.72512 .4933 m
.73567 .49462 L
s
.26538 .49877 m
.27485 .48882 L
s
.72515 .48882 m
.73462 .49877 L
s
1 0 0 r
.48882 .72515 m
.49877 .73462 L
s
.51118 .72515 m
.50123 .73462 L
s
0 0 1 r
.26566 .50465 m
.27455 .49336 L
s
.72545 .49336 m
.73434 .50465 L
s
1 0 0 r
.49336 .72545 m
.50465 .73434 L
s
.50664 .72545 m
.49535 .73434 L
s
0 0 1 r
.32986 .34018 m
.34543 .33524 L
s
1 0 0 r
.34018 .32986 m
.33524 .34543 L
s
.65982 .32986 m
.66476 .34543 L
s
0 0 1 r
.65457 .33524 m
.67014 .34018 L
s
.71464 .57184 m
.71606 .58854 L
s
1 0 0 r
.57184 .71464 m
.58854 .71606 L
s
.42816 .71464 m
.41146 .71606 L
s
0 0 1 r
.28394 .58854 m
.28536 .57184 L
s
.26311 .5 m
.27352 .5 L
s
1 0 0 r
.5 .26311 m
.5 .27352 L
s
0 0 1 r
.72648 .5 m
.73689 .5 L
s
1 0 0 r
.5 .72648 m
.5 .73689 L
s
0 0 1 r
.27017 .44658 m
.28149 .4402 L
s
1 0 0 r
.44658 .27017 m
.4402 .28149 L
s
.55342 .27017 m
.5598 .28149 L
s
0 0 1 r
.71851 .4402 m
.72983 .44658 L
s
.28823 .39804 m
.30135 .39093 L
s
1 0 0 r
.39804 .28823 m
.39093 .30135 L
s
.60196 .28823 m
.60907 .30135 L
s
0 0 1 r
.69865 .39093 m
.71177 .39804 L
s
.27148 .55261 m
.27599 .53695 L
s
.72401 .53695 m
.72852 .55261 L
s
1 0 0 r
.53695 .72401 m
.55261 .72852 L
s
.46305 .72401 m
.44739 .72852 L
s
0 0 1 r
.26183 .49627 m
.27208 .49488 L
s
.72792 .49488 m
.73817 .49627 L
s
1 0 0 r
.49488 .72792 m
.49627 .73817 L
s
.50512 .72792 m
.50373 .73817 L
s
0 0 1 r
.30958 .36103 m
.32416 .35475 L
s
1 0 0 r
.36103 .30958 m
.35475 .32416 L
s
.63897 .30958 m
.64525 .32416 L
s
0 0 1 r
.67584 .35475 m
.69042 .36103 L
s
.27174 .43372 m
.28329 .42668 L
s
1 0 0 r
.43372 .27174 m
.42668 .28329 L
s
.56628 .27174 m
.57332 .28329 L
s
0 0 1 r
.71671 .42668 m
.72826 .43372 L
s
.26054 .49425 m
.27059 .4914 L
s
.72941 .4914 m
.73946 .49425 L
s
1 0 0 r
.4914 .72941 m
.49425 .73946 L
s
.5086 .72941 m
.50575 .73946 L
s
0 0 1 r
.26643 .54289 m
.27178 .52802 L
s
.72822 .52802 m
.73357 .54289 L
s
1 0 0 r
.52802 .72822 m
.54289 .73357 L
s
.47198 .72822 m
.45711 .73357 L
s
0 0 1 r
.36015 .30856 m
.37655 .30577 L
s
1 0 0 r
.30856 .36015 m
.30577 .37655 L
s
.69144 .36015 m
.69423 .37655 L
s
0 0 1 r
.62345 .30577 m
.63985 .30856 L
s
.72221 .56233 m
.72445 .57862 L
s
1 0 0 r
.56233 .72221 m
.57862 .72445 L
s
0 0 1 r
.27555 .57862 m
.27779 .56233 L
s
1 0 0 r
.43767 .72221 m
.42138 .72445 L
s
0 0 1 r
.29165 .38328 m
.30505 .37595 L
s
1 0 0 r
.38328 .29165 m
.37595 .30505 L
s
.61672 .29165 m
.62405 .30505 L
s
0 0 1 r
.69495 .37595 m
.70835 .38328 L
s
.25931 .49396 m
.26912 .48961 L
s
.73088 .48961 m
.74069 .49396 L
s
1 0 0 r
.48961 .73088 m
.49396 .74069 L
s
.51039 .73088 m
.50604 .74069 L
s
0 0 1 r
.27369 .42016 m
.28549 .41257 L
s
1 0 0 r
.42016 .27369 m
.41257 .28549 L
s
.57984 .27369 m
.58743 .28549 L
s
0 0 1 r
.71451 .41257 m
.72631 .42016 L
s
.33655 .32612 m
.3523 .32152 L
s
1 0 0 r
.32612 .33655 m
.32152 .3523 L
s
.67388 .33655 m
.67848 .3523 L
s
0 0 1 r
.6477 .32152 m
.66345 .32612 L
s
.26258 .53343 m
.26873 .5195 L
s
.73127 .5195 m
.73742 .53343 L
s
1 0 0 r
.5195 .73127 m
.53343 .73742 L
s
.4805 .73127 m
.46657 .73742 L
s
0 0 1 r
.25823 .49538 m
.26774 .48951 L
s
.73226 .48951 m
.74177 .49538 L
s
1 0 0 r
.48951 .73226 m
.49538 .74177 L
s
.51049 .73226 m
.50462 .74177 L
s
0 0 1 r
.31502 .34634 m
.32986 .34018 L
s
1 0 0 r
.34634 .31502 m
.34018 .32986 L
s
.65366 .31502 m
.65982 .32986 L
s
0 0 1 r
.67014 .34018 m
.68498 .34634 L
s
.71606 .58854 m
.71603 .60508 L
s
1 0 0 r
.58854 .71606 m
.60508 .71603 L
s
.41146 .71606 m
.39492 .71603 L
s
0 0 1 r
.28397 .60508 m
.28394 .58854 L
s
.25983 .52447 m
.26673 .51163 L
s
.73327 .51163 m
.74017 .52447 L
s
1 0 0 r
.51163 .73327 m
.52447 .74017 L
s
.48837 .73327 m
.47553 .74017 L
s
0 0 1 r
.25742 .49845 m
.26657 .49106 L
s
.73343 .49106 m
.74258 .49845 L
s
1 0 0 r
.49106 .73343 m
.49845 .74258 L
s
.50894 .73343 m
.50155 .74258 L
s
0 0 1 r
.25792 .47456 m
.2677 .4695 L
s
1 0 0 r
.47456 .25792 m
.4695 .2677 L
s
.52544 .25792 m
.5305 .2677 L
s
0 0 1 r
.7323 .4695 m
.74208 .47456 L
s
.25698 .48319 m
.2666 .47925 L
s
1 0 0 r
.48319 .25698 m
.47925 .2666 L
s
.51681 .25698 m
.52075 .2666 L
s
0 0 1 r
.7334 .47925 m
.74302 .48319 L
s
.25703 .50305 m
.26573 .49418 L
s
.73427 .49418 m
.74297 .50305 L
s
1 0 0 r
.49418 .73427 m
.50305 .74297 L
s
.50582 .73427 m
.49695 .74297 L
s
0 0 1 r
.25809 .51627 m
.26566 .50465 L
s
.73434 .50465 m
.74191 .51627 L
s
1 0 0 r
.50465 .73434 m
.51627 .74191 L
s
.49535 .73434 m
.48373 .74191 L
s
0 0 1 r
.26841 .56834 m
.27148 .55261 L
s
.72852 .55261 m
.73159 .56834 L
s
1 0 0 r
.55261 .72852 m
.56834 .73159 L
s
.44739 .72852 m
.43166 .73159 L
s
0 0 1 r
.2572 .50906 m
.26538 .49877 L
s
.73462 .49877 m
.7428 .50906 L
s
1 0 0 r
.49877 .73462 m
.50906 .7428 L
s
.50123 .73462 m
.49094 .7428 L
s
0 0 1 r
.25891 .46462 m
.26886 .45855 L
s
1 0 0 r
.46462 .25891 m
.45855 .26886 L
s
.53538 .25891 m
.54145 .26886 L
s
0 0 1 r
.73114 .45855 m
.74109 .46462 L
s
.25601 .49039 m
.26549 .48766 L
s
1 0 0 r
.49039 .25601 m
.48766 .26549 L
s
.50961 .25601 m
.51234 .26549 L
s
0 0 1 r
.73451 .48766 m
.74399 .49039 L
s
.27616 .40607 m
.28823 .39804 L
s
1 0 0 r
.40607 .27616 m
.39804 .28823 L
s
.59393 .27616 m
.60196 .28823 L
s
0 0 1 r
.71177 .39804 m
.72384 .40607 L
s
.255 .49602 m
.26433 .49462 L
s
1 0 0 r
.49602 .255 m
.49462 .26433 L
s
.50398 .255 m
.50538 .26433 L
s
0 0 1 r
.73567 .49462 m
.745 .49602 L
s
.29588 .36845 m
.30958 .36103 L
s
1 0 0 r
.36845 .29588 m
.36103 .30958 L
s
.63155 .29588 m
.63897 .30958 L
s
0 0 1 r
.69042 .36103 m
.70412 .36845 L
s
.26003 .45354 m
.27017 .44658 L
s
1 0 0 r
.45354 .26003 m
.44658 .27017 L
s
.54646 .26003 m
.55342 .27017 L
s
0 0 1 r
.72983 .44658 m
.73997 .45354 L
s
.25393 .5 m
.26311 .5 L
s
1 0 0 r
.5 .25393 m
.5 .26311 L
s
0 0 1 r
.73689 .5 m
.74607 .5 L
s
1 0 0 r
.5 .73689 m
.5 .74607 L
s
0 0 1 r
.34426 .31273 m
.36015 .30856 L
s
1 0 0 r
.31273 .34426 m
.30856 .36015 L
s
.68727 .34426 m
.69144 .36015 L
s
0 0 1 r
.63985 .30856 m
.65574 .31273 L
s
.26254 .5579 m
.26643 .54289 L
s
.73357 .54289 m
.73746 .5579 L
s
1 0 0 r
.54289 .73357 m
.5579 .73746 L
s
.45711 .73357 m
.4421 .73746 L
s
0 0 1 r
.26138 .44146 m
.27174 .43372 L
s
1 0 0 r
.44146 .26138 m
.43372 .27174 L
s
.55854 .26138 m
.56628 .27174 L
s
0 0 1 r
.72826 .43372 m
.73862 .44146 L
s
.72445 .57862 m
.7252 .59482 L
s
1 0 0 r
.57862 .72445 m
.59482 .7252 L
s
.42138 .72445 m
.40518 .7252 L
s
0 0 1 r
.2748 .59482 m
.27555 .57862 L
s
.25283 .49775 m
.26183 .49627 L
s
.73817 .49627 m
.74717 .49775 L
s
1 0 0 r
.49627 .73817 m
.49775 .74717 L
s
.50373 .73817 m
.50225 .74717 L
s
0 0 1 r
.32148 .33205 m
.33655 .32612 L
s
1 0 0 r
.33205 .32148 m
.32612 .33655 L
s
.66795 .32148 m
.67388 .33655 L
s
0 0 1 r
.66345 .32612 m
.67852 .33205 L
s
.27928 .39163 m
.29165 .38328 L
s
1 0 0 r
.39163 .27928 m
.38328 .29165 L
s
.60837 .27928 m
.61672 .29165 L
s
0 0 1 r
.70835 .38328 m
.72072 .39163 L
s
.25176 .49726 m
.26054 .49425 L
s
.73946 .49425 m
.74824 .49726 L
s
1 0 0 r
.49425 .73946 m
.49726 .74824 L
s
.50575 .73946 m
.50274 .74824 L
s
0 0 1 r
.25788 .54756 m
.26258 .53343 L
s
.73742 .53343 m
.74212 .54756 L
s
1 0 0 r
.53343 .73742 m
.54756 .74212 L
s
.46657 .73742 m
.45244 .74212 L
s
0 0 1 r
.26307 .42857 m
.27369 .42016 L
s
1 0 0 r
.42857 .26307 m
.42016 .27369 L
s
.57143 .26307 m
.57984 .27369 L
s
0 0 1 r
.72631 .42016 m
.73693 .42857 L
s
.71603 .60508 m
.71451 .62134 L
s
1 0 0 r
.60508 .71603 m
.62134 .71451 L
s
.39492 .71603 m
.37866 .71451 L
s
0 0 1 r
.28549 .62134 m
.28397 .60508 L
s
.30104 .35374 m
.31502 .34634 L
s
1 0 0 r
.35374 .30104 m
.34634 .31502 L
s
.64626 .30104 m
.65366 .31502 L
s
0 0 1 r
.68498 .34634 m
.69896 .35374 L
s
.25079 .49853 m
.25931 .49396 L
s
.74069 .49396 m
.74921 .49853 L
s
1 0 0 r
.49396 .74069 m
.49853 .74921 L
s
.50604 .74069 m
.50147 .74921 L
s
0 0 1 r
.25439 .53756 m
.25983 .52447 L
s
.74017 .52447 m
.74561 .53756 L
s
1 0 0 r
.52447 .74017 m
.53756 .74561 L
s
.47553 .74017 m
.46244 .74561 L
s
0 0 1 r
.73159 .56834 m
.73314 .58405 L
s
1 0 0 r
.56834 .73159 m
.58405 .73314 L
s
0 0 1 r
.26686 .58405 m
.26841 .56834 L
s
1 0 0 r
.43166 .73159 m
.41595 .73314 L
s
0 0 1 r
.25004 .50151 m
.25823 .49538 L
s
.74177 .49538 m
.74996 .50151 L
s
1 0 0 r
.49538 .74177 m
.50151 .74996 L
s
.50462 .74177 m
.49849 .74996 L
s
0 0 1 r
.25194 .52817 m
.25809 .51627 L
s
.74191 .51627 m
.74806 .52817 L
s
1 0 0 r
.51627 .74191 m
.52817 .74806 L
s
.48373 .74191 m
.47183 .74806 L
s
0 0 1 r
.24963 .50612 m
.25742 .49845 L
s
.74258 .49845 m
.75037 .50612 L
s
1 0 0 r
.49845 .74258 m
.50612 .75037 L
s
.50155 .74258 m
.49388 .75037 L
s
0 0 1 r
.26525 .41502 m
.27616 .40607 L
s
1 0 0 r
.41502 .26525 m
.40607 .27616 L
s
.58498 .26525 m
.59393 .27616 L
s
0 0 1 r
.72384 .40607 m
.73475 .41502 L
s
.28319 .37701 m
.29588 .36845 L
s
1 0 0 r
.37701 .28319 m
.36845 .29588 L
s
.62299 .28319 m
.63155 .29588 L
s
0 0 1 r
.70412 .36845 m
.71681 .37701 L
s
.25043 .51965 m
.2572 .50906 L
s
.7428 .50906 m
.74957 .51965 L
s
1 0 0 r
.50906 .7428 m
.51965 .74957 L
s
.49094 .7428 m
.48035 .74957 L
s
0 0 1 r
.24971 .51223 m
.25703 .50305 L
s
.74297 .50305 m
.75029 .51223 L
s
1 0 0 r
.50305 .74297 m
.51223 .75029 L
s
.49695 .74297 m
.48777 .75029 L
s
0 0 1 r
.24947 .48 m
.25792 .47456 L
s
1 0 0 r
.48 .24947 m
.47456 .25792 L
s
.52 .24947 m
.52544 .25792 L
s
0 0 1 r
.74208 .47456 m
.75053 .48 L
s
.32902 .31833 m
.34426 .31273 L
s
1 0 0 r
.31833 .32902 m
.31273 .34426 L
s
.68167 .32902 m
.68727 .34426 L
s
0 0 1 r
.65574 .31273 m
.67098 .31833 L
s
.24868 .48741 m
.25698 .48319 L
s
1 0 0 r
.48741 .24868 m
.48319 .25698 L
s
.51259 .24868 m
.51681 .25698 L
s
0 0 1 r
.74302 .48319 m
.75132 .48741 L
s
.25028 .47117 m
.25891 .46462 L
s
1 0 0 r
.47117 .25028 m
.46462 .25891 L
s
.52883 .25028 m
.53538 .25891 L
s
0 0 1 r
.74109 .46462 m
.74972 .47117 L
s
.24787 .49329 m
.25601 .49039 L
s
1 0 0 r
.49329 .24787 m
.49039 .25601 L
s
.50671 .24787 m
.50961 .25601 L
s
0 0 1 r
.74399 .49039 m
.75213 .49329 L
s
.7252 .59482 m
.7244 .61082 L
s
1 0 0 r
.59482 .7252 m
.61082 .7244 L
s
.40518 .7252 m
.38918 .7244 L
s
0 0 1 r
.2756 .61082 m
.2748 .59482 L
s
.26018 .57297 m
.26254 .5579 L
s
.73746 .5579 m
.73982 .57297 L
s
1 0 0 r
.5579 .73746 m
.57297 .73982 L
s
.4421 .73746 m
.42703 .73982 L
s
0 0 1 r
.2512 .46108 m
.26003 .45354 L
s
1 0 0 r
.46108 .2512 m
.45354 .26003 L
s
.53892 .2512 m
.54646 .26003 L
s
0 0 1 r
.73997 .45354 m
.7488 .46108 L
s
.24701 .49751 m
.255 .49602 L
s
1 0 0 r
.49751 .24701 m
.49602 .255 L
s
.50249 .24701 m
.50398 .255 L
s
0 0 1 r
.745 .49602 m
.75299 .49751 L
s
.30723 .33933 m
.32148 .33205 L
s
1 0 0 r
.33933 .30723 m
.33205 .32148 L
s
.66067 .30723 m
.66795 .32148 L
s
0 0 1 r
.67852 .33205 m
.69277 .33933 L
s
.25232 .44989 m
.26138 .44146 L
s
1 0 0 r
.44989 .25232 m
.44146 .26138 L
s
.55011 .25232 m
.55854 .26138 L
s
0 0 1 r
.73862 .44146 m
.74768 .44989 L
s
.26806 .40101 m
.27928 .39163 L
s
1 0 0 r
.40101 .26806 m
.39163 .27928 L
s
.59899 .26806 m
.60837 .27928 L
s
0 0 1 r
.72072 .39163 m
.73194 .40101 L
s
.24611 .5 m
.25393 .5 L
s
1 0 0 r
.5 .24611 m
.5 .25393 L
s
0 0 1 r
.74607 .5 m
.75389 .5 L
s
1 0 0 r
.5 .74607 m
.5 .75389 L
s
0 0 1 r
.71451 .62134 m
.71144 .63722 L
s
1 0 0 r
.62134 .71451 m
.63722 .71144 L
s
.37866 .71451 m
.36278 .71144 L
s
0 0 1 r
.28856 .63722 m
.28549 .62134 L
s
.25474 .56181 m
.25788 .54756 L
s
.74212 .54756 m
.74526 .56181 L
s
1 0 0 r
.54756 .74212 m
.56181 .74526 L
s
.45244 .74212 m
.43819 .74526 L
s
0 0 1 r
.28803 .3624 m
.30104 .35374 L
s
1 0 0 r
.3624 .28803 m
.35374 .30104 L
s
.6376 .28803 m
.64626 .30104 L
s
0 0 1 r
.69896 .35374 m
.71197 .3624 L
s
.24521 .4993 m
.25283 .49775 L
s
.74717 .49775 m
.75479 .4993 L
s
1 0 0 r
.49775 .74717 m
.4993 .75479 L
s
.50225 .74717 m
.5007 .75479 L
s
0 0 1 r
.25376 .43777 m
.26307 .42857 L
s
1 0 0 r
.43777 .25376 m
.42857 .26307 L
s
.56223 .25376 m
.57143 .26307 L
s
0 0 1 r
.73693 .42857 m
.74624 .43777 L
s
.73314 .58405 m
.73309 .59965 L
s
1 0 0 r
.58405 .73314 m
.59965 .73309 L
s
.41595 .73314 m
.40035 .73309 L
s
0 0 1 r
.26691 .59965 m
.26686 .58405 L
s
.24438 .5004 m
.25176 .49726 L
s
.74824 .49726 m
.75562 .5004 L
s
1 0 0 r
.49726 .74824 m
.5004 .75562 L
s
.50274 .74824 m
.4996 .75562 L
s
0 0 1 r
.25049 .55082 m
.25439 .53756 L
s
.74561 .53756 m
.74951 .55082 L
s
1 0 0 r
.53756 .74561 m
.55082 .74951 L
s
.46244 .74561 m
.44918 .74951 L
s
0 0 1 r
.2437 .50329 m
.25079 .49853 L
s
.74921 .49853 m
.7563 .50329 L
s
1 0 0 r
.49853 .74921 m
.50329 .7563 L
s
.50147 .74921 m
.49671 .7563 L
s
0 0 1 r
.27164 .38671 m
.28319 .37701 L
s
1 0 0 r
.38671 .27164 m
.37701 .28319 L
s
.61329 .27164 m
.62299 .28319 L
s
0 0 1 r
.71681 .37701 m
.72836 .38671 L
s
.31454 .32538 m
.32902 .31833 L
s
1 0 0 r
.32538 .31454 m
.31833 .32902 L
s
.67462 .31454 m
.68167 .32902 L
s
0 0 1 r
.67098 .31833 m
.68546 .32538 L
s
.24734 .54029 m
.25194 .52817 L
s
.74806 .52817 m
.75266 .54029 L
s
1 0 0 r
.52817 .74806 m
.54029 .75266 L
s
.47183 .74806 m
.45971 .75266 L
s
0 0 1 r
.25564 .42488 m
.26525 .41502 L
s
1 0 0 r
.42488 .25564 m
.41502 .26525 L
s
.57512 .25564 m
.58498 .26525 L
s
0 0 1 r
.73475 .41502 m
.74436 .42488 L
s
.2433 .50788 m
.25004 .50151 L
s
.74996 .50151 m
.7567 .50788 L
s
1 0 0 r
.50151 .74996 m
.50788 .7567 L
s
.49849 .74996 m
.49212 .7567 L
s
0 0 1 r
.7244 .61082 m
.72199 .62652 L
s
1 0 0 r
.61082 .7244 m
.62652 .72199 L
s
.38918 .7244 m
.37348 .72199 L
s
0 0 1 r
.27801 .62652 m
.2756 .61082 L
s
.24519 .53048 m
.25043 .51965 L
s
.74957 .51965 m
.75481 .53048 L
s
1 0 0 r
.51965 .74957 m
.53048 .75481 L
s
.48035 .74957 m
.46952 .75481 L
s
0 0 1 r
.24332 .51406 m
.24963 .50612 L
s
.75037 .50612 m
.75668 .51406 L
s
1 0 0 r
.50612 .75037 m
.51406 .75668 L
s
.49388 .75037 m
.48594 .75668 L
s
0 0 1 r
.2439 .52166 m
.24971 .51223 L
s
.75029 .51223 m
.7561 .52166 L
s
1 0 0 r
.51223 .75029 m
.52166 .7561 L
s
.48777 .75029 m
.47834 .7561 L
s
0 0 1 r
.73982 .57297 m
.74054 .58799 L
s
1 0 0 r
.57297 .73982 m
.58799 .74054 L
s
0 0 1 r
.25946 .58799 m
.26018 .57297 L
s
1 0 0 r
.42703 .73982 m
.41201 .74054 L
s
0 0 1 r
.29392 .34796 m
.30723 .33933 L
s
1 0 0 r
.34796 .29392 m
.33933 .30723 L
s
.65204 .29392 m
.66067 .30723 L
s
0 0 1 r
.69277 .33933 m
.70608 .34796 L
s
.24246 .48579 m
.24947 .48 L
s
1 0 0 r
.48579 .24246 m
.48 .24947 L
s
.51421 .24246 m
.52 .24947 L
s
0 0 1 r
.75053 .48 m
.75754 .48579 L
s
.2431 .47818 m
.25028 .47117 L
s
1 0 0 r
.47818 .2431 m
.47117 .25028 L
s
.52182 .2431 m
.52883 .25028 L
s
0 0 1 r
.74972 .47117 m
.7569 .47818 L
s
.24184 .49189 m
.24868 .48741 L
s
1 0 0 r
.49189 .24184 m
.48741 .24868 L
s
.50811 .24184 m
.51259 .24868 L
s
0 0 1 r
.75132 .48741 m
.75816 .49189 L
s
.24381 .46919 m
.2512 .46108 L
s
1 0 0 r
.46919 .24381 m
.46108 .2512 L
s
.53081 .24381 m
.53892 .2512 L
s
0 0 1 r
.7488 .46108 m
.75619 .46919 L
s
.71144 .63722 m
.70678 .65258 L
s
1 0 0 r
.63722 .71144 m
.65258 .70678 L
s
.36278 .71144 m
.34742 .70678 L
s
0 0 1 r
.29322 .65258 m
.28856 .63722 L
s
.25813 .41141 m
.26806 .40101 L
s
1 0 0 r
.41141 .25813 m
.40101 .26806 L
s
.58859 .25813 m
.59899 .26806 L
s
0 0 1 r
.73194 .40101 m
.74187 .41141 L
s
.24119 .49636 m
.24787 .49329 L
s
1 0 0 r
.49636 .24119 m
.49329 .24787 L
s
.50364 .24119 m
.50671 .24787 L
s
0 0 1 r
.75213 .49329 m
.75881 .49636 L
s
.2447 .45899 m
.25232 .44989 L
s
1 0 0 r
.45899 .2447 m
.44989 .25232 L
s
.54101 .2447 m
.55011 .25232 L
s
0 0 1 r
.74768 .44989 m
.7553 .45899 L
s
.27614 .3723 m
.28803 .3624 L
s
1 0 0 r
.3723 .27614 m
.3624 .28803 L
s
.6277 .27614 m
.6376 .28803 L
s
0 0 1 r
.71197 .3624 m
.72386 .3723 L
s
.25325 .57608 m
.25474 .56181 L
s
.74526 .56181 m
.74675 .57608 L
s
1 0 0 r
.56181 .74526 m
.57608 .74675 L
s
.43819 .74526 m
.42392 .74675 L
s
0 0 1 r
.2405 .49908 m
.24701 .49751 L
s
1 0 0 r
.49908 .2405 m
.49751 .24701 L
s
.50092 .2405 m
.50249 .24701 L
s
0 0 1 r
.75299 .49751 m
.7595 .49908 L
s
.73309 .59965 m
.73137 .61501 L
s
1 0 0 r
.59965 .73309 m
.61501 .73137 L
s
.40035 .73309 m
.38499 .73137 L
s
0 0 1 r
.26863 .61501 m
.26691 .59965 L
s
.23979 .5 m
.24611 .5 L
s
1 0 0 r
.5 .23979 m
.5 .24611 L
s
0 0 1 r
.75389 .5 m
.76021 .5 L
s
1 0 0 r
.5 .75389 m
.5 .76021 L
s
0 0 1 r
.24587 .44774 m
.25376 .43777 L
s
1 0 0 r
.44774 .24587 m
.43777 .25376 L
s
.55226 .24587 m
.56223 .25376 L
s
0 0 1 r
.74624 .43777 m
.75413 .44774 L
s
.24826 .56418 m
.25049 .55082 L
s
.74951 .55082 m
.75174 .56418 L
s
1 0 0 r
.55082 .74951 m
.56418 .75174 L
s
.44918 .74951 m
.43582 .75174 L
s
0 0 1 r
.30096 .33389 m
.31454 .32538 L
s
1 0 0 r
.33389 .30096 m
.32538 .31454 L
s
.66611 .30096 m
.67462 .31454 L
s
0 0 1 r
.68546 .32538 m
.69904 .33389 L
s
.23911 .50092 m
.24521 .4993 L
s
.75479 .4993 m
.76089 .50092 L
s
1 0 0 r
.4993 .75479 m
.50092 .76089 L
s
.5007 .75479 m
.49908 .76089 L
s
0 0 1 r
.26137 .39753 m
.27164 .38671 L
s
1 0 0 r
.39753 .26137 m
.38671 .27164 L
s
.60247 .26137 m
.61329 .27164 L
s
0 0 1 r
.72836 .38671 m
.73863 .39753 L
s
.72199 .62652 m
.7179 .64178 L
s
1 0 0 r
.62652 .72199 m
.64178 .7179 L
s
.37348 .72199 m
.35822 .7179 L
s
0 0 1 r
.2821 .64178 m
.27801 .62652 L
s
.23854 .50368 m
.24438 .5004 L
s
.75562 .5004 m
.76146 .50368 L
s
1 0 0 r
.5004 .75562 m
.50368 .76146 L
s
.4996 .75562 m
.49632 .76146 L
s
0 0 1 r
.24746 .43562 m
.25564 .42488 L
s
1 0 0 r
.43562 .24746 m
.42488 .25564 L
s
.56438 .24746 m
.57512 .25564 L
s
0 0 1 r
.74436 .42488 m
.75254 .43562 L
s
.24441 .55256 m
.24734 .54029 L
s
.75266 .54029 m
.75559 .55256 L
s
1 0 0 r
.54029 .75266 m
.55256 .75559 L
s
.45971 .75266 m
.44744 .75559 L
s
0 0 1 r
.28169 .35796 m
.29392 .34796 L
s
1 0 0 r
.35796 .28169 m
.34796 .29392 L
s
.64204 .28169 m
.65204 .29392 L
s
0 0 1 r
.70608 .34796 m
.71831 .35796 L
s
.74054 .58799 m
.73955 .60286 L
s
1 0 0 r
.58799 .74054 m
.60286 .73955 L
s
.41201 .74054 m
.39714 .73955 L
s
0 0 1 r
.26045 .60286 m
.25946 .58799 L
s
.23818 .50822 m
.2437 .50329 L
s
.7563 .50329 m
.76182 .50822 L
s
1 0 0 r
.50329 .7563 m
.50822 .76182 L
s
.49671 .7563 m
.49178 .76182 L
s
0 0 1 r
.2416 .54151 m
.24519 .53048 L
s
.75481 .53048 m
.7584 .54151 L
s
1 0 0 r
.53048 .75481 m
.54151 .7584 L
s
.46952 .75481 m
.45849 .7584 L
s
0 0 1 r
.23816 .51445 m
.2433 .50788 L
s
.7567 .50788 m
.76184 .51445 L
s
1 0 0 r
.50788 .7567 m
.51445 .76184 L
s
.49212 .7567 m
.48555 .76184 L
s
0 0 1 r
.70678 .65258 m
.70048 .66731 L
s
1 0 0 r
.65258 .70678 m
.66731 .70048 L
s
.34742 .70678 m
.33269 .70048 L
s
0 0 1 r
.29952 .66731 m
.29322 .65258 L
s
.23972 .5313 m
.2439 .52166 L
s
.7561 .52166 m
.76028 .5313 L
s
1 0 0 r
.52166 .7561 m
.5313 .76028 L
s
.47834 .7561 m
.4687 .76028 L
s
0 0 1 r
.23862 .5222 m
.24332 .51406 L
s
.75668 .51406 m
.76138 .5222 L
s
1 0 0 r
.51406 .75668 m
.5222 .76138 L
s
.48594 .75668 m
.4778 .76138 L
s
0 0 1 r
.24962 .4228 m
.25813 .41141 L
s
1 0 0 r
.4228 .24962 m
.41141 .25813 L
s
.5772 .24962 m
.58859 .25813 L
s
0 0 1 r
.74187 .41141 m
.75038 .4228 L
s
.2655 .38344 m
.27614 .3723 L
s
1 0 0 r
.38344 .2655 m
.3723 .27614 L
s
.61656 .2655 m
.6277 .27614 L
s
0 0 1 r
.72386 .3723 m
.7345 .38344 L
s
.2375 .48563 m
.2431 .47818 L
s
1 0 0 r
.48563 .2375 m
.47818 .2431 L
s
.51437 .2375 m
.52182 .2431 L
s
0 0 1 r
.7569 .47818 m
.7625 .48563 L
s
.23705 .49193 m
.24246 .48579 L
s
1 0 0 r
.49193 .23705 m
.48579 .24246 L
s
.50807 .23705 m
.51421 .24246 L
s
0 0 1 r
.75754 .48579 m
.76295 .49193 L
s
.23801 .47784 m
.24381 .46919 L
s
1 0 0 r
.47784 .23801 m
.46919 .24381 L
s
.52216 .23801 m
.53081 .24381 L
s
0 0 1 r
.75619 .46919 m
.76199 .47784 L
s
.74675 .57608 m
.74649 .59028 L
s
1 0 0 r
.57608 .74675 m
.59028 .74649 L
s
0 0 1 r
.25351 .59028 m
.25325 .57608 L
s
1 0 0 r
.42392 .74675 m
.40972 .74649 L
s
0 0 1 r
.2366 .49662 m
.24184 .49189 L
s
1 0 0 r
.49662 .2366 m
.49189 .24184 L
s
.50338 .2366 m
.50811 .24184 L
s
0 0 1 r
.75816 .49189 m
.7634 .49662 L
s
.73137 .61501 m
.72792 .63002 L
s
1 0 0 r
.61501 .73137 m
.63002 .72792 L
s
.38499 .73137 m
.36998 .72792 L
s
0 0 1 r
.27208 .63002 m
.26863 .61501 L
s
.23866 .46874 m
.2447 .45899 L
s
1 0 0 r
.46874 .23866 m
.45899 .2447 L
s
.53126 .23866 m
.54101 .2447 L
s
0 0 1 r
.7553 .45899 m
.76134 .46874 L
s
.23613 .49958 m
.24119 .49636 L
s
1 0 0 r
.49958 .23613 m
.49636 .24119 L
s
.50042 .23613 m
.50364 .24119 L
s
0 0 1 r
.75881 .49636 m
.76387 .49958 L
s
.28841 .34387 m
.30096 .33389 L
s
1 0 0 r
.34387 .28841 m
.33389 .30096 L
s
.65613 .28841 m
.66611 .30096 L
s
0 0 1 r
.69904 .33389 m
.71159 .34387 L
s
.23956 .45847 m
.24587 .44774 L
s
1 0 0 r
.45847 .23956 m
.44774 .24587 L
s
.54153 .23956 m
.55226 .24587 L
s
0 0 1 r
.75413 .44774 m
.76044 .45847 L
s
.23562 .50073 m
.2405 .49908 L
s
1 0 0 r
.50073 .23562 m
.49908 .2405 L
s
.49927 .23562 m
.50092 .2405 L
s
0 0 1 r
.7595 .49908 m
.76438 .50073 L
s
.25249 .40946 m
.26137 .39753 L
s
1 0 0 r
.40946 .25249 m
.39753 .26137 L
s
.59054 .25249 m
.60247 .26137 L
s
0 0 1 r
.73863 .39753 m
.74751 .40946 L
s
.24779 .57754 m
.24826 .56418 L
s
.75174 .56418 m
.75221 .57754 L
s
1 0 0 r
.56418 .75174 m
.57754 .75221 L
s
.43582 .75174 m
.42246 .75221 L
s
0 0 1 r
.7179 .64178 m
.71209 .65647 L
s
1 0 0 r
.64178 .7179 m
.65647 .71209 L
s
.35822 .7179 m
.34353 .71209 L
s
0 0 1 r
.28791 .65647 m
.2821 .64178 L
s
.23511 .5 m
.23979 .5 L
s
1 0 0 r
.5 .23511 m
.5 .23979 L
s
0 0 1 r
.76021 .5 m
.76489 .5 L
s
1 0 0 r
.5 .76021 m
.5 .76489 L
s
0 0 1 r
.27068 .36931 m
.28169 .35796 L
s
1 0 0 r
.36931 .27068 m
.35796 .28169 L
s
.63069 .27068 m
.64204 .28169 L
s
0 0 1 r
.71831 .35796 m
.72932 .36931 L
s
.24085 .44721 m
.24746 .43562 L
s
1 0 0 r
.44721 .24085 m
.43562 .24746 L
s
.55279 .24085 m
.56438 .24746 L
s
0 0 1 r
.75254 .43562 m
.75915 .44721 L
s
.73955 .60286 m
.73677 .61747 L
s
1 0 0 r
.60286 .73955 m
.61747 .73677 L
s
.39714 .73955 m
.38253 .73677 L
s
0 0 1 r
.26323 .61747 m
.26045 .60286 L
s
.23467 .50261 m
.23911 .50092 L
s
.76089 .50092 m
.76533 .50261 L
s
1 0 0 r
.50092 .76089 m
.50261 .76533 L
s
.49908 .76089 m
.49739 .76533 L
s
0 0 1 r
.24324 .56489 m
.24441 .55256 L
s
.75559 .55256 m
.75676 .56489 L
s
1 0 0 r
.55256 .75559 m
.56489 .75676 L
s
.44744 .75559 m
.43511 .75676 L
s
0 0 1 r
.70048 .66731 m
.69251 .68126 L
s
1 0 0 r
.66731 .70048 m
.68126 .69251 L
s
.33269 .70048 m
.31874 .69251 L
s
0 0 1 r
.30749 .68126 m
.29952 .66731 L
s
.23438 .50707 m
.23854 .50368 L
s
.76146 .50368 m
.76562 .50707 L
s
1 0 0 r
.50368 .76146 m
.50707 .76562 L
s
.49632 .76146 m
.49293 .76562 L
s
0 0 1 r
.23978 .55264 m
.2416 .54151 L
s
.7584 .54151 m
.76022 .55264 L
s
1 0 0 r
.54151 .7584 m
.55264 .76022 L
s
.45849 .7584 m
.44736 .76022 L
s
0 0 1 r
.25625 .3958 m
.2655 .38344 L
s
1 0 0 r
.3958 .25625 m
.38344 .2655 L
s
.6042 .25625 m
.61656 .2655 L
s
0 0 1 r
.7345 .38344 m
.74375 .3958 L
s
.23436 .51331 m
.23818 .50822 L
s
.76182 .50822 m
.76564 .51331 L
s
1 0 0 r
.50822 .76182 m
.51331 .76564 L
s
.49178 .76182 m
.48669 .76564 L
s
0 0 1 r
.24266 .43515 m
.24962 .4228 L
s
1 0 0 r
.43515 .24266 m
.4228 .24962 L
s
.56485 .24266 m
.5772 .24962 L
s
0 0 1 r
.75038 .4228 m
.75734 .43515 L
s
.2373 .54109 m
.23972 .5313 L
s
.76028 .5313 m
.7627 .54109 L
s
1 0 0 r
.5313 .76028 m
.54109 .7627 L
s
.4687 .76028 m
.45891 .7627 L
s
0 0 1 r
.23474 .52118 m
.23816 .51445 L
s
.76184 .51445 m
.76526 .52118 L
s
1 0 0 r
.51445 .76184 m
.52118 .76526 L
s
.48555 .76184 m
.47882 .76526 L
s
0 0 1 r
.23567 .53052 m
.23862 .5222 L
s
.76138 .5222 m
.76433 .53052 L
s
1 0 0 r
.5222 .76138 m
.53052 .76433 L
s
.4778 .76138 m
.46948 .76433 L
s
0 0 1 r
.72792 .63002 m
.72268 .64456 L
s
1 0 0 r
.63002 .72792 m
.64456 .72268 L
s
.36998 .72792 m
.35544 .72268 L
s
0 0 1 r
.27732 .64456 m
.27208 .63002 L
s
.74649 .59028 m
.74441 .60431 L
s
1 0 0 r
.59028 .74649 m
.60431 .74441 L
s
.40972 .74649 m
.39569 .74441 L
s
0 0 1 r
.25559 .60431 m
.25351 .59028 L
s
.23362 .49349 m
.2375 .48563 L
s
1 0 0 r
.49349 .23362 m
.48563 .2375 L
s
.50651 .23362 m
.51437 .2375 L
s
0 0 1 r
.7625 .48563 m
.76638 .49349 L
s
.23391 .487 m
.23801 .47784 L
s
1 0 0 r
.487 .23391 m
.47784 .23801 L
s
.513 .23391 m
.52216 .23801 L
s
0 0 1 r
.76199 .47784 m
.76609 .487 L
s
.27705 .35532 m
.28841 .34387 L
s
1 0 0 r
.35532 .27705 m
.34387 .28841 L
s
.64468 .27705 m
.65613 .28841 L
s
0 0 1 r
.71159 .34387 m
.72295 .35532 L
s
.23337 .49839 m
.23705 .49193 L
s
1 0 0 r
.49839 .23337 m
.49193 .23705 L
s
.50161 .23337 m
.50807 .23705 L
s
0 0 1 r
.76295 .49193 m
.76663 .49839 L
s
.23433 .47909 m
.23866 .46874 L
s
1 0 0 r
.47909 .23433 m
.46874 .23866 L
s
.52091 .23433 m
.53126 .23866 L
s
0 0 1 r
.76134 .46874 m
.76567 .47909 L
s
.23311 .50158 m
.2366 .49662 L
s
1 0 0 r
.50158 .23311 m
.49662 .2366 L
s
.49842 .23311 m
.50338 .2366 L
s
0 0 1 r
.7634 .49662 m
.76689 .50158 L
s
.24517 .42246 m
.25249 .40946 L
s
1 0 0 r
.42246 .24517 m
.40946 .25249 L
s
.57754 .24517 m
.59054 .25249 L
s
0 0 1 r
.74751 .40946 m
.75483 .42246 L
s
.71209 .65647 m
.70453 .67047 L
s
1 0 0 r
.65647 .71209 m
.67047 .70453 L
s
.34353 .71209 m
.32953 .70453 L
s
0 0 1 r
.29547 .67047 m
.28791 .65647 L
s
.23496 .4699 m
.23956 .45847 L
s
1 0 0 r
.4699 .23496 m
.45847 .23956 L
s
.5301 .23496 m
.54153 .23956 L
s
0 0 1 r
.76044 .45847 m
.76504 .4699 L
s
.75221 .57754 m
.75082 .59079 L
s
1 0 0 r
.57754 .75221 m
.59079 .75082 L
s
0 0 1 r
.24918 .59079 m
.24779 .57754 L
s
1 0 0 r
.42246 .75221 m
.40921 .75082 L
s
0 0 1 r
.23281 .50295 m
.23613 .49958 L
s
1 0 0 r
.50295 .23281 m
.49958 .23613 L
s
.49705 .23281 m
.50042 .23613 L
s
0 0 1 r
.76387 .49958 m
.76719 .50295 L
s
.26103 .38198 m
.27068 .36931 L
s
1 0 0 r
.38198 .26103 m
.36931 .27068 L
s
.61802 .26103 m
.63069 .27068 L
s
0 0 1 r
.72932 .36931 m
.73897 .38198 L
s
.73677 .61747 m
.73213 .63168 L
s
1 0 0 r
.61747 .73677 m
.63168 .73213 L
s
.38253 .73677 m
.36832 .73213 L
s
0 0 1 r
.26787 .63168 m
.26323 .61747 L
s
.23251 .50244 m
.23562 .50073 L
s
1 0 0 r
.50244 .23251 m
.50073 .23562 L
s
.49756 .23251 m
.49927 .23562 L
s
0 0 1 r
.76438 .50073 m
.76749 .50244 L
s
.69251 .68126 m
.68286 .69429 L
s
1 0 0 r
.68126 .69251 m
.69429 .68286 L
s
.31874 .69251 m
.30571 .68286 L
s
0 0 1 r
.31714 .69429 m
.30749 .68126 L
s
.23593 .45962 m
.24085 .44721 L
s
1 0 0 r
.45962 .23593 m
.44721 .24085 L
s
.54038 .23593 m
.55279 .24085 L
s
0 0 1 r
.75915 .44721 m
.76407 .45962 L
s
.24395 .5772 m
.24324 .56489 L
s
.75676 .56489 m
.75605 .5772 L
s
1 0 0 r
.56489 .75676 m
.5772 .75605 L
s
.43511 .75676 m
.4228 .75605 L
s
0 0 1 r
.23222 .5 m
.23511 .5 L
s
1 0 0 r
.5 .23222 m
.5 .23511 L
s
0 0 1 r
.76489 .5 m
.76778 .5 L
s
1 0 0 r
.5 .76489 m
.5 .76778 L
s
0 0 1 r
.24852 .40933 m
.25625 .3958 L
s
1 0 0 r
.40933 .24852 m
.3958 .25625 L
s
.59067 .24852 m
.6042 .25625 L
s
0 0 1 r
.74375 .3958 m
.75148 .40933 L
s
.23204 .50435 m
.23467 .50261 L
s
.76533 .50261 m
.76796 .50435 L
s
1 0 0 r
.50261 .76533 m
.50435 .76796 L
s
.49739 .76533 m
.49565 .76796 L
s
0 0 1 r
.2374 .44842 m
.24266 .43515 L
s
1 0 0 r
.44842 .2374 m
.43515 .24266 L
s
.55158 .2374 m
.56485 .24266 L
s
0 0 1 r
.75734 .43515 m
.7626 .44842 L
s
.72268 .64456 m
.71559 .65848 L
s
1 0 0 r
.64456 .72268 m
.65848 .71559 L
s
.35544 .72268 m
.34152 .71559 L
s
0 0 1 r
.28441 .65848 m
.27732 .64456 L
s
.23985 .56382 m
.23978 .55264 L
s
.76022 .55264 m
.76015 .56382 L
s
1 0 0 r
.55264 .76022 m
.56382 .76015 L
s
.44736 .76022 m
.43618 .76015 L
s
0 0 1 r
.23205 .51056 m
.23438 .50707 L
s
.76562 .50707 m
.76795 .51056 L
s
1 0 0 r
.50707 .76562 m
.51056 .76795 L
s
.49293 .76562 m
.48944 .76795 L
s
0 0 1 r
.74441 .60431 m
.74041 .61804 L
s
1 0 0 r
.60431 .74441 m
.61804 .74041 L
s
.39569 .74441 m
.38196 .74041 L
s
0 0 1 r
.25959 .61804 m
.25559 .60431 L
s
.267 .3682 m
.27705 .35532 L
s
1 0 0 r
.3682 .267 m
.35532 .27705 L
s
.6318 .267 m
.64468 .27705 L
s
0 0 1 r
.72295 .35532 m
.733 .3682 L
s
.23677 .55096 m
.2373 .54109 L
s
.7627 .54109 m
.76323 .55096 L
s
1 0 0 r
.54109 .7627 m
.55096 .76323 L
s
.45891 .7627 m
.44904 .76323 L
s
0 0 1 r
.23239 .51851 m
.23436 .51331 L
s
.76564 .51331 m
.76761 .51851 L
s
1 0 0 r
.51331 .76564 m
.51851 .76761 L
s
.48669 .76564 m
.48149 .76761 L
s
0 0 1 r
.2346 .53894 m
.23567 .53052 L
s
.76433 .53052 m
.7654 .53894 L
s
1 0 0 r
.53052 .76433 m
.53894 .7654 L
s
.46948 .76433 m
.46106 .7654 L
s
0 0 1 r
.23319 .52804 m
.23474 .52118 L
s
.76526 .52118 m
.76681 .52804 L
s
1 0 0 r
.52118 .76526 m
.52804 .76681 L
s
.47882 .76526 m
.47196 .76681 L
s
0 0 1 r
.70453 .67047 m
.69519 .68363 L
s
1 0 0 r
.67047 .70453 m
.68363 .69519 L
s
.32953 .70453 m
.31637 .69519 L
s
0 0 1 r
.30481 .68363 m
.29547 .67047 L
s
.23952 .43648 m
.24517 .42246 L
s
1 0 0 r
.43648 .23952 m
.42246 .24517 L
s
.56352 .23952 m
.57754 .24517 L
s
0 0 1 r
.75483 .42246 m
.76048 .43648 L
s
.23168 .49663 m
.23391 .487 L
s
1 0 0 r
.49663 .23168 m
.487 .23391 L
s
.50337 .23168 m
.513 .23391 L
s
0 0 1 r
.76609 .487 m
.76832 .49663 L
s
.23161 .50172 m
.23362 .49349 L
s
1 0 0 r
.50172 .23161 m
.49349 .23362 L
s
.49828 .23161 m
.50651 .23362 L
s
0 0 1 r
.76638 .49349 m
.76839 .50172 L
s
.23184 .49 m
.23433 .47909 L
s
1 0 0 r
.49 .23184 m
.47909 .23433 L
s
.51 .23184 m
.52091 .23433 L
s
0 0 1 r
.76567 .47909 m
.76816 .49 L
s
.25288 .39595 m
.26103 .38198 L
s
1 0 0 r
.39595 .25288 m
.38198 .26103 L
s
.60405 .25288 m
.61802 .26103 L
s
0 0 1 r
.73897 .38198 m
.74712 .39595 L
s
.23156 .50513 m
.23337 .49839 L
s
1 0 0 r
.50513 .23156 m
.49839 .23337 L
s
.49487 .23156 m
.50161 .23337 L
s
0 0 1 r
.76663 .49839 m
.76844 .50513 L
s
.75082 .59079 m
.74747 .60384 L
s
1 0 0 r
.59079 .75082 m
.60384 .74747 L
s
.40921 .75082 m
.39616 .74747 L
s
0 0 1 r
.25253 .60384 m
.24918 .59079 L
s
.23219 .48199 m
.23496 .4699 L
s
1 0 0 r
.48199 .23219 m
.4699 .23496 L
s
.51801 .23219 m
.5301 .23496 L
s
0 0 1 r
.76504 .4699 m
.76781 .48199 L
s
.68286 .69429 m
.67153 .70626 L
s
1 0 0 r
.69429 .68286 m
.70626 .67153 L
s
.30571 .68286 m
.29374 .67153 L
s
0 0 1 r
.32847 .70626 m
.31714 .69429 L
s
.73213 .63168 m
.72558 .64538 L
s
1 0 0 r
.63168 .73213 m
.64538 .72558 L
s
.36832 .73213 m
.35462 .72558 L
s
0 0 1 r
.27442 .64538 m
.26787 .63168 L
s
.23149 .50674 m
.23311 .50158 L
s
1 0 0 r
.50674 .23149 m
.50158 .23311 L
s
.49326 .23149 m
.49842 .23311 L
s
0 0 1 r
.76689 .50158 m
.76851 .50674 L
s
.23285 .47278 m
.23593 .45962 L
s
1 0 0 r
.47278 .23285 m
.45962 .23593 L
s
.52722 .23285 m
.54038 .23593 L
s
0 0 1 r
.76407 .45962 m
.76715 .47278 L
s
.2314 .50645 m
.23281 .50295 L
s
1 0 0 r
.50645 .2314 m
.50295 .23281 L
s
.49355 .2314 m
.49705 .23281 L
s
0 0 1 r
.76719 .50295 m
.7686 .50645 L
s
.24245 .424 m
.24852 .40933 L
s
1 0 0 r
.424 .24245 m
.40933 .24852 L
s
.576 .24245 m
.59067 .24852 L
s
0 0 1 r
.75148 .40933 m
.75755 .424 L
s
.75605 .5772 m
.75335 .58938 L
s
1 0 0 r
.5772 .75605 m
.58938 .75335 L
s
0 0 1 r
.24665 .58938 m
.24395 .5772 L
s
1 0 0 r
.4228 .75605 m
.41062 .75335 L
s
0 0 1 r
.2313 .50421 m
.23251 .50244 L
s
1 0 0 r
.50421 .2313 m
.50244 .23251 L
s
.49579 .2313 m
.49756 .23251 L
s
0 0 1 r
.76749 .50244 m
.7687 .50421 L
s
.71559 .65848 m
.70663 .67164 L
s
1 0 0 r
.65848 .71559 m
.67164 .70663 L
s
.34152 .71559 m
.32836 .70663 L
s
0 0 1 r
.29337 .67164 m
.28441 .65848 L
s
.23396 .46254 m
.2374 .44842 L
s
1 0 0 r
.46254 .23396 m
.44842 .2374 L
s
.53746 .23396 m
.55158 .2374 L
s
0 0 1 r
.7626 .44842 m
.76604 .46254 L
s
.25843 .3825 m
.267 .3682 L
s
1 0 0 r
.3825 .25843 m
.3682 .267 L
s
.6175 .25843 m
.6318 .267 L
s
0 0 1 r
.733 .3682 m
.74157 .3825 L
s
.23126 .5 m
.23222 .5 L
s
1 0 0 r
.5 .23126 m
.5 .23222 L
s
0 0 1 r
.76778 .5 m
.76874 .5 L
s
1 0 0 r
.5 .76778 m
.5 .76874 L
s
0 0 1 r
.74041 .61804 m
.73443 .63134 L
s
1 0 0 r
.61804 .74041 m
.63134 .73443 L
s
.38196 .74041 m
.36866 .73443 L
s
0 0 1 r
.26557 .63134 m
.25959 .61804 L
s
.24192 .57494 m
.23985 .56382 L
s
.76015 .56382 m
.75808 .57494 L
s
1 0 0 r
.56382 .76015 m
.57494 .75808 L
s
.43618 .76015 m
.42506 .75808 L
s
0 0 1 r
.69519 .68363 m
.68405 .69579 L
s
1 0 0 r
.68363 .69519 m
.69579 .68405 L
s
.31637 .69519 m
.30421 .68405 L
s
0 0 1 r
.31595 .69579 m
.30481 .68363 L
s
.23135 .50614 m
.23204 .50435 L
s
.76796 .50435 m
.76865 .50614 L
s
1 0 0 r
.50435 .76796 m
.50614 .76865 L
s
.49565 .76796 m
.49386 .76865 L
s
0 0 1 r
.23825 .56084 m
.23677 .55096 L
s
.76323 .55096 m
.76175 .56084 L
s
1 0 0 r
.55096 .76323 m
.56084 .76175 L
s
.44904 .76323 m
.43916 .76175 L
s
0 0 1 r
.23568 .45146 m
.23952 .43648 L
s
1 0 0 r
.45146 .23568 m
.43648 .23952 L
s
.54854 .23568 m
.56352 .23952 L
s
0 0 1 r
.76048 .43648 m
.76432 .45146 L
s
.24637 .41116 m
.25288 .39595 L
s
1 0 0 r
.41116 .24637 m
.39595 .25288 L
s
.58884 .24637 m
.60405 .25288 L
s
0 0 1 r
.74712 .39595 m
.75363 .41116 L
s
.23168 .51412 m
.23205 .51056 L
s
.76795 .51056 m
.76832 .51412 L
s
1 0 0 r
.51056 .76795 m
.51412 .76832 L
s
.48944 .76795 m
.48588 .76832 L
s
0 0 1 r
.23553 .54742 m
.2346 .53894 L
s
.7654 .53894 m
.76447 .54742 L
s
1 0 0 r
.53894 .7654 m
.54742 .76447 L
s
.46106 .7654 m
.45258 .76447 L
s
0 0 1 r
.2324 .52379 m
.23239 .51851 L
s
.76761 .51851 m
.7676 .52379 L
s
1 0 0 r
.51851 .76761 m
.52379 .7676 L
s
.48149 .76761 m
.47621 .7676 L
s
0 0 1 r
.67153 .70626 m
.65853 .71701 L
s
1 0 0 r
.70626 .67153 m
.71701 .65853 L
s
.29374 .67153 m
.28299 .65853 L
s
0 0 1 r
.34147 .71701 m
.32847 .70626 L
s
.23363 .53498 m
.23319 .52804 L
s
.76681 .52804 m
.76637 .53498 L
s
1 0 0 r
.52804 .76681 m
.53498 .76637 L
s
.47196 .76681 m
.46502 .76637 L
s
0 0 1 r
.23142 .50667 m
.23168 .49663 L
s
1 0 0 r
.50667 .23142 m
.49663 .23168 L
s
.49333 .23142 m
.50337 .23168 L
s
0 0 1 r
.76832 .49663 m
.76858 .50667 L
s
.23133 .50141 m
.23184 .49 L
s
1 0 0 r
.50141 .23133 m
.49 .23184 L
s
.49859 .23133 m
.51 .23184 L
s
0 0 1 r
.76816 .49 m
.76867 .50141 L
s
.72558 .64538 m
.71707 .65841 L
s
1 0 0 r
.64538 .72558 m
.65841 .71707 L
s
.35462 .72558 m
.34159 .71707 L
s
0 0 1 r
.28293 .65841 m
.27442 .64538 L
s
.74747 .60384 m
.7421 .61656 L
s
1 0 0 r
.60384 .74747 m
.61656 .7421 L
s
.39616 .74747 m
.38344 .7421 L
s
0 0 1 r
.2579 .61656 m
.25253 .60384 L
s
.23158 .51028 m
.23161 .50172 L
s
1 0 0 r
.51028 .23158 m
.50172 .23161 L
s
.48972 .23158 m
.49828 .23161 L
s
0 0 1 r
.76839 .50172 m
.76842 .51028 L
s
.23139 .49467 m
.23219 .48199 L
s
1 0 0 r
.49467 .23139 m
.48199 .23219 L
s
.50533 .23139 m
.51801 .23219 L
s
0 0 1 r
.76781 .48199 m
.76861 .49467 L
s
.23175 .51212 m
.23156 .50513 L
s
1 0 0 r
.51212 .23175 m
.50513 .23156 L
s
.48788 .23175 m
.49487 .23156 L
s
0 0 1 r
.76844 .50513 m
.76825 .51212 L
s
.23818 .43973 m
.24245 .424 L
s
1 0 0 r
.43973 .23818 m
.424 .24245 L
s
.56027 .23818 m
.576 .24245 L
s
0 0 1 r
.75755 .424 m
.76182 .43973 L
s
.23172 .48662 m
.23285 .47278 L
s
1 0 0 r
.48662 .23172 m
.47278 .23285 L
s
.51338 .23172 m
.52722 .23285 L
s
0 0 1 r
.76715 .47278 m
.76828 .48662 L
s
.2319 .51207 m
.23149 .50674 L
s
1 0 0 r
.51207 .2319 m
.50674 .23149 L
s
.48793 .2319 m
.49326 .23149 L
s
0 0 1 r
.76851 .50674 m
.7681 .51207 L
s
.70663 .67164 m
.69577 .6839 L
s
1 0 0 r
.67164 .70663 m
.6839 .69577 L
s
.32836 .70663 m
.3161 .69577 L
s
0 0 1 r
.30423 .6839 m
.29337 .67164 L
s
.25146 .39814 m
.25843 .3825 L
s
1 0 0 r
.39814 .25146 m
.3825 .25843 L
s
.60186 .25146 m
.6175 .25843 L
s
0 0 1 r
.74157 .3825 m
.74854 .39814 L
s
.75335 .58938 m
.74858 .60132 L
s
1 0 0 r
.58938 .75335 m
.60132 .74858 L
s
.41062 .75335 m
.39868 .74858 L
s
0 0 1 r
.25142 .60132 m
.24665 .58938 L
s
.23247 .47744 m
.23396 .46254 L
s
1 0 0 r
.47744 .23247 m
.46254 .23396 L
s
.52256 .23247 m
.53746 .23396 L
s
0 0 1 r
.76604 .46254 m
.76753 .47744 L
s
.23202 .51005 m
.2314 .50645 L
s
1 0 0 r
.51005 .23202 m
.50645 .2314 L
s
.48995 .23202 m
.49355 .2314 L
s
0 0 1 r
.7686 .50645 m
.76798 .51005 L
s
.73443 .63134 m
.72642 .64407 L
s
1 0 0 r
.63134 .73443 m
.64407 .72642 L
s
.36866 .73443 m
.35593 .72642 L
s
0 0 1 r
.27358 .64407 m
.26557 .63134 L
s
.68405 .69579 m
.67114 .70681 L
s
1 0 0 r
.69579 .68405 m
.70681 .67114 L
s
.30421 .68405 m
.29319 .67114 L
s
0 0 1 r
.32886 .70681 m
.31595 .69579 L
s
.23215 .50602 m
.2313 .50421 L
s
1 0 0 r
.50602 .23215 m
.50421 .2313 L
s
.49398 .23215 m
.49579 .2313 L
s
0 0 1 r
.7687 .50421 m
.76785 .50602 L
s
.24164 .42753 m
.24637 .41116 L
s
1 0 0 r
.42753 .24164 m
.41116 .24637 L
s
.57247 .24164 m
.58884 .24637 L
s
0 0 1 r
.75363 .41116 m
.75836 .42753 L
s
.75808 .57494 m
.75391 .5859 L
s
1 0 0 r
.57494 .75808 m
.5859 .75391 L
s
0 0 1 r
.24609 .5859 m
.24192 .57494 L
s
1 0 0 r
.42506 .75808 m
.4141 .75391 L
s
0 0 1 r
.23378 .46731 m
.23568 .45146 L
s
1 0 0 r
.46731 .23378 m
.45146 .23568 L
s
.53269 .23378 m
.54854 .23568 L
s
0 0 1 r
.76432 .45146 m
.76622 .46731 L
s
.65853 .71701 m
.64389 .72639 L
s
1 0 0 r
.71701 .65853 m
.72639 .64389 L
s
.28299 .65853 m
.27361 .64389 L
s
0 0 1 r
.35611 .72639 m
.34147 .71701 L
s
.23237 .5 m
.23126 .5 L
s
1 0 0 r
.5 .23237 m
.5 .23126 L
s
0 0 1 r
.76874 .5 m
.76763 .5 L
s
1 0 0 r
.5 .76874 m
.5 .76763 L
s
0 0 1 r
.24185 .57064 m
.23825 .56084 L
s
.76175 .56084 m
.75815 .57064 L
s
1 0 0 r
.56084 .76175 m
.57064 .75815 L
s
.43916 .76175 m
.42936 .75815 L
s
0 0 1 r
.71707 .65841 m
.70657 .67063 L
s
1 0 0 r
.65841 .71707 m
.67063 .70657 L
s
.34159 .71707 m
.32937 .70657 L
s
0 0 1 r
.29343 .67063 m
.28293 .65841 L
s
.23275 .50795 m
.23135 .50614 L
s
.76865 .50614 m
.76725 .50795 L
s
1 0 0 r
.50614 .76865 m
.50795 .76725 L
s
.49386 .76865 m
.49205 .76725 L
s
0 0 1 r
.7421 .61656 m
.73462 .62882 L
s
1 0 0 r
.61656 .7421 m
.62882 .73462 L
s
.38344 .7421 m
.37118 .73462 L
s
0 0 1 r
.26538 .62882 m
.2579 .61656 L
s
.23342 .51772 m
.23168 .51412 L
s
.76832 .51412 m
.76658 .51772 L
s
1 0 0 r
.51412 .76832 m
.51772 .76658 L
s
.48588 .76832 m
.48228 .76658 L
s
0 0 1 r
.23859 .55588 m
.23553 .54742 L
s
.76447 .54742 m
.76141 .55588 L
s
1 0 0 r
.54742 .76447 m
.55588 .76141 L
s
.45258 .76447 m
.44412 .76141 L
s
0 0 1 r
.23291 .51326 m
.23133 .50141 L
s
1 0 0 r
.51326 .23291 m
.50141 .23133 L
s
.48674 .23291 m
.49859 .23133 L
s
0 0 1 r
.76867 .50141 m
.76709 .51326 L
s
.23583 .45643 m
.23818 .43973 L
s
1 0 0 r
.45643 .23583 m
.43973 .23818 L
s
.54357 .23583 m
.56027 .23818 L
s
0 0 1 r
.76182 .43973 m
.76417 .45643 L
s
.23267 .50787 m
.23139 .49467 L
s
1 0 0 r
.50787 .23267 m
.49467 .23139 L
s
.49213 .23267 m
.50533 .23139 L
s
0 0 1 r
.76861 .49467 m
.76733 .50787 L
s
.23328 .51706 m
.23142 .50667 L
s
1 0 0 r
.51706 .23328 m
.50667 .23142 L
s
.48294 .23328 m
.49333 .23142 L
s
0 0 1 r
.76858 .50667 m
.76672 .51706 L
s
.23452 .52912 m
.2324 .52379 L
s
.7676 .52379 m
.76548 .52912 L
s
1 0 0 r
.52379 .7676 m
.52912 .76548 L
s
.47621 .7676 m
.47088 .76548 L
s
0 0 1 r
.23619 .54193 m
.23363 .53498 L
s
.76637 .53498 m
.76381 .54193 L
s
1 0 0 r
.53498 .76637 m
.54193 .76381 L
s
.46502 .76637 m
.45807 .76381 L
s
0 0 1 r
.23368 .51912 m
.23158 .51028 L
s
1 0 0 r
.51912 .23368 m
.51028 .23158 L
s
.48088 .23368 m
.48972 .23158 L
s
0 0 1 r
.76842 .51028 m
.76632 .51912 L
s
.23267 .50107 m
.23172 .48662 L
s
1 0 0 r
.50107 .23267 m
.48662 .23172 L
s
.49893 .23267 m
.51338 .23172 L
s
0 0 1 r
.76828 .48662 m
.76733 .50107 L
s
.24623 .41506 m
.25146 .39814 L
s
1 0 0 r
.41506 .24623 m
.39814 .25146 L
s
.58494 .24623 m
.60186 .25146 L
s
0 0 1 r
.74854 .39814 m
.75377 .41506 L
s
.69577 .6839 m
.68304 .6951 L
s
1 0 0 r
.6839 .69577 m
.6951 .68304 L
s
.3161 .69577 m
.3049 .68304 L
s
0 0 1 r
.31696 .6951 m
.30423 .6839 L
s
.23408 .51931 m
.23175 .51212 L
s
1 0 0 r
.51931 .23408 m
.51212 .23175 L
s
.48069 .23408 m
.48788 .23175 L
s
0 0 1 r
.76825 .51212 m
.76592 .51931 L
s
.23304 .49303 m
.23247 .47744 L
s
1 0 0 r
.49303 .23304 m
.47744 .23247 L
s
.50697 .23304 m
.52256 .23247 L
s
0 0 1 r
.76753 .47744 m
.76696 .49303 L
s
.67114 .70681 m
.65648 .71654 L
s
1 0 0 r
.70681 .67114 m
.71654 .65648 L
s
.29319 .67114 m
.28346 .65648 L
s
0 0 1 r
.34352 .71654 m
.32886 .70681 L
s
.74858 .60132 m
.74167 .6129 L
s
1 0 0 r
.60132 .74858 m
.6129 .74167 L
s
.39868 .74858 m
.3871 .74167 L
s
0 0 1 r
.25833 .6129 m
.25142 .60132 L
s
.23445 .51753 m
.2319 .51207 L
s
1 0 0 r
.51753 .23445 m
.51207 .2319 L
s
.48247 .23445 m
.48793 .2319 L
s
0 0 1 r
.7681 .51207 m
.76555 .51753 L
s
.72642 .64407 m
.71634 .6561 L
s
1 0 0 r
.64407 .72642 m
.6561 .71634 L
s
.35593 .72642 m
.3439 .71634 L
s
0 0 1 r
.28366 .6561 m
.27358 .64407 L
s
.2388 .44498 m
.24164 .42753 L
s
1 0 0 r
.44498 .2388 m
.42753 .24164 L
s
.55502 .2388 m
.57247 .24164 L
s
0 0 1 r
.75836 .42753 m
.7612 .44498 L
s
.64389 .72639 m
.62768 .73427 L
s
1 0 0 r
.72639 .64389 m
.73427 .62768 L
s
.27361 .64389 m
.26573 .62768 L
s
0 0 1 r
.37232 .73427 m
.35611 .72639 L
s
.23393 .48394 m
.23378 .46731 L
s
1 0 0 r
.48394 .23393 m
.46731 .23378 L
s
.51606 .23393 m
.53269 .23378 L
s
0 0 1 r
.76622 .46731 m
.76607 .48394 L
s
.23481 .51372 m
.23202 .51005 L
s
1 0 0 r
.51372 .23481 m
.51005 .23202 L
s
.48628 .23481 m
.48995 .23202 L
s
0 0 1 r
.76798 .51005 m
.76519 .51372 L
s
.75391 .5859 m
.74756 .59661 L
s
1 0 0 r
.5859 .75391 m
.59661 .74756 L
s
.4141 .75391 m
.40339 .74756 L
s
0 0 1 r
.25244 .59661 m
.24609 .5859 L
s
.70657 .67063 m
.69409 .68189 L
s
1 0 0 r
.67063 .70657 m
.68189 .69409 L
s
.32937 .70657 m
.31811 .69409 L
s
0 0 1 r
.30591 .68189 m
.29343 .67063 L
s
.23519 .50787 m
.23215 .50602 L
s
1 0 0 r
.50787 .23519 m
.50602 .23215 L
s
.49213 .23519 m
.49398 .23215 L
s
0 0 1 r
.76785 .50602 m
.76481 .50787 L
s
.23551 .474 m
.23583 .45643 L
s
1 0 0 r
.474 .23551 m
.45643 .23583 L
s
.526 .23551 m
.54357 .23583 L
s
0 0 1 r
.76417 .45643 m
.76449 .474 L
s
.73462 .62882 m
.72501 .64048 L
s
1 0 0 r
.62882 .73462 m
.64048 .72501 L
s
.37118 .73462 m
.35952 .72501 L
s
0 0 1 r
.27499 .64048 m
.26538 .62882 L
s
.75815 .57064 m
.75235 .58027 L
s
1 0 0 r
.57064 .75815 m
.58027 .75235 L
s
0 0 1 r
.24765 .58027 m
.24185 .57064 L
s
1 0 0 r
.42936 .75815 m
.41973 .75235 L
s
0 0 1 r
.23567 .5 m
.23237 .5 L
s
1 0 0 r
.5 .23567 m
.5 .23237 L
s
0 0 1 r
.76763 .5 m
.76433 .5 L
s
1 0 0 r
.5 .76763 m
.5 .76433 L
s
0 0 1 r
.24287 .43316 m
.24623 .41506 L
s
1 0 0 r
.43316 .24287 m
.41506 .24623 L
s
.56684 .24287 m
.58494 .24623 L
s
0 0 1 r
.75377 .41506 m
.75713 .43316 L
s
.68304 .6951 m
.66844 .70509 L
s
1 0 0 r
.6951 .68304 m
.70509 .66844 L
s
.3049 .68304 m
.29491 .66844 L
s
0 0 1 r
.33156 .70509 m
.31696 .6951 L
s
.23615 .5215 m
.23267 .50787 L
s
1 0 0 r
.5215 .23615 m
.50787 .23267 L
s
.4785 .23615 m
.49213 .23267 L
s
0 0 1 r
.76733 .50787 m
.76385 .5215 L
s
.2367 .52546 m
.23291 .51326 L
s
1 0 0 r
.52546 .2367 m
.51326 .23291 L
s
.47454 .2367 m
.48674 .23291 L
s
0 0 1 r
.76709 .51326 m
.7633 .52546 L
s
.23636 .50979 m
.23275 .50795 L
s
.76725 .50795 m
.76364 .50979 L
s
1 0 0 r
.50795 .76725 m
.50979 .76364 L
s
.49205 .76725 m
.49021 .76364 L
s
0 0 1 r
.2358 .51602 m
.23267 .50107 L
s
1 0 0 r
.51602 .2358 m
.50107 .23267 L
s
.48398 .2358 m
.49893 .23267 L
s
0 0 1 r
.76733 .50107 m
.7642 .51602 L
s
.24387 .56423 m
.23859 .55588 L
s
.76141 .55588 m
.75613 .56423 L
s
1 0 0 r
.55588 .76141 m
.56423 .75613 L
s
.44412 .76141 m
.43577 .75613 L
s
0 0 1 r
.23735 .52773 m
.23328 .51706 L
s
1 0 0 r
.52773 .23735 m
.51706 .23328 L
s
.47227 .23735 m
.48294 .23328 L
s
0 0 1 r
.76672 .51706 m
.76265 .52773 L
s
.23738 .52134 m
.23342 .51772 L
s
.76658 .51772 m
.76262 .52134 L
s
1 0 0 r
.51772 .76658 m
.52134 .76262 L
s
.48228 .76658 m
.47866 .76262 L
s
0 0 1 r
.65648 .71654 m
.64013 .72482 L
s
1 0 0 r
.71654 .65648 m
.72482 .64013 L
s
.28346 .65648 m
.27518 .64013 L
s
0 0 1 r
.35987 .72482 m
.34352 .71654 L
s
.24099 .54885 m
.23619 .54193 L
s
.76381 .54193 m
.75901 .54885 L
s
1 0 0 r
.54193 .76381 m
.54885 .75901 L
s
.45807 .76381 m
.45115 .75901 L
s
0 0 1 r
.23888 .53445 m
.23452 .52912 L
s
.76548 .52912 m
.76112 .53445 L
s
1 0 0 r
.52912 .76548 m
.53445 .76112 L
s
.47088 .76548 m
.46555 .76112 L
s
0 0 1 r
.23577 .5092 m
.23304 .49303 L
s
1 0 0 r
.5092 .23577 m
.49303 .23304 L
s
.4908 .23577 m
.50697 .23304 L
s
0 0 1 r
.76696 .49303 m
.76423 .5092 L
s
.23802 .52817 m
.23368 .51912 L
s
1 0 0 r
.52817 .23802 m
.51912 .23368 L
s
.47183 .23802 m
.48088 .23368 L
s
0 0 1 r
.76632 .51912 m
.76198 .52817 L
s
.23797 .46339 m
.2388 .44498 L
s
1 0 0 r
.46339 .23797 m
.44498 .2388 L
s
.53661 .23797 m
.55502 .2388 L
s
0 0 1 r
.7612 .44498 m
.76203 .46339 L
s
.62768 .73427 m
.60997 .74049 L
s
1 0 0 r
.73427 .62768 m
.74049 .60997 L
s
.26573 .62768 m
.25951 .60997 L
s
0 0 1 r
.39003 .74049 m
.37232 .73427 L
s
.71634 .6561 m
.70419 .66728 L
s
1 0 0 r
.6561 .71634 m
.66728 .70419 L
s
.3439 .71634 m
.33272 .70419 L
s
0 0 1 r
.29581 .66728 m
.28366 .6561 L
s
.74167 .6129 m
.73255 .624 L
s
1 0 0 r
.6129 .74167 m
.624 .73255 L
s
.3871 .74167 m
.376 .73255 L
s
0 0 1 r
.26745 .624 m
.25833 .6129 L
s
.23866 .52665 m
.23408 .51931 L
s
1 0 0 r
.52665 .23866 m
.51931 .23408 L
s
.47335 .23866 m
.48069 .23408 L
s
0 0 1 r
.76592 .51931 m
.76134 .52665 L
s
.23622 .50123 m
.23393 .48394 L
s
1 0 0 r
.50123 .23622 m
.48394 .23393 L
s
.49877 .23622 m
.51606 .23393 L
s
0 0 1 r
.76607 .48394 m
.76378 .50123 L
s
.23927 .52309 m
.23445 .51753 L
s
1 0 0 r
.52309 .23927 m
.51753 .23445 L
s
.47691 .23927 m
.48247 .23445 L
s
0 0 1 r
.76555 .51753 m
.76073 .52309 L
s
.69409 .68189 m
.67965 .69204 L
s
1 0 0 r
.68189 .69409 m
.69204 .67965 L
s
.31811 .69409 m
.30796 .67965 L
s
0 0 1 r
.32035 .69204 m
.30591 .68189 L
s
.23732 .4923 m
.23551 .474 L
s
1 0 0 r
.4923 .23732 m
.474 .23551 L
s
.5077 .23732 m
.526 .23551 L
s
0 0 1 r
.76449 .474 m
.76268 .4923 L
s
.74756 .59661 m
.73895 .60693 L
s
1 0 0 r
.59661 .74756 m
.60693 .73895 L
s
.40339 .74756 m
.39307 .73895 L
s
0 0 1 r
.26105 .60693 m
.25244 .59661 L
s
.2415 .4523 m
.24287 .43316 L
s
1 0 0 r
.4523 .2415 m
.43316 .24287 L
s
.5477 .2415 m
.56684 .24287 L
s
0 0 1 r
.75713 .43316 m
.7585 .4523 L
s
.23987 .51745 m
.23481 .51372 L
s
1 0 0 r
.51745 .23987 m
.51372 .23481 L
s
.48255 .23987 m
.48628 .23481 L
s
0 0 1 r
.76519 .51372 m
.76013 .51745 L
s
.66844 .70509 m
.65205 .71371 L
s
1 0 0 r
.70509 .66844 m
.71371 .65205 L
s
.29491 .66844 m
.28629 .65205 L
s
0 0 1 r
.34795 .71371 m
.33156 .70509 L
s
.72501 .64048 m
.71324 .6514 L
s
1 0 0 r
.64048 .72501 m
.6514 .71324 L
s
.35952 .72501 m
.3486 .71324 L
s
0 0 1 r
.28676 .6514 m
.27499 .64048 L
s
.24052 .50973 m
.23519 .50787 L
s
1 0 0 r
.50973 .24052 m
.50787 .23519 L
s
.49027 .24052 m
.49213 .23519 L
s
0 0 1 r
.76481 .50787 m
.75948 .50973 L
s
.64013 .72482 m
.62217 .73151 L
s
1 0 0 r
.72482 .64013 m
.73151 .62217 L
s
.27518 .64013 m
.26849 .62217 L
s
0 0 1 r
.37783 .73151 m
.35987 .72482 L
s
.75235 .58027 m
.74425 .58962 L
s
1 0 0 r
.58027 .75235 m
.58962 .74425 L
s
.41973 .75235 m
.41038 .74425 L
s
0 0 1 r
.25575 .58962 m
.24765 .58027 L
s
.2419 .53543 m
.23615 .5215 L
s
1 0 0 r
.53543 .2419 m
.5215 .23615 L
s
.46457 .2419 m
.4785 .23615 L
s
0 0 1 r
.76385 .5215 m
.7581 .53543 L
s
.24118 .53134 m
.2358 .51602 L
s
1 0 0 r
.53134 .24118 m
.51602 .2358 L
s
.46866 .24118 m
.48398 .2358 L
s
0 0 1 r
.7642 .51602 m
.75882 .53134 L
s
.23925 .48262 m
.23797 .46339 L
s
1 0 0 r
.48262 .23925 m
.46339 .23797 L
s
.51738 .23925 m
.53661 .23797 L
s
0 0 1 r
.76203 .46339 m
.76075 .48262 L
s
.24278 .5379 m
.2367 .52546 L
s
1 0 0 r
.5379 .24278 m
.52546 .2367 L
s
.4621 .24278 m
.47454 .2367 L
s
0 0 1 r
.7633 .52546 m
.75722 .5379 L
s
.60997 .74049 m
.59087 .74493 L
s
1 0 0 r
.74049 .60997 m
.74493 .59087 L
s
.25951 .60997 m
.25507 .59087 L
s
0 0 1 r
.40913 .74493 m
.39003 .74049 L
s
.24075 .52581 m
.23577 .5092 L
s
1 0 0 r
.52581 .24075 m
.5092 .23577 L
s
.47419 .24075 m
.4908 .23577 L
s
0 0 1 r
.76423 .5092 m
.75925 .52581 L
s
.24129 .5 m
.23567 .5 L
s
1 0 0 r
.5 .24129 m
.5 .23567 L
s
0 0 1 r
.76433 .5 m
.75871 .5 L
s
1 0 0 r
.5 .76433 m
.5 .75871 L
s
0 0 1 r
.24373 .53859 m
.23735 .52773 L
s
1 0 0 r
.53859 .24373 m
.52773 .23735 L
s
.46141 .24373 m
.47227 .23735 L
s
0 0 1 r
.76265 .52773 m
.75627 .53859 L
s
.75613 .56423 m
.74853 .5724 L
s
1 0 0 r
.56423 .75613 m
.5724 .74853 L
s
0 0 1 r
.25147 .5724 m
.24387 .56423 L
s
1 0 0 r
.43577 .75613 m
.4276 .74853 L
s
0 0 1 r
.70419 .66728 m
.68997 .67745 L
s
1 0 0 r
.66728 .70419 m
.67745 .68997 L
s
.33272 .70419 m
.32255 .68997 L
s
0 0 1 r
.31003 .67745 m
.29581 .66728 L
s
.2423 .51162 m
.23636 .50979 L
s
.76364 .50979 m
.7577 .51162 L
s
1 0 0 r
.50979 .76364 m
.51162 .7577 L
s
.49021 .76364 m
.48838 .7577 L
s
0 0 1 r
.24074 .51903 m
.23622 .50123 L
s
1 0 0 r
.51903 .24074 m
.50123 .23622 L
s
.48097 .24074 m
.49877 .23622 L
s
0 0 1 r
.76378 .50123 m
.75926 .51903 L
s
.24812 .55564 m
.24099 .54885 L
s
.75901 .54885 m
.75188 .55564 L
s
1 0 0 r
.54885 .75901 m
.55564 .75188 L
s
.45115 .75901 m
.44436 .75188 L
s
0 0 1 r
.73255 .624 m
.7212 .63447 L
s
1 0 0 r
.624 .73255 m
.63447 .7212 L
s
.376 .73255 m
.36553 .7212 L
s
0 0 1 r
.2788 .63447 m
.26745 .624 L
s
.24468 .53735 m
.23802 .52817 L
s
1 0 0 r
.53735 .24468 m
.52817 .23802 L
s
.46265 .24468 m
.47183 .23802 L
s
0 0 1 r
.76198 .52817 m
.75532 .53735 L
s
.24368 .52494 m
.23738 .52134 L
s
.76262 .52134 m
.75632 .52494 L
s
1 0 0 r
.52134 .76262 m
.52494 .75632 L
s
.47866 .76262 m
.47506 .75632 L
s
0 0 1 r
.24557 .53971 m
.23888 .53445 L
s
.76112 .53445 m
.75443 .53971 L
s
1 0 0 r
.53445 .76112 m
.53971 .75443 L
s
.46555 .76112 m
.46029 .75443 L
s
0 0 1 r
.67965 .69204 m
.6633 .70092 L
s
1 0 0 r
.69204 .67965 m
.70092 .6633 L
s
.30796 .67965 m
.29908 .6633 L
s
0 0 1 r
.3367 .70092 m
.32035 .69204 L
s
.24221 .47236 m
.2415 .4523 L
s
1 0 0 r
.47236 .24221 m
.4523 .2415 L
s
.52764 .24221 m
.5477 .2415 L
s
0 0 1 r
.7585 .4523 m
.75779 .47236 L
s
.24134 .5112 m
.23732 .4923 L
s
1 0 0 r
.5112 .24134 m
.4923 .23732 L
s
.4888 .24134 m
.5077 .23732 L
s
0 0 1 r
.76268 .4923 m
.75866 .5112 L
s
.24559 .53407 m
.23866 .52665 L
s
1 0 0 r
.53407 .24559 m
.52665 .23866 L
s
.46593 .24559 m
.47335 .23866 L
s
0 0 1 r
.76134 .52665 m
.75441 .53407 L
s
.65205 .71371 m
.63394 .72083 L
s
1 0 0 r
.71371 .65205 m
.72083 .63394 L
s
.28629 .65205 m
.27917 .63394 L
s
0 0 1 r
.36606 .72083 m
.34795 .71371 L
s
.73895 .60693 m
.72805 .61676 L
s
1 0 0 r
.60693 .73895 m
.61676 .72805 L
s
.39307 .73895 m
.38324 .72805 L
s
0 0 1 r
.27195 .61676 m
.26105 .60693 L
s
.62217 .73151 m
.60272 .73648 L
s
1 0 0 r
.73151 .62217 m
.73648 .60272 L
s
.26849 .62217 m
.26352 .60272 L
s
0 0 1 r
.39728 .73648 m
.37783 .73151 L
s
.24646 .5287 m
.23927 .52309 L
s
1 0 0 r
.5287 .24646 m
.52309 .23927 L
s
.4713 .24646 m
.47691 .23927 L
s
0 0 1 r
.76073 .52309 m
.75354 .5287 L
s
.71324 .6514 m
.69932 .66143 L
s
1 0 0 r
.6514 .71324 m
.66143 .69932 L
s
.3486 .71324 m
.33857 .69932 L
s
0 0 1 r
.30068 .66143 m
.28676 .6514 L
s
.24271 .50251 m
.23925 .48262 L
s
1 0 0 r
.50251 .24271 m
.48262 .23925 L
s
.49749 .24271 m
.51738 .23925 L
s
0 0 1 r
.76075 .48262 m
.75729 .50251 L
s
.59087 .74493 m
.57052 .74747 L
s
1 0 0 r
.74493 .59087 m
.74747 .57052 L
s
.25507 .59087 m
.25253 .57052 L
s
0 0 1 r
.42948 .74747 m
.40913 .74493 L
s
.24733 .52119 m
.23987 .51745 L
s
1 0 0 r
.52119 .24733 m
.51745 .23987 L
s
.47881 .24733 m
.48255 .23987 L
s
0 0 1 r
.76013 .51745 m
.75267 .52119 L
s
.24889 .54691 m
.24118 .53134 L
s
1 0 0 r
.54691 .24889 m
.53134 .24118 L
s
.45309 .24889 m
.46866 .24118 L
s
0 0 1 r
.75882 .53134 m
.75111 .54691 L
s
.24802 .54273 m
.24075 .52581 L
s
1 0 0 r
.54273 .24802 m
.52581 .24075 L
s
.45727 .24802 m
.47419 .24075 L
s
0 0 1 r
.75925 .52581 m
.75198 .54273 L
s
.25 .54956 m
.2419 .53543 L
s
1 0 0 r
.54956 .25 m
.53543 .2419 L
s
.45044 .25 m
.46457 .2419 L
s
0 0 1 r
.7581 .53543 m
.75 .54956 L
s
.74425 .58962 m
.73382 .59857 L
s
1 0 0 r
.58962 .74425 m
.59857 .73382 L
s
.41038 .74425 m
.40143 .73382 L
s
0 0 1 r
.26618 .59857 m
.25575 .58962 L
s
.25123 .55048 m
.24278 .5379 L
s
1 0 0 r
.55048 .25123 m
.5379 .24278 L
s
.44952 .25123 m
.4621 .24278 L
s
0 0 1 r
.75722 .5379 m
.74877 .55048 L
s
.68997 .67745 m
.67375 .68646 L
s
1 0 0 r
.67745 .68997 m
.68646 .67375 L
s
.32255 .68997 m
.31354 .67375 L
s
0 0 1 r
.32625 .68646 m
.31003 .67745 L
s
.24754 .5372 m
.24074 .51903 L
s
1 0 0 r
.5372 .24754 m
.51903 .24074 L
s
.4628 .24754 m
.48097 .24074 L
s
0 0 1 r
.75926 .51903 m
.75246 .5372 L
s
.24825 .51159 m
.24052 .50973 L
s
1 0 0 r
.51159 .24825 m
.50973 .24052 L
s
.48841 .24825 m
.49027 .24052 L
s
0 0 1 r
.75948 .50973 m
.75175 .51159 L
s
.24507 .49316 m
.24221 .47236 L
s
1 0 0 r
.49316 .24507 m
.47236 .24221 L
s
.50684 .24507 m
.52764 .24221 L
s
0 0 1 r
.75779 .47236 m
.75493 .49316 L
s
.25249 .54953 m
.24373 .53859 L
s
1 0 0 r
.54953 .25249 m
.53859 .24373 L
s
.45047 .25249 m
.46141 .24373 L
s
0 0 1 r
.75627 .53859 m
.74751 .54953 L
s
.6633 .70092 m
.64512 .70838 L
s
1 0 0 r
.70092 .6633 m
.70838 .64512 L
s
.29908 .6633 m
.29162 .64512 L
s
0 0 1 r
.35488 .70838 m
.3367 .70092 L
s
.24761 .53052 m
.24134 .5112 L
s
1 0 0 r
.53052 .24761 m
.5112 .24134 L
s
.46948 .24761 m
.4888 .24134 L
s
0 0 1 r
.75866 .5112 m
.75239 .53052 L
s
.7212 .63447 m
.70762 .64418 L
s
1 0 0 r
.63447 .7212 m
.64418 .70762 L
s
.36553 .7212 m
.35582 .70762 L
s
0 0 1 r
.29238 .64418 m
.2788 .63447 L
s
.74853 .5724 m
.73855 .58028 L
s
1 0 0 r
.5724 .74853 m
.58028 .73855 L
s
.4276 .74853 m
.41972 .73855 L
s
0 0 1 r
.26145 .58028 m
.25147 .5724 L
s
.24932 .5 m
.24129 .5 L
s
1 0 0 r
.5 .24932 m
.5 .24129 L
s
0 0 1 r
.75871 .5 m
.75068 .5 L
s
1 0 0 r
.5 .75871 m
.5 .75068 L
s
0 0 1 r
.63394 .72083 m
.61422 .7263 L
s
1 0 0 r
.72083 .63394 m
.7263 .61422 L
s
.27917 .63394 m
.2737 .61422 L
s
0 0 1 r
.38578 .7263 m
.36606 .72083 L
s
.25374 .54657 m
.24468 .53735 L
s
1 0 0 r
.54657 .25374 m
.53735 .24468 L
s
.45343 .25374 m
.46265 .24468 L
s
0 0 1 r
.75532 .53735 m
.74626 .54657 L
s
.25066 .51343 m
.2423 .51162 L
s
.7577 .51162 m
.74934 .51343 L
s
1 0 0 r
.51162 .7577 m
.51343 .74934 L
s
.48838 .7577 m
.48657 .74934 L
s
0 0 1 r
.75188 .55564 m
.74235 .56225 L
s
1 0 0 r
.55564 .75188 m
.56225 .74235 L
s
0 0 1 r
.25765 .56225 m
.24812 .55564 L
s
1 0 0 r
.44436 .75188 m
.43775 .74235 L
s
0 0 1 r
.60272 .73648 m
.58191 .73961 L
s
1 0 0 r
.73648 .60272 m
.73961 .58191 L
s
.26352 .60272 m
.26039 .58191 L
s
0 0 1 r
.41809 .73961 m
.39728 .73648 L
s
.2524 .52848 m
.24368 .52494 L
s
.75632 .52494 m
.7476 .52848 L
s
1 0 0 r
.52494 .75632 m
.52848 .7476 L
s
.47506 .75632 m
.47152 .7476 L
s
0 0 1 r
.25468 .54486 m
.24557 .53971 L
s
.75443 .53971 m
.74532 .54486 L
s
1 0 0 r
.53971 .75443 m
.54486 .74532 L
s
.46029 .75443 m
.45514 .74532 L
s
0 0 1 r
.57052 .74747 m
.54909 .74801 L
s
1 0 0 r
.74747 .57052 m
.74801 .54909 L
s
.25253 .57052 m
.25199 .54909 L
s
0 0 1 r
.45091 .74801 m
.42948 .74747 L
s
.24841 .52289 m
.24271 .50251 L
s
1 0 0 r
.52289 .24841 m
.50251 .24271 L
s
.47711 .24841 m
.49749 .24271 L
s
0 0 1 r
.75729 .50251 m
.75159 .52289 L
s
.25493 .54151 m
.24559 .53407 L
s
1 0 0 r
.54151 .25493 m
.53407 .24559 L
s
.45849 .25493 m
.46593 .24559 L
s
0 0 1 r
.75441 .53407 m
.74507 .54151 L
s
.69932 .66143 m
.68328 .67043 L
s
1 0 0 r
.66143 .69932 m
.67043 .68328 L
s
.33857 .69932 m
.32957 .68328 L
s
0 0 1 r
.31672 .67043 m
.30068 .66143 L
s
.72805 .61676 m
.71485 .62595 L
s
1 0 0 r
.61676 .72805 m
.62595 .71485 L
s
.38324 .72805 m
.37405 .71485 L
s
0 0 1 r
.28515 .62595 m
.27195 .61676 L
s
.25763 .55979 m
.24802 .54273 L
s
1 0 0 r
.55979 .25763 m
.54273 .24802 L
s
.44021 .25763 m
.45727 .24802 L
s
0 0 1 r
.75198 .54273 m
.74237 .55979 L
s
.25895 .56258 m
.24889 .54691 L
s
1 0 0 r
.56258 .25895 m
.54691 .24889 L
s
.43742 .25895 m
.45309 .24889 L
s
0 0 1 r
.75111 .54691 m
.74105 .56258 L
s
.25665 .55556 m
.24754 .5372 L
s
1 0 0 r
.55556 .25665 m
.5372 .24754 L
s
.44444 .25665 m
.4628 .24754 L
s
0 0 1 r
.75246 .5372 m
.74335 .55556 L
s
.25608 .53429 m
.24646 .5287 L
s
1 0 0 r
.53429 .25608 m
.5287 .24646 L
s
.46571 .25608 m
.4713 .24646 L
s
0 0 1 r
.75354 .5287 m
.74392 .53429 L
s
.25014 .51451 m
.24507 .49316 L
s
1 0 0 r
.51451 .25014 m
.49316 .24507 L
s
.48549 .25014 m
.50684 .24507 L
s
0 0 1 r
.75493 .49316 m
.74986 .51451 L
s
.26046 .56374 m
.25 .54956 L
s
1 0 0 r
.56374 .26046 m
.54956 .25 L
s
.43626 .26046 m
.45044 .25 L
s
0 0 1 r
.75 .54956 m
.73954 .56374 L
s
.67375 .68646 m
.65558 .69417 L
s
1 0 0 r
.68646 .67375 m
.69417 .65558 L
s
.31354 .67375 m
.30583 .65558 L
s
0 0 1 r
.34442 .69417 m
.32625 .68646 L
s
.25617 .55008 m
.24761 .53052 L
s
1 0 0 r
.55008 .25617 m
.53052 .24761 L
s
.44992 .25617 m
.46948 .24761 L
s
0 0 1 r
.75239 .53052 m
.74383 .55008 L
s
.64512 .70838 m
.62522 .71429 L
s
1 0 0 r
.70838 .64512 m
.71429 .62522 L
s
.29162 .64512 m
.28571 .62522 L
s
0 0 1 r
.37478 .71429 m
.35488 .70838 L
s
.26207 .56308 m
.25123 .55048 L
s
1 0 0 r
.56308 .26207 m
.55048 .25123 L
s
.43692 .26207 m
.44952 .25123 L
s
0 0 1 r
.74877 .55048 m
.73793 .56308 L
s
.73382 .59857 m
.72102 .60703 L
s
1 0 0 r
.59857 .73382 m
.60703 .72102 L
s
.40143 .73382 m
.39297 .72102 L
s
0 0 1 r
.27898 .60703 m
.26618 .59857 L
s
.25723 .52491 m
.24733 .52119 L
s
1 0 0 r
.52491 .25723 m
.52119 .24733 L
s
.47509 .25723 m
.47881 .24733 L
s
0 0 1 r
.75267 .52119 m
.74277 .52491 L
s
.61422 .7263 m
.59304 .73 L
s
1 0 0 r
.7263 .61422 m
.73 .59304 L
s
.2737 .61422 m
.27 .59304 L
s
0 0 1 r
.40696 .73 m
.38578 .7263 L
s
.58191 .73961 m
.55991 .7408 L
s
1 0 0 r
.73961 .58191 m
.7408 .55991 L
s
.26039 .58191 m
.2592 .55991 L
s
0 0 1 r
.44009 .7408 m
.41809 .73961 L
s
.54909 .74801 m
.52675 .74647 L
s
1 0 0 r
.74801 .54909 m
.74647 .52675 L
s
0 0 1 r
.47325 .74647 m
.45091 .74801 L
s
1 0 0 r
.25199 .54909 m
.25353 .52675 L
s
0 0 1 r
.70762 .64418 m
.69184 .65299 L
s
1 0 0 r
.64418 .70762 m
.65299 .69184 L
s
.35582 .70762 m
.34701 .69184 L
s
0 0 1 r
.30816 .65299 m
.29238 .64418 L
s
.25636 .54356 m
.24841 .52289 L
s
1 0 0 r
.54356 .25636 m
.52289 .24841 L
s
.45644 .25636 m
.47711 .24841 L
s
0 0 1 r
.75159 .52289 m
.74364 .54356 L
s
.26368 .56046 m
.25249 .54953 L
s
1 0 0 r
.56046 .26368 m
.54953 .25249 L
s
.43954 .26368 m
.45047 .25249 L
s
0 0 1 r
.74751 .54953 m
.73632 .56046 L
s
.25845 .51344 m
.24825 .51159 L
s
1 0 0 r
.51344 .25845 m
.51159 .24825 L
s
.48656 .25845 m
.48841 .24825 L
s
0 0 1 r
.75175 .51159 m
.74155 .51344 L
s
.73855 .58028 m
.72617 .58778 L
s
1 0 0 r
.58028 .73855 m
.58778 .72617 L
s
.41972 .73855 m
.41222 .72617 L
s
0 0 1 r
.27383 .58778 m
.26145 .58028 L
s
.25983 .5 m
.24932 .5 L
s
1 0 0 r
.5 .25983 m
.5 .24932 L
s
0 0 1 r
.75068 .5 m
.74017 .5 L
s
1 0 0 r
.5 .75068 m
.5 .74017 L
s
0 0 1 r
.26524 .55575 m
.25374 .54657 L
s
1 0 0 r
.55575 .26524 m
.54657 .25374 L
s
.44425 .26524 m
.45343 .25374 L
s
0 0 1 r
.74626 .54657 m
.73476 .55575 L
s
.25743 .5362 m
.25014 .51451 L
s
1 0 0 r
.5362 .25743 m
.51451 .25014 L
s
.4638 .25743 m
.48549 .25014 L
s
0 0 1 r
.74986 .51451 m
.74257 .5362 L
s
.68328 .67043 m
.66521 .67825 L
s
1 0 0 r
.67043 .68328 m
.67825 .66521 L
s
.32957 .68328 m
.32175 .66521 L
s
0 0 1 r
.33479 .67825 m
.31672 .67043 L
s
.74235 .56225 m
.73038 .56858 L
s
1 0 0 r
.56225 .74235 m
.56858 .73038 L
s
.43775 .74235 m
.43142 .73038 L
s
0 0 1 r
.26962 .56858 m
.25765 .56225 L
s
.2615 .51521 m
.25066 .51343 L
s
.74934 .51343 m
.7385 .51521 L
s
1 0 0 r
.51343 .74934 m
.51521 .7385 L
s
.48657 .74934 m
.48479 .7385 L
s
0 0 1 r
.26957 .57681 m
.25763 .55979 L
s
1 0 0 r
.57681 .26957 m
.55979 .25763 L
s
.42319 .26957 m
.44021 .25763 L
s
0 0 1 r
.74237 .55979 m
.73043 .57681 L
s
.26806 .57391 m
.25665 .55556 L
s
1 0 0 r
.57391 .26806 m
.55556 .25665 L
s
.42609 .26806 m
.44444 .25665 L
s
0 0 1 r
.74335 .55556 m
.73194 .57391 L
s
.74532 .54486 m
.73375 .54983 L
s
1 0 0 r
.54486 .74532 m
.54983 .73375 L
s
0 0 1 r
.26625 .54983 m
.25468 .54486 L
s
1 0 0 r
.45514 .74532 m
.45017 .73375 L
s
0 0 1 r
.26359 .53192 m
.2524 .52848 L
s
.7476 .52848 m
.73641 .53192 L
s
1 0 0 r
.52848 .7476 m
.53192 .73641 L
s
.47152 .7476 m
.46808 .73641 L
s
0 0 1 r
.71485 .62595 m
.69937 .63437 L
s
1 0 0 r
.62595 .71485 m
.63437 .69937 L
s
.37405 .71485 m
.36563 .69937 L
s
0 0 1 r
.30063 .63437 m
.28515 .62595 L
s
.27136 .57818 m
.25895 .56258 L
s
1 0 0 r
.57818 .27136 m
.56258 .25895 L
s
.42182 .27136 m
.43742 .25895 L
s
0 0 1 r
.74105 .56258 m
.72864 .57818 L
s
.267 .56967 m
.25617 .55008 L
s
1 0 0 r
.56967 .267 m
.55008 .25617 L
s
.43033 .267 m
.44992 .25617 L
s
0 0 1 r
.74383 .55008 m
.733 .56967 L
s
.65558 .69417 m
.63559 .70043 L
s
1 0 0 r
.69417 .65558 m
.70043 .63559 L
s
.30583 .65558 m
.29957 .63559 L
s
0 0 1 r
.36441 .70043 m
.34442 .69417 L
s
.26674 .54888 m
.25493 .54151 L
s
1 0 0 r
.54888 .26674 m
.54151 .25493 L
s
.45112 .26674 m
.45849 .25493 L
s
0 0 1 r
.74507 .54151 m
.73326 .54888 L
s
.62522 .71429 m
.60376 .71852 L
s
1 0 0 r
.71429 .62522 m
.71852 .60376 L
s
.28571 .62522 m
.28148 .60376 L
s
0 0 1 r
.39624 .71852 m
.37478 .71429 L
s
.55991 .7408 m
.53693 .73996 L
s
1 0 0 r
.7408 .55991 m
.73996 .53693 L
s
.2592 .55991 m
.26004 .53693 L
s
0 0 1 r
.46307 .73996 m
.44009 .7408 L
s
.59304 .73 m
.57058 .73183 L
s
1 0 0 r
.73 .59304 m
.73183 .57058 L
s
.27 .59304 m
.26817 .57058 L
s
0 0 1 r
.42942 .73183 m
.40696 .73 L
s
.49628 .7428 m
.47325 .74647 L
s
.52675 .74647 m
.50372 .7428 L
s
1 0 0 r
.74647 .52675 m
.7428 .50372 L
s
.25353 .52675 m
.2572 .50372 L
s
0 0 1 r
.27331 .57781 m
.26046 .56374 L
s
1 0 0 r
.57781 .27331 m
.56374 .26046 L
s
.42219 .27331 m
.43626 .26046 L
s
0 0 1 r
.73954 .56374 m
.72669 .57781 L
s
.26656 .5643 m
.25636 .54356 L
s
1 0 0 r
.5643 .26656 m
.54356 .25636 L
s
.4357 .26656 m
.45644 .25636 L
s
0 0 1 r
.74364 .54356 m
.73344 .5643 L
s
.26819 .5398 m
.25608 .53429 L
s
1 0 0 r
.5398 .26819 m
.53429 .25608 L
s
.4602 .26819 m
.46571 .25608 L
s
0 0 1 r
.74392 .53429 m
.73181 .5398 L
s
.27531 .57555 m
.26207 .56308 L
s
1 0 0 r
.57555 .27531 m
.56308 .26207 L
s
.42445 .27531 m
.43692 .26207 L
s
0 0 1 r
.73793 .56308 m
.72469 .57555 L
s
.72102 .60703 m
.70588 .61485 L
s
1 0 0 r
.60703 .72102 m
.61485 .70588 L
s
.39297 .72102 m
.38515 .70588 L
s
0 0 1 r
.29412 .61485 m
.27898 .60703 L
s
.69184 .65299 m
.67393 .66076 L
s
1 0 0 r
.65299 .69184 m
.66076 .67393 L
s
.34701 .69184 m
.33924 .67393 L
s
0 0 1 r
.32607 .66076 m
.30816 .65299 L
s
.26694 .558 m
.25743 .5362 L
s
1 0 0 r
.558 .26694 m
.5362 .25743 L
s
.442 .26694 m
.4638 .25743 L
s
0 0 1 r
.74257 .5362 m
.73306 .558 L
s
.26963 .52856 m
.25723 .52491 L
s
1 0 0 r
.52856 .26963 m
.52491 .25723 L
s
.47144 .26963 m
.47509 .25723 L
s
0 0 1 r
.74277 .52491 m
.73037 .52856 L
s
.27729 .57124 m
.26368 .56046 L
s
1 0 0 r
.57124 .27729 m
.56046 .26368 L
s
.42876 .27729 m
.43954 .26368 L
s
0 0 1 r
.73632 .56046 m
.72271 .57124 L
s
.28173 .59205 m
.26806 .57391 L
s
1 0 0 r
.59205 .28173 m
.57391 .26806 L
s
.40795 .28173 m
.42609 .26806 L
s
0 0 1 r
.73194 .57391 m
.71827 .59205 L
s
.28006 .58907 m
.267 .56967 L
s
1 0 0 r
.58907 .28006 m
.56967 .267 L
s
.41093 .28006 m
.43033 .267 L
s
0 0 1 r
.733 .56967 m
.71994 .58907 L
s
.66521 .67825 m
.64521 .68475 L
s
1 0 0 r
.67825 .66521 m
.68475 .64521 L
s
.32175 .66521 m
.31525 .64521 L
s
0 0 1 r
.35479 .68475 m
.33479 .67825 L
s
.28379 .5936 m
.26957 .57681 L
s
1 0 0 r
.5936 .28379 m
.57681 .26957 L
s
.4064 .28379 m
.42319 .26957 L
s
0 0 1 r
.73043 .57681 m
.71621 .5936 L
s
.50372 .7428 m
.48024 .73698 L
s
1 0 0 r
.7428 .50372 m
.73698 .48024 L
s
0 0 1 r
.51976 .73698 m
.49628 .7428 L
s
1 0 0 r
.2572 .50372 m
.26302 .48024 L
s
0 0 1 r
.53693 .73996 m
.51319 .73705 L
s
1 0 0 r
.73996 .53693 m
.73705 .51319 L
s
0 0 1 r
.48681 .73705 m
.46307 .73996 L
s
1 0 0 r
.26004 .53693 m
.26295 .51319 L
s
0 0 1 r
.72617 .58778 m
.71138 .59478 L
s
1 0 0 r
.58778 .72617 m
.59478 .71138 L
s
.41222 .72617 m
.40522 .71138 L
s
0 0 1 r
.28862 .59478 m
.27383 .58778 L
s
.57058 .73183 m
.54705 .7317 L
s
1 0 0 r
.73183 .57058 m
.7317 .54705 L
s
.26817 .57058 m
.2683 .54705 L
s
0 0 1 r
.45295 .7317 m
.42942 .73183 L
s
.27896 .58488 m
.26656 .5643 L
s
1 0 0 r
.58488 .27896 m
.5643 .26656 L
s
.41512 .27896 m
.4357 .26656 L
s
0 0 1 r
.73344 .5643 m
.72104 .58488 L
s
.63559 .70043 m
.61394 .70512 L
s
1 0 0 r
.70043 .63559 m
.70512 .61394 L
s
.29957 .63559 m
.29488 .61394 L
s
0 0 1 r
.38606 .70512 m
.36441 .70043 L
s
.27115 .51524 m
.25845 .51344 L
s
1 0 0 r
.51524 .27115 m
.51344 .25845 L
s
.48476 .27115 m
.48656 .25845 L
s
0 0 1 r
.74155 .51344 m
.72885 .51524 L
s
.60376 .71852 m
.58092 .72097 L
s
1 0 0 r
.71852 .60376 m
.72097 .58092 L
s
.28148 .60376 m
.27903 .58092 L
s
0 0 1 r
.41908 .72097 m
.39624 .71852 L
s
.28609 .59352 m
.27136 .57818 L
s
1 0 0 r
.59352 .28609 m
.57818 .27136 L
s
.40648 .28609 m
.42182 .27136 L
s
0 0 1 r
.72864 .57818 m
.71391 .59352 L
s
.27919 .56477 m
.26524 .55575 L
s
1 0 0 r
.56477 .27919 m
.55575 .26524 L
s
.43523 .27919 m
.44425 .26524 L
s
0 0 1 r
.73476 .55575 m
.72081 .56477 L
s
.69937 .63437 m
.68168 .64189 L
s
1 0 0 r
.63437 .69937 m
.64189 .68168 L
s
.36563 .69937 m
.35811 .68168 L
s
0 0 1 r
.31832 .64189 m
.30063 .63437 L
s
.73038 .56858 m
.71596 .57455 L
s
1 0 0 r
.56858 .73038 m
.57455 .71596 L
s
.43142 .73038 m
.42545 .71596 L
s
0 0 1 r
.28404 .57455 m
.26962 .56858 L
s
.27285 .5 m
.25983 .5 L
s
1 0 0 r
.5 .27285 m
.5 .25983 L
s
0 0 1 r
.74017 .5 m
.72715 .5 L
s
1 0 0 r
.5 .74017 m
.5 .72715 L
s
0 0 1 r
.27862 .57967 m
.26694 .558 L
s
1 0 0 r
.57967 .27862 m
.558 .26694 L
s
.42033 .27862 m
.442 .26694 L
s
0 0 1 r
.73306 .558 m
.72138 .57967 L
s
.2885 .59162 m
.27331 .57781 L
s
1 0 0 r
.59162 .2885 m
.57781 .27331 L
s
.40838 .2885 m
.42219 .27331 L
s
0 0 1 r
.72669 .57781 m
.7115 .59162 L
s
.73375 .54983 m
.71969 .55456 L
s
1 0 0 r
.54983 .73375 m
.55456 .71969 L
s
.45017 .73375 m
.44544 .71969 L
s
0 0 1 r
.28031 .55456 m
.26625 .54983 L
s
.27485 .51692 m
.2615 .51521 L
s
.7385 .51521 m
.72515 .51692 L
s
1 0 0 r
.51521 .7385 m
.51692 .72515 L
s
.48479 .7385 m
.48308 .72515 L
s
0 0 1 r
.73641 .53192 m
.72271 .53522 L
s
1 0 0 r
.53192 .73641 m
.53522 .72271 L
s
0 0 1 r
.27729 .53522 m
.26359 .53192 L
s
1 0 0 r
.46808 .73641 m
.46478 .72271 L
s
0 0 1 r
.28102 .55609 m
.26674 .54888 L
s
1 0 0 r
.55609 .28102 m
.54888 .26674 L
s
.44391 .28102 m
.45112 .26674 L
s
0 0 1 r
.73326 .54888 m
.71898 .55609 L
s
.54343 .72902 m
.51976 .73698 L
s
.48024 .73698 m
.45657 .72902 L
s
1 0 0 r
.73698 .48024 m
.72902 .45657 L
s
.26302 .48024 m
.27098 .45657 L
s
0 0 1 r
.51319 .73705 m
.48894 .73204 L
s
1 0 0 r
.73705 .51319 m
.73204 .48894 L
s
0 0 1 r
.51106 .73204 m
.48681 .73705 L
s
1 0 0 r
.26295 .51319 m
.26796 .48894 L
s
0 0 1 r
.29527 .60807 m
.28006 .58907 L
s
1 0 0 r
.60807 .29527 m
.58907 .28006 L
s
.39193 .29527 m
.41093 .28006 L
s
0 0 1 r
.71994 .58907 m
.70473 .60807 L
s
.29092 .58774 m
.27531 .57555 L
s
1 0 0 r
.58774 .29092 m
.57555 .27531 L
s
.41226 .29092 m
.42445 .27531 L
s
0 0 1 r
.72469 .57555 m
.70908 .58774 L
s
.29757 .60977 m
.28173 .59205 L
s
1 0 0 r
.60977 .29757 m
.59205 .28173 L
s
.39023 .29757 m
.40795 .28173 L
s
0 0 1 r
.71827 .59205 m
.70243 .60977 L
s
.67393 .66076 m
.65399 .66734 L
s
1 0 0 r
.66076 .67393 m
.66734 .65399 L
s
.33924 .67393 m
.33266 .65399 L
s
0 0 1 r
.34601 .66734 m
.32607 .66076 L
s
.29348 .60506 m
.27896 .58488 L
s
1 0 0 r
.60506 .29348 m
.58488 .27896 L
s
.39494 .29348 m
.41512 .27896 L
s
0 0 1 r
.72104 .58488 m
.70652 .60506 L
s
.54705 .7317 m
.52267 .72957 L
s
1 0 0 r
.7317 .54705 m
.72957 .52267 L
s
.2683 .54705 m
.27043 .52267 L
s
0 0 1 r
.47733 .72957 m
.45295 .7317 L
s
.70588 .61485 m
.68844 .62192 L
s
1 0 0 r
.61485 .70588 m
.62192 .68844 L
s
.38515 .70588 m
.37808 .68844 L
s
0 0 1 r
.31156 .62192 m
.29412 .61485 L
s
.30021 .60996 m
.28379 .5936 L
s
1 0 0 r
.60996 .30021 m
.5936 .28379 L
s
.39004 .30021 m
.4064 .28379 L
s
0 0 1 r
.71621 .5936 m
.69979 .60996 L
s
.58092 .72097 m
.55692 .72154 L
s
1 0 0 r
.72097 .58092 m
.72154 .55692 L
s
.27903 .58092 m
.27846 .55692 L
s
0 0 1 r
.44308 .72154 m
.41908 .72097 L
s
.29238 .60095 m
.27862 .57967 L
s
1 0 0 r
.60095 .29238 m
.57967 .27862 L
s
.39905 .29238 m
.42033 .27862 L
s
0 0 1 r
.72138 .57967 m
.70762 .60095 L
s
.28278 .54517 m
.26819 .5398 L
s
1 0 0 r
.54517 .28278 m
.5398 .26819 L
s
.45483 .28278 m
.4602 .26819 L
s
0 0 1 r
.73181 .5398 m
.71722 .54517 L
s
.64521 .68475 m
.62344 .6898 L
s
1 0 0 r
.68475 .64521 m
.6898 .62344 L
s
.31525 .64521 m
.3102 .62344 L
s
0 0 1 r
.37656 .6898 m
.35479 .68475 L
s
.61394 .70512 m
.5908 .70813 L
s
1 0 0 r
.70512 .61394 m
.70813 .5908 L
s
.29488 .61394 m
.29187 .5908 L
s
0 0 1 r
.4092 .70813 m
.38606 .70512 L
s
.29329 .58174 m
.27729 .57124 L
s
1 0 0 r
.58174 .29329 m
.57124 .27729 L
s
.41826 .29329 m
.42876 .27729 L
s
0 0 1 r
.72271 .57124 m
.70671 .58174 L
s
.30305 .60843 m
.28609 .59352 L
s
1 0 0 r
.60843 .30305 m
.59352 .28609 L
s
.39157 .30305 m
.40648 .28609 L
s
0 0 1 r
.71391 .59352 m
.69695 .60843 L
s
.56703 .71897 m
.54343 .72902 L
s
.45657 .72902 m
.43297 .71897 L
s
1 0 0 r
.72902 .45657 m
.71897 .43297 L
s
.27098 .45657 m
.28103 .43297 L
s
0 0 1 r
.53555 .72493 m
.51106 .73204 L
s
.48894 .73204 m
.46445 .72493 L
s
1 0 0 r
.73204 .48894 m
.72493 .46445 L
s
.26796 .48894 m
.27507 .46445 L
s
0 0 1 r
.28453 .53209 m
.26963 .52856 L
s
1 0 0 r
.53209 .28453 m
.52856 .26963 L
s
.46791 .28453 m
.47144 .26963 L
s
0 0 1 r
.73037 .52856 m
.71547 .53209 L
s
.30999 .6246 m
.29348 .60506 L
s
1 0 0 r
.6246 .30999 m
.60506 .29348 L
s
.3754 .30999 m
.39494 .29348 L
s
0 0 1 r
.70652 .60506 m
.69001 .6246 L
s
.71138 .59478 m
.69424 .60119 L
s
1 0 0 r
.59478 .71138 m
.60119 .69424 L
s
.40522 .71138 m
.39881 .69424 L
s
0 0 1 r
.30576 .60119 m
.28862 .59478 L
s
.31251 .62642 m
.29527 .60807 L
s
1 0 0 r
.62642 .31251 m
.60807 .29527 L
s
.37358 .31251 m
.39193 .29527 L
s
0 0 1 r
.70473 .60807 m
.68749 .62642 L
s
.30811 .6216 m
.29238 .60095 L
s
1 0 0 r
.6216 .30811 m
.60095 .29238 L
s
.3784 .30811 m
.39905 .29238 L
s
0 0 1 r
.70762 .60095 m
.69189 .6216 L
s
.52267 .72957 m
.49773 .72539 L
s
1 0 0 r
.72957 .52267 m
.72539 .49773 L
s
0 0 1 r
.50227 .72539 m
.47733 .72957 L
s
1 0 0 r
.27043 .52267 m
.27461 .49773 L
s
0 0 1 r
.68168 .64189 m
.66186 .64839 L
s
1 0 0 r
.64189 .68168 m
.64839 .66186 L
s
.35811 .68168 m
.35161 .66186 L
s
0 0 1 r
.33814 .64839 m
.31832 .64189 L
s
.30594 .605 m
.2885 .59162 L
s
1 0 0 r
.605 .30594 m
.59162 .2885 L
s
.395 .30594 m
.40838 .2885 L
s
0 0 1 r
.7115 .59162 m
.69406 .605 L
s
.31548 .62685 m
.29757 .60977 L
s
1 0 0 r
.62685 .31548 m
.60977 .29757 L
s
.37315 .31548 m
.39023 .29757 L
s
0 0 1 r
.70243 .60977 m
.68452 .62685 L
s
.29556 .57352 m
.27919 .56477 L
s
1 0 0 r
.57352 .29556 m
.56477 .27919 L
s
.42648 .29556 m
.43523 .27919 L
s
0 0 1 r
.72081 .56477 m
.70444 .57352 L
s
.28636 .51697 m
.27115 .51524 L
s
1 0 0 r
.51697 .28636 m
.51524 .27115 L
s
.48303 .28636 m
.48476 .27115 L
s
0 0 1 r
.72885 .51524 m
.71364 .51697 L
s
.59029 .70691 m
.56703 .71897 L
s
.43297 .71897 m
.40971 .70691 L
s
1 0 0 r
.71897 .43297 m
.70691 .40971 L
s
.28103 .43297 m
.29309 .40971 L
s
0 0 1 r
.55692 .72154 m
.532 .72018 L
s
1 0 0 r
.72154 .55692 m
.72018 .532 L
s
.27846 .55692 m
.27982 .532 L
s
0 0 1 r
.468 .72018 m
.44308 .72154 L
s
.71596 .57455 m
.69913 .58007 L
s
1 0 0 r
.57455 .71596 m
.58007 .69913 L
s
.42545 .71596 m
.41993 .69913 L
s
0 0 1 r
.30087 .58007 m
.28404 .57455 L
s
.31873 .62568 m
.30021 .60996 L
s
1 0 0 r
.62568 .31873 m
.60996 .30021 L
s
.37432 .31873 m
.39004 .30021 L
s
0 0 1 r
.69979 .60996 m
.68127 .62568 L
s
.56 .71578 m
.53555 .72493 L
s
.46445 .72493 m
.44 .71578 L
s
1 0 0 r
.72493 .46445 m
.71578 .44 L
s
.27507 .46445 m
.28422 .44 L
s
0 0 1 r
.65399 .66734 m
.63218 .67262 L
s
1 0 0 r
.66734 .65399 m
.67262 .63218 L
s
.33266 .65399 m
.32738 .63218 L
s
0 0 1 r
.36782 .67262 m
.34601 .66734 L
s
.32834 .64326 m
.30999 .6246 L
s
1 0 0 r
.64326 .32834 m
.6246 .30999 L
s
.35674 .32834 m
.3754 .30999 L
s
0 0 1 r
.69001 .6246 m
.67166 .64326 L
s
.32564 .64136 m
.30811 .6216 L
s
1 0 0 r
.64136 .32564 m
.6216 .30811 L
s
.35864 .32564 m
.3784 .30811 L
s
0 0 1 r
.69189 .6216 m
.67436 .64136 L
s
.28837 .5 m
.27285 .5 L
s
1 0 0 r
.5 .28837 m
.5 .27285 L
s
0 0 1 r
.72715 .5 m
.71163 .5 L
s
1 0 0 r
.5 .72715 m
.5 .71163 L
s
0 0 1 r
.5908 .70813 m
.56641 .70937 L
s
1 0 0 r
.70813 .5908 m
.70937 .56641 L
s
.29187 .5908 m
.29063 .56641 L
s
0 0 1 r
.43359 .70937 m
.4092 .70813 L
s
.30882 .5995 m
.29092 .58774 L
s
1 0 0 r
.5995 .30882 m
.58774 .29092 L
s
.4005 .30882 m
.41226 .29092 L
s
0 0 1 r
.70908 .58774 m
.69118 .5995 L
s
.62344 .6898 m
.6001 .69329 L
s
1 0 0 r
.6898 .62344 m
.69329 .6001 L
s
.3102 .62344 m
.30671 .6001 L
s
0 0 1 r
.3999 .69329 m
.37656 .6898 L
s
.71969 .55456 m
.70319 .55897 L
s
1 0 0 r
.55456 .71969 m
.55897 .70319 L
s
.44544 .71969 m
.44103 .70319 L
s
0 0 1 r
.29681 .55897 m
.28031 .55456 L
s
.33161 .6439 m
.31251 .62642 L
s
1 0 0 r
.6439 .33161 m
.62642 .31251 L
s
.3561 .33161 m
.37358 .31251 L
s
0 0 1 r
.68749 .62642 m
.66839 .6439 L
s
.29772 .56304 m
.28102 .55609 L
s
1 0 0 r
.56304 .29772 m
.55609 .28102 L
s
.43696 .29772 m
.44391 .28102 L
s
0 0 1 r
.71898 .55609 m
.70228 .56304 L
s
.72515 .51692 m
.70931 .51854 L
s
1 0 0 r
.51692 .72515 m
.51854 .70931 L
s
0 0 1 r
.29069 .51854 m
.27485 .51692 L
s
1 0 0 r
.48308 .72515 m
.48146 .70931 L
s
0 0 1 r
.40971 .70691 m
.38709 .69295 L
s
1 0 0 r
.70691 .40971 m
.69295 .38709 L
s
0 0 1 r
.61291 .69295 m
.59029 .70691 L
s
1 0 0 r
.29309 .40971 m
.30705 .38709 L
s
0 0 1 r
.72271 .53522 m
.70654 .53833 L
s
1 0 0 r
.53522 .72271 m
.53833 .70654 L
s
.46478 .72271 m
.46167 .70654 L
s
0 0 1 r
.29346 .53833 m
.27729 .53522 L
s
.49773 .72539 m
.47249 .71919 L
s
1 0 0 r
.72539 .49773 m
.71919 .47249 L
s
0 0 1 r
.52751 .71919 m
.50227 .72539 L
s
1 0 0 r
.27461 .49773 m
.28081 .47249 L
s
0 0 1 r
.32212 .62271 m
.30305 .60843 L
s
1 0 0 r
.62271 .32212 m
.60843 .30305 L
s
.37729 .32212 m
.39157 .30305 L
s
0 0 1 r
.69695 .60843 m
.67788 .62271 L
s
.3448 .65998 m
.32564 .64136 L
s
1 0 0 r
.65998 .3448 m
.64136 .32564 L
s
.34002 .3448 m
.35864 .32564 L
s
0 0 1 r
.67436 .64136 m
.6552 .65998 L
s
.68844 .62192 m
.66881 .62813 L
s
1 0 0 r
.62192 .68844 m
.62813 .66881 L
s
.37808 .68844 m
.37187 .66881 L
s
0 0 1 r
.33119 .62813 m
.31156 .62192 L
s
.58413 .70467 m
.56 .71578 L
s
.44 .71578 m
.41587 .70467 L
s
1 0 0 r
.71578 .44 m
.70467 .41587 L
s
.28422 .44 m
.29533 .41587 L
s
0 0 1 r
.33527 .64308 m
.31548 .62685 L
s
1 0 0 r
.64308 .33527 m
.62685 .31548 L
s
.35692 .33527 m
.37315 .31548 L
s
0 0 1 r
.68452 .62685 m
.66473 .64308 L
s
.34834 .66081 m
.32834 .64326 L
s
1 0 0 r
.66081 .34834 m
.64326 .32834 L
s
.33919 .34834 m
.35674 .32834 L
s
0 0 1 r
.67166 .64326 m
.65166 .66081 L
s
.38709 .69295 m
.36536 .67725 L
s
1 0 0 r
.69295 .38709 m
.67725 .36536 L
s
0 0 1 r
.63464 .67725 m
.61291 .69295 L
s
1 0 0 r
.30705 .38709 m
.32275 .36536 L
s
0 0 1 r
.36536 .67725 m
.3448 .65998 L
s
1 0 0 r
.67725 .36536 m
.65998 .3448 L
s
.32275 .36536 m
.34002 .3448 L
s
0 0 1 r
.6552 .65998 m
.63464 .67725 L
s
.532 .72018 m
.50644 .71687 L
s
1 0 0 r
.72018 .532 m
.71687 .50644 L
s
.27982 .532 m
.28313 .50644 L
s
0 0 1 r
.49356 .71687 m
.468 .72018 L
s
.3116 .59182 m
.29329 .58174 L
s
1 0 0 r
.59182 .3116 m
.58174 .29329 L
s
.40818 .3116 m
.41826 .29329 L
s
0 0 1 r
.70671 .58174 m
.6884 .59182 L
s
.29981 .55033 m
.28278 .54517 L
s
1 0 0 r
.55033 .29981 m
.54517 .28278 L
s
.44967 .29981 m
.45483 .28278 L
s
0 0 1 r
.71722 .54517 m
.70019 .55033 L
s
.35239 .66029 m
.33161 .6439 L
s
1 0 0 r
.66029 .35239 m
.6439 .33161 L
s
.33971 .35239 m
.3561 .33161 L
s
0 0 1 r
.66839 .6439 m
.64761 .66029 L
s
.60763 .6917 m
.58413 .70467 L
s
.41587 .70467 m
.39237 .6917 L
s
1 0 0 r
.70467 .41587 m
.6917 .39237 L
s
.29533 .41587 m
.3083 .39237 L
s
0 0 1 r
.36977 .67702 m
.34834 .66081 L
s
1 0 0 r
.67702 .36977 m
.66081 .34834 L
s
.32298 .36977 m
.33919 .34834 L
s
0 0 1 r
.65166 .66081 m
.63023 .67702 L
s
.47249 .71919 m
.44726 .71099 L
s
1 0 0 r
.71919 .47249 m
.71099 .44726 L
s
0 0 1 r
.55274 .71099 m
.52751 .71919 L
s
1 0 0 r
.28081 .47249 m
.28901 .44726 L
s
0 0 1 r
.32553 .61776 m
.30594 .605 L
s
1 0 0 r
.61776 .32553 m
.605 .30594 L
s
.38224 .32553 m
.395 .30594 L
s
0 0 1 r
.69406 .605 m
.67447 .61776 L
s
.33916 .64056 m
.31873 .62568 L
s
1 0 0 r
.64056 .33916 m
.62568 .31873 L
s
.35944 .33916 m
.37432 .31873 L
s
0 0 1 r
.68127 .62568 m
.66084 .64056 L
s
.39237 .6917 m
.36977 .67702 L
s
1 0 0 r
.6917 .39237 m
.67702 .36977 L
s
0 0 1 r
.63023 .67702 m
.60763 .6917 L
s
1 0 0 r
.3083 .39237 m
.32298 .36977 L
s
0 0 1 r
.56641 .70937 m
.54102 .70877 L
s
1 0 0 r
.70937 .56641 m
.70877 .54102 L
s
.29063 .56641 m
.29123 .54102 L
s
0 0 1 r
.45898 .70877 m
.43359 .70937 L
s
.66186 .64839 m
.64009 .65373 L
s
1 0 0 r
.64839 .66186 m
.65373 .64009 L
s
.35161 .66186 m
.34627 .64009 L
s
0 0 1 r
.35991 .65373 m
.33814 .64839 L
s
.69424 .60119 m
.67483 .60689 L
s
1 0 0 r
.60119 .69424 m
.60689 .67483 L
s
.39881 .69424 m
.39311 .67483 L
s
0 0 1 r
.32517 .60689 m
.30576 .60119 L
s
.35677 .65823 m
.33527 .64308 L
s
1 0 0 r
.65823 .35677 m
.64308 .33527 L
s
.34177 .35677 m
.35692 .33527 L
s
0 0 1 r
.66473 .64308 m
.64323 .65823 L
s
.37461 .67537 m
.35239 .66029 L
s
1 0 0 r
.67537 .37461 m
.66029 .35239 L
s
.32463 .37461 m
.33971 .35239 L
s
0 0 1 r
.64761 .66029 m
.62539 .67537 L
s
.30188 .53546 m
.28453 .53209 L
s
1 0 0 r
.53546 .30188 m
.53209 .28453 L
s
.46454 .30188 m
.46791 .28453 L
s
0 0 1 r
.71547 .53209 m
.69812 .53546 L
s
.6001 .69329 m
.5754 .69513 L
s
1 0 0 r
.69329 .6001 m
.69513 .5754 L
s
.30671 .6001 m
.30487 .5754 L
s
0 0 1 r
.4246 .69513 m
.3999 .69329 L
s
.57767 .70088 m
.55274 .71099 L
s
.44726 .71099 m
.42233 .70088 L
s
1 0 0 r
.71099 .44726 m
.70088 .42233 L
s
.28901 .44726 m
.29912 .42233 L
s
0 0 1 r
.63218 .67262 m
.6087 .67648 L
s
1 0 0 r
.67262 .63218 m
.67648 .6087 L
s
.32738 .63218 m
.32352 .6087 L
s
0 0 1 r
.3913 .67648 m
.36782 .67262 L
s
.31425 .58188 m
.29556 .57352 L
s
1 0 0 r
.58188 .31425 m
.57352 .29556 L
s
.41812 .31425 m
.42648 .29556 L
s
0 0 1 r
.70444 .57352 m
.68575 .58188 L
s
.50644 .71687 m
.48053 .71159 L
s
1 0 0 r
.71687 .50644 m
.71159 .48053 L
s
0 0 1 r
.51947 .71159 m
.49356 .71687 L
s
1 0 0 r
.28313 .50644 m
.28841 .48053 L
s
0 0 1 r
.34314 .63617 m
.32212 .62271 L
s
1 0 0 r
.63617 .34314 m
.62271 .32212 L
s
.36383 .34314 m
.37729 .32212 L
s
0 0 1 r
.67788 .62271 m
.65686 .63617 L
s
.39802 .68896 m
.37461 .67537 L
s
1 0 0 r
.68896 .39802 m
.67537 .37461 L
s
.31104 .39802 m
.32463 .37461 L
s
0 0 1 r
.62539 .67537 m
.60198 .68896 L
s
.32888 .61067 m
.30882 .5995 L
s
1 0 0 r
.61067 .32888 m
.5995 .30882 L
s
.38933 .32888 m
.4005 .30882 L
s
0 0 1 r
.69118 .5995 m
.67112 .61067 L
s
.42233 .70088 m
.39802 .68896 L
s
1 0 0 r
.70088 .42233 m
.68896 .39802 L
s
0 0 1 r
.60198 .68896 m
.57767 .70088 L
s
1 0 0 r
.29912 .42233 m
.31104 .39802 L
s
0 0 1 r
.69913 .58007 m
.67997 .58504 L
s
1 0 0 r
.58007 .69913 m
.58504 .67997 L
s
.41993 .69913 m
.41496 .67997 L
s
0 0 1 r
.32003 .58504 m
.30087 .58007 L
s
.30403 .51861 m
.28636 .51697 L
s
1 0 0 r
.51861 .30403 m
.51697 .28636 L
s
.48139 .30403 m
.48303 .28636 L
s
0 0 1 r
.71364 .51697 m
.69597 .51861 L
s
.36131 .6544 m
.33916 .64056 L
s
1 0 0 r
.6544 .36131 m
.64056 .33916 L
s
.3456 .36131 m
.35944 .33916 L
s
0 0 1 r
.66084 .64056 m
.63869 .6544 L
s
.37972 .6721 m
.35677 .65823 L
s
1 0 0 r
.6721 .37972 m
.65823 .35677 L
s
.3279 .37972 m
.34177 .35677 L
s
0 0 1 r
.64323 .65823 m
.62028 .6721 L
s
.54102 .70877 m
.51492 .70631 L
s
1 0 0 r
.70877 .54102 m
.70631 .51492 L
s
.29123 .54102 m
.29369 .51492 L
s
0 0 1 r
.48508 .70631 m
.45898 .70877 L
s
.48053 .71159 m
.45459 .70439 L
s
1 0 0 r
.71159 .48053 m
.70439 .45459 L
s
0 0 1 r
.54541 .70439 m
.51947 .71159 L
s
1 0 0 r
.28841 .48053 m
.29561 .45459 L
s
0 0 1 r
.66881 .62813 m
.64712 .63336 L
s
1 0 0 r
.62813 .66881 m
.63336 .64712 L
s
.37187 .66881 m
.36664 .64712 L
s
0 0 1 r
.35288 .63336 m
.33119 .62813 L
s
.31678 .56966 m
.29772 .56304 L
s
1 0 0 r
.56966 .31678 m
.56304 .29772 L
s
.43034 .31678 m
.43696 .29772 L
s
0 0 1 r
.70228 .56304 m
.68322 .56966 L
s
.30635 .5 m
.28837 .5 L
s
.71163 .5 m
.69365 .5 L
s
1 0 0 r
.5 .30635 m
.5 .28837 L
s
.5 .71163 m
.5 .69365 L
s
0 0 1 r
.70319 .55897 m
.68431 .563 L
s
1 0 0 r
.55897 .70319 m
.563 .68431 L
s
.44103 .70319 m
.437 .68431 L
s
0 0 1 r
.31569 .563 m
.29681 .55897 L
s
.34709 .62973 m
.32553 .61776 L
s
1 0 0 r
.62973 .34709 m
.61776 .32553 L
s
.37027 .34709 m
.38224 .32553 L
s
0 0 1 r
.67447 .61776 m
.65291 .62973 L
s
.70931 .51854 m
.69102 .52006 L
s
1 0 0 r
.51854 .70931 m
.52006 .69102 L
s
.48146 .70931 m
.47994 .69102 L
s
0 0 1 r
.30898 .52006 m
.29069 .51854 L
s
.70654 .53833 m
.68796 .54119 L
s
1 0 0 r
.53833 .70654 m
.54119 .68796 L
s
.46167 .70654 m
.45881 .68796 L
s
0 0 1 r
.31204 .54119 m
.29346 .53833 L
s
.40388 .68453 m
.37972 .6721 L
s
1 0 0 r
.68453 .40388 m
.6721 .37972 L
s
.31547 .40388 m
.3279 .37972 L
s
0 0 1 r
.62028 .6721 m
.59612 .68453 L
s
.33209 .60135 m
.3116 .59182 L
s
1 0 0 r
.60135 .33209 m
.59182 .3116 L
s
.39865 .33209 m
.40818 .3116 L
s
0 0 1 r
.6884 .59182 m
.66791 .60135 L
s
.45459 .70439 m
.42893 .69533 L
s
1 0 0 r
.70439 .45459 m
.69533 .42893 L
s
.29561 .45459 m
.30467 .42893 L
s
0 0 1 r
.57107 .69533 m
.54541 .70439 L
s
.5754 .69513 m
.54962 .69525 L
s
1 0 0 r
.69513 .5754 m
.69525 .54962 L
s
.30487 .5754 m
.30475 .54962 L
s
0 0 1 r
.45038 .69525 m
.4246 .69513 L
s
.42893 .69533 m
.40388 .68453 L
s
1 0 0 r
.69533 .42893 m
.68453 .40388 L
s
0 0 1 r
.59612 .68453 m
.57107 .69533 L
s
1 0 0 r
.30467 .42893 m
.31547 .40388 L
s
0 0 1 r
.64009 .65373 m
.61654 .65782 L
s
1 0 0 r
.65373 .64009 m
.65782 .61654 L
s
.34627 .64009 m
.34218 .61654 L
s
0 0 1 r
.38346 .65782 m
.35991 .65373 L
s
.3659 .64862 m
.34314 .63617 L
s
1 0 0 r
.64862 .3659 m
.63617 .34314 L
s
.35138 .3659 m
.36383 .34314 L
s
0 0 1 r
.65686 .63617 m
.6341 .64862 L
s
.38495 .667 m
.36131 .6544 L
s
1 0 0 r
.667 .38495 m
.6544 .36131 L
s
.333 .38495 m
.3456 .36131 L
s
0 0 1 r
.63869 .6544 m
.61505 .667 L
s
.6087 .67648 m
.58377 .67883 L
s
1 0 0 r
.67648 .6087 m
.67883 .58377 L
s
.32352 .6087 m
.32117 .58377 L
s
0 0 1 r
.41623 .67883 m
.3913 .67648 L
s
.51492 .70631 m
.48842 .70197 L
s
1 0 0 r
.70631 .51492 m
.70197 .48842 L
s
.29369 .51492 m
.29803 .48842 L
s
0 0 1 r
.51158 .70197 m
.48508 .70631 L
s
.31921 .5552 m
.29981 .55033 L
s
1 0 0 r
.5552 .31921 m
.55033 .29981 L
s
.4448 .31921 m
.44967 .29981 L
s
0 0 1 r
.70019 .55033 m
.68079 .5552 L
s
.67483 .60689 m
.65329 .61179 L
s
1 0 0 r
.60689 .67483 m
.61179 .65329 L
s
.39311 .67483 m
.38821 .65329 L
s
0 0 1 r
.34671 .61179 m
.32517 .60689 L
s
.35093 .6211 m
.32888 .61067 L
s
1 0 0 r
.6211 .35093 m
.61067 .32888 L
s
.3789 .35093 m
.38933 .32888 L
s
0 0 1 r
.67112 .61067 m
.64907 .6211 L
s
.33515 .58973 m
.31425 .58188 L
s
1 0 0 r
.58973 .33515 m
.58188 .31425 L
s
.41027 .33515 m
.41812 .31425 L
s
0 0 1 r
.68575 .58188 m
.66485 .58973 L
s
.40978 .6782 m
.38495 .667 L
s
1 0 0 r
.6782 .40978 m
.667 .38495 L
s
.3218 .40978 m
.333 .38495 L
s
0 0 1 r
.61505 .667 m
.59022 .6782 L
s
.48842 .70197 m
.46185 .6958 L
s
1 0 0 r
.70197 .48842 m
.6958 .46185 L
s
0 0 1 r
.53815 .6958 m
.51158 .70197 L
s
1 0 0 r
.29803 .48842 m
.3042 .46185 L
s
0 0 1 r
.54962 .69525 m
.52306 .69362 L
s
1 0 0 r
.69525 .54962 m
.69362 .52306 L
s
.30475 .54962 m
.30638 .52306 L
s
0 0 1 r
.47694 .69362 m
.45038 .69525 L
s
.3216 .53862 m
.30188 .53546 L
s
1 0 0 r
.53862 .3216 m
.53546 .30188 L
s
.46138 .3216 m
.46454 .30188 L
s
0 0 1 r
.69812 .53546 m
.6784 .53862 L
s
.3704 .64073 m
.34709 .62973 L
s
1 0 0 r
.64073 .3704 m
.62973 .34709 L
s
.35927 .3704 m
.37027 .34709 L
s
0 0 1 r
.65291 .62973 m
.6296 .64073 L
s
.39015 .65989 m
.3659 .64862 L
s
1 0 0 r
.65989 .39015 m
.64862 .3659 L
s
.34011 .39015 m
.35138 .3659 L
s
0 0 1 r
.6341 .64862 m
.60985 .65989 L
s
.43552 .68784 m
.40978 .6782 L
s
1 0 0 r
.68784 .43552 m
.6782 .40978 L
s
.31216 .43552 m
.3218 .40978 L
s
0 0 1 r
.59022 .6782 m
.56448 .68784 L
s
.46185 .6958 m
.43552 .68784 L
s
1 0 0 r
.6958 .46185 m
.68784 .43552 L
s
0 0 1 r
.56448 .68784 m
.53815 .6958 L
s
1 0 0 r
.3042 .46185 m
.31216 .43552 L
s
0 0 1 r
.67997 .58504 m
.65862 .58939 L
s
1 0 0 r
.58504 .67997 m
.58939 .65862 L
s
.41496 .67997 m
.41061 .65862 L
s
0 0 1 r
.34138 .58939 m
.32003 .58504 L
s
.64712 .63336 m
.62358 .6375 L
s
1 0 0 r
.63336 .64712 m
.6375 .62358 L
s
.36664 .64712 m
.3625 .62358 L
s
0 0 1 r
.37642 .6375 m
.35288 .63336 L
s
.58377 .67883 m
.55768 .6796 L
s
1 0 0 r
.67883 .58377 m
.6796 .55768 L
s
.32117 .58377 m
.3204 .55768 L
s
0 0 1 r
.44232 .6796 m
.41623 .67883 L
s
.32405 .52013 m
.30403 .51861 L
s
1 0 0 r
.52013 .32405 m
.51861 .30403 L
s
0 0 1 r
.69597 .51861 m
.67595 .52013 L
s
1 0 0 r
.47987 .32405 m
.48139 .30403 L
s
0 0 1 r
.61654 .65782 m
.59146 .66055 L
s
1 0 0 r
.65782 .61654 m
.66055 .59146 L
s
.34218 .61654 m
.33945 .59146 L
s
0 0 1 r
.40854 .66055 m
.38346 .65782 L
s
.35459 .61018 m
.33209 .60135 L
s
1 0 0 r
.61018 .35459 m
.60135 .33209 L
s
.38982 .35459 m
.39865 .33209 L
s
0 0 1 r
.66791 .60135 m
.64541 .61018 L
s
.33804 .57582 m
.31678 .56966 L
s
1 0 0 r
.57582 .33804 m
.56966 .31678 L
s
.42418 .33804 m
.43034 .31678 L
s
0 0 1 r
.68322 .56966 m
.66196 .57582 L
s
.52306 .69362 m
.49604 .69022 L
s
1 0 0 r
.69362 .52306 m
.69022 .49604 L
s
0 0 1 r
.50396 .69022 m
.47694 .69362 L
s
1 0 0 r
.30638 .52306 m
.30978 .49604 L
s
0 0 1 r
.68431 .563 m
.66318 .56657 L
s
1 0 0 r
.563 .68431 m
.56657 .66318 L
s
.437 .68431 m
.43343 .66318 L
s
0 0 1 r
.33682 .56657 m
.31569 .563 L
s
.41561 .66981 m
.39015 .65989 L
s
1 0 0 r
.66981 .41561 m
.65989 .39015 L
s
.33019 .41561 m
.34011 .39015 L
s
0 0 1 r
.60985 .65989 m
.58439 .66981 L
s
.69365 .5 m
.67333 .5 L
s
1 0 0 r
.5 .69365 m
.5 .67333 L
s
0 0 1 r
.32667 .5 m
.30635 .5 L
s
1 0 0 r
.5 .32667 m
.5 .30635 L
s
0 0 1 r
.68796 .54119 m
.66708 .54377 L
s
1 0 0 r
.54119 .68796 m
.54377 .66708 L
s
.45881 .68796 m
.45623 .66708 L
s
0 0 1 r
.33292 .54377 m
.31204 .54119 L
s
.69102 .52006 m
.67042 .52143 L
s
1 0 0 r
.52006 .69102 m
.52143 .67042 L
s
.47994 .69102 m
.47857 .67042 L
s
0 0 1 r
.32958 .52143 m
.30898 .52006 L
s
.37475 .63061 m
.35093 .6211 L
s
1 0 0 r
.63061 .37475 m
.6211 .35093 L
s
.36939 .37475 m
.3789 .35093 L
s
0 0 1 r
.64907 .6211 m
.62525 .63061 L
s
.39522 .65061 m
.3704 .64073 L
s
1 0 0 r
.65061 .39522 m
.64073 .3704 L
s
.34939 .39522 m
.35927 .3704 L
s
0 0 1 r
.6296 .64073 m
.60478 .65061 L
s
.49604 .69022 m
.46889 .68508 L
s
1 0 0 r
.69022 .49604 m
.68508 .46889 L
s
0 0 1 r
.53111 .68508 m
.50396 .69022 L
s
1 0 0 r
.30978 .49604 m
.31492 .46889 L
s
0 0 1 r
.65329 .61179 m
.62981 .61579 L
s
1 0 0 r
.61179 .65329 m
.61579 .62981 L
s
.38821 .65329 m
.38421 .62981 L
s
0 0 1 r
.37019 .61579 m
.34671 .61179 L
s
.44197 .67825 m
.41561 .66981 L
s
1 0 0 r
.67825 .44197 m
.66981 .41561 L
s
0 0 1 r
.58439 .66981 m
.55803 .67825 L
s
1 0 0 r
.32175 .44197 m
.33019 .41561 L
s
0 0 1 r
.34082 .5597 m
.31921 .5552 L
s
1 0 0 r
.5597 .34082 m
.5552 .31921 L
s
0 0 1 r
.68079 .5552 m
.65918 .5597 L
s
1 0 0 r
.4403 .34082 m
.4448 .31921 L
s
0 0 1 r
.55768 .6796 m
.53074 .67875 L
s
1 0 0 r
.6796 .55768 m
.67875 .53074 L
s
.3204 .55768 m
.32125 .53074 L
s
0 0 1 r
.46926 .67875 m
.44232 .6796 L
s
.35806 .59695 m
.33515 .58973 L
s
1 0 0 r
.59695 .35806 m
.58973 .33515 L
s
.40305 .35806 m
.41027 .33515 L
s
0 0 1 r
.66485 .58973 m
.64194 .59695 L
s
.46889 .68508 m
.44197 .67825 L
s
1 0 0 r
.68508 .46889 m
.67825 .44197 L
s
0 0 1 r
.55803 .67825 m
.53111 .68508 L
s
1 0 0 r
.31492 .46889 m
.32175 .44197 L
s
0 0 1 r
.62358 .6375 m
.59842 .64046 L
s
1 0 0 r
.6375 .62358 m
.64046 .59842 L
s
.3625 .62358 m
.35954 .59842 L
s
0 0 1 r
.40158 .64046 m
.37642 .6375 L
s
.59146 .66055 m
.56514 .66187 L
s
1 0 0 r
.66055 .59146 m
.66187 .56514 L
s
.33945 .59146 m
.33813 .56514 L
s
0 0 1 r
.43486 .66187 m
.40854 .66055 L
s
.42125 .65922 m
.39522 .65061 L
s
1 0 0 r
.65922 .42125 m
.65061 .39522 L
s
0 0 1 r
.60478 .65061 m
.57875 .65922 L
s
1 0 0 r
.34078 .42125 m
.34939 .39522 L
s
0 0 1 r
.34354 .54152 m
.3216 .53862 L
s
1 0 0 r
.54152 .34354 m
.53862 .3216 L
s
0 0 1 r
.6784 .53862 m
.65646 .54152 L
s
1 0 0 r
.45848 .34354 m
.46138 .3216 L
s
0 0 1 r
.37888 .61818 m
.35459 .61018 L
s
1 0 0 r
.61818 .37888 m
.61018 .35459 L
s
.38182 .37888 m
.38982 .35459 L
s
0 0 1 r
.64541 .61018 m
.62112 .61818 L
s
.65862 .58939 m
.63526 .59303 L
s
1 0 0 r
.58939 .65862 m
.59303 .63526 L
s
.41061 .65862 m
.40697 .63526 L
s
0 0 1 r
.36474 .59303 m
.34138 .58939 L
s
.53074 .67875 m
.50326 .67625 L
s
1 0 0 r
.67875 .53074 m
.67625 .50326 L
s
.32125 .53074 m
.32375 .50326 L
s
0 0 1 r
.49674 .67625 m
.46926 .67875 L
s
.40008 .63907 m
.37475 .63061 L
s
1 0 0 r
.63907 .40008 m
.63061 .37475 L
s
.36093 .40008 m
.36939 .37475 L
s
0 0 1 r
.62525 .63061 m
.59992 .63907 L
s
.36134 .58144 m
.33804 .57582 L
s
1 0 0 r
.58144 .36134 m
.57582 .33804 L
s
.41856 .36134 m
.42418 .33804 L
s
0 0 1 r
.66196 .57582 m
.63866 .58144 L
s
.44816 .66643 m
.42125 .65922 L
s
1 0 0 r
.66643 .44816 m
.65922 .42125 L
s
.33357 .44816 m
.34078 .42125 L
s
0 0 1 r
.57875 .65922 m
.55184 .66643 L
s
.34629 .52151 m
.32405 .52013 L
s
1 0 0 r
.52151 .34629 m
.52013 .32405 L
s
0 0 1 r
.67595 .52013 m
.65371 .52151 L
s
1 0 0 r
.47849 .34629 m
.47987 .32405 L
s
0 0 1 r
.50326 .67625 m
.47562 .67213 L
s
1 0 0 r
.67625 .50326 m
.67213 .47562 L
s
0 0 1 r
.52438 .67213 m
.49674 .67625 L
s
1 0 0 r
.32375 .50326 m
.32787 .47562 L
s
0 0 1 r
.66318 .56657 m
.63999 .56962 L
s
1 0 0 r
.56657 .66318 m
.56962 .63999 L
s
.43343 .66318 m
.43038 .63999 L
s
0 0 1 r
.36001 .56962 m
.33682 .56657 L
s
.56514 .66187 m
.53788 .66171 L
s
1 0 0 r
.66187 .56514 m
.66171 .53788 L
s
.33813 .56514 m
.33829 .53788 L
s
0 0 1 r
.46212 .66171 m
.43486 .66187 L
s
.47562 .67213 m
.44816 .66643 L
s
1 0 0 r
.67213 .47562 m
.66643 .44816 L
s
0 0 1 r
.55184 .66643 m
.52438 .67213 L
s
1 0 0 r
.32787 .47562 m
.33357 .44816 L
s
0 0 1 r
.62981 .61579 m
.60464 .6188 L
s
1 0 0 r
.61579 .62981 m
.6188 .60464 L
s
.38421 .62981 m
.3812 .60464 L
s
0 0 1 r
.39536 .6188 m
.37019 .61579 L
s
.67333 .5 m
.65081 .5 L
s
1 0 0 r
.5 .67333 m
.5 .65081 L
s
0 0 1 r
.34919 .5 m
.32667 .5 L
s
1 0 0 r
.5 .34919 m
.5 .32667 L
s
0 0 1 r
.66708 .54377 m
.64408 .54601 L
s
1 0 0 r
.54377 .66708 m
.54601 .64408 L
s
.45623 .66708 m
.45399 .64408 L
s
0 0 1 r
.35592 .54601 m
.33292 .54377 L
s
.38276 .60342 m
.35806 .59695 L
s
1 0 0 r
.60342 .38276 m
.59695 .35806 L
s
.39658 .38276 m
.40305 .35806 L
s
0 0 1 r
.64194 .59695 m
.61724 .60342 L
s
.67042 .52143 m
.64765 .52265 L
s
1 0 0 r
.52143 .67042 m
.52265 .64765 L
s
.47857 .67042 m
.47735 .64765 L
s
0 0 1 r
.35235 .52265 m
.32958 .52143 L
s
.59842 .64046 m
.57193 .64218 L
s
1 0 0 r
.64046 .59842 m
.64218 .57193 L
s
.35954 .59842 m
.35782 .57193 L
s
0 0 1 r
.42807 .64218 m
.40158 .64046 L
s
.42662 .64635 m
.40008 .63907 L
s
1 0 0 r
.64635 .42662 m
.63907 .40008 L
s
.35365 .42662 m
.36093 .40008 L
s
0 0 1 r
.59992 .63907 m
.57338 .64635 L
s
.36446 .56376 m
.34082 .5597 L
s
1 0 0 r
.56376 .36446 m
.5597 .34082 L
s
0 0 1 r
.65918 .5597 m
.63554 .56376 L
s
1 0 0 r
.43624 .36446 m
.4403 .34082 L
s
0 0 1 r
.40467 .62521 m
.37888 .61818 L
s
1 0 0 r
.62521 .40467 m
.61818 .37888 L
s
.37479 .40467 m
.38182 .37888 L
s
0 0 1 r
.62112 .61818 m
.59533 .62521 L
s
.53788 .66171 m
.51003 .66005 L
s
1 0 0 r
.66171 .53788 m
.66005 .51003 L
s
0 0 1 r
.48997 .66005 m
.46212 .66171 L
s
1 0 0 r
.33829 .53788 m
.33995 .51003 L
s
0 0 1 r
.63526 .59303 m
.61013 .59588 L
s
1 0 0 r
.59303 .63526 m
.59588 .61013 L
s
.40697 .63526 m
.40412 .61013 L
s
0 0 1 r
.38987 .59588 m
.36474 .59303 L
s
.45403 .65232 m
.42662 .64635 L
s
1 0 0 r
.65232 .45403 m
.64635 .42662 L
s
0 0 1 r
.57338 .64635 m
.54597 .65232 L
s
1 0 0 r
.34768 .45403 m
.35365 .42662 L
s
0 0 1 r
.65646 .54152 m
.63251 .5441 L
s
.36749 .5441 m
.34354 .54152 L
s
1 0 0 r
.5441 .36749 m
.54152 .34354 L
s
.4559 .36749 m
.45848 .34354 L
s
0 0 1 r
.38642 .58642 m
.36134 .58144 L
s
1 0 0 r
.58642 .38642 m
.58144 .36134 L
s
0 0 1 r
.63866 .58144 m
.61358 .58642 L
s
1 0 0 r
.41358 .38642 m
.41856 .36134 L
s
0 0 1 r
.51003 .66005 m
.48196 .65691 L
s
1 0 0 r
.66005 .51003 m
.65691 .48196 L
s
0 0 1 r
.51804 .65691 m
.48997 .66005 L
s
1 0 0 r
.33995 .51003 m
.34309 .48196 L
s
0 0 1 r
.57193 .64218 m
.54444 .6426 L
s
1 0 0 r
.64218 .57193 m
.6426 .54444 L
s
.35782 .57193 m
.3574 .54444 L
s
0 0 1 r
.45556 .6426 m
.42807 .64218 L
s
.48196 .65691 m
.45403 .65232 L
s
1 0 0 r
.65691 .48196 m
.65232 .45403 L
s
0 0 1 r
.54597 .65232 m
.51804 .65691 L
s
1 0 0 r
.34309 .48196 m
.34768 .45403 L
s
0 0 1 r
.60464 .6188 m
.57805 .62075 L
s
1 0 0 r
.6188 .60464 m
.62075 .57805 L
s
.3812 .60464 m
.37925 .57805 L
s
0 0 1 r
.42195 .62075 m
.39536 .6188 L
s
.43166 .63116 m
.40467 .62521 L
s
1 0 0 r
.63116 .43166 m
.62521 .40467 L
s
0 0 1 r
.59533 .62521 m
.56834 .63116 L
s
1 0 0 r
.36884 .43166 m
.37479 .40467 L
s
0 0 1 r
.63999 .56962 m
.61495 .57209 L
s
1 0 0 r
.56962 .63999 m
.57209 .61495 L
s
.43038 .63999 m
.42791 .61495 L
s
0 0 1 r
.38505 .57209 m
.36001 .56962 L
s
.40897 .60904 m
.38276 .60342 L
s
1 0 0 r
.60904 .40897 m
.60342 .38276 L
s
0 0 1 r
.61724 .60342 m
.59103 .60904 L
s
1 0 0 r
.39096 .40897 m
.39658 .38276 L
s
0 0 1 r
.65371 .52151 m
.62947 .52273 L
s
.37053 .52273 m
.34629 .52151 L
s
1 0 0 r
.52273 .37053 m
.52151 .34629 L
s
.47727 .37053 m
.47849 .34629 L
s
0 0 1 r
.64408 .54601 m
.61919 .54787 L
s
1 0 0 r
.54601 .64408 m
.54787 .61919 L
s
.45399 .64408 m
.45213 .61919 L
s
0 0 1 r
.38081 .54787 m
.35592 .54601 L
s
.65081 .5 m
.62632 .5 L
s
1 0 0 r
.5 .65081 m
.5 .62632 L
s
0 0 1 r
.37368 .5 m
.34919 .5 L
s
1 0 0 r
.5 .37368 m
.5 .34919 L
s
0 0 1 r
.63554 .56376 m
.61012 .56731 L
s
.38988 .56731 m
.36446 .56376 L
s
1 0 0 r
.56731 .38988 m
.56376 .36446 L
s
.43269 .38988 m
.43624 .36446 L
s
0 0 1 r
.64765 .52265 m
.62294 .52368 L
s
1 0 0 r
.52265 .64765 m
.52368 .62294 L
s
.47735 .64765 m
.47632 .62294 L
s
0 0 1 r
.37706 .52368 m
.35235 .52265 L
s
.54444 .6426 m
.51628 .6417 L
s
1 0 0 r
.6426 .54444 m
.6417 .51628 L
s
.3574 .54444 m
.3583 .51628 L
s
0 0 1 r
.48372 .6417 m
.45556 .6426 L
s
.45951 .63594 m
.43166 .63116 L
s
1 0 0 r
.63594 .45951 m
.63116 .43166 L
s
.36406 .45951 m
.36884 .43166 L
s
0 0 1 r
.56834 .63116 m
.54049 .63594 L
s
.61013 .59588 m
.58352 .59788 L
s
1 0 0 r
.59588 .61013 m
.59788 .58352 L
s
.40412 .61013 m
.40212 .58352 L
s
0 0 1 r
.41648 .59788 m
.38987 .59588 L
s
.57805 .62075 m
.55039 .62161 L
s
1 0 0 r
.62075 .57805 m
.62161 .55039 L
s
.37925 .57805 m
.37839 .55039 L
s
0 0 1 r
.44961 .62161 m
.42195 .62075 L
s
.61358 .58642 m
.58701 .59068 L
s
.41299 .59068 m
.38642 .58642 L
s
1 0 0 r
.59068 .41299 m
.58642 .38642 L
s
.40932 .41299 m
.41358 .38642 L
s
0 0 1 r
.51628 .6417 m
.48785 .63947 L
s
1 0 0 r
.6417 .51628 m
.63947 .48785 L
s
0 0 1 r
.51215 .63947 m
.48372 .6417 L
s
1 0 0 r
.3583 .51628 m
.36053 .48785 L
s
0 0 1 r
.43637 .61371 m
.40897 .60904 L
s
1 0 0 r
.61371 .43637 m
.60904 .40897 L
s
0 0 1 r
.59103 .60904 m
.56363 .61371 L
s
1 0 0 r
.38629 .43637 m
.39096 .40897 L
s
0 0 1 r
.48785 .63947 m
.45951 .63594 L
s
1 0 0 r
.63947 .48785 m
.63594 .45951 L
s
0 0 1 r
.54049 .63594 m
.51215 .63947 L
s
1 0 0 r
.36053 .48785 m
.36406 .45951 L
s
0 0 1 r
.63251 .5441 m
.60679 .54632 L
s
.39321 .54632 m
.36749 .5441 L
s
1 0 0 r
.54632 .39321 m
.5441 .36749 L
s
.45368 .39321 m
.4559 .36749 L
s
0 0 1 r
.61495 .57209 m
.58837 .57393 L
s
1 0 0 r
.57209 .61495 m
.57393 .58837 L
s
.42791 .61495 m
.42607 .58837 L
s
0 0 1 r
.41163 .57393 m
.38505 .57209 L
s
.55039 .62161 m
.522 .62133 L
s
1 0 0 r
.62161 .55039 m
.62133 .522 L
s
.37839 .55039 m
.37867 .522 L
s
0 0 1 r
.478 .62133 m
.44961 .62161 L
s
.62947 .52273 m
.6035 .52376 L
s
.3965 .52376 m
.37053 .52273 L
s
1 0 0 r
.52376 .3965 m
.52273 .37053 L
s
.47624 .3965 m
.47727 .37053 L
s
0 0 1 r
.56363 .61371 m
.53541 .61735 L
s
.46459 .61735 m
.43637 .61371 L
s
1 0 0 r
.61735 .46459 m
.61371 .43637 L
s
.38265 .46459 m
.38629 .43637 L
s
0 0 1 r
.61012 .56731 m
.58323 .57029 L
s
.41677 .57029 m
.38988 .56731 L
s
1 0 0 r
.57029 .41677 m
.56731 .38988 L
s
.42971 .41677 m
.43269 .38988 L
s
0 0 1 r
.58352 .59788 m
.55575 .59899 L
s
1 0 0 r
.59788 .58352 m
.59899 .55575 L
s
.40212 .58352 m
.40101 .55575 L
s
0 0 1 r
.44425 .59899 m
.41648 .59788 L
s
.61919 .54787 m
.59268 .54932 L
s
1 0 0 r
.54787 .61919 m
.54932 .59268 L
s
.45213 .61919 m
.45068 .59268 L
s
0 0 1 r
.40732 .54932 m
.38081 .54787 L
s
.62632 .5 m
.60013 .5 L
s
1 0 0 r
.5 .62632 m
.5 .60013 L
s
0 0 1 r
.39987 .5 m
.37368 .5 L
s
1 0 0 r
.5 .39987 m
.5 .37368 L
s
0 0 1 r
.58701 .59068 m
.55926 .59413 L
s
.44074 .59413 m
.41299 .59068 L
s
1 0 0 r
.59413 .44074 m
.59068 .41299 L
s
.40587 .44074 m
.40932 .41299 L
s
0 0 1 r
.62294 .52368 m
.59657 .52451 L
s
1 0 0 r
.52368 .62294 m
.52451 .59657 L
s
.47632 .62294 m
.47549 .59657 L
s
0 0 1 r
.40343 .52451 m
.37706 .52368 L
s
.522 .62133 m
.49327 .6199 L
s
1 0 0 r
.62133 .522 m
.6199 .49327 L
s
0 0 1 r
.50673 .6199 m
.478 .62133 L
s
1 0 0 r
.37867 .522 m
.3801 .49327 L
s
0 0 1 r
.49327 .6199 m
.46459 .61735 L
s
1 0 0 r
.6199 .49327 m
.61735 .46459 L
s
0 0 1 r
.53541 .61735 m
.50673 .6199 L
s
1 0 0 r
.3801 .49327 m
.38265 .46459 L
s
0 0 1 r
.60679 .54632 m
.57962 .54814 L
s
.42038 .54814 m
.39321 .54632 L
s
1 0 0 r
.54814 .42038 m
.54632 .39321 L
s
.45186 .42038 m
.45368 .39321 L
s
0 0 1 r
.58837 .57393 m
.56056 .57509 L
s
1 0 0 r
.57393 .58837 m
.57509 .56056 L
s
.42607 .58837 m
.42491 .56056 L
s
0 0 1 r
.43944 .57509 m
.41163 .57393 L
s
.55575 .59899 m
.52719 .59917 L
s
1 0 0 r
.59899 .55575 m
.59917 .52719 L
s
.40101 .55575 m
.40083 .52719 L
s
0 0 1 r
.47281 .59917 m
.44425 .59899 L
s
.46928 .59673 m
.44074 .59413 L
s
1 0 0 r
.59673 .46928 m
.59413 .44074 L
s
0 0 1 r
.55926 .59413 m
.53072 .59673 L
s
1 0 0 r
.40327 .46928 m
.40587 .44074 L
s
0 0 1 r
.58323 .57029 m
.55519 .57264 L
s
.44481 .57264 m
.41677 .57029 L
s
1 0 0 r
.57264 .44481 m
.57029 .41677 L
s
.42736 .44481 m
.42971 .41677 L
s
0 0 1 r
.6035 .52376 m
.5761 .52457 L
s
.4239 .52457 m
.3965 .52376 L
s
1 0 0 r
.52457 .4239 m
.52376 .3965 L
s
.47543 .4239 m
.47624 .3965 L
s
0 0 1 r
.59268 .54932 m
.5649 .55031 L
s
1 0 0 r
.54932 .59268 m
.55031 .5649 L
s
.45068 .59268 m
.44969 .5649 L
s
0 0 1 r
.4351 .55031 m
.40732 .54932 L
s
.52719 .59917 m
.49823 .59841 L
s
1 0 0 r
.59917 .52719 m
.59841 .49823 L
s
0 0 1 r
.50177 .59841 m
.47281 .59917 L
s
1 0 0 r
.40083 .52719 m
.40159 .49823 L
s
0 0 1 r
.49823 .59841 m
.46928 .59673 L
s
1 0 0 r
.59841 .49823 m
.59673 .46928 L
s
0 0 1 r
.53072 .59673 m
.50177 .59841 L
s
1 0 0 r
.40159 .49823 m
.40327 .46928 L
s
0 0 1 r
.60013 .5 m
.57255 .5 L
s
1 0 0 r
.5 .60013 m
.5 .57255 L
s
0 0 1 r
.42745 .5 m
.39987 .5 L
s
1 0 0 r
.5 .42745 m
.5 .39987 L
s
0 0 1 r
.59657 .52451 m
.56886 .52512 L
s
1 0 0 r
.52451 .59657 m
.52512 .56886 L
s
.47549 .59657 m
.47488 .56886 L
s
0 0 1 r
.43114 .52512 m
.40343 .52451 L
s
.56056 .57509 m
.5319 .57555 L
s
1 0 0 r
.57509 .56056 m
.57555 .5319 L
s
0 0 1 r
.4681 .57555 m
.43944 .57509 L
s
1 0 0 r
.42491 .56056 m
.42445 .5319 L
s
0 0 1 r
.57962 .54814 m
.55134 .54952 L
s
.44866 .54952 m
.42038 .54814 L
s
1 0 0 r
.54952 .44866 m
.54814 .42038 L
s
.45048 .44866 m
.45186 .42038 L
s
0 0 1 r
.55519 .57264 m
.52639 .57431 L
s
.47361 .57431 m
.44481 .57264 L
s
1 0 0 r
.57431 .47361 m
.57264 .44481 L
s
.42569 .47361 m
.42736 .44481 L
s
0 0 1 r
.5649 .55031 m
.5362 .55084 L
s
1 0 0 r
.55031 .5649 m
.55084 .5362 L
s
.44969 .5649 m
.44916 .5362 L
s
0 0 1 r
.4638 .55084 m
.4351 .55031 L
s
.5319 .57555 m
.50278 .57529 L
s
1 0 0 r
.57555 .5319 m
.57529 .50278 L
s
.42445 .5319 m
.42471 .50278 L
s
0 0 1 r
.49722 .57529 m
.4681 .57555 L
s
.5761 .52457 m
.54763 .52517 L
s
.45237 .52517 m
.4239 .52457 L
s
1 0 0 r
.52517 .45237 m
.52457 .4239 L
s
.47483 .45237 m
.47543 .4239 L
s
0 0 1 r
.50278 .57529 m
.47361 .57431 L
s
1 0 0 r
.57529 .50278 m
.57431 .47361 L
s
0 0 1 r
.52639 .57431 m
.49722 .57529 L
s
1 0 0 r
.42471 .50278 m
.42569 .47361 L
s
0 0 1 r
.56886 .52512 m
.54018 .5255 L
s
1 0 0 r
.52512 .56886 m
.5255 .54018 L
s
0 0 1 r
.45982 .5255 m
.43114 .52512 L
s
1 0 0 r
.47488 .56886 m
.4745 .54018 L
s
0 0 1 r
.45605 .5 m
.42745 .5 L
s
.57255 .5 m
.54395 .5 L
s
1 0 0 r
.5 .45605 m
.5 .42745 L
s
.5 .57255 m
.5 .54395 L
s
0 0 1 r
.47766 .55044 m
.44866 .54952 L
s
1 0 0 r
.55044 .47766 m
.54952 .44866 L
s
0 0 1 r
.55134 .54952 m
.52234 .55044 L
s
1 0 0 r
.44956 .47766 m
.45048 .44866 L
s
0 0 1 r
.5362 .55084 m
.50698 .55089 L
s
1 0 0 r
.55084 .5362 m
.55089 .50698 L
s
0 0 1 r
.49302 .55089 m
.4638 .55084 L
s
1 0 0 r
.44916 .5362 m
.44911 .50698 L
s
0 0 1 r
.50698 .55089 m
.47766 .55044 L
s
1 0 0 r
.55089 .50698 m
.55044 .47766 L
s
0 0 1 r
.52234 .55044 m
.49302 .55089 L
s
1 0 0 r
.44911 .50698 m
.44956 .47766 L
s
0 0 1 r
.48151 .52552 m
.45237 .52517 L
s
1 0 0 r
.52552 .48151 m
.52517 .45237 L
s
0 0 1 r
.54763 .52517 m
.51849 .52552 L
s
1 0 0 r
.47448 .48151 m
.47483 .45237 L
s
0 0 1 r
.54018 .5255 m
.51092 .52563 L
s
1 0 0 r
.5255 .54018 m
.52563 .51092 L
s
.4745 .54018 m
.47437 .51092 L
s
0 0 1 r
.48908 .52563 m
.45982 .5255 L
s
.54395 .5 m
.51472 .5 L
s
1 0 0 r
.5 .54395 m
.5 .51472 L
s
0 0 1 r
.48528 .5 m
.45605 .5 L
s
1 0 0 r
.5 .48528 m
.5 .45605 L
s
0 0 1 r
.51849 .52552 m
.48908 .52563 L
s
.51092 .52563 m
.48151 .52552 L
s
1 0 0 r
.52563 .51092 m
.52552 .48151 L
s
.47437 .51092 m
.47448 .48151 L
s
0 0 1 r
.51472 .5 m
.48528 .5 L
s
1 0 0 r
.5 .51472 m
.5 .48528 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0026OolCO027Ool0081ooaml
085oo`00O7oo9g`0OGoo001iOol]O01jOol007Eoo`Ml009oo`=l009ooaUl009oo`=l009oo`Ml07Io
o`00Lgoo1g`00goo0g`000=oog`0O0006g`000Aoog`0O01l00=oo`Ml07Aoo`00LGoo1W`000Aoog`0
Oomoo`=l009oo`]l0003Ooml07oo00Il0003Ooml07`000Ql009oo`=l009oo`03O01oog`000El079o
o`00Kgoo17`000Ioog`0Oomoog`0Ool2O0000gooO01oo`09O0000gooO01oo`03O0001GooO01l07`0
Ool00g`000=oog`0Ool02G`000=oog`0Ool00W`000Ioog`0Oomoog`0Ool4O01`Ool006eoo`9l0005
Ooml07ooOoml0002Ool00g`0Ooml0003Ool8O0001WooO01oogooO01oo`Al0004Ooml07`0Ool3O000
1WooO01oogooO01oo`Ml0007Ooml07ooOoml07ooO0000Woo00El07ooOoml07oo009l06ioo`00Jgoo
0W`00Woo00El07ooOoml07oo009l009oo`03O01oogoo00Ql000BOoml07ooOoml07ooO01oog`0Ooml
07ooO01oog`0Ooml07oo0g`00Woo00=l07ooO00027`000Aoog`0Oomoo`9l0005Ooml07ooOoml0002
Ool2O01/Ool006Uoo`=l009oo`06O01oog`0O01oog`00goo00=l07ooOol01W`000Ioog`0Oomoog`0
Ool2O0003gooO01oog`0Ooml07ooO01oog`0Ooml07ooO01oo`02O0001WooO01oogooO01oo`Ml0003
Ooml07oo009oo`06O01oog`0O01oog`00Woo0g`0JWoo001XOol2O003Ool3O002Ool01G`0Oomoogoo
O0000Woo1W`000Aoog`0Oomoo`9l000BOoml07`0Ooml07ooO01oog`0Ooml07ooO01oog`0Ooml07oo
0W`000Aoog`0O01oo`9l0003Ooml07`000Al009oo`05O01oogooOoml0002Ool3O003Ool2O01YOol0
06Ioo`=l009oo`=l00=oo`06O01oogooOoml07oo1g`000=oog`0O0000Woo00Al07ooO01oo`9l009o
o`09O01oog`0Ooml07ooO01oog`0009oo`9l0004Ooml07ooO002Ool3O0000gooO01l0004O0001Goo
O01oogooO0000goo00Al07ooO01l009oo`=l06Moo`00IGoo00=l07ooO0000Woo00Al07ooOoml00=o
o`05O01oogooO01oo`04O0001WooO01oog`0Ooml009oo`9l0005Ooml07`0Ooml0002Ool02G`0Ooml
07ooO01oog`0Ooml0002Ool2O0000gooO01oo`02O00027ooO01l07ooO01oog`0Ool4O0001GooO01o
ogooO0000goo00Al07ooOoml009oo`03O01oog`006Ioo`00I7oo00=l07ooO0000Woo00Al07ooOoml
00=oo`05O01oogooO01oo`04O0001GooO01oog`0Ool00W`00Woo00=l07ooOol00W`000=oog`0Ool0
0W`000Moog`0Ooml07ooO01oo`02O0000gooO01oo`02O002Ool00g`0Oomoo`02O0001GooO01l07`0
Ool017`000Eoog`0Oomoog`0009oo`05O01oogooOoml0002Ool00g`0Ooml001UOol006=oo`03O01o
og`000=oo`04O01oogooO002Ool017`0Oomoogoo1G`00Woo0W`000Eoog`0Ooml07oo009l0003Ooml
07oo009l009oo`08O01oogooO01oog`0Ooml009oo`04O01oog`0Ool2O002Ool2O0002WooO01l07oo
O01oog`0Ooml07oo17`00goo00Al07ooOoml009oo`07O01oogooOoml07ooO000I7oo001ROol00g`0
Ooml0003Ool017`0Oomoog`00goo00=l07ooOol017`000Moog`0Ooml07ooO01oo`02O002Ool2O000
0gooO01oo`02O002Ool027`0Oomoog`0Ooml07ooO002Ool00g`0Oomoo`02O0000gooO01oo`02O002
Ool2O0001GooO01oog`0Ool01W`00goo00Al07ooOoml009oo`04O01oogooO002Ool00g`0Oomoo`1Q
Ool0065oo`04O01oogooO002Ool017`0Oomoog`00goo00=l07ooOol01W`00Woo0W`000]oog`0Ooml
07ooO01oog`0Ooml07oo009l009oo`08O01oogooO01oog`0Ooml009oo`03O01oogoo009l0007Ooml
07ooO01oog`0Ool00W`000Aoog`0Ooml009oo`Il00=oo`04O01oogooO002Ool017`0Oomoog`00Woo
00=l07ooOol0H7oo001POol017`0Oomoog`00Woo00Al07ooOoml00=oo`03O01oogoo00Il009oo`04
O01oog`0Ool2O002Ool2O002Ool2O0000gooO01oo`02O0001GooO01oogooO0000Woo00=l07ooO000
0Woo00Al07ooO01l009oo`9l009oo`9l0004Ooml07ooO002Ool00g`0Ooml0003O002Ool01g`0Oomo
ogooO01oog`000=oo`03O01oog`0069oo`00H7oo00=l07ooO0000goo00=l07ooO0000goo00=l07oo
Ool00g`000=oog`0O0000Woo0W`000=oog`0Ool00W`000Moog`0Ooml07ooO01oo`02O002Ool2O000
1GooO01oogooO0000Woo00Al07ooO01l009oo`=l009oo`9l009oo`9l0003Ooml07oo009l009oo`9l
0004Ooml07`0O002Ool017`0Oomoog`00Woo00Al07ooOoml009oo`03O01oogoo05moo`00Ggoo00Al
07ooOoml009oo`04O01oogooO003Ool00g`0Ooml0002O00017ooO01l07`00Woo00il07ooO01oog`0
Ooml07ooO01oog`0Ooml07oo0W`00Woo0W`000Eoog`0Oomoog`0009oo`04O01oog`0O002Ool2O000
1gooO01oog`0Ooml07oo009l009oo`=l009oo`04O01oog`0Ool3O0000gooO01oo`02Ool017`0Oomo
og`00Woo00Al07ooOoml061oo`00GWoo00Al07ooOoml009oo`04O01oogooO002Ool00`0OO01l0003
O000100OO0007g`00P0O0W`000<07g`001l00W`00Woo00Il07ooO01oog`0Ool2O002Ool2O0001Goo
O01oogooO0000Woo00Al07ooO01l009oo`9l0006Ooml07ooO01oog`00Woo0W`000<07g`001l00W`0
0P0O00Al000OO0007`El000301moog`0009oo`04O01oogooO002Ool00g`0Oomoo`1NOol005ioo`04
O01oogooO002Ool00g`001l07`0301l01GooO01l07`0Ool00W`000=oog`0Ool00Woo0W`000=oog`0
Ool00W`00`0O00Il000OOoml07ooO003Ool2O0001GooO01oogooO0000Woo00Al07ooO01l009oo`9l
0005Ooml07oo01ml000301l2O002Ool3O002Ool2O00017ooO01l07oo0g`000=oo`0O01l00`0O00Al
07ooOoml009oo`03O01oogoo05eoo`00GGoo00Ql07ooOoml07oo01ml000O0Woo00=l07ooOol01G`0
00Aoog`0O01l009oo`9l0003Ooml07oo009l009oo`04O01oog`0Ool201l2O0000`0OOomoo`02O000
1GooO01oogooO0000Woo00Al07ooO01l009oo`0301ml000O00807`03Ooml07`000=oo`03O01oogoo
009l0006Ooml07ooOoml07oo1g`00Woo00Al07ooOoml00807`04O01oogooO01OOol005eoo`07O01o
ogooO0007gooO0000Woo00=l07ooOol01g`000D07g`001l07g`000<07`04O0007g`0O002Ool2O002
Ool01G`0Ooml07`0Ool00P0O00Al000OOoml009oo`05O01oogooO01oo`02O00201l01GooO01l07oo
O0000Woo0W`00Woo0W`00P0O00=l000OO0000`0O00=l000OO0001W`00Woo00Ml07ooOoml07oo01ml
0002Ool00g`0Oomoo`1LOol005aoo`04O01oo`0OO002Ool01W`0OomoogooO01oo`Al0004Ooml07`0
Ool2O002Ool2O0001WooO01oog`0Ooml00807`9l00807`04O0007g`0O003Ool017`0Ool07`0O0Woo
00=l07ooOol00P0O00=oog`0Ool00Woo0W`000@07g`001l07`9l00807`9l009oo`9l0003Ooml07oo
009l009oo`9l0003Ooml07`0009l0005Ooml07ooOoml0002Ool017`001l07g`0GWoo001LOol017`0
01moog`00Woo00=l000O01l00P0O17`000Eoog`0O01l07oo009l0007Ooml07ooO01oog`0Ool00W`0
0goo0W`00Woo00=l07ooO0000`0O0W`00Woo00Al000O01ml00807`04O01oogooO00401l00g`0Ooml
0002Ool2O003Ool2O002Ool3O002Ool2O0001GooO01l07`0Ool017`0100O00El07ooOoml07oo0080
7eeoo`00FWoo00T07g`0Oomoog`0Ool07g`001l00Woo2G`000Ioog`0Ooml07ooO00201l00g`001l0
7`02O002Ool01G`0Ooml07ooO0000Woo0W`00Woo0W`000<07gooO0000P0O00Il000O01ml07oo01l2
O002Ool2O00017ooO01oogoo0W`00goo0W`00P0O00El000O01ml07oo009l009oo`03O01oog`000Il
009oo`04O0007`0OO002Ool00g`001l07`1KOol005Qoo`807`08Ooml07ooOoml000OOoml00=oo`El
000301ml07`000807`06O0007`0OO0007goo0W`000Aoog`001ml00807`9l00807`03O0007goo009l
009oo`9l00D07`03O0007`0O00<07`9l009oo`9l0007Ool07g`001ml000OO0000P0O00Al000OOomo
o`9l0003Ooml000O00807`06O0007g`001ml000O1G`00goo00Al07oo01l07`9oo`04O01oo`0O01mI
Ool005Ioo`807`9oo`04O01oo`0OO003Ool00g`0Oomoo`05O0001P0OO01oog`0Ooml009oo`9l0003
Ooml07`0009oo`03O01oog`0009oo`9l009oo`03O01oog`000D07`03O01oogoo00<07`04O0007`0O
01l2Ool00g`001l07`0201l017`001moog`00Woo0W`00Woo00=l07ooO0000Woo0W`000Eoog`0O01o
og`0009oo`04O01oog`001l5O002Ool017`0Oomoog`00P0O00Al07ooOomoo`807eMoo`00EGoo00<0
7gooOol00Woo0P0O00=oog`0Ool00Woo00=l000OO0000g`000Aoog`0O01oo`9l0003Ooml07oo009l
009oo`9l009oo`9l00=oo`9l009oo`05O01oog`0Ooml000301l017`001l07g`00Woo00Al07ooOoml
00807`09O0007`0O01ml07ooO01oog`0009oo`9l00=oo`9l009oo`9l0008Ooml07ooO01oog`0Ooml
009oo`9l0003Ooml07`0009l00807`=oo`04O01oo`0O01l4Ool00`0OOomoo`1DOol005=oo`807`=o
o`807`=oo`05O0007`0OO01oo`04O00027ooO01l07`0Ooml07ooO00201l2O00201l2O00301l00g`0
01l07`0201l00g`001l07`02Ool00g`001l07`02Ool02`0OO01oogooO0007gooO01oo`0OO0000Woo
00Al000OOomoo`807`03O01oog`000807`03O0007`0O00807`04O0007`0O01l2O00201l2O0001P0O
O0007gooO01oo`=l0003Ooml07`0009l0005Ool07`0O01ml0002Ool00g`001l07`03Ool201mDOol0
059oo`0401moogooOol201l017ooO01oogoo0P0O0Woo2G`000D07g`0O0007g`0009oo`05O01oogoo
Ooml0002Ool00g`0Ooml0002Ool01G`0Ooml07ooO0000P0O0W`00`0O0W`00Woo00Al000O01ml0080
7`03O01oogoo009l00<07`9l00807`05O01oog`0Ooml0002Ool2O003Ool00g`0Oomoo`02O002Ool0
0g`001ml000201l5O00017ooO01l07`00Woo0P0O0Woo00Al07oo01l07`=oo`0301moogoo055oo`00
DGoo00<07gooOol00P0O0goo00Al000O01ml00=oo`9l0004Ooml07`001l2O0000`0OOoml0002O002
Ool2O002Ool2O002Ool00g`0Ooml0002Ool01g`0Ooml07ooO0007goo009l00@07`04O0007`0O01l2
Ool00g`0Oomoo`0301l00g`001l07`0201l2O0001goo01ml07ooO01oog`0009oo`03O01oog`0009o
o`05O01oogooOoml0002Ool01W`0Ooml07`0Ool07`9l000401ml07`0Ool2O003Ool017`001l07g`0
0goo0P0O0Woo00<07gooOol0D7oo001@Ool0100OOomoo`0O17oo0P0O0Woo00=l07ooOol00W`000L0
7g`0O01oog`0Ooml0002Ool3O002Ool017`0Oomoogoo0W`00Woo0W`00goo00=l07ooO0000P0O00Ao
o`0OO01l009oo`807`03O01oog`000<07`04O0007`0O01l2Ool00g`001l07`02Ool2O0001`0OOol0
7`0OO01oog`0009oo`03O01oog`0009oo`9l009oo`9l009oo`=l009oo`04O01oog`0Ool2O0000`0O
O01l0002Ool00g`0Oomoo`0201l4Ool0100OOomoo`0ODGoo001?Ool0100OOol07`0O0goo0P0O00Ql
07ooOomoog`001ml000O0W`000Aoog`0O01oo`9l0005Ooml07`0Ooml000201l01G`001l07`0OO000
100O00=l000O01l00P0O00=l000O01l00`0O00Ml000O01l07g`0Ooml000401l00gooO01oo`0401l0
0g`0Ooml000301l00g`001l07`0301l00g`001l07`0201l00g`001l07`0201l01G`001l07`0OO000
0P0O0W`000=oog`0Ool00W`000Aoog`0O01oo`=l00807`05O01oogooOoml000201l3Ool201l00goo
01moo`1?Ool004ioo`0301moo`0O00Aoo`0501moogooO01oo`0201l00g`0Ooml0002O0001GooO01l
07`0Ool00W`000@07g`0O01l009oo`9l00=oo`04O01oogooOol2O002Ool201l00g`001l07`02Ool0
0g`001moo`0401l00g`0Ooml0003Ool01g`0OomoogooO01oog`000@07`03Ool07g`0009oo`807`03
O0007`0O009oo`9l00=oo`04O01oogooOol2O002Ool3O00201l00g`0Ooml0002O0001WooO01l07`0
Ooml00807`05Ooml07ooOol07`04Ool00`0OOol07`1?Ool004eoo`0301moo`0O00=oo`807`=oo`05
O0007gooO01oo`05O0000`0OO0007`02O0000gooO01oo`02O002Ool00g`0Oomoo`02Ool01W`0Oomo
og`0Ooml00807`05O01oog`0Ooml000201l2O0000goo01l07`02O0000goo01l07`0301l00g`001l0
7`0301l00gooO01l000201l00gooO01l000201l01G`0Ooml07ooO0000P0O00=l07ooO0000Woo00=l
07ooOol00Woo00=l07ooOol00W`000Qoog`0Ool07g`001ml000O1W`00Woo00<07g`0Ool00Woo0P0O
0goo0P0OCgoo001=Ool201l3Ool0100OOomoogoo0P0O00=l07ooOol00g`000=oog`001l00W`00Woo
0W`000=oog`0Ool00W`00Woo00El07ooOomoog`000=oo`03O01oog`0009oo`807`03O0007`0O009o
o`03O0007`0O009oo`9l009oo`@07`03O0007`0O00807`9oo`9l009oo`807`03O01oogoo00807`03
O0007`0O009oo`03O01oog`000=oo`05O01oogooOoml0002Ool2O0000gooO01oo`02O0001gooO01l
07`001ml07oo00=l009oo`03O0007`0O00=oo`0401moogooOol201m>Ool004aoo`807`9oo`807`9o
o`807`9oo`05O01oogooO01oo`04O0001GooO01oog`0Ool00W`00Woo0W`00P0O00El000O01l07g`0
00@07`03O0007`0O00<07`03O0007`0O00807`03O0007`0O00<07`04O0007`0OO003Ool01G`0Oomo
ogooO0000P0O00=l000O01l00`0O00=l000O01l00P0O00=l000O01l00`0O00=l000O01l00P0O00El
000O01l07g`000807`04O0007gooOol2O0001GooO01oog`0Ool017`000Eoog`0Oomoog`0009oo`80
7`9oo`807`9oo`807deoo`00Bgoo0P0O0Woo00D07gooOomoo`0O00=oo`04O01oogoo01l2O00017oo
O01l07oo0g`00Woo00<07g`001l00W`00goo00El07ooOomoog`0009oo`807`03O0007`0O00807`04
Ooml000O01l2Ool2O0000goo01l07`02O00501l00gooO01oo`0501l2O00201l00gooO01l0002Ool2
01l00g`0Ool07`0301l00g`001l07`02Ool01G`0OomoogooO0000goo00Ql000O01ml000OOoml07oo
0W`000Aoog`0O01oo`9l000401moogooO003Ool01@0OOomoogoo01l00Woo00<07gooOol0Bgoo001;
Ool0100OOomoo`0O0goo00<07gooOol00Woo0`0O0W`000Qoog`0O01l07ooO0007g`00P0O0W`000=o
og`0O0000Woo0W`00goo00Il07oo01moo`0OO00201l01W`001l07g`0Ooml009oo`03O0007`0O009o
o`9l009oo`05O0007`0O01ml000301l00g`0Oomoo`02O002Ool201l01W`0Oomoog`0Ooml00807`09
O0007`0OO0007goo01moog`000=oo`9l009oo`9l0003Ooml07`000807`04O0007g`0Ool3O0000goo
O01l000301l4Ool01P0OOomoogoo01moo`807daoo`00BWoo0P0O00=oo`0OOol00Woo00@07gooOomo
o`807`03O01oogoo00=l0006Ooml000OO01oog`00Woo0W`00Woo0W`00Woo0W`00Woo0W`000H07goo
01l07g`0Ool201l01GooO01oogooO0000P0O0W`00goo00<07g`001l00P0O0goo00Al07ooOomoo`<0
7`03O0007goo009oo`9l00807`05O01oogooO01oo`0201l01WooO0007`0OOol07`9l009oo`9l009o
o`9l009oo`9l0008Ooml07`0Ooml000OO01oo`=l009oo`03O0007`0O00=oo`0401moogoo01l2Ool0
0`0OOomoo`1:Ool004Yoo`0501moogoo01moo`0201l2Ool201l2Ool01G`0Ooml07`0Ool00g`000Ao
og`0O01l009oo`9l009oo`04O01oogooOol2O00201l00g`001l07`0201l00g`001l07`0301l00g`0
01l07`0301l00g`001l07`0301l017`001l07`0O0goo00Al07ooOomoo`<07`03O0007`0O00<07`03
O0007`0O00<07`03O0007`0O00<07`03O0007`0O00807`05O0007`0O01ml0003Ool00g`0Oomoo`02
O002Ool3O0001GooO01l07`0Ool00W`000Aoog`0Oomoo`807`9oo`807`05Ool07gooOol07`1;Ool0
04Uoo`807`04Ool07`0O01l3Ool00`0OOomoo`02Ool01W`0Ooml000OO01oo`=l0003Ooml07oo009o
o`05O0007`0O01ml000201l2O003Ool01W`001l07`0OOoml00=oo`03O0007g`0009oo`03O01oo`0O
009l00=oo`9l009oo`05O0007`0O01ml000301l00g`0Oomoo`02O003Ool2O0000`0OOoml0002Ool0
0g`001ml0003Ool00g`0Ool07`0201l01G`0OomoogooO0000`0O00El000O01l07g`0009oo`9l000:
Ooml07`0O01oog`001ml07ooO004Ool0100OOomoogoo0`0O00=oo`0OOol0BWoo0019Ool0100OOol0
7`0O17oo00<07gooOol00goo1W`000Eoog`0O01oog`0009oo`0401ml07ooOol2O002Ool2O002Ool0
100OO0007goo0P0O00=l07oo01l00P0O00=oog`001l00`0O00=oog`0O0000goo0W`01@0O00=oog`0
Ool01@0O0W`00goo0W`000=oo`0O01l00P0O00=l07oo01l00P0O00Qoog`001l07goo01ml000O0Woo
0W`00Woo0W`00Woo00Il000OOomoog`0Ool2O0000gooO01l0004O005Ool02@0OOomoogoo01moo`0O
Ool07`1:Ool004Qoo`<07`03Ool07goo009oo`0301moogoo00=oo`0<01ml07`0Ooml07ooO01oog`0
Ool07g`00P0O0W`00Woo0W`00Woo0W`000Ioo`0O01ml07oo01l2Ool00g`001moo`0301l00g`0Ooml
0003Ool2O00401l017`0Oomoog`00goo00El07ooOomoog`0009oo`03O0007`0O00807`9l00=oo`03
O01oog`000<07`03Ool07g`0009oo`0301moog`000807`03Ooml07`0009oo`9l009oo`9l00807`09
O0007gooO01oog`0Ooml07oo009l000301moogoo00=oo`0601moogooOol07goo0P0OBWoo0018Ool2
01l00goo01moo`02Ool00`0OOomoo`02Ool201l017ooO01oogoo0W`00P0O00Al000OO01l009oo`9l
0004Ooml07ooO002Ool01G`001l07`0OO0001@0O00Ml000O01l07g`001ml000501l2O00401l017`0
01l07g`00goo00El07ooOomoog`000807`03O0007`0O00807`9l00D07`03O0007g`000<07`03O000
7`0O00807`03O0007`0O00807`07O01oogooO01oog`0Ool00W`00Woo0W`000@07g`001l07`9l009o
o`04O01oo`0O01l4Ool0100OOomoo`0O0Woo0P0OBGoo0018Ool01@0OOomoo`0OOol00P0O0goo0P0O
0Woo0W`000Eoog`0O01l07oo009l0003Ooml07`0009oo`9l0003Ooml000O00807`05O0007`0OOol0
7`02O0001@0OOol07g`001l00goo00=l07ooO0000P0O0goo0W`00goo0W`000=oo`0O01l00`0O00=l
000O01l00`0O00=oog`0O0000goo0W`00goo0P0O00=l07ooO0000goo00El000O01moo`0O009l0004
01moo`0OO00401l017`0Ooml07`00Woo0W`000Aoog`0O01oo`=l0003Ooml07`0009oo`807`=oo`80
7`03Ool07goo00807dUoo`00Agoo0P0O00Aoo`0OOol07`=oo`807`=oo`Al0004Ooml07ooOol3O000
17ooO01oog`00`0O00Ml07ooO01oog`001ml000201l2O00201l00gooO01oo`02Ool201l017`001mo
og`00goo00=l07ooOol00`0O00Al000OOoml00=oo`08O01oogooOoml07oo01ml00<07`03Ooml07`0
00=oo`03O01oog`000<07`=oo`04O01oo`0O01l2O00201l01g`001ml07ooO01oog`000<07`05O01o
og`0O01oo`02O002Ool00g`0Ooml0003O003Ool201l3Ool0100OOol07goo0P0OB7oo0017Ool01@0O
Ool07goo01l00goo00<07gooOol00goo17`000=oog`0Ool00W`000=oog`001l00P0O00Al07ooO01l
009oo`04O0007g`0Ool201l00gooO01l0003Ool01G`001l07`0OOol00W`00Woo00Al000O01ml00<0
7`9oo`9l009oo`05O01oogooOoml0003Ool00g`0Oomoo`02O002Ool201l01G`001l07`0OO0000Woo
0W`000Eoo`0O01l07g`000=oo`9l000=Ool07`0OOoml000OO01oog`0Ooml07ooO0000`0O00Ml07oo
O01l07ooO01oo`04O005Ool01P0OOomoogoo01moo`<07dQoo`00AWoo0`0O0Woo00@07gooOol07`Ao
o`0601ml07`0Ooml07oo0W`000Ioog`0O0007g`0Ool2O002Ool2O002Ool027`001ml000OO01oo`0O
O00401l01g`001l07`0OO0007g`000807`04O0007`0OO00501l2O00601l00g`001l07`0401l2O005
01l017`001l07g`00P0O00=l000OO0000`0O00=l000O01l00P0O00Ql000OOoml000OO0007g`00Woo
0W`00Woo0W`000=oog`001l00W`000Ioog`0O01oog`0Ool2O0000`0OOomoo`02Ool0100OOomoo`0O
0Woo0`0OAgoo0016Ool201l2Ool0100OOomoo`0O0goo0P0O00Il07ooO01oog`0Ool2O000100OO01l
07`00Woo0W`00Woo0W`00`0O00=l000O01l00`0O00Ml000O01l07gooO01oo`0201l00g`0Ooml0002
Ool00g`0Oomoo`02O003Ool201l00g`001l07`0401l00g`001l07`0401l00g`001l07`03Ool2O002
Ool01W`0Oomoog`0Ooml00807`03Ooml07oo00<07`03O0007`0O00<07`04O0007`0O01l2O002Ool2
O002Ool3O0002@0OO01l07ooO01oog`0Ooml000201l3Ool01@0OOomoo`0OOol00`0OAgoo0016Ool2
01l01Goo01moogoo01l00Woo0P0O0Woo0W`000Eoog`001ml000O009l0003Ooml07`0009oo`04O01o
o`0O01l2O00301l027`001l07g`0Ooml000OO003Ool01g`001moogooO01oog`0009oo`04O01oogoo
O00401l00gooO01l0002Ool01G`0OomoogooO0000goo00=l07ooOol00W`000=oo`0O01l00P0O00Al
07ooOoml009oo`03O01oog`0009oo`0301ml07oo009oo`9l000301moog`000807`04O0007`0O01l2
O00201l017ooO01oogoo0W`000Aoog`0O01l00807`04O01oog`0O002Ool201l2Ool01@0OOomoo`0O
Ool00P0OAgoo0015Ool201l00goo01moo`0201l2Ool0200OOomoogooO01oog`001l3O00017ooO01l
07oo0W`00P0O00El000OOomoog`000<07`9l0007Ool07`0O01ml07ooO0000`0O00Ml07ooOomoog`0
Ooml000501l2O003Ool00g`0Ooml0002Ool01G`0OomoogooO0000goo00Il07ooOoml07ooO003Ool2
O00501l00g`0Ooml0003Ool01g`001l07`0OO01oog`000<07`03Ooml07`000807`9l009oo`0401ml
000O01l2O00017ooO01l07oo0g`000@07g`0Ooml00=oo`0301moogoo00807`04Ool07`0O01m7Ool0
04Eoo`<07`04Ool07gooOol201l4Ool2O0000gooO01oo`02O00017ooO01oo`0O0W`00Woo00El07oo
Oomoog`000<07`9l000701moog`0Ooml000OO0000goo00=l000O01l00`0O00Al000O01ml00807`9l
00D07`04O0007`0OO00201l00gooO01oo`0201l017`001l07g`01@0O0W`00P0O00Al000O01ml00D0
7`0;O01oogooOoml000OO01oog`0Ool07`02O00301l01G`0OomoogooO0000Woo0W`000@07gooO01o
o`9l0003Ooml07oo009l00Aoo`807`9oo`0301moo`0O00807dIoo`00AGoo0P0O00Eoo`0OOomoo`0O
00Eoo`07O01oog`0Ooml07ooO0000Woo00=l000OOol00W`000=oog`0O0000Woo00L07g`001moo`0O
O01oo`0201l00g`001ml000401l2O0001P0OOomoog`0Ooml009oo`03O01oogoo009l00=oo`03O000
7g`000H07`03O0007`0O00@07`03O0007g`000=oo`9l009oo`06O01oogooO01oog`00Woo00<07g`0
01l0100O00=l000OO0000P0O00Moog`001moo`0OO0007`02Ool00g`0Oomoo`02O0000goo01ml0002
Ool01g`0Ooml07ooO01oog`000Eoo`0301moo`0O009oo`807dIoo`00AGoo0P0O00Aoo`0OOol07`Ao
o`807`9l000:Ooml07ooOoml000OO01oog`0Ool2O00017ooO01l07oo0P0O00El000O01l07g`00080
7`03Ooml07`0009oo`03O0007goo009l00=oo`9l009oo`0501ml000O01ml000501l01GooO01oogoo
O0000goo00El07ooOomoog`0009oo`03O01oo`0O00@07`09O0007`0OO0007gooO01oog`000=oo`9l
0008Ool07g`0Ooml07ooO01oo`807`05O0007`0O01ml000201l017ooO01l07oo0W`000Ioog`0Ooml
000OO002Ool017`0Ooml07`00P0O17oo00@07goo01moo`807dIoo`00A7oo0P0O00Aoo`0OOol07`=o
o`807`06Ooml07ooO01oog`00P0O00Il07ooO01oog`0Ool2O0000gooO01l000201l2O00301l017`0
Oomoogoo0W`00P0O00=l07ooOol00W`00Woo00<07g`0O0000P0O00Aoog`0Oomoo`9l00=oo`03O01o
og`0009oo`05O01oogooOoml0003Ool01W`0Oomoog`0Ooml00=oo`9l009oo`04O01oo`0O01l2O000
0`0OOomoo`02O002Ool00g`001l07`02O003Ool01G`001l07`0OO0000`0O0W`000Uoog`0O01oog`0
Ooml07ooO0000P0O00Il07ooO01oog`0Ool201l3Ool201l2Ool201m5Ool004Aoo`807`03Ool07`0O
00=oo`0401moogooOol2O0001P0OO01oogooO01oo`9l0004Ooml07`0Ool201l017`001l07`0O0W`0
00@07gooOoml00<07`9l009oo`04O01oo`0OO00301l00gooO01l0003Ool00g`001l07`02O00301l0
0g`001ml000201l01G`001moogooO0000Woo00L07g`001l07g`001ml000301l2O00301l3Ool2O000
27oo01l07`0OO0007gooO002Ool2O00301l017`0Oomoo`0O0W`00`0O00Al000O01moo`9l0005Ooml
07`0Ooml0002Ool017`001ml07`00goo00@07gooOomoo`807`03Ool07`0O04Eoo`00A7oo100O0goo
00T07gooOomoog`001ml07ooO0000Woo00Al07ooO01oo`807`06O0007g`0O0007g`00P0O0W`00Woo
00<07g`0Ool00Woo0W`00P0O00Al000O01ml00D07`04O0007`0OO003Ool2O00301l00g`001ml0002
01l01G`001l07`0OO0000`0O00Il000O01ml000OO00301l2O003Ool301l00g`001l07`0301l017`0
01l07g`00P0O0W`00goo00Al000OOomoo`9l00807`9l000401ml000OO00201l2O0002GooO01oogoo
O01oog`001ml0003Ool0100OOomoogoo100OAGoo0013Ool501l2Ool01`0OOomoogoo01ml07oo009l
009oo`06O0007`0OO0007goo0W`000=oo`0OO0000P0O0Woo00Al000O01l07`9l00<07`9l009oo`03
O01oogoo009l00=oo`9l00807`04O0007`0O01l2O003Ool00g`0Ooml0002Ool01G`0OomoogooO000
0goo00Il07ooOoml07ooO003Ool2O00301l00g`001l07`02O0000`0OOomoo`02O002Ool00g`0Oomo
o`02O00301l00g`001l07`0201l00g`0Oomoo`0201l00g`001moo`02O0000goo01ml000201l00g`0
Oomoo`02O0000gooO0007`03Ool00`0OOomoo`0401m5Ool004=oo`@07`9oo`0:01moogooOol07g`0
Ooml07ooO00201l017`0Oomoog`00Woo00El07oo01l07g`000<07`03O0007g`000807`9l00=oo`9l
009oo`04O01oogooO00401l2O002Ool017`0Oomoogoo0W`00goo00=l07ooO0000Woo00El07ooOomo
og`000=oo`06O01oogooO01oog`00goo0W`00goo00=l07ooOol00W`000Eoo`0O01l07g`0009oo`03
O01oogoo009l00=oo`9l00807`9l00@07`03O0007`0O009l009oo`04O01oogooO00201l01W`0Ooml
07ooO0007`=oo`0301moogoo00@07dAoo`00@goo0`0O0Woo00<07gooOol00P0O00Qoog`0Ooml000O
O01oog`00goo00Al07ooOoml00<07`03O0007`0O009l000401ml07ooOol2O003Ool00g`0Ool07`04
01l2O003Ool2O002Ool017`0Oomoogoo0W`00goo00=l07ooO0000Woo00El07ooOomoog`000=oo`06
O01oogooO01oog`00goo0W`00goo00=l07ooOol00W`00goo0W`01@0O0W`00goo0W`00Woo00Al000O
O01l00807`05O0007`0O01ml0002Ool037`0OomoogooO01oog`001ml07ooO01oo`807`9oo`0301mo
ogoo00<07dAoo`00@goo0`0O00Eoo`0OOomoo`0O009oo`05O01oog`001ml0002Ool027`0Oomoog`0
Ooml000OO00201l2O0001Woo01l07g`0Ooml009oo`9l00<07`09O0007gooOoml07ooO0007g`000@0
7`03O0007`0O00@07`9l00<07`03O0007g`000H07`03O0007`0O00@07`03O0007g`000@07`03O000
7`0O00@07`03O0007`0O00807`9l009oo`05O01oogoo01ml000301l2O002Ool00g`0Ooml000201l0
0gooO01l000201l017`001ml07`00goo00Ql07ooOoml000OO01oog`00Woo00D07gooOol07goo00<0
7dAoo`00@goo100O0Woo00T07gooOomoog`001ml07ooO0000Woo00Ql07oo01ml000OO0007g`00`0O
00=l000OOol00W`000Aoog`001l07`9l00<07`03O0007`0O00<07`03O0007`0O00<07`9l00807`04
O0007`0O01l2O003Ool00g`0Ooml0002Ool01G`0OomoogooO0000goo00Il07ooOoml07ooO003Ool2
O00301l00g`001l07`02O00501l00g`001l07`0301l017`001l07`0O0W`00P0O00Ml07ooO01l07oo
01ml000301l027`001ml000OO0007gooO002Ool01G`0Ooml000OO0000goo00<07gooOol0100OA7oo
0013Ool301l2Ool00`0OOomoo`0201l2O002Ool00g`001ml000201l00gooO0007`02O00301l2O000
1Woo01l07g`001ml009oo`9l00=oo`03O01oogoo00<07`03O01oog`000=oo`9l009oo`04O01oogoo
Ool2O003Ool00g`0Ooml0002Ool01G`0OomoogooO0000goo00Il07ooOoml07ooO003Ool2O003Ool0
0g`0Oomoo`02O003Ool00g`0Ooml000301l2Ool017`0Oomoogoo0W`00Woo00=l000OO0000P0O00=o
og`0Ool00P0O00Il000OO0007g`0Ool201l00g`001ml0002Ool2O00201l2Ool00`0OOomoo`0301m4
Ool0049oo`H07`9oo`0501moog`0Ooml000201l00g`0Ooml0002Ool0200OO0007`0OO0007g`001l2
O000100OOoml07`00Woo00Al000OO01l00<07`09O0007`0OOoml07ooO01oog`000=oo`9l009oo`04
O01oogooOol2O003Ool00g`0Ooml0002Ool01G`0OomoogooO0000goo00Il07ooOoml07ooO003Ool2
O003Ool00g`0Oomoo`02O003Ool01W`0Ooml07ooO01oo`807`04O0007`0O01l2O000100OO01oogoo
0W`000Qoo`0OO01l000OO0007g`00P0O00Ml000OOomoog`0Ooml000201l01G`0Ooml07oo01l00Woo
1@0OA7oo0012Ool401l2Ool201l2Ool01G`001ml07ooO0000Woo00Al07oo01ml00<07`04O0007g`0
Ool2O002Ool01W`001l07`0OO01oo`9l00=oo`09O01oogooOoml07ooO01oog`0009oo`0301ml07`0
00H07`03O0007`0O00@07`03O0007`0O00@07`03O0007`0O00@07`03O0007`0O00@07`03O0007`0O
00@07`9l000801moogooO01oog`0Ooml00=oo`04O01oogooOol2O0001WooO0007`0OO0007`9oo`9l
0004Ooml000OO00201l01G`001l07gooO0000Woo00El07ooO0007g`0009oo`807`9oo`@07d=oo`00
@Woo100O00=oo`0OOol00Woo00<07g`0O0000Woo00Al07oo01ml00807`09O0007`0O01ml000OO01o
og`000<07`9l0004Ool07g`001l2O00301l01g`001l07`0OO0007g`000D07`9l00807`04O0007`0O
01l2O0001P0OOomoog`0Ooml009oo`05O01oogooOoml0003Ool01W`0Oomoog`0Ooml009oo`0301ml
07`000<07`03O0007`0O009l00D07`03O0007g`000<07`04O0007`0O01l2O000100OO0007goo0W`0
0`0O00El07ooO0007g`000<07`07O0007`0OO0007gooO0000Woo0W`000H07gooOomoo`0OOol401m3
Ool0049oo`D07`9oo`807`03O01oog`000807`03O0007g`000<07`03O01oo`0O009l000701ml000O
O0007g`001l00W`000@07gooO01l00D07`09O0007`0OOoml07ooO01oog`000=oo`9l009oo`04O01o
ogooOol2O003Ool00g`0Ooml0002Ool01G`0OomoogooO0000goo00Il07ooOoml07ooO003Ool2O003
Ool00g`0Oomoo`02O003Ool01W`0Ooml07ooO01oo`807`04O0007`0OO00201l2O00047oo01ml07`0
01ml000OO0007g`001ml07oo01moog`00`0O00=l000OO0000P0O00=l07ooO0000P0O0Woo1@0O@goo
0012Ool401l00goo01l07`02Ool01G`001ml07ooO0000P0O00El000O01l07g`000807`04O0007`0O
01l2O00301l2O00201l2O002Ool017`0Oomoog`00goo00El07ooO01oog`000=oo`9l009oo`04O01o
ogooOol2O003Ool00g`0Ooml0002Ool01G`0OomoogooO0000goo00Il07ooOoml07ooO003Ool2O003
Ool00g`0Oomoo`02O003Ool01G`0Ooml07ooO0000goo00Al07ooOoml009oo`9l00807`9l00<07`9l
00<07`04O0007`0OO00301l027`001l07g`0Ooml000OO002Ool201l00goo01l07`0201m3Ool0049o
o`D07`9oo`807`05O01oog`0Ooml000201l017`001l07g`00`0O00Ul000O01l07g`001moog`0Ool0
0W`00goo00Al07ooOoml009oo`09O01oogooOoml07ooO01oog`000=oo`9l009oo`04O01oogooOol2
O003Ool00g`0Ooml0002Ool01G`0OomoogooO0000goo00Il07ooOoml07ooO003Ool2O003Ool00g`0
Oomoo`02O003Ool01G`0Ooml07ooO0000goo00Al07ooOoml009oo`04O01oogooOol2O0000gooO01o
o`02O00301l017`001l07g`00`0O00Ql000O01ml07ooO01oog`00P0O0Woo1@0O@goo0012Ool701l0
17ooO0007g`00P0O00Al000O01ml00807`08O0007`0OOoml07ooO01oo`9l0003Ooml07oo009l0004
Ool07`0OO00201l017`001l07g`0100O0W`000<07g`001l00`0O00=l000O01l0100O00=l000O01l0
100O00=l000O01l0100O00=l000O01l0100O00=l000O01l0100O00=l000O01l0100O00=l000O01l0
0P0O00Al000OO01l00@07`04O0007`0OO00201l017`001l07goo0W`000=oog`0Ool00W`000Qoog`0
Ooml000OOol07g`00P0O00Al000O01ml00807`04O0007g`0Ool701m3Ool0049oo`<07`08Ool07goo
Ool07g`0Ooml00807`04O0007`0OO00201l017`001l07g`00P0O00Al000OO01l00<07`03O0007g`0
00807`04O01oogooO002Ool2O003Ool2O0000gooO01oo`02Ool01G`0OomoogooO0000goo0W`00goo
00=l07ooO0000Woo00El07ooOomoog`000=oo`06O01oogooO01oog`00goo0W`00goo00El07ooOomo
og`000=oo`04O01oog`0O003Ool2O002Ool017`0Oomoog`00P0O00=l000OO0000`0O0W`000@07g`0
01ml00<07`04O0007gooO00201l01g`001l07g`0Ooml000O009oo`D07d=oo`00@Woo1`0O00Ioog`0
01ml000OO00201l02G`001l07`0OO0007gooO0007`02Ool3O002Ool2O0001GooO01oogooO0000Woo
00=l07ooOol00W`00goo0W`000=oog`0Ool00Woo00=l07ooOol00Woo00El07ooO01oog`000=oo`03
O01oog`0009oo`05O01oogooOoml0003Ool01W`0Oomoog`0Ooml00=oo`9l009oo`03O01oogoo009o
o`06O01oogooOoml07oo0W`00goo0W`00Woo00Al07ooOoml009oo`04O01oog`0O002Ool3O002Ool0
1@0OO0007`0OO0000P0O00Yl000O01l07g`001ml000OO01oo`L07d=oo`00@Woo200O00El000OO000
7g`000807`08O0007goo01ml000OOoml00=oo`03O01oog`0009oo`9l0005Ooml07ooOoml0003Ool0
17`0Ooml07`00goo0W`000=oog`0Ool00Woo0W`00goo00El07ooO01oog`000=oo`03O01oog`0009o
o`05O01oogooOoml0003Ool01W`0Oomoog`0Ooml00=oo`05O01oog`0Ooml0003Ool2O003Ool017`0
Ooml07`00goo0W`000=oog`0Ool00Woo00Il07ooOoml07ooO003Ool3O003Ool017`0Ool07g`00P0O
00Uoog`0Ool07g`001ml000OO000200O@goo0012Ool701l017`001l07g`0100O00El000O01l07g`0
00H07`03O0007`0O00807`03O0007`0O00<07`03O0007`0O00<07`03O0007`0O00T07`03O0007`0O
00@07`03O0007`0O00D07`03O0007`0O00@07`03O0007`0O00@07`03O0007`0O00D07`03O0007`0O
00@07`03O0007`0O00T07`03O0007`0O00<07`03O0007`0O00<07`03O0007`0O00807`03O0007`0O
00@07`05O0007`0O01ml000401l017`001l07g`01`0O@goo0012Ool501l01Goo01ml07ooO0000P0O
00]l000OOoml07oo01ml000OOol07g`000=oo`9l0003Ooml07oo009l0006Ooml07ooO01oog`00Woo
00Al07ooO01l00=oo`9l009oo`03O01oogoo009l00=oo`05O01oog`0Ooml0003Ool00g`0Ooml0002
Ool01G`0OomoogooO0000goo00Il07ooOoml07ooO003Ool01G`0Ooml07ooO0000goo0W`00Woo00=l
07ooOol00W`00goo0W`000Aoog`0Oomoo`9l009oo`07O01oog`0O01oog`0Ool00W`00goo00]l000O
Ool07g`001moog`001moog`000807`03O01oog`000L07d=oo`00@Woo100O00Uoo`0O01ml000OO01o
o`0OO0000P0O00Ql000OOoml000OOol07g`00goo0W`000=oog`0Ool00W`00Woo0W`000Aoog`0Oomo
o`9l0003Ooml07oo009oo`9l009oo`03O01oogoo009l00=oo`05O01oog`0Ooml0003Ool00g`0Ooml
0002Ool01G`0OomoogooO0000goo00Il07ooOoml07ooO003Ool01G`0Ooml07ooO0000goo0W`00Woo
00=l07ooOol00W`00Woo00El07ooO01oog`0009oo`04O01oog`0O002Ool2O0000gooO01oo`02O003
Ool02g`001moogooO01oo`0OO01oo`0OO0000P0O00=l000OO0000P0O00=oo`0O01l00P0O@goo0012
Ool701l02G`0Ooml000OO0007goo01ml0002Ool017`0Ool07g`017oo00Ul07ooO01l07ooO01oog`0
Ool00W`000Aoog`0Oomoo`9l009oo`03O01oogoo009l009oo`03O01oogoo009l00=oo`05O01oog`0
Ooml0003Ool00g`0Ooml0002Ool01G`0OomoogooO0000goo00Il07ooOoml07ooO003Ool01G`0Ooml
07ooO0000goo0W`00Woo00=l07ooOol00W`00Woo00=l07ooOol00W`00Woo00Ul07ooO01l07ooO01o
og`0Ool00W`000=oog`0Ool00Woo00Ql000OOomoog`0Ool07g`00P0O00Il07oo01ml07ooO00701m3
Ool0049oo`L07`03O0007g`000@07`08Ooml07ooOoml07oo01ml00Aoo`04O01oog`0Ool2O0000goo
O01oo`02O0000gooO01oo`02Ool017`0Oomoog`00Woo0W`00Woo00=l07ooOol00W`00goo00El07oo
O01oog`000=oo`03O01oog`0009oo`05O01oogooOoml0003Ool01W`0Oomoog`0Ooml00=oo`05O01o
og`0Ooml0003Ool2O002Ool00g`0Oomoo`02O002Ool017`0Oomoog`00goo00Ml07ooO01l07ooO01o
o`02O00017ooO01oog`017oo00Ql000OOoml000OOoml07oo100O00=l000OO0001`0O@goo0012Ool6
01l01W`0Ool07g`0Ooml00<07`03O0007`0O00<07`03O0007`0O009oo`04O01oog`0Ool2O0000goo
O01oo`02O002Ool017`0Oomoog`00Woo00=l07ooOol00W`00Woo00=l07ooOol00W`00goo00El07oo
O01oog`000=oo`03O01oog`0009oo`05O01oogooOoml0003Ool01W`0Oomoog`0Ooml00=oo`05O01o
og`0Ooml0003Ool2O002Ool00g`0Oomoo`02O002Ool017`0Oomoog`00Woo00=l07ooOol00W`000=o
og`0Ool00W`000Aoog`0Ooml009oo`807`03O0007`0O00<07`0:O0007`0O01ml07ooO0007gooO006
01m3Ool0049oo`H07`09O0007`0OO01oog`001moog`0009oo`0501ml000O01ml000401l00g`001l0
7`0201l00g`001l07`0201l017`001l07g`00Woo00Al07ooOoml00=oo`04O01oogooO002Ool2O003
Ool01G`0Ooml07ooO0000goo00=l07ooO0000Woo00El07ooOomoog`000=oo`06O01oogooO01oog`0
0goo00El07ooO01oog`000=oo`9l009oo`04O01oogooO003Ool017`0Oomoog`00Woo00Al000O01ml
00@07`03O0007`0O00807`03O0007`0O00807`05O0007`0OO0007`02Ool02G`0Ool07g`0Ooml07oo
01ml000601m3Ool0049oo`H07`09O0007`0OO0007g`001moog`0009oo`0501ml000OOoml0004Ool0
1W`0Oomoog`0Ooml009oo`03O01oog`001T07`03O0007`0O01<07`03O0007`0O00D07`03O0007`0O
01L07`03O01oog`0009oo`03O01oog`0009oo`03O01oogoo009oo`0=O01oo`0OO01oo`0OOoml07oo
01ml07ooO0000P0O00=l000O01l0100O@goo0012Ool601l00g`001ml000401l01WooO01oo`0OO000
7`9oo`03O01oogoo009oo`04O01oogooOol3O0000gooO01oo`02O0001GooO01oogooO0000goo00Al
07ooOoml009oo`03O01oogoo009l00=oo`05O01oog`0Ooml0003Ool00g`0Ooml0002Ool01G`0Oomo
ogooO0000goo00Il07ooOoml07ooO003Ool01G`0Ooml07ooO0000goo0W`00Woo00Al07ooOoml009o
o`05O01oogooOoml0002Ool01g`0Ooml07`0Ooml07oo00=l00=oo`03O01oogoo009oo`09O01oogoo
O01oo`0OOoml07oo00@07`03O0007g`000H07d=oo`00@Woo200O00Ml000O01ml07oo01ml000201l0
1G`001moogooO00017oo00Al07ooOomoo`=l009oo`=l009oo`04O01oog`0O002Ool017`0Oomoog`0
0Woo00Il07ooOoml07ooO002Ool01G`0Ooml07ooO0000goo00=l07ooO0000Woo00El07ooOomoog`0
00=oo`06O01oogooO01oog`00goo00El07ooO01oog`0009oo`03O01oog`0009oo`04O01oogooO002
Ool00g`0Oomoo`02O00017ooO01oogoo0g`00Woo0g`00goo00=l07ooOol00Woo00El07ooOol07g`0
00807`04O0007gooO00201l00g`001l07`0501m4Ool004=oo`L07`04O0007gooO00401l00gooO000
7`0401l3Ool00g`0Oomoo`02Ool017`0Ooml07oo0g`00Woo00Al07ooO01l009oo`04O01oogooO003
Ool01G`0Ooml07ooO0000Woo00El07ooO01oog`000=oo`03O01oog`0009oo`05O01oogooOoml0003
Ool01W`0Oomoog`0Ooml00=oo`05O01oog`0Ooml0002Ool01G`0Ooml07ooO0000goo00Al07ooOoml
009oo`9l0004Ooml07ooOol3O00017ooO01oog`017oo00Al07ooOomoo`D07`03O0007`0O00<07`04
O01oo`0OO00701m4Ool004=oo`D07`03O0007g`000<07`03Ool07g`000807`06O0007`0O01ml07oo
1P0O0Woo00Al07ooO01oo`9l0004Ooml07ooOol3O002Ool017`0Oomoog`00goo00El07ooO01oog`0
009oo`05O01oog`0Ooml0003Ool00g`0Ooml0002Ool01G`0OomoogooO0000goo00Il07ooOoml07oo
O003Ool01G`0Ooml07ooO0000Woo00El07ooO01oog`0009oo`9l009oo`03O01oogoo00=l009oo`08
O01oog`0O01oog`0Ooml009oo`H07`03Ooml000O00807`06O0007`0OO0007goo0`0O00=l000OO000
1@0OA7oo0013Ool501l01W`001l07goo01ml00807`04O01oogooO003Ool00g`001l07`0201l00g`0
Oomoo`0201l00g`001l07`0201l00g`0Ooml0002Ool3O002Ool00g`0Oomoo`02O002Ool01G`0Ooml
07ooO0000Woo00El07ooO01oog`000Aoo`9l009oo`05O01oogooOoml0003Ool00g`0Oomoo`02O004
Ool01G`0Ooml07ooO0000Woo00El07ooO01oog`0009oo`9l009oo`03O01oogoo00=l009oo`03O01o
og`000@07`03O0007`0O009oo`03O0007`0O00807`08O01oogooOoml07oo01ml00807`03O0007`0O
00807`03O0007`0O00<07dAoo`00@goo2P0O00=l000OO0000`0O00El07ooOomoog`000=oo`03O000
7`0O00P07`03O0007`0O00<07`03O0007`0O00@07`9l009oo`05O01oog`0Ooml0002Ool00g`0Ooml
0002Ool017`0Oomoogoo0W`00Woo00El07ooOomoog`000=oo`03O01oogoo009l00=oo`06O01oogoo
O01oog`00Woo00El07ooO01oog`0009oo`9l00H07`03O0007`0O00<07`03O0007`0O00L07`03O01o
ogoo009oo`05O01oogooOoml000301l00g`001ml000:01m4Ool004=oo`X07`07O01oog`001moo`0O
O0000`0O00El07ooOomoog`000Eoo`04O01oog`0Ool3O0001GooO0007`0OO0001P0O00=l000O01l0
5`0O0Woo00=l07ooOol06@0O00=l000O01l0100O00El000O01ml07oo00=l0004Ooml07ooO005Ool0
1G`0OomoogooO0000`0O00Ml000OOol07g`001ml000:01m4Ool004=oo`807`03Ool07`0O00@07`08
Ool07`0OO0007goo01ml00=oo`05O0007`0OOoml0005Ool017`0Ooml07oo0g`000Eoog`0Oomoog`0
009oo`04O01oog`0Ool2O003Ool2O0000gooO01oo`02Ool00g`0Ool07`0K01l00g`0Ooml0003Ool0
17`0Ooml07`00goo0W`000Aoog`0Ooml009oo`05O01oogooO01oo`04O002Ool00g`0Oomoo`03Ool0
1G`0Ool07`0OO0000goo00El000OOol07g`000807`03Ool07g`000@07`03Ool07`0O04Aoo`00@goo
0P0O00=oo`0O01l00P0O00Il000O01ml07ooO00301l01G`0OomoogooO0000Woo00@07g`001l07`=o
o`0;O01oogooO01oog`0Ooml07ooO01oo`02O0001GooO01oog`0Ool00W`00goo0W`000=oog`0Ool0
0Woo00El07ooO01oog`000=oo`9l009oo`05O01oogooOoml0003Ool00g`0Oomoo`02O003Ool01G`0
Ooml07ooO0000goo00Al07ooO01l00=oo`9l0005Ooml07ooO01oo`02O00027ooO01oog`0Ooml07oo
O002Ool017`0Oomoogoo0P0O00El000OOomoog`000=oo`07O0007`0O01ml07ooO0000P0O00=l000O
O0000P0O00=oo`0OOol0A7oo0014Ool201l01Goo01ml000OO0000`0O00Ioog`0Oomoo`0OO00301l0
1G`0OomoogooO0000Woo1`0O00Moog`0Ooml07ooO01oo`02O00017ooO01oogoo0W`000Aoog`0Oomo
o`9l0003Ooml07oo009oo`05O01oog`0Ooml0003Ool2O002Ool01G`0OomoogooO0000goo00=l07oo
Ool00W`00goo00El07ooO01oog`000=oo`04O01oog`0O002Ool017`0Ooml07`00Woo00Ul07ooO01l
07ooO01oog`0Ool00W`01`0O0Woo00El07ooOomoog`000<07`06O0007gooOoml07oo0`0O00=l000O
O000100OAGoo0014Ool201l00goo01ml000601l01G`0Oomoo`0OO0000`0O00=l000O01l00`0O17oo
00Il07ooOomoo`0OO00501l2O00017ooO01oogoo0W`000Aoog`0Oomoo`9l0003Ooml07oo009oo`05
O01oog`0Ooml0003Ool2O002Ool01G`0OomoogooO0000goo00=l07ooOol00W`00goo00El07ooO01o
og`000=oo`04O01oog`0O002Ool017`0Ooml07`00Woo00Al07ooO01l00D07`03O0007goo009oo`03
O01oogoo009oo`D07`06O0007`0O01ml000O0Woo00=l000O01l0100O00=l000OOol00P0OAGoo0014
Ool401l01G`001l07`0OO0000P0O00El000O01moog`000=oo`06O0007gooOoml07oo100O00=l000O
01l00Woo0W`000=oog`0Ool00W`01P0O00=l07ooO0000Woo0W`00Woo00Ql07ooOoml07ooO01oog`0
0goo0W`00Woo00El07ooOomoog`000=oo`03O01oogoo009l00=oo`05O01oog`0Ooml0002Ool00g`0
Oomoo`02O002Ool00g`0Ooml000601l2O0001GooO01l07ooO0000Woo0P0O00=l000O01l00P0O00Io
og`0Oomoo`0OO003Ool01G`0Ool07`0OO0000P0O00El000O01l07g`000@07dEoo`00A7oo0P0O00Mo
o`0OO01oog`001ml000301l017`001l07g`00goo00=l07oo01l00P0O1Goo00=l07ooOol00P0O00=l
000O01l00P0O0W`000Aoog`0Ooml009oo`03O0007`0O00D07`09Ooml07ooOoml07ooO01oog`000=o
o`9l009oo`05O01oogooOoml0003Ool00g`0Oomoo`02O003Ool01G`0Ooml07ooO0000Woo00=l07oo
01l01P0O00Ml07ooOoml07ooO01oo`02O00401l00g`001l07`02Ool00g`0Oomoo`03Ool301l00goo
O01oo`02Ool017`001l07g`00`0O00Ql000OO0007g`001moo`0OAWoo0015Ool401l00gooO01oo`07
01l01G`001l07gooO00017oo100O00=oog`0Ool00goo0W`000Eoog`0O0007g`000H07`03O0007`0O
00@07`03Ool07`0O00l07`=oo`04O01oogooOolA01l00g`001l07`0401l00g`001l07`0401l01G`0
01ml07`0Ool00W`017oo00=l07oo01l00`0O17oo00El07oo01l07g`000L07`03Ooml07oo00@07dIo
o`00AGoo0`0O00El000OO01oog`000<07`09O0007`0OO0007goo01ml000O00=oo`04O01oogooOol4
01l2Ool2O002Ool3O002Ool2O002Ool017`0Oomoog`00Woo00=l000O01l0:00O0W`00Woo00Al07oo
Ooml009oo`9l009oo`=l009oo`9l009oo`@07`=oo`0:O01oogooOol07g`001moo`0OO00201l02G`0
01l07`0OO01oog`001ml000301m6Ool004Eoo`<07`06O01oog`001ml07oo0P0O00Al000OOoml00L0
7`03Ooml07oo00=oo`03O01oogoo00807`04O0007`0OOol4O0001GooO01oog`0Ool00W`000Aoog`0
Oomoo`9l0009Ooml07ooOoml07ooO01oog`000=oo`9l009oo`05O01oogooOoml0003Ool00g`0Oomo
o`02O003Ool017`0Ooml07`00goo00Al07ooO01l009oo`09O01oog`0O01oog`0Ooml07oo00Al0004
Ool07`0OO00201l2Ool00g`0Oomoo`02Ool00g`0Ool07`0601l017`0Ool07g`00P0O00=oog`001l0
0W`0100OAWoo0016Ool301l2O0000goo01ml000501l01W`0Ool07`0OO01oo`<07`03O01oogoo009o
o`03O01oogoo009oo`03O01oogoo00<07`9l009oo`9l0005Ooml07`0Ooml0002Ool2O002Ool00g`0
Oomoo`02O0000gooO01oo`02Ool2O002Ool01G`0OomoogooO0000goo00=l07ooOol00W`00goo00Al
07ooO01l009oo`03O01oogoo009l009oo`05O01oog`0O01oo`02O002Ool2O00301l2Ool00g`0Oomo
o`02Ool00g`0Oomoo`02Ool01W`001l07`0OOoml00807`03Ooml000O00@07`03O0007goo009l00<0
7dMoo`00AWoo0`0O0W`000=oo`0OO000100O00=oo`0OOol00Woo00=l000OOol00Woo00Il000O01l0
7gooO005Ool017`0Ooml07oo0W`01@0O0g`000=oog`0Ool00Woo00Al07ooOoml009oo`9l0003Ooml
07oo009oo`9l009oo`05O01oogooOoml0003Ool00g`0Oomoo`02O003Ool017`0Ooml07`00Woo00Al
07ooOoml009oo`03O01oogoo00=l00D07`=l009oo`03O01oogoo00=oo`03O01oo`0O00807`06O01o
ogooOol07g`00goo00<07goo01l00`0O00=l000OOol00W`00`0OAgoo0016Ool401l017`0Ool07g`0
1@0O00=l000OOol00Woo00El000OOomoog`0009oo`H07`9oo`05O01oogooO01oo`03O002Ool00g`0
01l07`0601l017`0Oomoog`00Woo0W`000=oog`0Ool00Woo0W`00Woo00El07ooOomoog`000=oo`03
O01oogoo009l00=oo`04O01oog`0O002Ool017`0Oomoog`0200O00Al07ooO01oo`9l0005Ooml07oo
Ooml0002Ool601l2Ool01G`0Oomoo`0OO0000goo00<07g`001l0100O00Al000OOoml00@07dMoo`00
Agoo0P0O00Ql000OO0007g`001moog`00`0O00Ioo`0O01moog`0Ool201l00g`0Oomoo`02Ool00g`0
01l07`0301l00g`001l07`0201l01GooO01oog`0Ool00g`000Aoog`0Ooml009oo`L07`03O01oog`0
00=oo`9l009oo`05O01oogooOoml0003Ool00g`0Oomoo`02O003Ool00g`0Ooml000701l01WooO01o
ogooO01oo`=l0005Ooml07`0O01oo`0401l00g`001l07`0301l00g`0Oomoo`02Ool01W`001l07goo
O01oo`807`0<Ool07`0O01ml07oo01ml000OO0007g`00P0OB7oo0017Ool201l027`001ml000OO000
7gooO00501l00goo01ml0003Ool00g`001moo`02Ool017`0Oomoogoo0P0O00=l07ooOol00Woo00<0
7g`001l06@0O00=l000O01l0100O00=l000O01l0100O00=l000O01l04P0O00=l000O01l00`0O00=l
000OOol00goo00=l000O01l00goo00Il07ooOomoo`0OO003Ool00g`001moo`0501l027`0Ool07g`0
01ml000OO00201m8Ool004Qoo`0901ml000OO0007g`001moog`000@07`04Ool07`0O01l3Ool01W`0
Ool07`0OOoml00Eoo`03O0007`0O00807`05Ooml07`0O01oo`03O002Ool017`0Ooml07oo0W`00Woo
00Al07ooOoml009oo`03O01oogoo009l009oo`05O01oogooOoml0003Ool00g`0Oomoo`02O002Ool0
17`0Oomoog`00Woo00=l07ooOol00W`000Aoog`0Ooml009oo`=l0005Ooml07`0O01oo`0401l00g`0
Oomoo`03Ool01W`0Ool07`0OOoml00=oo`<07`03Ool07`0O00807`05O01oo`0OO0007`02O00201m9
Ool004Qoo`807`9l000701ml000O01ml000OOol00`0O00=oo`0OO0000`0O00Al07ooOomoo`807`03
O01oogoo009oo`03O01oogoo009oo`D07`Al0004Ooml07ooOol3O002Ool017`0Oomoog`00Woo00=l
07ooOol00W`00Woo00El07ooOomoog`000=oo`03O01oogoo009l009oo`04O01oogooO002Ool00g`0
Oomoo`03O002Ool00g`0Ooml0003O00501l4Ool00g`0Oomoo`02Ool00g`001l07`03Ool01g`001l0
7`0OO0007goo00<07`07Ool07g`001ml07oo01l00W`00P0OBGoo0019Ool201l017ooO01oog`00`0O
0Woo0`0O00Ioo`0O01moo`0OO00301l2Ool201l3Ool00g`0Oomoo`03Ool017`0Ooml07`00P0O00Il
000O01l07g`0Ool2O00017ooO01oog`00Woo00Al07ooOoml009oo`9l009oo`05O01oogooOoml0003
Ool00g`0Oomoo`02O002Ool017`0Oomoog`00Woo00Al07ooO01oo`9l0003Ooml000O00807`03O000
7`0O009l0003Ooml07oo00Aoo`04O01oogooOol201l2Ool301l00g`001moo`0201l017oo01l07`0O
0Woo0`0O00Al000OO01oo`807dYoo`00BGoo00P07g`001ml000OO0007goo0P0O00=oog`001l00`0O
00Aoo`0OOoml00807`04Ool07`0OO00401l00gooO01oo`03Ool00g`0Oomoo`04O0000gooO01oo`03
01l01G`0Ooml07ooO0000Woo00Al07ooOoml00=oo`04O01oogooO003Ool01G`0OomoogooO0000Woo
00Al07ooOoml00=oo`08O01oogooO01oog`0Ooml00<07`03Ooml07oo00Al009oo`03O01oogoo009o
o`03O01oo`0O00<07`04O0007`0OOol201l017`0Ool07g`0100O00al07oo01l07g`001ml000OO000
7g`001m:Ool004Yoo`807`09O0007g`001moog`0Ool07g`000<07`05Ool07goo01ml0002Ool201l0
0gooO01oo`03Ool701l3Ool00g`0Ooml0002O002Ool00g`0Ooml000601l2O002Ool017`0Oomoog`0
0Woo00El07ooOomoog`000=oo`04O01oogooO002Ool00g`0Oomoo`02O00601l01W`0Ooml07ooO01o
o`9l0003Ooml07oo009oo`03O0007`0O00@07`Aoo`04O01oo`0O01l2Ool01G`001moo`0OOol00`0O
00]l000OOoml07oo01ml000OO0007g`004]oo`00BWoo0P0O00Ioog`001l07gooO002Ool00g`0Ool0
7`0201l01G`001l07g`001l00goo0P0O1Goo00=l07ooOol02P0O00Qoog`0Ooml07ooO01oog`00Woo
00=l07ooO0006`0O00=l07ooO0000Woo00Il07ooO01oog`0Ool2O00601l017`001l07`0O0Woo00=l
07ooOol00goo0P0O0goo00D07g`001l07g`000<07`06Ooml07ooOoml07oo0P0O00Al07oo01l07d]o
o`00BWoo0P0O00=oog`0Ool00`0O00=l07ooO0000Woo100O00=oo`0OO0000P0O0Woo00Al000O01l0
7`9oo`03O01oogoo00=oo`@07`03Ooml07`001<07`03O0007`0O00<07`03Ooml07oo00D07`03O000
7`0O01407`03Ooml07oo00@07`Eoo`03O01oogoo00<07`03O01oogoo00807`03O0007goo00@07`9o
o`04O01oogooO00301l00g`001ml001<Ool004]oo`807`08O0007g`0Ool07g`0Ooml00=oo`L07`04
Ool07`0OO003Ool401l4Ool017`0Oomoogoo100O0W`000Uoog`0O01l07ooO01oog`0Ool00W`00Woo
00Al07ooOoml009oo`05O01oogooOoml0003Ool017`0Oomoog`00Woo00=l07ooOol00W`000Eoog`0
Ooml07oo00=l0003Ooml07`000@07`=oo`03O01oogoo009oo`@07`=oo`04O0007`0OOol701l2Ool0
2G`0OomoogooO01oog`001ml000201m<Ool004]oo`0301ml000O00807`06O0007`0O01moog`00goo
100O00=l000O01l01@0O0goo00=l07oo01l00P0O00=oog`0Ool017oo0W`0100O00Moog`0Ooml07oo
O01oo`02O002Ool017`0Oomoog`00Woo00El07ooOomoog`000=oo`04O01oogooO002Ool00g`0Oomo
o`02O0001gooO01oog`0Ooml07oo00@07`9l00Eoo`03O01oo`0O00807`03Ooml07oo009oo`L07`03
O0007`0O00807`=oo`04O01oo`0O01l2O00301l00g`0Oomoo`1;Ool004aoo`0:O0007`0O01ml07oo
O01oo`0OO003Ool01g`001l07`0OO0007goo00<07`03O0007`0O00<07`Aoo`807`Eoo`El0003Ool0
7`0O00<07`03O01oogoo009l0005Ooml07ooOoml0002Ool01G`0OomoogooO0000goo00Al07ooOoml
009oo`04O01oog`0O002Ool00g`001l07`0301l00gooO01l0003O005Ool201l4Ool00g`001l07`02
01l01g`001l07`0OOol07g`000<07`0:O01oogooOoml000OOoml07ooO00401m=Ool004aoo`807`05
O01oo`0OOoml0002Ool00g`001l07`02Ool00g`001l07`0401l00goo01ml0003Ool:01l3Ool00g`0
Ooml0005O002Ool00g`001l07`0701l2O0000gooO01oo`02Ool01G`0OomoogooO0000Woo00=l000O
01l01`0O00=l07ooO0001W`000=oog`0Ool00Woo1`0O00=l000O01l00goo00=l000OOol01P0O00=l
07ooOol00P0O00El07ooOoml07oo00807`03O0007goo04eoo`00CGoo0W`0100O00=l07ooO0000Woo
0P0O00=l07oo01l00`0O00=oo`0OOol00P0O17oo00=l000O01l00Woo00=l07oo01l01P0O1W`000Eo
og`0Ooml07oo009l0004Ooml07ooOol?01l2Ool01G`0Ooml07`0Ool00W`00Woo0W`000Aoog`0O01l
00L07`04Ooml07ooOol201l00g`0Oomoo`02Ool201l00goo01moo`0401l017ooO0007`0O0Woo00Al
07ooOoml00<07`03O0007goo04eoo`00CGoo00L07g`001l07g`0Ool07`02Ool01G`0OomoogooO000
1P0O00Aoo`0O01moo`807`9oo`03O01oogoo00807`03Ooml07oo00=ooa/07`03O0007`0O01T07`Ao
o`04O01oo`0O01l2Ool00g`0Oomoo`0201l017oo01l07goo1P0O00El07ooOomoog`0009oo`0301mo
og`000807`03O01oogoo04eoo`00CWoo00H07g`001ml07ooO00201l01G`0OomoogooO0000Woo1P0O
00Al000OOomoo`807`03O01oogoo009oo`0301ml07oo00=oo`04O01oogooOol401l00gooO01oo`02
O0000gooO01l0002Ool017`0Oomoog`00Woo00Al07ooOoml009oo`03O01oogoo009l0005Ooml07oo
O01oo`02O0000gooO01oo`02O00401l3Ool00g`0Oomoo`02Ool00g`001moo`03Ool00g`001l07`02
Ool00`0OO0007`0501l2Ool01G`0OomoogooO0000P0O00Il07ooO0007g`001m?Ool004moo`0901ml
000O01ml000OOoml000O009oo`03O01oogoo009oo`D07`03Ool07`0O009oo`0301moogoo00=oo`04
O0007`0O01l2Ool00g`0Oomoo`02Ool2O00401l01gooO01l07ooO01oog`0009oo`04O01oogooO002
Ool017`0Oomoog`00Woo0W`000Eoog`0Ooml07oo009l0003Ool07`0O00807`9l00Aoo`03O01oogoo
00<07`03O01oogoo00=oo`0301moogoo00807`03O0007`0O00<07`Aoo`08O01oogoo01ml07oo01ml
00807`03O0007goo04moo`00D7oo00El000OO0007g`0009oo`05O0007`0OOoml0003Ool00g`001l0
7`0:01l3Ool017`0Oomoogoo0P0O00=l07ooOol00goo17`000=oo`0O01l0100O00Al07ooOoml009o
o`04O01oogooO002Ool00g`0Oomoo`02O0000gooO0007`0501l00gooO01l0002O005Ool00g`001l0
7`03Ool017`0Oomoogoo300O00Il07ooOomoog`0Ool201l027`0Oomoog`001ml000OO01AOol0055o
o`0701ml07ooO0007gooO0000Woo00<07g`0Ool00Woo00Ul07oo01l07gooO01oo`0OOol00P0O00=o
o`0O01l01@0O0goo00=l000OOol017oo0g`000Moog`0Ooml07ooO01oo`0801l00gooO01oo`0801l0
1gooO01oog`0Ooml07oo00=l00Eoo`0301ml07oo009oo`L07`08O0007`0OOol07gooO01oo`807`03
Ooml07oo009oo`07O0007gooOoml07oo01l00W`00P0ODWoo001BOol01P0OO0007g`001ml00Aoo`06
O0007`0OOoml07oo0P0O00=l000OOol00P0O00=oo`0O01l00Woo0`0O00Eoo`0O01l07g`000`07`03
O0007`0O01L07`03O0007`0O00X07`05O0007`0O01moo`0301l2Ool201l01Woo01l07goo01ml0080
7`03Ooml07oo00807`03O01oogoo009oo`06O0007g`0Ooml000ODgoo001BOol2O0001GooO01oo`0O
O0000goo00=l07ooOol00`0O00=oo`0O01l00`0O00Aoo`0OO01oo`807`03Ooml07oo00807`9oo`03
O01oogoo009oo`807`03O0007g`0009l0009Ooml07ooOoml07ooO01oog`0009oo`04O01oogooO002
Ool02G`0Oomoog`0Ooml07ooO01oo`06O000100OO0007`0O17oo00=l07ooOol00P0O00=l07ooOol0
0P0O00Aoog`001moo`D07`04Ool07g`001l2Ool01g`0OomoogooO0007goo009l000301moogoo059o
o`00Dgoo00Ml000O01ml07ooO0007`02Ool01W`0OomoogooO01oo`<07`07O0007goo01moog`001l0
0Woo0P0O00=l07ooOol00`0O00=l07ooOol00goo00=l07oo01l00`0O00Ql000OOoml07ooO01oog`0
0Woo00Al07ooOoml009oo`0;O01oogooO01oog`0Ooml07oo01ml000401l00gooO01oo`04Ool017`0
01l07`0O0Woo00=l000O01l00Woo00L07g`0Ool07goo01ml000301l00gooO01oo`02Ool01g`0Oomo
o`0OO01oog`000807`03O01oogoo059oo`00E7oo0P0O00Al07ooOoml00807`03Ooml07oo009oo`04
O01oogooOol301l01Goo01l07goo01l00goo0P0O17oo0`0O0goo00=l07ooOol01G`01@0O00Al07oo
Ooml009oo`05O01oogooO01oo`02O00501l5O002Ool017`0Oomoogoo0`0O17oo0P0O0goo00D07goo
01l07goo00<07`=oo`06O01oogooOoml07oo0P0O00Al07ooOoml00807eEoo`00EGoo00El000OO01o
og`0009oo`<07`9oo`06O01oogooOoml07oo200O00=oog`0Ool00P0O0Woo00=l07ooOol0100O0goo
1W`000Aoog`0Ooml00@07`03Ooml07oo00@07`9l009oo`Il009oo`03O0007`0O00807`9oo`03O01o
ogoo00807`03Ooml07oo00P07`03Ooml07oo009oo`06O01oogoo01ml000O0Woo00El07ooO0007g`0
05Ioo`00EGoo0g`000<07gooO0000Woo00=l07oo01l00P0O17oo00Il07oo01moo`0OO00?01l2Ool3
01l00gooO01l000I01l2O00017oo01l07`0O0Woo3`0O00Il000OOol07gooO004Ool301l01gooO01o
ogooO01oo`0O009l05Moo`00EWoo00=l000OO0000P0O0goo00Al07ooOomoo`807`9oo`03O01oogoo
00@07`04Ool07`0OOol201l4Ool017`001moogoo0P0O00=l000O01l0100O00=l07ooO00017`000Eo
og`0Oomoog`0009oo`03O01oog`000Il00H07`03O0007`0O009oo`0301ml07oo00=oo`807`04Ool0
7`0OOol401l2Ool00g`0Oomoo`0201l3Ool02G`0OomoogooO0007g`001ml001GOol005Moo`04O000
7g`0Ool201l00gooO01oo`02Ool00g`0Ool07`0401l2Ool301l2Ool201l00goo01l07`02Ool017`0
Ool07`0O0Woo00=l07ooOol00Woo0W`0100O0g`000Eoog`0Oomoog`0009oo`03O01oog`0009l00@0
7`03O01oogoo00=oo`03O01oogoo00807`04Ooml07ooOol201l00goo01l07`02Ool301l2Ool501l0
0gooO01oo`02Ool027`0Ool07g`0Ooml000OO01HOol005Qoo`<07`05O01oo`0O01ml0003Ool01W`0
OomoogooO01oo`<07`07O0007`0O01moog`001l00Woo0P0O00Al07ooOomoo`<07`Eoo`El00@07`9l
0003Ooml07oo009l00@07`El00Eoo`<07`=oo`03O0007`0O009oo`0301ml07oo00<07`06O0007`0O
01moog`00goo00El07ooOomoog`000807`05Ooml07`001ml001IOol005Uoo`0401ml000OO002Ool2
01l2Ool01G`0OomoogooO00017oo00=l07ooOol01`0O00Aoo`0O01l07`=oo`03O0007`0O00807`03
Ooml07`0009l0005Ooml07`0O01oo`0301l01G`001l07`0OOol027`000=oo`0O01l00P0O00Al07oo
Oomoo`<07`03Ool07`0O00D07`9oo`03O01oogoo009oo`05O01oogooOoml0002Ool201l2Ool017`0
01ml07`0FWoo001JOol0100OO0007`0O0Woo00El000O01l07g`000=oo`03O01oogoo009oo`03O01o
ogoo00807`03O01oogoo00<07`03O0007`0O01807`El01@07`04O0007`0O01l2Ool00g`001l07`02
Ool00g`0Oomoo`02Ool01G`0OomoogooO0000`0O00=l07ooOol00P0O00=l000OOol0FWoo001KOol2
01l01G`001l07gooO0000Woo0`0O00=oog`0Ool00goo00=l07ooOol00Woo0`0O0Woo00<07g`0Ool0
0goo0P0O1Goo0W`0100O2g`0100O0W`01Goo0P0O17oo00Al000OOomoo`<07`Aoo`03O01oogoo009o
o`03O01oo`0O00807`9oo`05O01oo`0O01ml000201mLOol005aoo`807`9l00807`05O01oogooO01o
o`0401l3Ool00g`0Oomoo`02Ool401l017ooO0007`0O0goo00=l000O01l00goo00=l07ooO0000g`0
2`0O17`000=oog`0Ool00Woo0P0O00Al07ooOomoo`807`03O01oo`0O00<07`Aoo`04O01oogooOol4
01l01GooO01oogooO0000P0O0W`00P0OGGoo001NOol2O00017ooO0007`0O0W`00goo00=l07oo01l0
1P0O00Eoog`0Ool07goo00807`06O01oo`0O01moog`00Woo0`0O00Al07ooO01l00807`03O0007`0O
00807`03O0007`0O00807`03O0007`0O009l0003Ooml000O00807`9oo`06O01oo`0O01moog`00P0O
00Eoo`0OOoml07oo00L07`03Ooml07oo009oo`9l00807`04O01oog`0O01OOol005moo`<07`06Ooml
000O01ml000O0Woo00El07ooOomoog`000=oo`807`03O0007`0O01407`ml01<07`03O0007`0O009o
o`03O01oogoo009oo`05O01oogoo01ml000201l00g`0Ool07`0201mPOol0061oo`0501ml000O01ml
0002Ool017`001l07g`00P0O0Woo00=l07ooOol00Woo00Al07ooOomoo`807`03O0007`0O009l00<0
7`9oo`04O01oog`0O00501l5O00501l2O00017ooO01oogoo0`0O0W`00P0O00=l000O01l00goo00=l
07ooOol00Woo00=l07ooOol00P0O00Al000O01ml009oo`05O0007`0OO0007`1QOol0069oo`=l0080
7`03O01oogoo00=l00807`al000501ml000O01ml0002Ool401l3Ool00g`001l07`0901l017`0Oomo
ogoo100O0Woo00El000O01ml000O00]l00<07`=l009oo`03O0007`0O00=l06=oo`00Hgoo0P0O17`0
0P0O00=oog`0Ool00Woo00=l000O01l02`0O00Eoog`001l07g`000807`03O0007`0O00807`]l00@0
7`04O0007`0OO00201l00g`0Ool07`0<01l01W`0OomoogooO01oo`807`Al00807fAoo`00I7oo00El
000OO01l07oo009l000301ml07`000Al00=oo`03O01oog`000Al00P07`=l009oo`@07`El00@07`9o
o`=l00P07`Il00Aoo`Il000401ml07`0Ool2O0000`0OO01oo`1TOol006Eoo`04O0007`0O01l3O000
0gooO0007`0201l6O004Ool00g`0Oomoo`02Ool201l2O00301l6O00201l00g`001l07`06O00301l2
O00201l4Ool00g`0Oomoo`02Ool5O0001Woo01l07`0OO01oo`9l00@07`03O01oogoo06Aoo`00IWoo
00=l000OO0000W`00`0O0W`000=oo`0O01l01@0O0Woo1G`000<07g`001l02`0O1G`03P0O1G`00Woo
1`0O00=oog`0O0000`0O0g`000<07g`0Ool0IWoo001XOol017`001l07g`00Woo0`0O1g`01`0O0Woo
17`00`0O00=l07ooOol02@0O0Woo00Al000O01l07`Al009oo`L07`Ml00<07`9oo`04O0007`0OO01Y
Ool006Yoo`Il0003Ool07`0O00807`=oo`04O01oogooOol6O002Ool3O0000goo01l07`0501l00g`0
01l07`0501l017ooO01l07`00Woo1W`00goo00Al07ooOomoo`@07`03Ooml07`000Al06]oo`00K7oo
0g`000<07g`001l00g`01`0O00=l000O01l02@0O0g`0100O00=l000O01l00P0O0g`02P0O00=l000O
01l01P0O0g`000<07g`001l00g`0KGoo001_Ool3O00301l01G`001l07gooO0000Woo17`00Woo00=l
07ooO0001G`000=oo`0O01l01`0O00=oog`0O00017`000Aoog`0Oomoo`Al009oo`05O01oo`0O01ml
000301l3O01`Ool0075oo`Ml00807`03O0007`0O00h07`Ul01007`03O0007`0O00Ml079oo`00Lgoo
3g`000=oog`0Ool01G`000=oog`0Ool00g`000Eoog`0Ooml07oo00El0003Ooml07oo00ml07Aoo`00
MGoo1W`000Aoog`0Oomoo`il0007Ooml07`0O01oog`0Ool037`00Woo00=l07ooO0001G`0MWoo001h
Ool7O002Ool4O002Ool2O002Ool9O002Ool2O0000gooO01l0003O002Ool7O01iOol007]oo`al0003
Ooml07`000el0003Ooml07`000Yl07aoo`00Ogoo2G`000=oog`0O0002g`000=oog`0O0001g`0P7oo
0026OolCO027Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0001\
\>"],
  ImageRangeCache->{{{91.5625, 320.938}, {465.625, 236.25}} -> {-0.399192, \
1.02998, 0.00348777, 0.00348777}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 819}},
WindowSize->{1032, 391},
WindowMargins->{{22, Automatic}, {Automatic, 130}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 266, 9, 108, "Title"],
Cell[2045, 64, 452, 9, 71, "Text"],
Cell[2500, 75, 45, 0, 33, "Text"],
Cell[2548, 77, 227, 4, 90, "Input"],
Cell[2778, 83, 55, 0, 33, "Text"],
Cell[2836, 85, 277, 7, 57, "Input"],

Cell[CellGroupData[{
Cell[3138, 96, 61, 1, 73, "Section"],
Cell[3202, 99, 306, 6, 52, "Text"],
Cell[3511, 107, 2449, 44, 689, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5997, 156, 480, 17, 103, "Section"],
Cell[6480, 175, 1457, 39, 115, "Text"],

Cell[CellGroupData[{
Cell[7962, 218, 622, 12, 133, "Input"],

Cell[CellGroupData[{
Cell[8609, 234, 10969, 363, 296, 3069, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[19581, 599, 11807, 373, 296, 3073, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[31391, 974, 3172, 265, 296, 3053, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[34566, 1241, 11781, 373, 296, 3059, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[46350, 1616, 3186, 265, 296, 3067, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[49539, 1883, 11666, 372, 296, 3065, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[61208, 2257, 3192, 265, 296, 3073, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[64403, 2524, 3176, 265, 296, 3057, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[67582, 2791, 3194, 265, 296, 3075, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[70779, 3058, 11149, 365, 296, 3071, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[81931, 3425, 3184, 265, 296, 3065, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[85118, 3692, 3184, 265, 296, 3065, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[88305, 3959, 10426, 356, 296, 3061, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[98734, 4317, 10127, 353, 296, 3065, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[108864, 4672, 9782, 348, 296, 3065, 261, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],
Cell[118673, 5024, 1125, 33, 74, "Text"],

Cell[CellGroupData[{
Cell[119823, 5061, 130, 3, 30, "Input"],
Cell[119956, 5066, 70454, 3776, 296, 37853, 3369, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[190447, 8847, 169, 3, 50, "Input"],

Cell[CellGroupData[{
Cell[190641, 8854, 9797, 349, 296, 3071, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[200441, 9205, 10598, 358, 296, 3067, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[211042, 9565, 3184, 265, 296, 3065, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[214229, 9832, 3174, 265, 296, 3055, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[217406, 10099, 3186, 265, 296, 3067, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[220595, 10366, 3182, 265, 296, 3063, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[223780, 10633, 3160, 265, 296, 3041, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[226943, 10900, 3192, 265, 296, 3073, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[230138, 11167, 3188, 265, 296, 3069, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[233329, 11434, 3174, 265, 296, 3055, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[236506, 11701, 3156, 265, 296, 3037, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[239665, 11968, 3194, 265, 296, 3075, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[242862, 12235, 11287, 367, 296, 3079, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[254152, 12604, 11186, 366, 296, 3055, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[265341, 12972, 11113, 365, 296, 3051, 261, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[276503, 13343, 132, 3, 27, "Input"],
Cell[276638, 13348, 70621, 3778, 296, 37853, 3369, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[347296, 17131, 119, 3, 30, "Input"],
Cell[347418, 17136, 132535, 9061, 296, 89755, 8528, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[479968, 26200, 250, 7, 36, "Text"],

Cell[CellGroupData[{
Cell[480243, 26211, 173, 3, 82, "Input"],
Cell[480419, 26216, 498, 11, 121, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[480954, 26232, 114, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[481093, 26238, 9957, 351, 296, 3061, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[491053, 26591, 10817, 361, 296, 3071, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[501873, 26954, 10973, 363, 296, 3085, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[512849, 27319, 11113, 365, 296, 3075, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[523965, 27686, 3192, 265, 296, 3073, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[527160, 27953, 3186, 265, 296, 3067, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[530349, 28220, 3190, 265, 296, 3071, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[533542, 28487, 3182, 265, 296, 3063, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[536727, 28754, 3178, 265, 296, 3059, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[539908, 29021, 3180, 265, 296, 3061, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[543091, 29288, 3194, 265, 296, 3075, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[546288, 29555, 3184, 265, 296, 3065, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[549475, 29822, 11230, 366, 296, 3063, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[560708, 30190, 11135, 365, 296, 3073, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[571846, 30557, 11032, 364, 296, 3067, 261, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],
Cell[582905, 30925, 639, 22, 52, "Text"],

Cell[CellGroupData[{
Cell[583569, 30951, 140, 3, 30, "Input"],
Cell[583712, 30956, 49110, 3520, 296, 37265, 3369, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[632859, 34481, 169, 3, 50, "Input"],

Cell[CellGroupData[{
Cell[633053, 34488, 10760, 360, 296, 3071, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[643816, 34850, 11583, 371, 296, 3063, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[655402, 35223, 3188, 265, 296, 3069, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[658593, 35490, 3172, 265, 296, 3053, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[661768, 35757, 3184, 265, 296, 3065, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[664955, 36024, 3182, 265, 296, 3063, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[668140, 36291, 3190, 265, 296, 3071, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[671333, 36558, 3190, 265, 296, 3071, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[674526, 36825, 3174, 265, 296, 3055, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[677703, 37092, 3172, 265, 296, 3053, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[680878, 37359, 3194, 265, 296, 3075, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[684075, 37626, 3150, 265, 296, 3031, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[687228, 37893, 10742, 360, 296, 3073, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[697973, 38255, 10520, 358, 296, 3057, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[708496, 38615, 10283, 355, 296, 3059, 261, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[718828, 38976, 140, 3, 27, "Input"],
Cell[718971, 38981, 77149, 3866, 296, 37265, 3369, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[796135, 42850, 441, 6, 52, "Text"],

Cell[CellGroupData[{
Cell[796601, 42860, 100, 2, 30, "Input"],
Cell[796704, 42864, 129566, 8955, 296, 87843, 8436, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[926307, 51824, 136, 3, 30, "Input"],
Cell[926446, 51829, 118876, 7989, 296, 80997, 7517, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1045359, 59823, 86, 1, 30, "Input"],
Cell[1045448, 59826, 118865, 7989, 296, 80997, 7517, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1164362, 67821, 484, 17, 103, "Section"],
Cell[1164849, 67840, 1418, 37, 112, "Text"],

Cell[CellGroupData[{
Cell[1166292, 67881, 622, 12, 133, "Input"],

Cell[CellGroupData[{
Cell[1166939, 67897, 9797, 349, 296, 3071, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1176739, 68248, 10598, 358, 296, 3067, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1187340, 68608, 10767, 361, 296, 3065, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1198110, 68971, 10898, 362, 296, 3055, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1209011, 69335, 11044, 364, 296, 3067, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1220058, 69701, 11178, 366, 296, 3063, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1231239, 70069, 11245, 367, 296, 3041, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1242487, 70438, 11305, 367, 296, 3073, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1253795, 70807, 11329, 367, 296, 3069, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1265127, 71176, 11336, 368, 296, 3055, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1276466, 71546, 11302, 368, 296, 3037, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1287771, 71916, 11327, 367, 296, 3075, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1299101, 72285, 11287, 367, 296, 3079, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1310391, 72654, 11186, 366, 296, 3055, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1321580, 73022, 11113, 365, 296, 3051, 261, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],
Cell[1332720, 73391, 1030, 34, 55, "Text"],
Cell[1333753, 73427, 235, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[1334013, 73434, 135, 3, 30, "Input"],
Cell[1334151, 73439, 70621, 3778, 296, 37853, 3369, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1404809, 77222, 169, 3, 50, "Input"],

Cell[CellGroupData[{
Cell[1405003, 77229, 10969, 363, 296, 3069, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1415975, 77594, 11807, 373, 296, 3073, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1427785, 77969, 11759, 373, 296, 3053, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1439547, 78344, 11781, 373, 296, 3059, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1451331, 78719, 11753, 373, 296, 3067, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1463087, 79094, 11666, 372, 296, 3065, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1474756, 79468, 11589, 371, 296, 3073, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1486348, 79841, 11451, 369, 296, 3057, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1497802, 80212, 11303, 367, 296, 3075, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1509108, 80581, 11149, 365, 296, 3071, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1520260, 80948, 10933, 363, 296, 3065, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1531196, 81313, 10682, 360, 296, 3065, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1541881, 81675, 10426, 356, 296, 3061, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1552310, 82033, 10127, 353, 296, 3065, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1562440, 82388, 9782, 348, 296, 3065, 261, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1572271, 82742, 135, 3, 27, "Input"],
Cell[1572409, 82747, 70456, 3776, 296, 37853, 3369, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1642902, 86528, 90, 2, 30, "Input"],
Cell[1642995, 86532, 135359, 9416, 296, 92603, 8884, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1778369, 95951, 250, 7, 36, "Text"],

Cell[CellGroupData[{
Cell[1778644, 95962, 189, 4, 82, "Input"],
Cell[1778836, 95968, 516, 11, 121, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1779389, 95984, 115, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[1779529, 95990, 9957, 351, 296, 3061, 261, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1789489, 96343, 10793, 361, 296, 3071, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1800285, 96706, 3182, 265, 296, 3063, 261, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[1803470, 96973, 11050, 364, 296, 3061, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1814523, 97339, 11169, 365, 296, 3071, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1825695, 97706, 11224, 366, 296, 3065, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1836922, 98074, 11265, 367, 296, 3077, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1848190, 98443, 11297, 367, 296, 3061, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1859490, 98812, 11307, 367, 296, 3067, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1870800, 99181, 11287, 367, 296, 3055, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1882090, 99550, 11289, 367, 296, 3073, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1893382, 99919, 11265, 367, 296, 3061, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1904650, 100288, 11240, 366, 296, 3073, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1915893, 100656, 11218, 366, 296, 3079, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1927114, 101024, 11198, 366, 296, 3059, 261, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],
Cell[1938339, 101394, 621, 21, 52, "Text"],

Cell[CellGroupData[{
Cell[1938985, 101419, 140, 3, 30, "Input"],
Cell[1939128, 101424, 49251, 3521, 296, 37265, 3369, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1988416, 104950, 165, 3, 50, "Input"],

Cell[CellGroupData[{
Cell[1988606, 104957, 10760, 360, 296, 3071, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1999369, 105319, 11461, 369, 296, 3083, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2010833, 105690, 11321, 367, 296, 3073, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2022157, 106059, 11161, 365, 296, 3075, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2033321, 106426, 3196, 265, 296, 3077, 261, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2036520, 106693, 10752, 360, 296, 3071, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2047275, 107055, 10495, 357, 296, 3065, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2057773, 107414, 10125, 353, 296, 3067, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2067901, 107769, 3192, 265, 296, 3073, 261, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[2071096, 108036, 9211, 341, 296, 3069, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2080310, 108379, 8618, 334, 296, 3059, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2088931, 108715, 8071, 327, 296, 3055, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2097005, 109044, 7695, 323, 296, 3075, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2104703, 109369, 7458, 320, 296, 3065, 261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2112164, 109691, 7255, 317, 296, 3061, 261, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[2119468, 110014, 140, 3, 27, "Input"],
Cell[2119611, 110019, 77088, 3865, 296, 37265, 3369, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2196714, 113887, 574, 12, 52, "Text"],

Cell[CellGroupData[{
Cell[2197313, 113903, 100, 2, 30, "Input"],
Cell[2197416, 113907, 133450, 9407, 296, 91427, 8884, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2330903, 123319, 134, 3, 30, "Input"],
Cell[2331040, 123324, 118836, 7989, 296, 80997, 7517, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2449913, 131318, 86, 1, 30, "Input"],
Cell[2450002, 131321, 118877, 7989, 296, 80997, 7517, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2568928, 139316, 131, 4, 73, "Section"],
Cell[2569062, 139322, 990, 33, 52, "Text"],

Cell[CellGroupData[{
Cell[2570077, 139359, 87, 2, 30, "Input"],
Cell[2570167, 139363, 210104, 15836, 296, 162055, 15238, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

